/******************************************************************************
 *
 * Copyright 2000, Rohde & Schwarz, inc.
 *
 * NAME:        RSCMU_TDMA.h
 *
 * PURPOSE:     This file includes a list of constants, definitions, and 
 *              prototypes used to define the Rohde & Schwarz IS136 driver
 *              for the CMU.
 *
 * DESCRIPTION: There is no executable code in this file.
 *
 ******************************************************************************/

//#pragma pack(1)

#ifndef _RSCMUK2T_H_
#define _RSCMUK2T_H_

#ifndef _DLL
   #define _REMVXIPNP
#endif   

#if defined(_MSC_VER) || defined(_CVI_)
   #define _OUTSIDEVEE_
#endif

/* INCLUDE FILES */
// modif JMG
#if defined(_CVI_)
    // CVI  environnement
    #include    <stdio.h>
    #include    <stdlib.h>
    #include    <string.h>
    #include    <time.h>
    #include    <ctype.h>
    #include    <visa.h>
    #include    "rscmu200.h"    
#else
    // VC++ 6.0 environnement
    #include    <windows.h>
    #include    <stdio.h>
    #include    <stdlib.h>
    #include    <string.h>
    #include    <float.h>
    #include    <math.h>
    #include    <time.h>
    #include    <visa.h>
    #include    "rscmu200.h"
#endif


#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/* PREPROCESSING DIRECTIVES */

// null pointer value
#ifndef NULL 
#define NULL 0L
#endif  // NULL

// maximum sizes
#define MAX_PARAMETERS                    15
#define MAX_STRING_SIZE                   31
#define MAX_STATUS_STRING                 256
#define MAX_PARM_SIZE                     40
#define MAX_LIST_OPTIONS                  25

// data type constants for command table
#define INTEGER_TYPE                      0
#define FLOAT_TYPE                        1
#define STRING_30_TYPE                    2


// ********************************************************************
// command indices
// ********************************************************************
// Synchronization
#define RSCMU_IS136_OFF                   0
#define RSCMU_IS136_IS1                   1
#define RSCMU_IS136_IS2                   2
#define RSCMU_IS136_IS3                   3
#define RSCMU_IS136_IS4                   4
#define RSCMU_IS136_IS5                   5
#define RSCMU_IS136_IS6                   6
#define RSCMU_IS136_ALL                   7

// Burst Duration
#define RSCMU_NORMAL                      0
#define RSCMU_SHORT                       1

// Reference Frequency
#define RSCMU_REF_FREQ_9_72               0
#define RSCMU_REF_FREQ_12_96              1
#define RSCMU_REF_FREQ_19_44              2
#define RSCMU_REF_FREQ_38_88              3

// Control Channel Timeslots
#define RSCMU_CCH_C1                      0
#define RSCMU_CCH_C14                     1

// Traffic Channel Timeslots
#define RSCMU_TCH_C14                     0
#define RSCMU_TCH_C25                     1
#define RSCMU_TCH_C36                     2     

// Measurement Types
#define RSCMU_OVERVIEW                    0
#define RSCMU_PERROR                      1
#define RSCMU_MERROR                      2
#define RSCMU_EVM                         3

// Burst Measurement
#define RSCMU_WBURST                      0
#define RSCMU_F10SYMBOLS                  1

// Sampling Rate
#define RSCMU_OVERSAMPLE1                 0
#define RSCMU_OVERSAMPLE8                 1

// Measured Values Type
#define RSCMU_SCALAR                      0
#define RSCMU_ARRAY                       1

// BER measurements
#define RSCMU_TDMA_BER                    0
#define RSCMU_TDMA_PRBS                   1
#define RSCMU_TDMA_CW                     2

// Trigger Sources
#define RSCMU_TDMA_FRUN                   0
#define RSCMU_TDMA_RFP                    1
#define RSCMU_TDMA_IFP                    2
#define RSCMU_TDMA_EXT                    3
#define RSCMU_TDMA_SIG                    4

//
#define RSCMU_LIM_CURR                    0
#define RSCMU_LIM_AVER                    1
#define RSCMU_LIM_MAX                     2
#define RSCMU_LIM_MIN                     3

//
#define RSCMU_MOD_CURR                    0
#define RSCMU_MOD_AVER                    1
#define RSCMU_MOD_MMAX                    2
#define RSCMU_MOD_CURR_SUB                3
#define RSCMU_MOD_AVER_SUB                4
#define RSCMU_MOD_MMAX_SUB                5

//
#define RSCMU_OEMP_LIM_CMMAX              0
#define RSCMU_OEMP_LIM_AVER               1

// 
#define RSCMU_DELAY_0                     0
#define RSCMU_DELAY_15                    1
#define RSCMU_DELAY_30                    2
#define RSCMU_DELAY_45                    3
#define RSCMU_DELAY_60                    4
#define RSCMU_DELAY_75                    5
#define RSCMU_DELAY_90                    6
#define RSCMU_DELAY_105                   7
#define RSCMU_DELAY_150                   8
#define RSCMU_DELAY_195                   9
#define RSCMU_DELAY_240                   10                
#define RSCMU_DELAY_285                   11
#define RSCMU_DELAY_330                   12
#define RSCMU_DELAY_375                   13
#define RSCMU_DELAY_420                   14

// Bit Error Rate (BER) Results
#define RSCMU_BER0                        0
#define RSCMU_BER1                        1
#define RSCMU_BER2                        2
#define RSCMU_BER3                        3
#define RSCMU_BER4                        4
#define RSCMU_BER5                        5
#define RSCMU_BER6                        6
#define RSCMU_BER7                        7

#define RSCMU_IS136_TSET1                 1
#define RSCMU_IS136_TSET2                 2
#define RSCMU_IS136_TSET3                 3
#define RSCMU_IS136_TSET4                 4
#define RSCMU_IS136_TSET5                 5

#define RSCMU_BER_STATUS_PASS             0
#define RSCMU_BER_STATUS_FAIL             1

// RSSI Results
#define RSCMU_RS0                         0
#define RSCMU_RS1                         1
#define RSCMU_RS2                         2
#define RSCMU_RS3                         3
#define RSCMU_RS4                         4
#define RSCMU_RS5                         5
#define RSCMU_RS6                         6
#define RSCMU_RS7                         7
#define RSCMU_RS8                         8
#define RSCMU_RS9                         9
#define RSCMU_RS10                        10
#define RSCMU_RS11                        11
#define RSCMU_RS12                        12
#define RSCMU_RS13                        13
#define RSCMU_RS14                        14
#define RSCMU_RS15                        15
#define RSCMU_RS16                        16
#define RSCMU_RS17                        17
#define RSCMU_RS18                        18
#define RSCMU_RS19                        19
#define RSCMU_RS20                        20
#define RSCMU_RS21                        21
#define RSCMU_RS22                        22
#define RSCMU_RS23                        23
#define RSCMU_RS24                        24
#define RSCMU_RS25                        25
#define RSCMU_RS26                        26
#define RSCMU_RS27                        27
#define RSCMU_RS28                        28
#define RSCMU_RS29                        29
#define RSCMU_RS30                        30
#define RSCMU_RS31                        31

// Mobile Station Identity
#define RSCMU_ID20                        0
#define RSCMU_ID24                        1
#define RSCMU_IDMIN                       2
#define RSCMU_ID50                        3

// Voice Coder
#define RSCMU_VSELP                       0
#define RSCMU_ACELP                       1
#define RSCMU_MSELECTED                   2

// Speech Mode
#define RSCMU_ECHO                        0
#define RSCMU_LOOP                        1
#define RSCMU_HSET                        2

// Speech Encoder/Decoder
#if defined RSCMU_GENERATOR 
    #undef RSCMU_GENERATOR
#endif  
#if defined RSCMU_ANALYSER 
    #undef RSCMU_ANALYSER
#endif  
#if defined RSCMU_HANDSET 
    #undef RSCMU_HANDSET
#endif  
#if defined RSCMU_ANALYSER2 
    #undef RSCMU_ANALYSER2
#endif  
#if defined RSCMU_BOTH_ANALYSERS 
    #undef RSCMU_BOTH_ANALYSERS
#endif  
    
#define RSCMU_GENERATOR                   0
#define RSCMU_ANALYSER                    0
#define RSCMU_HANDSET                     1
#define RSCMU_ANALYSER2                   2
#define RSCMU_BOTH_ANALYSERS              3

// Limits
#define RSCMU_UPPER                       0
#define RSCMU_LOWER                       1

#define RSCMU_PLUS                        0
#define RSCMU_MINUS                       1

//Start/Stop measurements
#define RSCMU_MEAS_OFF                    0
#define RSCMU_MEAS_RUN                    1
#define RSCMU_MEAS_STOP                   2
#define RSCMU_MEAS_ERR                    3
#define RSCMU_MEAS_STEP                   4
#define RSCMU_MEAS_RDY                    5
#define RSCMU_MEAS_NEXT                   6

// DIC
#define RSCMU_DCCH                        0
#define RSCMU_DTC                         1

// Matching      
#define RSCMU_MEAS_STATUS_PASS            0
#define RSCMU_MEAS_STATUS_INV             1
#define RSCMU_MEAS_STATUS_FAIL            2
#define RSCMU_MEAS_STATUS_TMER            3
#define RSCMU_MEAS_STATUS_IMP             4

#define RSCMU_MEAS_MATCH_OK               0
#define RSCMU_MEAS_MATCH_INV              1
#define RSCMU_MEAS_MATCH_NMAU             2
#define RSCMU_MEAS_MATCH_NMAL             3

#define RSCMU_MATCH_MATC                  0
#define RSCMU_MATCH_INV                   1 
#define RSCMU_MATCH_NMAT                  2
#define RSCMU_MATCH_NTSC                  3
#define RSCMU_MATCH_OUT                   4

// CMU Signalling State - Options
#define RSCMU_TDMA_STATE_SOFF             0
#define RSCMU_TDMA_STATE_SON              1
#define RSCMU_TDMA_STATE_REG              2
#define RSCMU_TDMA_STATE_ALRT             3 
#define RSCMU_TDMA_STATE_CEST             4 
#define RSCMU_TDMA_STATE_CPEN             5
#define RSCMU_TDMA_STATE_RPEN             6

// CMU Signalling States - Returned
#define RSCMU_SOFF                        0
#define RSCMU_SON                         1
#define RSCMU_CTM                         2
#define RSCMU_SMS                         3
#define RSCMU_CREL                        4 
#define RSCMU_HANDOFF                     5

// Handoff Targets
#if !defined(_RSCMUK2A_H_)
#define RSCMU_HANDOFF_IS136800MS          0
#define RSCMU_HANDOFF_IS1361900MS         1
#define RSCMU_HANDOFF_AMPSMS              2
#define RSCMU_HANDOFF_IS136800MSFallback  3
#define RSCMU_HANDOFF_IS1361900MSFallback 4
#define RSCMU_HANDOFF_AMPSMSFallback      5
#define RSCMU_HANDOFF_NONE                6
#endif

#define RSCMU_TDMA_CFM                    0
#define RSCMU_TDMA_RFM                    1
#define RSCMU_TDMA_LORL                   2
#define RSCMU_TDMA_MREG                   3
#define RSCMU_TDMA_MINV                   4
#define RSCMU_TDMA_RFNS                   6
#define RSCMU_TDMA_MDER                   7
#define RSCMU_TDMA_TCH                    9
#define RSCMU_TDMA_MREP                   10
#define RSCMU_TDMA_RFIO                   11
#define RSCMU_TDMA_RFIU                   12

#define RSCMU_TDMA_RANGE_ALL              0
#define RSCMU_TDMA_RANGE_ARI              1
#define RSCMU_TDMA_RANGE_MIN              2
#define RSCMU_TDMA_RANGE_MAX              3

#define RSCMU_CURRENT_SUB                 4
#define RSCMU_AVERAGE_SUB                 5
#define RSCMU_MAXIMUM_SUB                 6
#define RSCMU_MINIMUM_SUB                 7

#define RSCMU_TDMA_MAHO                   0
#define RSCMU_TDMA_EMAHO                  1

#define RSCMU_TDMA_CIR                    0
#define RSCMU_TDMA_WER                        1

#define RSCMU_TDMA_B08                        1
#define RSCMU_TDMA_B19                        2

/************************************************************/
/*                      DEFINES                             */
/************************************************************/

#ifndef _OUTSIDEVEE_

// Logical values: 
#define RSCMU_FALSE                       0
#define RSCMU_TRUE                        1

// On/Off values: 
#define RSCMU_ON                          1
#define RSCMU_OFF                         0
#define RSCMU_VAL_ON                      1
#define RSCMU_VAL_OFF                     0

// None value:
#define RSCMU_NONE                        0

/*---------------------------------------------------------------------------*/

#define RSCMU_SECONDARY_ADDRESS_MIN       1
#define RSCMU_SECONDARY_ADDRESS_MAX       30

#define RSCMU_TMO_VALUE                   10000

/*---------------------------------------------------------------------------*/
/* File I/O buffer size:
/*---------------------------------------------------------------------------*/

#define WR_BUFFER_SIZE                    512L
#define RD_BUFFER_SIZE                    512L
#define RD_BUFFER_SIZE_ARRAY              32767L

// Mathematical Values
#define RSCMU_NAN                         9.91e+37
#define RSCMU_NAN_VI_INT32                0x80000000

//Function Group Names FW2.0
#define RSCMU_NOT_MAPPED                  -1
#define RSCMU_BASE                        0
#define RSCMU_RF_NSIG                     1
#define RSCMU_GSM400MS_NSIG               2
#define RSCMU_GSM400MS_SIG                3
#define RSCMU_GSM400BS_NSIG               4
#define RSCMU_GSM400BS_SIG                5
#define RSCMU_GSM900MS_NSIG               6
#define RSCMU_GSM900MS_SIG                7
#define RSCMU_GSM900BS_NSIG               8
#define RSCMU_GSM900BS_SIG                9
#define RSCMU_GSM1800MS_NSIG              10
#define RSCMU_GSM1800MS_SIG               11
#define RSCMU_GSM1800BS_NSIG              12
#define RSCMU_GSM1800BS_SIG               13
#define RSCMU_GSM1900MS_NSIG              14
#define RSCMU_GSM1900MS_SIG               15
#define RSCMU_GSM1900BS_NSIG              16
#define RSCMU_GSM1900BS_SIG               17
#define RSCMU_IS136800MS_NSIG             18
#define RSCMU_IS136800MS_SIG              19
#define RSCMU_IS1361900MS_NSIG            20
#define RSCMU_IS1361900MS_SIG             21
#define RSCMU_AUDIO_NSIG                  22
#define RSCMU_AMPSMS_NSIG                 23
#define RSCMU_AMPSMS_SIG                  24

//Units
#define RSCMU_HZ                          0
#define RSCMU_KHZ                         1
#define RSCMU_MHZ                         2
#define RSCMU_GHZ                         3
#define RSCMU_US                          0
#define RSCMU_MS                          1
#define RSCMU_S                           2

#define RSCMU_10HZ                        0
#define RSCMU_20HZ                        1
#define RSCMU_30HZ                        2
#define RSCMU_50HZ                        3
#define RSCMU_100HZ                       4
#define RSCMU_200HZ                       5
#define RSCMU_300HZ                       6
#define RSCMU_500HZ                       7
#define RSCMU_1KHZ                        8
#define RSCMU_2KHZ                        9
#define RSCMU_3KHZ                        10
#define RSCMU_5KHZ                        11 
#define RSCMU_10KHZ                       12
#define RSCMU_20KHZ                       13
#define RSCMU_30KHZ                       14
#define RSCMU_50KHZ                       15
#define RSCMU_100KHZ                      16
#define RSCMU_200KHZ                      17
#define RSCMU_300KHZ                      18
#define RSCMU_500KHZ                      19
#define RSCMU_1MHZ                        20
#define RSCMU_WIDE                        21    
#define RSCMU_FREQ_AUTO                   21

//SCPI Connection
#define RSCMU_GPIB                        0
#define RSCMU_COM                         1
#define RSCMU_COM1                        1
#define RSCMU_COM2                        2

//Parity
#define RSCMU_PARITY_NONE                 0
#define RSCMU_PARITY_ODD                  1
#define RSCMU_PARITY_EVEN                 2
 
//Protocol
#define RSCMU_PROTOCOL_NONE               0
#define RSCMU_PROTOCOL_XON                1
#define RSCMU_PROTOCOL_ACK                2

// Status byte  
#define RSCMU_STB_OFF                     0
#define RSCMU_STB_ON                      1

//Query
#define RSCMU_DO_QUERY                    1
#define RSCMU_SKIP_QUERY                  0

//Reset
#define RSCMU_RESET_ON                    1
#define RSCMU_RESET_OFF                   0

//Reference Frequency
#define RSCMU_INTERNAL                    0
#define RSCMU_EXTERNAL                    1
#define RSCMU_REF_FRQ_MIN                 1.2190
#define RSCMU_REF_FRQ_MAX                 39.0

//Attenuation
#define RSCMU_NORM                        0
#define RSCMU_LNO                         1
#define RSCMU_LDIS                        2
#define RSCMU_LOW_NOISE                   1
#define RSCMU_LOW_DIST                    2

//Trigger Condition
#define RSCMU_IMM                         0
#define RSCMU_SIGN                        0
#define RSCMU_RFP                         1
#define RSCMU_IFP                         2
#define RSCMU_EXT                         3
#define RSCMU_FRUN                        3

//Trigger Condition
#define RSCMU_LOW                         0
#define RSCMU_MED                         1
#define RSCMU_HIGH                        2

//Measurement Repetition
#define RSCMU_STOP_ON                     1
#define RSCMU_STOP_ALIM                   1
#define RSCMU_STOP_FLIM                   2
#define RSCMU_STEP                        1
#define RSCMU_STEP_ON                     1
#define RSCMU_ON_LIMIT_FAILURE            1

//Measurement Repetition FW 2.0
#define RSCMU_CONTINUOUS                  0
#define RSCMU_SINGLE_SHOT                 1

//Event Reporting
#define RSCMU_SRQ                         1
#define RSCMU_SOPC                        2
#define RSCMU_SRSQ                        3

// TimeOuts
#define RSCMU_SENS_TRIG_MEAS_TMO_MIN      1.0
#define RSCMU_SENS_TRIG_MEAS_TMO_MAX      1000.0

/*===========================================================================*/
/*                          Measurement Control                              */
/*===========================================================================*/


// Generator Status
#define RSCMU_GEN_STAT_OFF                0
#define RSCMU_GEN_STAT_RUN                1
#define RSCMU_GEN_STAT_ERR                2

// Measurement Status
#define RSCMU_MEAS_STAT_OFF               0
#define RSCMU_MEAS_STAT_RUN               1
#define RSCMU_MEAS_STAT_STOP              2
#define RSCMU_MEAS_STAT_ERR               3
#define RSCMU_MEAS_STAT_STEP              4
#define RSCMU_MEAS_STAT_RDY               5

// Sensitivity Measurement Status
#define RSCMU_MEAS_STAT_PASS              0
#define RSCMU_MEAS_STAT_INV               1
#define RSCMU_MEAS_STAT_FAIL              2
#define RSCMU_MEAS_STAT_TMER              3
#define RSCMU_MEAS_STAT_IMP               4

/*===========================================================================*/
/*                                                                           */
/*===========================================================================*/


//Frequency Bandwidth
#define RSCMU_BAND_RESTRICT               0
#define RSCMU_BAND_WIDE                   1
#define RSCMU_BANDWIDTH_30KHZ             1
#define RSCMU_BANDWIDTH_300KHZ            2

// Generator Modulation
#define RSCMU_SSB                         1

//Input connectors
#define RSCMU_INPUT_RF1                   0
#define RSCMU_INPUT_RF2                   1
#define RSCMU_INPUT_RF4                   2

//Output Connectors
#define RSCMU_OUTPUT_RF1                  0
#define RSCMU_OUTPUT_RF2                  1
#define RSCMU_OUTPUT_RF3                  2

// Audio input signal
#define RSCMU_AFAN_AFIN                   0
#define RSCMU_AFAN_AUX1                   1

// Audio path coupling
#define RSCMU_AFAN_AC                     0
#define RSCMU_AFAN_DC                     1

// Speech Encoder Input
#define RSCMU_SPEN_HAND                   0
#define RSCMU_SPEN_GEN                    1
#define RSCMU_SPEN_AUX1                   2

// Speech Decoder Output
#define RSCMU_SPD_HAND                    0
#define RSCMU_SPD_ANAL                    1
#define RSCMU_SPD_AUX2                    2

// Limit Check
#define RSCMU_OK                          0
#define RSCMU_INV                         1
#define RSCMU_NMAU                        2
#define RSCMU_NMAL                        3

#define RSCMU_MATCH_MATC                  0
#define RSCMU_MATCH_INV                   1 
#define RSCMU_MATCH_NMAT                  2
#define RSCMU_MATCH_NTSC                  3
#define RSCMU_MATCH_OUT                   4
#define RSCMU_MATCH_NTR                   5
#define RSCMU_MATCH_BNF                   6
#define RSCMU_MATCH_OFF                   7

#define RSCMU_MANUAL                      0
#define RSCMU_AUTO                        1
#define RSCMU_PCL                         2
#define RSCMU_ALWAYS                      0

#define RSCMU_CURRENT                     0
#define RSCMU_AVERAGE                     1
#define RSCMU_MAXMIN                      2
#define RSCMU_MAXIMUM                     2
#define RSCMU_MINIMUM                     3
#define RSCMU_AVERAGED                    1 // Do not remove it due to keep the compatibility

//Serial interface
#define RSCMU_APPL_TRAN                   0 
#define RSCMU_APPL_REM                    1 
#define RSCMU_APPL_PRIN                   2 

//Input/output attenuation
#define RSCMU_ATT_MIN                     -50
#define RSCMU_ATT_MAX                     +50

//Multiple Measurement
#define RSCMU_MULT_MEAS_MIN               1
#define RSCMU_MULT_MEAS_MAX               10000

//Absolute level on used Timeslot
//#define RSCMU_USEDSLOTMIN                 -137.0
//#define RSCMU_USEDSLOTMAX                 +13.0

//Frequency offset
#define RSCMU_FREQ_OFFSET_MIN             -135000
#define RSCMU_FREQ_OFFSET_MAX             +135000

//Power Level Range
#define RSCMU_LEV_RANGE_MIN               10
#define RSCMU_LEV_RANGE_MAX               100

//Test Points Number
#define RSCMU_TEST_PTS_MIN                1
#define RSCMU_TEST_PTS_MAX                560

#define RSCMU_REG_MAX                     32767
#define RSCMU_SUB_REG_MAX                 15
#define RSCMU_ADDR_PRIM_MAX               30
#define RSCMU_ADDR_SEC_MAX                30  

#define RSCMU_DATABITS_MIN                7
#define RSCMU_DATABITS_MAX                8
#define RSCMU_STOPBITS_MIN                1
#define RSCMU_STOPBITS_MAX                2

#define RSCMU_SUM1                        1
#define RSCMU_SUM2                        2

//Keyboard Assignment
#define RSCMU_KBUS                        0
#define RSCMU_KBGR                        1

//positive / negative
#define RSCMU_POS                         1
#define RSCMU_NEG                         0

// Frequency hopping
#define RSCMU_REL                         0
#define RSCMU_ABS                         1

#endif // end of rscmu200 defines for VEE

/*****************************************************************************/
/*= Define Instrument Specific Error/Warning Codes Here =====================*/
/*****************************************************************************/
/*---------------------------------------------------------------------------*/
/* The codes for instrument specific ERRORS must be in the range             */
/* 0xBFFC0900 to 0xBFFC0FFF and defined as follows:                          */
/* #define PREFIX_SPECIFIC_ERROR (VI_INSTR_ERROR_OFFSET + n)                 */
/*                                                                           */
/* The codes for instrument specific WARNINGS must be in the range           */
/* 0x3FFC0900 to 0x3FFC0FFF and defined as follows:                          */
/* #define PREFIX_SPECIFIC_WARNING (VI_INSTR_WARNINGS_OFFSET + n)            */
/*                                                                           */
/* Where n represents each instrument specific error/warning number.         */
/* The valid range for n is 0x000 to 0x1FF  for CMU Base                     */
/* The valid range for n is 0x200 to 0x2FF  for K2G Option                   */
/* The valid range for n is 0x300 to 0x3FF  for K2T Option                   */
/*                                                                           */
/* For ease of use the lower 16 bits of warnings and errors should not       */
/* overlap in the same driver.                                               */
/*                                                                           */
/*---------------------------------------------------------------------------*/

#ifdef _OUTSIDEVEE_

#if !defined(_RSCMUK2A_H_) && !defined(_RSCMUK8C_H_) && !defined(__K2G_HEADER)
#define VI_INSTR_WARNING_OFFSET                          (0x3FFC0900L)
#define VI_INSTR_ERROR_OFFSET                            (_VI_ERROR+0x3FFC0900L)
#endif

#define RSCMU_LIST_OF_SPECIFIC_ERROR_MESSAGES_IS136 \
IS136_EXPAND(RSCMU_IS136_ERROR_CALL_FROM_MS_FAILED,      (VI_INSTR_ERROR_OFFSET + 0x300L), "Call from mobile station failed") \
IS136_EXPAND(RSCMU_IS136_ERROR_CALL_TO_MS_FAILED,        (VI_INSTR_ERROR_OFFSET + 0x301L), "Call to mobile station failed") \
IS136_EXPAND(RSCMU_IS136_ERROR_RELEASE_TO_MS_FAILED,     (VI_INSTR_ERROR_OFFSET + 0x302L), "Release to mobile station failed") \
IS136_EXPAND(RSCMU_IS136_ERROR_INVALID_SIGN_STAT,        (VI_INSTR_ERROR_OFFSET + 0x303L), "The RSCMU is in an internal signalling state where the command is not allowed") \
IS136_EXPAND(RSCMU_IS136_ERROR_INVALID_HANDOVER_TARGET,  (VI_INSTR_ERROR_OFFSET + 0x304L), "The handover target is not available") \
IS136_EXPAND(RSCMU_IS136_WARNING_GPIB_FEATURE,           (VI_INSTR_WARNING_OFFSET + 0x001L), "GPIB feature not implemanted") 

typedef enum {
#define IS136_EXPAND(id, value, text) id = value,
    RSCMU_LIST_OF_SPECIFIC_ERROR_MESSAGES_IS136
#undef IS136_EXPAND
} RSCMU_ErrorList_IS136;

// ********************************************************************
// structures for command table definitions
// ********************************************************************
#if !defined(_RSCMUK2A_H_) && !defined(_RSCMUK8C_H_)
typedef struct listNode {
   ViInt16        num;
   const ViUInt8 *list[MAX_LIST_OPTIONS];
} LIST, *LISTPTR;

typedef struct {
   ViInt32         type;
   ViInt32         min;
   ViInt32         max;
   LISTPTR         params;
} INT_PARAM_INFO;

typedef struct {
   ViInt32         type;
   ViReal64        min;
   ViReal64        max;
   LISTPTR         params;
} FLOAT_PARAM_INFO;

typedef struct {
   ViInt32         type;
   ViUInt8        *min;       // Placeholder ONLY
   ViUInt8        *max;       // Placeholder ONLY
   LISTPTR         params;
} STRING30_PARAM_INFO;

typedef union {
   INT_PARAM_INFO      i;
   FLOAT_PARAM_INFO    f;
   STRING30_PARAM_INFO s30;
} PARAM_INFO_UNION;

typedef struct {
   ViInt32             num;
   STRING30_PARAM_INFO p[MAX_PARAMETERS];
} STRING_PARAM_BLOCK;

typedef struct {
   ViInt32          num;
   PARAM_INFO_UNION p[MAX_PARAMETERS];
} PARAM_BLOCK;

typedef struct {
   const char    *instrCommand;    // ASCII instrument command
   const char    *instrResponse;   // format for response message
   void           (*transmit)();   // transmit routine
   void           (*response)();   // response routine
   PARAM_BLOCK   *xmit;            // pointer to transmit parameter block
   PARAM_BLOCK   *rcvr;            // pointer to receive parameter block
} COMMAND_INFO;

#endif // !defined(_RSCMUK2A_H_) && !defined(_RSCMUK8C_H_)

typedef struct {
   double Current;
   double Average;
   double MaxMin;
} RSCMUK2T_ERROR_LIMITS;

typedef struct {
   RSCMUK2T_ERROR_LIMITS Peak;
   RSCMUK2T_ERROR_LIMITS RMS;
   RSCMUK2T_ERROR_LIMITS OriginOffset;
   RSCMUK2T_ERROR_LIMITS IQImbalance;
   RSCMUK2T_ERROR_LIMITS FreqErr;
   long                  Sync;
   double                AmplitudeDrop;
   double                TimingErr;
   double                PowerRMS;
   double                BurstsOutOfTolerance;
} RSCMUK2T_ERROR_MOD;

typedef struct {
   RSCMUK2T_ERROR_LIMITS PErrPeak;
   RSCMUK2T_ERROR_LIMITS PErrRMS;
   RSCMUK2T_ERROR_LIMITS MErrPeak;
   RSCMUK2T_ERROR_LIMITS MErrRMS;
   RSCMUK2T_ERROR_LIMITS EVMPeak;
   RSCMUK2T_ERROR_LIMITS EVMRMS;
   RSCMUK2T_ERROR_LIMITS OriginOffset;
   RSCMUK2T_ERROR_LIMITS IQImbalance;
   RSCMUK2T_ERROR_LIMITS FreqErr;
   long                  Sync;
   double                AmplitudeDrop;
   double                TimingErr;
   double                PowerRMS;
   double                BurstsOutOfTolerance;
} RSCMUK2T_OVERVIEW;

typedef struct {
   ViInt32  SOC;
   ViInt32  BSMC;
   ViInt32  AsyncData;
   ViInt32  G3Fax;
   ViInt32  SMS;
   ViInt32  Subaddressing;
   ViInt32  BandAB_800;
   ViInt32  BandA_1900;
   ViInt32  BandB_1900;
   ViInt32  BandC_1900;
   ViInt32  BandD_1900;
   ViInt32  BandE_1900;
   ViInt32  BandF_1900;
   ViInt32  IRA;
   ViInt32  UserGroup;
   ViInt32  AnalogSpeech_800;
   ViInt32  HalfRateDTC;
   ViInt32  DoubleRateDTC;
   ViInt32  TripleRateDTC;
   ViInt32  STU3;
   ViInt32  VselpVoiceCoder;
   ViInt32  AltVoiceCoder;
   ViInt32  AltSOC;
} CAPABILITY;

typedef struct {
   double Peak[7];
   double RMS[7];
   double PeakPeak[6];
   double PeakRMS[6];
   double AverageRMS[6];
   double BurstsOutOfTolerance;
} SCALAR_ACP;

typedef struct {
   double TestTimeInSeconds;
   double BER;
   long   NumBitsDefaultPattern;
   long   Status;
   long   NumFramesTransmitted;
   double TxPower;
   long   TxCarrierFreqErr;
   long   SyncPatternDetected;
   long   Percentage;
} BER_RESULTS;

typedef struct {
   long   Channel;
   long   RSSI;
   double Level;
} MAHO;

typedef struct {
   long   Channel;
   long   RSSI;
} EMAHO;

#endif // _OUTSIDEVEE_

/* GLOBAL PROCEDURES PROVIDED */
ViStatus _VI_FUNC RSCMU_Init_TDMA (ViSession instrSessionBase,
                                   ViPSession instrSessionTDMA,
                                   ViInt32 TDMAFunctionGroup,
                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_InpState (ViSession instrumentHandle,
                                       ViInt32 selectionofInputConnector,
                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_OutpState (ViSession instrumentHandle,
                                        ViInt32 selectionofOutputConnector,
                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_SenseCorrLossInp (ViSession instrumentHandle,
                                               ViInt32 selectionofInputConnector,
                                               ViReal64 externalAttenuationdB,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_SourceCorrLossInp (ViSession instrumentHandle,
                                                ViInt32 selectionofInputConnector,
                                                ViReal64 externalAttenuationdB,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_SenseCorrLossOutp (ViSession instrumentHandle,
                                                ViInt32 selectionofOutputConnector,
                                                ViReal64 externalAttenuationdB,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_SourceCorrLossOutp (ViSession instrumentHandle,
                                                 ViInt32 selectionofOutputConnector,
                                                 ViReal64 externalAttenuationdB,
                                                 ViChar _VI_FAR errorMessage[]);

ViStatus _VI_FUNC RSCMU_TDMA_CorrLossInpOutp (ViSession instrumentHandle,
                                              ViInt32 selection_ofOutputConnector,
                                              ViReal64 outputAttenuation_dB,
                                              ViInt32 selection_ofInputConnector,
                                              ViReal64 inputAttenuation_dB,
                                              ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_TDMA_RoutSpenInp (ViSession instrumentHandle,
                                          ViInt32 speechEncoder,
                                          ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_TDMA_RoutSpdOutp (ViSession instrumentHandle,
                                          ViInt32 speechDecoder,
                                          ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_TDMA_SourceDmClockState (ViSession instrumentHandle,
                                                 ViBoolean referenceFreqatREFOUT2,
                                                 ViChar _VI_FAR errorMessage[]);
                                                 
ViStatus _VI_FUNC RSCMU_TDMA_SourceDmClockFreq (ViSession instrumentHandle,
                                                ViInt32 referenceFrequencyMHz,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_SenseLevMode (ViSession instrumentHandle,
                                           ViInt32 inputLevelSetting,
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_SenseLevMax (ViSession instrumentHandle,
                                          ViReal64 inputLevelMaximumdBm,
                                          ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_SenseLevDefault (ViSession instrumentHandle,
                                              ViBoolean state,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_SenseLevAtt (ViSession instrumentHandle,
                                          ViInt32 inputLevelAttenuation,
                                          ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_TrigSeqSource (ViSession instrumentHandle,
                                            ViInt32 triggerMode,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_TrigSeqThreshold (ViSession instrumentHandle,
                                               ViInt32 triggerThreshold,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_TrigSeqDefault (ViSession instrumentHandle,
                                             ViBoolean state,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_SenseRfanChan (ViSession instrumentHandle,
                                            ViInt32 channel,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_SenseRfanFreq (ViSession instrumentHandle,
                                            ViReal64 frequency, ViInt32 units,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_SenseRfanFreqOffset (ViSession instrumentHandle,
                                                  ViReal64 frequencyOffsetkHz,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_SenseRfanEMsSync (ViSession instrumentHandle,
                                               ViInt32 syncSequence,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_SourceRfGLevRfl (ViSession instrumentHandle,
                                              ViReal64 inputLevelMaximumdBm,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_SenseRfGChan (ViSession instrumentHandle,
                                           ViInt32 channel,
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_SenseRfGFreq (ViSession instrumentHandle,
                                           ViReal64 frequency,
                                           ViInt32 units,
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_SenseRfGFreqOffset (ViSession instrumentHandle,
                                                 ViReal64 frequencyOffsetkHz,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_SourceRfGModRfsType (ViSession instrumentHandle,
                                                  ViInt32 modulationType,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_InitRfGenerator (ViSession instrumentHandle,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_AbortRfGenerator (ViSession instrumentHandle,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_FetchRfGeneratorStatus (ViSession instrumentHandle,
                                                     ViPInt32 generatorStatus,
                                                     ViChar _VI_FAR errorMessage[]);

ViStatus _VI_FUNC RSCMU_TDMA_NPowSetExpectedPower (ViSession instrumentHandle,
                                                   ViReal64 setExpectedPower_dBm,
                                                   ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_TDMA_ConfNPowControl (ViSession instrumentHandle,
                                              ViInt32 statistics,
                                              ViInt32 repetition,
                                              ViInt32 stopCondition,
                                              ViInt32 stepMode,
                                              ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_TDMA_ConfNPowControlStats (ViSession instrumentHandle,
                                                   ViInt32 statistics,
                                                   ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_TDMA_ConfNPowControlRep (ViSession instrumentHandle,
                                                 ViInt32 repetition,
                                                 ViInt32 stopCondition,
                                                 ViInt32 stepMode,
                                                 ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_TDMA_InitNPow (ViSession instrumentHandle,
                                       ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_TDMA_AbortNPow (ViSession instrumentHandle,
                                        ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_TDMA_StopNPow (ViSession instrumentHandle,
                                       ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_TDMA_ContinueNPow (ViSession instrumentHandle,
                                           ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_TDMA_FetchNPowStatus (ViSession instrumentHandle,
                                              ViInt32 *measurementStatus,
                                              ViInt32 *counter_forStatisticsCycle,
                                              ViInt32 *counter_forEvaluationPeriod,
                                              ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_TDMA_ConfNPowEReport (ViSession instrumentHandle,
                                              ViInt32 measurementEventReporting,
                                              ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_TDMA_ReadNPow (ViSession instrumentHandle,
                                       ViReal64 *currentAveragePower_dBm,
                                       ViReal64 *currentMinPower_dBm,
                                       ViReal64 *currentMaxPower_dBm,
                                       ViReal64 *averageAveragePower_dBm,
                                       ViReal64 *averageMinPower_dBm,
                                       ViReal64 *averageMaxPower_dBm,
                                       ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_TDMA_FetchNPow (ViSession instrumentHandle,
                                        ViReal64 *currentAveragePower_dBm,
                                        ViReal64 *averageAveragePower_dBm,
                                        ViReal64 *currentMinPower_dBm,
                                        ViReal64 *averageMinPower_dBm,
                                        ViReal64 *currentMaxPower_dBm,
                                        ViReal64 *averageMaxPower_dBm,
                                        ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_TDMA_SampleNPow (ViSession instrumentHandle,
                                         ViReal64 *currentAveragePower_dBm,
                                         ViReal64 *averageAveragePower_dBm,
                                         ViReal64 *currentMinPower_dBm,
                                         ViReal64 *averageMinPower_dBm,
                                         ViReal64 *currentMaxPower_dBm,
                                         ViReal64 *averageMaxPower_dBm,
                                         ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_TDMA_ConfPowCont (ViSession instrumentHandle,
                                          ViInt32 application, ViInt32 mode,
                                          ViInt32 bursts, ViInt32 oversampling,
                                          ViChar _VI_FAR errorMessage[]);

ViStatus _VI_FUNC RSCMU_TDMA_ConfPowContRep (ViSession instrumentHandle,
                                             ViInt32 application,
                                             ViInt32 repetition,
                                             ViInt32 stopCondition,
                                             ViInt32 stepMode,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfPowContDefault (ViSession instrumentHandle,
                                                 ViInt32 application,
                                                 ViBoolean enable,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_DispPowContGrid (ViSession instrumentHandle,
                                              ViInt32 application,
                                              ViBoolean gridLines,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfPowUppLimLineLevel (ViSession  instrumentHandle,
                                                     ViInt32    application,
                                                     ViInt32    areaNumber,
                                                     ViReal64   level,
                                                     ViBoolean  state,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfPowUppLimLineEnable (ViSession instrumentHandle,
                                                      ViInt32   application,
                                                      ViInt32   areaNumber,
                                                      ViBoolean state,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfPowLowLimLineLevel (ViSession  instrumentHandle,
                                                     ViInt32    application,
                                                     ViReal64   level,
                                                     ViBoolean  state,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfPowLowLimLineEnable (ViSession instrumentHandle,
                                                      ViInt32   application,
                                                      ViBoolean state,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfPowLimitLeakage (ViSession instrumentHandle,
                                                  ViInt32   application,
                                                  ViReal64  level,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfPowLimitDefault (ViSession     instrumentHandle,
                                                  ViInt32       application,
                                                  ViBoolean     enable,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_InitPow (ViSession instrumentHandle,
                                      ViInt32 application,
                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_AbortPow (ViSession instrumentHandle,
                                       ViInt32 application,
                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_StopPow (ViSession instrumentHandle,
                                      ViInt32 application,
                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_RestartPow (ViSession instrumentHandle,
                                         ViInt32 application,
                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ContinuePow (ViSession instrumentHandle,
                                          ViInt32 application,
                                          ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_FetchPowStatus (ViSession instrumentHandle,
                                             ViInt32 application,
                                             ViPInt32 measurementStatus,
                                             ViPInt32 counterforMeasurementCycle,
                                             ViPInt32 counterforBursts,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfPowErep (ViSession instrumentHandle,
                                          ViInt32 application,
                                          ViInt32 measurementEventReporting,
                                          ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ReadScalPow (ViSession instrumentHandle,
                                          ViInt32 application,
                                          ViPReal64 burstsOutOfTolerance,
                                          ViPReal64 peakPower, ViPReal64 RMSPower,
                                          ViPReal64 peakLeakagePower,
                                          ViPReal64 RMSLeakagePower,
                                          ViPInt32 burstMatchingCurrent,
                                          ViPInt32 burstMatchingMin,
                                          ViPInt32 burstMatchingMax,
                                          ViPInt32 burstMatchingAvg,
                                          ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_FetchScalPow (ViSession instrumentHandle,
                                           ViInt32 application,
                                           ViPReal64 burstsOutOfTolerance,
                                           ViPReal64 peakPower, ViPReal64 RMSPower,
                                           ViPReal64 peakLeakagePower,
                                           ViPReal64 RMSLeakagePower,
                                           ViPInt32 burstMatchingCurrent,
                                           ViPInt32 burstMatchingMin,
                                           ViPInt32 burstMatchingMax,
                                           ViPInt32 burstMatchingAvg,
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_SampleScalPow (ViSession instrumentHandle,
                                            ViInt32 application,
                                            ViPReal64 burstsOutOfTolerance,
                                            ViPReal64 peakPower, ViPReal64 RMSPower,
                                            ViPReal64 peakLeakagePower,
                                            ViPReal64 RMSLeakagePower,
                                            ViPInt32 burstMatchingCurrent,
                                            ViPInt32 burstMatchingMin,
                                            ViPInt32 burstMatchingMax,
                                            ViPInt32 burstMatchingAvg,
                                            ViChar _VI_FAR errorMessage[]);
/* JMG 010709  ViStatus _VI_FUNC RSCMU_TDMA_CalcScalPowMatchBurst (ViSession instrumentHandle,
                                                    ViInt32 application,
                                                    ViPInt32 toleranceError,
                                                    ViChar _VI_FAR errorMessage[]); */
ViStatus _VI_FUNC RSCMU_TDMA_CalcScalPowMatchBurst (ViSession instrumentHandle,
                                                    ViInt32 application, 
                                                    ViPInt32 Current_Power,
                                                    ViPInt32 Min_Power,
                                                    ViPInt32 Max_Power,                                                    
                                                    ViPInt32 Average_Power,
                                                    ViChar _VI_FAR errorMessage[]);
/* JMG 021231 ViStatus _VI_FUNC RSCMU_TDMA_ConfArrPowRange (ViSession instrumentHandle,
                                              ViInt32 application,
                                              ViInt32 firstMeasurementPoint,
                                              ViInt32 numberofResultstoReturn,
                                              ViChar _VI_FAR errorMessage[]); */
ViStatus _VI_FUNC RSCMU_TDMA_ConfArrPowRange( ViSession instrSession
                                             , ViInt32   application
                                             , ViInt32   powMode
                                             , ViInt32   oversamp
                                             , ViInt32   firstMeasurementPoint
                                             , ViInt32   numberofResultstoReturn
                                             , ViChar    errorMessage[]
                                             );
ViStatus _VI_FUNC RSCMU_TDMA_ReadArrPowBurst (ViSession     instrumentHandle,
                                              ViInt32       application,
                                              ViInt32       measurementType,
                                              ViReal64      _VI_FAR burstPower[],
                                              ViChar        _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_FetchArrPowBurst (ViSession    instrumentHandle,
                                               ViInt32      application,
                                               ViInt32      measurementType,
                                               ViReal64     _VI_FAR burstPower[],
                                               ViChar       _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_SampleArrPowBurst (ViSession   instrumentHandle,
                                                ViInt32     application,
                                                ViInt32     measurementType,
                                                ViReal64    _VI_FAR burstPower[],
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_CalcArrPowMatchArea (ViSession instrumentHandle,
                                                  ViInt32 application,
                                                  ViInt32 measurementType,
                                                  ViPInt32 upperLimitArea,
                                                  ViPInt32 lowerLimitArea,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_SPowerContRep (ViSession instrumentHandle,
                                            ViInt32 repetition,
                                            ViInt32 stopCondition, ViInt32 stepMode,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_InitSPower (ViSession instrumentHandle,
                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_AbortSPower (ViSession instrumentHandle,
                                          ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_StopSPower (ViSession instrumentHandle,
                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ContinueSPower (ViSession instrumentHandle,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_FetchSPowerStatus (ViSession instrumentHandle,
                                                ViPInt32 measurementStatus,
                                                ViPInt32 counterforMeasurementCycle,
                                                ViPInt32 counterforBursts,
                                                ViChar _VI_FAR errorMessage[]);

ViStatus _VI_FUNC RSCMU_TDMA_ConfSPowerEReport (ViSession instrumentHandle,
                                                ViInt32 measurementEventReporting,
                                                ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_TDMA_ReadSPowerResult (ViSession instrumentHandle,
                                               ViPReal64 peakPower,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_FetchSPowerResult (ViSession instrumentHandle,
                                                ViPReal64 peakPower,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_SampleSPowerResult (ViSession instrumentHandle,
                                                 ViPReal64 peakPower,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfModCont (ViSession instrumentHandle, ViInt32 type,
                                          ViInt32 mode, ViInt32 bursts,
                                          ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfModContRep (ViSession instrumentHandle,
                                             ViInt32 type, ViInt32 repetition,
                                             ViInt32 stopCondition,
                                             ViInt32 stepMode,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_DispModContGrid (ViSession instrumentHandle,
                                              ViInt32 type, ViBoolean gridLines,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfModContDefault (ViSession instrumentHandle,
                                                 ViInt32 type, ViBoolean enable,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfModLimDefault (ViSession instrumentHandle,
                                                ViBoolean enable,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfModLim (ViSession instrumentHandle,
                                         ViInt32 measurementMode,
                                         ViInt32 typeofBursts,
                                         ViReal64 phaseErrorPeak,
                                         ViReal64 phaseErrorRMS,
                                         ViReal64 magErrorPeak,
                                         ViReal64 magErrorRMS,
                                         ViReal64 EVMErrorPeak,
                                         ViReal64 EVMErrorRMS,
                                         ViReal64 originOffsetdB,
                                         ViReal64 IQImbalancedB,
                                         ViReal64 frequencyErrorHz,
                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_InitMod (ViSession instrumentHandle, ViInt32 type,
                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_AbortMod (ViSession instrumentHandle, ViInt32 type,
                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_StopMod (ViSession instrumentHandle, ViInt32 type,
                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ContinueMod (ViSession instrumentHandle, ViInt32 type,
                                          ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_FetchModStatus (ViSession instrumentHandle,
                                             ViInt32 type,
                                             ViPInt32 measurementStatus,
                                             ViPInt32 counterforcurrentstatcycle,
                                             ViPInt32 counterforevalperiod,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfModErep (ViSession instrumentHandle, ViInt32 type,
                                          ViInt32 measurementEventReporting,
                                          ViChar _VI_FAR errorMessage[]);
#ifdef _OUTSIDEVEE_

ViStatus _VI_FUNC RSCMU_TDMA_ReadMod (ViSession instrumentHandle,
                                      ViInt32 measurementType,
                                      ViInt32 selectNumberofBursts,
                                      RSCMUK2T_ERROR_MOD *errorModulation,
                                      RSCMUK2T_OVERVIEW *overview,
                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_FetchMod (ViSession instrumentHandle,
                                       ViInt32 measurementType,
                                       ViInt32 selectNumberofBursts,
                                       RSCMUK2T_ERROR_MOD *errorModulation,
                                       RSCMUK2T_OVERVIEW *overview,
                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_SampleMod (ViSession instrumentHandle,
                                        ViInt32 measurementType,
                                        ViInt32 selectNumberofBursts,
                                        RSCMUK2T_ERROR_MOD *errorModulation,
                                        RSCMUK2T_OVERVIEW *overview,
                                        ViChar _VI_FAR errorMessage[]);

ViStatus _VI_FUNC RSCMU_TDMA_CalcMod (ViSession instrumentHandle,
                                      ViInt32 measurementType,
                                      ViInt32 selectNumberofBursts,
                                      RSCMUK2T_ERROR_MOD *errorModulation,
                                      RSCMUK2T_OVERVIEW *overview,
                                      ViChar _VI_FAR errorMessage[]);
#endif


ViStatus _VI_FUNC RSCMU_TDMA_ConfArrModRange (ViSession instrSession,
                                              ViInt32   measurementType,
                                              ViInt32   measurementMode,
                                              ViInt32   firstMeasurementPoint,
                                              ViInt32   numberofResultstoReturn,
                                              ViChar    errorMessage[]);

ViStatus _VI_FUNC RSCMU_TDMA_ReadArrayMod (ViSession    instrumentHandle,
                                           ViInt32      measurementType,
                                           ViInt32      measurementSetting,
                                           ViReal64     _VI_FAR bursts[],
                                           ViChar       _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_FetchArrayMod (ViSession   instrumentHandle,
                                            ViInt32     measurementType,
                                            ViInt32     measurementSetting,
                                            ViReal64    _VI_FAR bursts[],
                                            ViChar      _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_SampleArrayMod (ViSession  instrumentHandle,
                                             ViInt32    measurementType,
                                             ViInt32    measurementSetting,
                                             ViReal64   _VI_FAR bursts[],
                                             ViChar     _VI_FAR errorMessage[]);

ViStatus _VI_FUNC RSCMU_TDMA_ConfBERTset (ViSession instrumentHandle,
                                          ViInt32 tset, ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_TDMA_ConfSpecContRep (ViSession instrumentHandle,
                                              ViInt32 repetition,
                                              ViInt32 stopCondition,
                                              ViInt32 stepMode,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_DispSpecContGrid (ViSession instrumentHandle,
                                               ViBoolean gridLines,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfSpecContDefault (ViSession instrumentHandle,
                                                  ViBoolean enable,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfSpecStatBurst (ViSession instrumentHandle,
                                                ViInt32 count,
                                                ViChar _VI_FAR errorMessage[]);
//ViStatus _VI_FUNC RSCMU_TDMA_ConfSpecStatGraph (ViSession instrumentHandle,ViInt32 graphMode,ViChar _VI_FAR errorMessage[]);
// JMG 030102
ViStatus _VI_FUNC RSCMU_TDMA_ConfSpecStatGraph (ViSession instrumentHandle,
                                                ViInt32 measurementMode,
                                                ViReal64 firstMeasurementPoint,
                                                ViInt32 number_ofResults_toReturn,
                                                ViChar errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfSpecStatDefault (ViSession instrumentHandle,
                                                  ViBoolean enable,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfSpecTimeAdjChan (ViSession instrumentHandle,
                                                  ViInt32 numberofAdjacentChannels,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfSpecTimeRange (ViSession instrumentHandle,
                                                ViReal64 firstMeasurementSymbol,
                                                ViInt32 numberofResults,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfSpecLimChan (ViSession instrumentHandle,
                                              ViInt32 channelNumber,
                                              ViInt32 limitLine, ViReal64 peak,
                                              ViReal64 RMS, ViBoolean state,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfSpecLimChanEnable (ViSession instrumentHandle,
                                                    ViInt32 channelNumber,
                                                    ViInt32 limitLine,
                                                    ViBoolean state,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfSpecLimChanDefault (ViSession instrumentHandle,
                                                     ViBoolean enable,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_InitSpec (ViSession instrumentHandle,
                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_AbortSpec (ViSession instrumentHandle,
                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_StopSpec (ViSession instrumentHandle,
                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_RestartSpec (ViSession instrumentHandle,
                                          ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ContinueSpec (ViSession instrumentHandle,
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_FetchSpecStatus (ViSession instrumentHandle,
                                              ViPInt32 measurementStatus,
                                              ViPInt32 counterformeasurementcycle,
                                              ViPInt32 counterforstatistics,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfSpecErep (ViSession instrumentHandle,
                                           ViInt32 measurementEventReporting,
                                           ViChar _VI_FAR errorMessage[]);
#ifdef _OUTSIDEVEE_

ViStatus _VI_FUNC RSCMU_TDMA_ReadScalSpec (ViSession instrumentHandle,
                                           SCALAR_ACP *ACP,
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_FetchScalSpec (ViSession instrumentHandle,
                                            SCALAR_ACP *ACP,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_SampleScalSpec (ViSession instrumentHandle,
                                             SCALAR_ACP *ACP,
                                             ViChar _VI_FAR errorMessage[]);
#endif

ViStatus _VI_FUNC RSCMU_TDMA_CalcSpecLimitMatch (ViSession instrumentHandle,
                                                 ViInt32 ACPeakPower[],
                                                 ViInt32 ACRMSPower[],
                                                 ViInt32 ACPeakPower_Peak[],
                                                 ViInt32 ACPeakPower_RMS[],
                                                 ViInt32 ACAveragePower_RMS[],
                                                 ViChar errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ReadArrSpec (ViSession     instrumentHandle,
                                          ViInt32       measurementMode,
                                          ViReal64      _VI_FAR burstPower[],
                                          ViChar        _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_FetchArrSpec (ViSession    instrumentHandle,
                                           ViInt32      measurementMode,
                                           ViReal64     _VI_FAR burstPower[],
                                           ViChar       _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_SampleArrSpec (ViSession   instrumentHandle,
                                            ViInt32     measurementMode,
                                            ViReal64    _VI_FAR burstPower[],
                                            ViChar      _VI_FAR errorMessage[]);

ViStatus _VI_FUNC RSCMU_TDMA_ConfBERContRep (ViSession instrumentHandle,
                                             ViInt32 tset, ViInt32 repetition,
                                             ViInt32 stopCondition,
                                             ViInt32 stepMode,
                                             ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_TDMA_ConfBER (ViSession instrumentHandle,
                                      ViReal64 RFGeneratorLevel,
                                      ViInt32 numFramesTransmitted, ViReal64 limit,
                                      ViChar _VI_FAR errorMessage[]);

ViStatus _VI_FUNC RSCMU_TDMA_ConfBER_Ex (ViSession  instrumentHandle,
                                         ViInt32    tset,
                                         ViReal64   RFGeneratorLevel,
                                         ViInt32    numFramesTransmitted,
                                         ViReal64   limit, 
                                         ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_TDMA_ConfBERContLimDefault (ViSession   instrSession,
                                                    ViBoolean   state,
                                                    ViChar      errorMessage[]);                                         

ViStatus _VI_FUNC RSCMU_TDMA_InitBER (ViSession instrumentHandle,
                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_AbortBER (ViSession instrumentHandle,
                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_StopBER (ViSession instrumentHandle,
                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ContinueBER (ViSession instrumentHandle,
                                          ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_FetchBERStatus (ViSession instrumentHandle,
                                             ViPInt32 measurementStatus,
                                             ViPInt32 counterformeasurementcycle,
                                             ViPInt32 counterforstatistics,
                                             ViChar _VI_FAR errorMessage[]);
#ifdef _OUTSIDEVEE_

ViStatus _VI_FUNC RSCMU_TDMA_ConfBERErep (ViSession instrumentHandle,
                                          ViInt32 measurementEventReporting,
                                          ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_TDMA_ReadBER (ViSession instrumentHandle,
                                      BER_RESULTS *BERResults,
                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_FetchBER (ViSession instrumentHandle,
                                       BER_RESULTS *BERResults,
                                       ViChar _VI_FAR errorMessage[]);
#endif

ViStatus _VI_FUNC RSCMU_TDMA_CalcBERLimitMatch (ViSession   instrumentHandle,
                                                ViInt32     *BERLimitMatch,
                                                ViChar      errorMessage[]);

ViStatus _VI_FUNC RSCMU_TDMA_ConfMAHODef (ViSession instrumentHandle,
                                          ViBoolean measSelection,
                                          ViBoolean enable,
                                          ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_TDMA_ConfMAHOChanSort (ViSession instrumentHandle,
                                               ViBoolean measSelection,
                                               ViBoolean enable,
                                               ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_TDMA_ConfEMAHOMeasMode (ViSession instrumentHandle,
                                                ViBoolean measurementMode,
                                                ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_TDMA_ConfMAHONeighborChan (ViSession instrumentHandle,
                                                   ViBoolean measSelection,
                                                   ViInt32 neighborChannel,
                                                   ViInt32 band,
                                                   ViInt32 channelNumber,
                                                   ViBoolean enable,
                                                   ViChar errorMessage[]);

#ifdef _OUTSIDEVEE_
ViStatus _VI_FUNC RSCMU_TDMA_MAHOCell (ViSession instrumentHandle,
                                       ViInt32          channel, 
                                       MAHO             *singleCellMAHO,
                                       ViChar           errorMessage[]);

ViStatus _VI_FUNC RSCMU_TDMA_MAHOAllCells (ViSession    instrumentHandle,
                                            MAHO        *allCellsMAHO,
                                            ViChar      errorMessage[]);

ViStatus _VI_FUNC RSCMU_TDMA_EMAHOAllCells (ViSession   instrumentHandle,
                                            EMAHO       *allCellsEMAHO,
                                            ViChar      errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_EMAHOCell  (ViSession      instrumentHandle, 
                                            ViInt32     channel,
                                            EMAHO       *EMAHOCell,
                                            ViChar      errorMessage[]);
#endif
ViStatus _VI_FUNC RSCMU_TDMA_EMAHO_BER (ViSession instrumentHandle,
                                        ViInt32 *EMAHOBER, 
                                        ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_TDMA_EMAHO_WER (ViSession instrumentHandle,
                                        ViInt32 *EMAHORSSI,
                                        ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_TDMA_EMAHO_RSSI (ViSession instrumentHandle,
                                         ViInt32 *RSSI,
                                         ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_TDMA_EMAHO_CIR (ViSession instrumentHandle,
                                        ViInt32 *EMAHOCIR, ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_TDMA_ProcSigAction (ViSession instrumentHandle,
                                            ViInt32 action,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfBSGlobal (ViSession instrumentHandle,
                                           ViInt32 DCCHChannel, ViInt32 DCCHSlot,
                                           ViInt32 DCCHMAC,
                                           ViReal64 DCCHPowerLeveldBm,
                                           ViInt32 DTCChannel, ViInt32 DTCSlot,
                                           ViInt32 DTCMAC,
                                           ViReal64 DTCPowerLeveldBm, ViInt32 SID,
                                           ViInt32 voiceCoder,
                                           ViInt32 digitalVoiceColorCode,
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfBSSignalCCHChannel (ViSession instrumentHandle,
                                                     ViInt32 channel,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfBSSignalCCHSlot (ViSession instrumentHandle,
                                                  ViInt32 slotConfig,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfBSSignalCCHLevel (ViSession instrumentHandle,
                                                   ViReal64 level,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfBSSignalTCHChannel (ViSession instrumentHandle,
                                                     ViInt32 channel,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfBSSignalTCHSlot (ViSession instrumentHandle,
                                                  ViInt32 slotConfig,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfBSSignalTCHLevel (ViSession instrumentHandle,
                                                   ViReal64 level,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfBSSignalSpeech (ViSession instrumentHandle,
                                                 ViInt32 speech,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfBSSignalVoiceCoder (ViSession instrumentHandle,
                                                     ViInt32 voiceCoder,
                                                     ViChar _VI_FAR errorMessage[]);

ViStatus _VI_FUNC RSCMU_TDMA_NetIdSID (ViSession instrumentHandle, ViInt32 SID,
                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_NetIdSOC (ViSession instrumentHandle, ViInt32 SOC,
                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_NetIdMCC (ViSession instrumentHandle,
                                       ViInt32 mobileCountryCode,
                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_NetIdASID (ViSession instrumentHandle, ViBoolean state,
                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfNetSignalModePOReg (ViSession instrumentHandle,
                                                     ViBoolean state,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfNetSigModePDReg (ViSession instrumentHandle,
                                                  ViBoolean state,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfNetSigModeSysReg (ViSession instrumentHandle,
                                                   ViBoolean state,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfNetSigModeReg (ViSession instrumentHandle,
                                                ViBoolean state,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfNetSigModeIdType (ViSession instrumentHandle,
                                                   ViInt32 IDType,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfNetSigModeID20 (ViSession instrumentHandle,
                                                 ViInt32 ID20,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfNetSigModeID24 (ViSession instrumentHandle,
                                                 ViInt32 ID24,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfNetSigModeIDMIN (ViSession instrumentHandle,
                                                  ViChar _VI_FAR IDMIN[],
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfNetSigModeIDIMSI (ViSession instrumentHandle,
                                                   ViChar _VI_FAR IMSI[],
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfNetReqSN (ViSession instrumentHandle,
                                           ViBoolean state,
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfNetReqCapability (ViSession instrumentHandle,
                                                   ViBoolean state,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfNetDccMac (ViSession instrumentHandle,
                                            ViInt32 level,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfNetDtcMac (ViSession instrumentHandle,
                                            ViInt32 level,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfNetDic (ViSession instrumentHandle, ViInt32 state,
                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfNetSuff (ViSession instrumentHandle, ViInt32 SUFF,
                                          ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfNetRaMin (ViSession instrumentHandle,
                                           ViInt32 RAMIN,
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfNetScanInt (ViSession instrumentHandle,
                                             ViInt32 scanInterval,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfNetDelay (ViSession instrumentHandle,
                                           ViInt32 delay,
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfNetShortBurstInd (ViSession instrumentHandle,
                                                   ViInt32 burstIndicator,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfNetSysNumFbcchSlots (ViSession instrumentHandle,
                                                      ViInt32 numberofSlots,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfNetSysNumEbcchSlots (ViSession instrumentHandle,
                                                      ViInt32 numberofSlots,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfNetSysCcsDvcc (ViSession instrumentHandle,
                                                ViInt32 digitalVoiceColorCode,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfNetTimeoutLostConn (ViSession instrumentHandle,
                                                     ViInt32 timeout,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfNetTimeoutRegPeriod (ViSession instrumentHandle,
                                                      ViInt32 timeout,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfNetNeighborChan (ViSession instrumentHandle,
                                                  ViInt32 neighborChannel,
                                                  ViInt32 channelNumber,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfNetNeighborChanSort (ViSession instrumentHandle,
                                                      ViBoolean enable,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_Registration (ViSession instrumentHandle,
                                           ViInt32 timeout,
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_Origination (ViSession instrumentHandle,
                                          ViInt32 timeout,
                                          ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_PagingCallToMS (ViSession instrumentHandle,
                                             ViInt32 timeout,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ReleaseCallFromMS (ViSession instrumentHandle,
                                                ViInt32 timeout,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ReleaseCallFromBST (ViSession instrumentHandle,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ProcSigState (ViSession instrumentHandle,
                                           ViPInt32 state,
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ProcSigDtcMac (ViSession instrumentHandle,
                                            ViInt32 level,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ProcSigTrafficChan (ViSession instrumentHandle,
                                                 ViInt32 channel,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ProcBSSignalTCHLevel (ViSession instrumentHandle,
                                                   ViReal64 level,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ProcSigSlotConfig (ViSession instrumentHandle,
                                                ViInt32 slotConfig,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ProcBSSignalSpeech (ViSession instrumentHandle,
                                                 ViInt32 speech,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ConfHandoffTDMA (ViSession instrumentHandle,
                                              ViInt32 DTCChannel, ViReal64 level,
                                              ViInt32 DTCMAC, ViInt32 slotConfig,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_Handoff (ViSession originatingHandle,
                                      ViSession destinationHandle, ViInt32 target,
                                      ViInt32 timeout,
                                      ViChar _VI_FAR errorMessage[]);
#ifdef _OUTSIDEVEE_
ViStatus _VI_FUNC RSCMU_TDMA_SenseMobileInfoCapability (ViSession instrumentHandle,
                                                        ViChar softwareVersion[],
                                                        ViChar firmwareVersion[],
                                                        ViChar modelNumber[],
                                                        ViChar manufacturerCode[],
                                                        ViInt32 *maxPFC,
                                                        CAPABILITY *capabilities,
                                                        ViChar errorMessage[]);
#endif
ViStatus _VI_FUNC RSCMU_TDMA_SenseMobileInfoIdType (ViSession instrumentHandle,
                                                    ViPInt32 IDType,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_SenseMobileInfoNum (ViSession instrumentHandle,
                                                 ViChar _VI_FAR number[],
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_SenseMobileInfoESN (ViSession instrumentHandle,
                                                 ViChar _VI_FAR ESN[],
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_SenseMobileInfoPowClass (ViSession instrumentHandle,
                                                      ViPInt32 powerClass,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_SenseMobileInfoDtx (ViSession instrumentHandle,
                                                 ViPInt32 DTX,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_SenseMobileInfoBandwidth (ViSession instrumentHandle,
                                                       ViPInt32 bandwidth,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_SenseMobileInfoProtocolVer (ViSession instrumentHandle,
                                                         ViPInt32 protocolVersion,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_SenseMobileInfoDialledNum (ViSession instrumentHandle,
                                                     ViChar _VI_FAR dialledNumber[],
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_SenseMobileInfoVoiceCoder (ViSession instrumentHandle,
                                                        ViPInt32 voiceCoder,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_SenseChanQualityBER (ViSession instrumentHandle,
                                                  ViPInt32 bitErrorRate,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_SenseChanQualityRSSI (ViSession instrumentHandle,
                                                   ViPInt32 RSSI,
                                                   ViPInt32 BSTRFleveldBm,
                                                   ViChar _VI_FAR errorMessage[]);

#ifdef _OUTSIDEVEE_

ViStatus _VI_FUNC RSCMU_TDMA_SenseChanQualityMAHONCells (ViSession instrumentHandle,
                                                         MAHO *allCellsMAHO,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_SenseChanQualityMAHOCell (ViSession instrumentHandle,
                                                       ViInt32 channel,
                                                       MAHO *singleCellMAHO,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_GetResourceName (ViSession instrSession,
                                              ViSession instrSessionBase,
                                              ViChar _VI_FAR sessionName[]);
#endif

ViStatus _VI_FUNC RSCMU_TDMA_SetCmuVersion (ViSession instrumentHandle,
                                            ViChar firmwareVersion[],
                                            ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_TDMA_Reset (ViSession   instrSession,
                                    ViUInt32    max_timeout_in_ms,
                                    ViChar      _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_GPIB_Timeout (ViSession instrumentHandle,
                                           ViUInt32 timeout_in_ms,
                                           ViChar _VI_FAR errorMessage[]);

ViStatus _VI_FUNC RSCMU_TDMA_StatOperSymbEnab (ViSession instrSession,
                                               ViBoolean CFM, 
                                               ViBoolean RFM,
                                               ViBoolean LORL, 
                                               ViBoolean MREG,
                                               ViBoolean MINV,                                               
                                               ViBoolean RFNS,
                                               ViBoolean MDER,
                                               ViBoolean TCH,
                                               ViBoolean MREP, 
                                               ViBoolean RFIO,
                                               ViBoolean RFIU,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_StatOperSymbEvent (ViSession   instrSession,
                                                ViInt32     *nb,
                                                ViInt32     *statusOperEvent,
                                                ViChar      _VI_FAR SstatusOperEvent[],
                                                ViChar      _VI_FAR errorMessage[]);
                                                
ViStatus _VI_FUNC RSCMU_TDMA_Close (ViSession instrumentHandleTDMA,
                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_FetchMod_Error_Ex (ViSession instrumentHandle,
                                                ViInt32 measurementType,
                                                ViInt32 selectNumber_ofBursts,
                                                ViReal64 peak[], ViReal64 RMS[],
                                                ViReal64 originOffset[],
                                                ViReal64 IQImbalance[],
                                                ViReal64 freqErr[],
                                                ViInt32 *sync,
                                                ViReal64 *amplitudeDrop,
                                                ViReal64 *timingError,
                                                ViReal64 *powerRMS,
                                                ViReal64 *burstsOut_ofTolerance,
                                                ViChar errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_SampleMod_Error_Ex (ViSession instrumentHandle,
                                                 ViInt32 measurementType,
                                                 ViInt32 selectNumber_ofBursts,
                                                 ViReal64 peak[], ViReal64 RMS[],
                                                 ViReal64 originOffset[],
                                                 ViReal64 IQImbalance[],
                                                 ViReal64 freqErr[],
                                                 ViInt32 *sync,
                                                 ViReal64 *amplitudeDrop,
                                                 ViReal64 *timingError,
                                                 ViReal64 *powerRMS,
                                                 ViReal64 *burstsOut_ofTolerance,
                                                 ViChar errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ReadMod_Error_Ex (ViSession instrumentHandle,
                                               ViInt32 measurementType,
                                               ViInt32 selectNumber_ofBursts,
                                               ViReal64 peak[], ViReal64 RMS[],
                                               ViReal64 originOffset[],
                                               ViReal64 IQImbalance[],
                                               ViReal64 freqErr[], ViInt32 *sync,
                                               ViReal64 *amplitudeDrop,
                                               ViReal64 *timingError,
                                               ViReal64 *powerRMS,
                                               ViReal64 *burstsOut_ofTolerance,
                                               ViChar errorMessage[]);
                                               
ViStatus _VI_FUNC RSCMU_TDMA_CalcMod_Error_Ex( ViSession instrSession
                                              , ViInt32   type
                                              , ViInt32   SelectNumBursts
                                              , ViReal64  peak[]
                                              , ViReal64  RMS[]
                                              , ViReal64  originOffset[]
                                              , ViReal64  IQImbalance[]
                                              , ViReal64  freqErr[]
                                              , ViInt32  *sync
                                              , ViReal64 *amplitudeDrop
                                              , ViReal64 *timingError
                                              , ViReal64 *powerRMS
                                              , ViReal64 *burstsOut_ofTolerance
                                              , ViChar    errorMessage[]
                                              );
ViStatus _VI_FUNC RSCMU_TDMA_ReadMod_Overview_Ex (ViSession instrumentHandle,
                                                  ViInt32 selectNumber_ofBursts,
                                                  ViReal64 phaseErrorPeak[],
                                                  ViReal64 phaseErrorRMS[],
                                                  ViReal64 modErrorPeak[],
                                                  ViReal64 modErrorRMS[],
                                                  ViReal64 EVMPeak[],
                                                  ViReal64 EVMRMS[],
                                                  ViReal64 originOffset[],
                                                  ViReal64 IQImbalance[],
                                                  ViReal64 frequencyError[],
                                                  ViInt32 *sync,
                                                  ViReal64 *amplitudeDrop,
                                                  ViReal64 *timingError,
                                                  ViReal64 *powerRMS,
                                                  ViReal64 *burstsOut_ofTolerance,
                                                  ViChar errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_FetchMod_Overview_Ex (ViSession instrumentHandle,
                                                   ViInt32 selectNumber_ofBursts,
                                                   ViReal64 phaseErrorPeak[],
                                                   ViReal64 phaseErrorRMS[],
                                                   ViReal64 modErrorPeak[],
                                                   ViReal64 modErrorRMS[],
                                                   ViReal64 EVMPeak[],
                                                   ViReal64 EVMRMS[],
                                                   ViReal64 originOffset[],
                                                   ViReal64 IQImbalance[],
                                                   ViReal64 frequencyError[],
                                                   ViInt32 *sync,
                                                   ViReal64 *amplitudeDrop,
                                                   ViReal64 *timingError,
                                                   ViReal64 *powerRMS,
                                                   ViReal64 *burstsOut_ofTolerance,
                                                   ViChar errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_SampleMod_Overview_Ex (ViSession instrumentHandle,
                                                    ViInt32 selectNumber_ofBursts,
                                                    ViReal64 phaseErrorPeak[],
                                                    ViReal64 phaseErrorRMS[],
                                                    ViReal64 modErrorPeak[],
                                                    ViReal64 modErrorRMS[],
                                                    ViReal64 EVMPeak[],
                                                    ViReal64 EVMRMS[],
                                                    ViReal64 originOffset[],
                                                    ViReal64 IQImbalance[],
                                                    ViReal64 frequencyError[],
                                                    ViInt32 *sync,
                                                    ViReal64 *amplitudeDrop,
                                                    ViReal64 *timingError,
                                                    ViReal64 *powerRMS,
                                                    ViReal64 *burstsOut_ofTolerance,
                                                    ViChar errorMessage[]);
ViStatus _VI_FUNC  RSCMU_TDMA_CalcMod_Overview_Ex( ViSession instrSession
                                                   , ViInt32   SelectNumBursts
                                                   , ViReal64  phaseErrorPeak[]
                                                   , ViReal64  phaseErrorRMS[]
                                                   , ViReal64  modErrorPeak[]
                                                   , ViReal64  modErrorRMS[]
                                                   , ViReal64  EVMPeak[]
                                                   , ViReal64  EVMRMS[]
                                                   , ViReal64  originOffset[]
                                                   , ViReal64  IQImbalance[]
                                                   , ViReal64  frequencyError[]
                                                   , ViInt32  *sync
                                                   , ViReal64 *amplitudeDrop
                                                   , ViReal64 *timingError
                                                   , ViReal64 *powerRMS
                                                   , ViReal64 *burstsOut_ofTolerance
                                                   , ViChar    errorMessage[]
                                                   );
                                                    
ViStatus _VI_FUNC RSCMU_TDMA_ReadScalSpec_Ex (ViSession instrumentHandle,
                                              ViReal64 peak[], ViReal64 RMS[],
                                              ViReal64 peakPeak[],
                                              ViReal64 peakRMS[],
                                              ViReal64 averageRMS[],
                                              ViReal64 *burstOut_ofTolerance,
                                              ViChar errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_FetchScalSpec_Ex (ViSession instrumentHandle,
                                               ViReal64 peak[], ViReal64 RMS[],
                                               ViReal64 peakPeak[],
                                               ViReal64 peakRMS[],
                                               ViReal64 averageRMS[],
                                               ViReal64 *burstOut_ofTolerance,
                                               ViChar errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_SampleScalSpec_Ex (ViSession instrumentHandle,
                                                ViReal64 peak[], ViReal64 RMS[],
                                                ViReal64 peakPeak[],
                                                ViReal64 peakRMS[],
                                                ViReal64 averageRMS[],
                                                ViReal64 *burstOut_ofTolerance,
                                                ViChar errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_ReadBER_Ex (ViSession instrumentHandle,
                                         ViReal64 *testTimeInSeconds,
                                         ViReal64 *BER,
                                         ViInt32 *numBitsDefaultPatern,
                                         ViInt32 *status,
                                         ViInt32 *numFramesTransmitted,
                                         ViReal64 *TXPower,
                                         ViInt32 *TXCarrierFreqErr,
                                         ViInt32 *syncPatternDetected,
                                         ViInt32 *percentage,
                                         ViChar errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_FetchBER_Ex (ViSession instrumentHandle,
                                          ViReal64 *testTimeInSeconds,
                                          ViReal64 *BER,
                                          ViInt32 *numBitsDefaultPatern,
                                          ViInt32 *status,
                                          ViInt32 *numFramesTransmitted,
                                          ViReal64 *TXPower,
                                          ViInt32 *TXCarrierFreqErr,
                                          ViInt32 *syncPatternDetected,
                                          ViInt32 *percentage,
                                          ViChar errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_SenseChanQualityMAHONC_Ex (ViSession instrumentHandle,
                                                        ViInt32 channel[],
                                                        ViInt32 RSSI[],
                                                        ViReal64 level[],
                                                        ViChar errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_SenseChanQualityMAHOC_Ex (ViSession instrumentHandle,
                                                       ViInt32 channel,
                                                       ViInt32 *Channel,
                                                       ViInt32 *RSSI,
                                                       ViReal64 *level,
                                                       ViChar errorMessage[]);
ViStatus _VI_FUNC RSCMU_TDMA_SenseMSInfoCapability_Ex( ViSession   instrSession
                                                       , ViChar      softwareVersion[]
                                                       , ViChar      firmwareVersion[]
                                                       , ViChar      modelNumber[]
                                                       , ViChar      manufacturerCode[]
                                                       , ViInt32    *maxPFC
                                                       , ViInt32     capabilities[]
                                                       , ViChar      errorMessage[]
                                                       );


#ifndef _REMVXIPNP

ViStatus _VI_FUNC RSCMU_GetInstrumentHandle (ViSession, ViSession*);
ViStatus _VI_FUNC RSCMU_initTDMA (ViSession, ViSession, ViUInt32);

ViStatus _VI_FUNC RSCMU_TDMA_EMAHOAllCells_Ex (ViSession instrSession,
                                               ViInt32[], ViInt32[],
                                               ViChar[]);

ViStatus _VI_FUNC RSCMU_TDMA_EMAHOCell_Ex (ViSession,
                                           ViInt32,ViInt32[],
                                           ViInt32[], ViChar[]);

ViStatus _VI_FUNC RSCMU_TDMA_MAHOAllCells_Ex (ViSession,
                                              ViInt32[],
                                              ViInt32[], ViReal64[],ViChar[]);

ViStatus _VI_FUNC RSCMU_TDMA_MAHOCell_Ex (ViSession,
                                          ViInt32, ViInt32[],
                                          ViInt32[], ViReal64[],
                                          ViChar[]);

ViStatus _VI_FUNC RSCMU_init (ViRsrc, ViBoolean, ViBoolean, ViPSession);
ViStatus _VI_FUNC RSCMU_reset (ViSession);    
ViStatus _VI_FUNC RSCMU_self_test (ViSession, ViPInt16, ViChar[]);
ViStatus _VI_FUNC RSCMU_error_query (ViSession, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_error_message (ViSession, ViStatus, ViChar[]);
ViStatus _VI_FUNC RSCMU_revision_query (ViSession, ViChar[], ViChar[]);
ViStatus _VI_FUNC RSCMU_close (ViSession);

#endif

#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif

#endif  // _RSCMUK2T_H_
