/******************************************************************************
 *
 * Copyright 2000, Rohde & Schwarz, Inc. 
 *
 * NAME:        rscmuk2t.c
 *
 * PURPOSE:     This file contains the routines used to implement the IS136
 *              (TDMA) device driver for the Rohde & Schwarz CMU.
 *
 * DESCRIPTION: There are multiple functions in this file.  
 *              Refer to their corresponding headers for more detailed 
 *              information.
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ******************************************************************************
 * ----------------------------------------------------------------------------
 *                              REVISION HISTORY 
 * ----------------------------------------------------------------------------
 *  Date     | Author     | Description
 *   Release |    Company |            
 * ----------------------------------------------------------------------------
 *  23.10.00 | M.KOUTNY   | Addition (Splitted structures):
 *  V1.00    |            |   Function RSCMU_TDMA_ReadMod_Error_Ex
 *           |            |   Function RSCMU_TDMA_FetchMod_Error_Ex
 *           |            |   Function RSCMU_TDMA_SampleMod_Error_Ex
 *           |            |   Function RSCMU_TDMA_ReadMod_Overview_Ex
 *           |            |   Function RSCMU_TDMA_FetchMod_Overview_Ex
 *           |            |   Function RSCMU_TDMA_SampleMod_Overview_Ex
 *           |            |   Function RSCMU_TDMA_ReadScalSpec_Ex
 *           |            |   Function RSCMU_TDMA_FetchScalSpec_Ex
 *           |            |   Function RSCMU_TDMA_SampleScalSpec_Ex
 *           |            |   Function RSCMU_TDMA_ReadBER_Ex
 *           |            |   Function RSCMU_TDMA_FetchBER_Ex
 *           |            |   Function RSCMU_TDMA_SenseChanQualityMAHONC_Ex
 *           |            |   Function RSCMU_TDMA_SenseChanQualityMAHOC_Ex
 *           |            | Modification :
 *           |            |
 *  V1.10    |            |   Delivery Version 1.01
 * ----------------------------------------------------------------------------
 *  25.10.00 | J. SIMA    |  Additions: 
 *  V1.11    |            |     VXIplug&play support
 *           |            |  Modifications:
 *           |            |     Removed compiler warnings MSVC++ Level 1 except for parameter checking macros
 *           |            |  Delivery Version: V1.11
 * ----------------------------------------------------------------------------
 *  3.01.01  | Z.RYKALA   | Additions:
 *           |            |     RSCMU_TDMA_GetResourceName
 *  V1.12    |            |     (This function is used only in LabVIEW 5.x and higher)
 * ----------------------------------------------------------------------------
 *  26.1.01  | J. SIMA    | Modifications
 *  V1.13    |            |     Made changes to the driver source code based
 *           |            |     on the multithread proof version 1.12 from
 *           |            |     Christophe Petit.
 * ----------------------------------------------------------------------------
 *  12.02.01 | J. SIMA    | Modifications                                    
 *  V1.14    |            |     Changed revision macro to RSCMUK2T_REVISION.
 * ----------------------------------------------------------------------------
 *  15.02.01 | J. SIMA    | Modifications                                    
 *  V1.15    |            |     RSCMU_revision_query now returns the instrument 
 *           |            |     driver revision..
 * ----------------------------------------------------------------------------
 *  19.02.01 | J. SIMA    | Modifications                                    
 *  V1.16    |            |     No modification to CVI driver, this was due to
 *           |            |     a change in RSCMU_TDMA_revision_query.vi. Error
 *           |            |     Message parameter had to be removed from DLL call.
 * ----------------------------------------------------------------------------
 *  23.02.01 | J. SIMA    | Modifications                                    
 *  V1.17    |            |     Init now automatically assigns sec addr if
 *           |            |     func group not already assigned.
 * ----------------------------------------------------------------------------
 *  04.05.01 | JM GAYET   | Modifications                                    
 *  V1.171   |            |     RSCMU_TDMA_ReadMod_Overview_Ex Debug
 * ---------------------------------------------------------------------------- 
 *  09.07.01 | JM GAYET   | Modifications                                    
 *  V1.172   |            |     RSCMU_TDMA_Registration add delay 100 msbetween 2 state queries
 *           |            |     RSCMU_TDMA_PagingCallToMS  idem
 *           |            |     RSCMU_TDMA_CalcScalPowMatchBurst. Add parameters and FP 
 * ---------------------------------------------------------------------------- 
 *  10.07.01 | JM GAYET   | Modifications                                    
 *  V1.173   |            |     RSCMU_TDMA_FetchMod_Overview_Ex   Debug
 *           |            |     RSCMU_TDMA_SampleMod_Overview_Ex  Debug 
 *           |            |     RSCMU_TDMA_ReadMod_Error_Ex       Debug
 *           |            |     RSCMU_TDMA_FetchMod_Error_Ex      Debug
 *           |            |     RSCMU_TDMA_SampleMod_Error_Ex     Debug
 * ---------------------------------------------------------------------------- 
 *  16.07.01 | JM GAYET   | Modifications                                    
 *  V1.174   |            |     RSCMU_TDMA_ReadScalSpec_Ex            Debug
 *           |            |     RSCMU_TDMA_FetchScalSpec_Ex           Debug
 *           |            |     RSCMU_TDMA_SampleScalSpec_Ex          Debug  
 *           |            |     RSCMU_TDMA_SenseChanQualityMAHONC_Ex  Debug 
 *           |            |     RSCMU_TDMA_SenseChanQualityMAHOC_Ex   Debug
 * ---------------------------------------------------------------------------- 
 *  17.07.01 | JM GAYET   | Modifications                                    
 *  V1.175   |            |     RSCMU_TDMA_Origination         add 100 ms delay
 *           |            |     RSCMU_TDMA_PagingCallToMS      add 100 ms delay
 *           |            |     RSCMU_TDMA_ReleaseCallFromMS   add 100 ms delay 
 *           |            |     RSCMU_TDMA_ReadBER_Ex          Debug
 *           |            |     RSCMU_TDMA_FetchBER_Ex         Debug
 *           |            |     RSCMU_Init_TDMA                Timeoutset to RSCMU_TMO_VALUE
 * ---------------------------------------------------------------------------- 
 *  18.09.01 | R SCHMIDT  | Modifications FW 3.05                                   
 *  V1.176   | RSA        |     Corrected duplicate declarations
 *           |            |     RSCMU_TDMA_SenseMobileInfoCapability New
 *           |            |     RSCMU_TDMA_NetIdSOC                  New
 *           |            |     RSCMU_TDMA_ConfBSSignalSpeech        added HANDSET option
 *           |            |     RSCMU_TDMA_ProcBSSignalSpeech        added HANDSET option 
 *           |            |     RSCMU_TDMA_ConfNetTimeoutRegPeriod   Modified
 * ---------------------------------------------------------------------------- 
 *  27.11.01 | JM GAYET   | Modifications                                    
 *  V1.177   | RSA        |     VXI PNP
 * ----------------------------------------------------------------------------  
 *  27.01.02 | JM GAYET   | NPower Object - Creation - requires FW 3.07
 *  V1.178   | RSA        | RSCMU_CDMA_NPowSetExpectedPower
 *           |            | RSCMU_CDMA_ConfNPowControl
 *           |            | RSCMU_CDMA_ConfNPowControlRep
 *           |            | RSCMU_CDMA_InitNPow
 *           |            | RSCMU_CDMA_AbortNPow
 *           |            | RSCMU_CDMA_StopNPow
 *           |            | RSCMU_CDMA_ContinueNPow 
 *           |            | RSCMU_CDMA_FetchNPowStatus
 *           |            | RSCMU_CDMA_ConfNPowEReport
 *           |            | RSCMU_CDMA_ReadNPow
 *           |            | RSCMU_CDMA_FetchNPow  
 *           |            | RSCMU_CDMA_SampleNPow  
 * ----------------------------------------------------------------------------  
 *  01.04.02 | JM GAYET   | route speech coder/decoder - requires FW 3.05
 *  V1.179   | RSA        | RSCMU_TDMA_RoutSpenInp
 *           |            | RSCMU_TDMA_RoutSpdOutp
 *           |            | Final release for 3.07
 * ----------------------------------------------------------------------------  
 *  14.10.02 | J KOMINEK  | fixed RSCMU_TDMA_Init, RSCMU_initTDMA - copying 
 *  V1.180   |            | data from base session data structure
 *           |            | Additions:
 *           |            |    RSCMU_TDMA_SenseMobileInfoCapability_Ex
 *           |            |    RSCMU_TDMA_CalcMod_Overview_Ex
 *           |            |    RSCMU_TDMA_CalcMod_Error_Ex
 * ----------------------------------------------------------------------------  
 *  05.11.02 |            | Changed revision number
 *  V3.07.2  |            |
 * ----------------------------------------------------------------------------  
 *  03.01.03 | JM GAYET   | 
 *  V3.10RC00|            | Creation
 *           |            |  RSCMU_TDMA_CorrLossInpOutp 
 *           |            |  RSCMU_TDMA_Reset
 *           |            |  RSCMU_TDMA_GPIB_Timeout 
 *           |            |  RSCMU_TDMA_ConfBERContRep
 *           |            |  RSCMU_TDMA_ConfBER_Ex
 *           |            |  RSCMU_TDMA_ConfBERContLimDefault
 *           |            |  RSCMU_TDMA_CalcBERLimitMatch
 *           |            |  RSCMU_TDMA_ConfBERErep
 *           |            |  RSCMU_TDMA_ConfBERTset
 *           |            |  RSCMU_TDMA_ConfSPowerEReport 
 *           |            |  RSCMU_TDMA_StatOperSymbEnab
 *           |            |  RSCMU_TDMA_StatOperSymbEvent
 *           |            |  RSCMU_TDMA_SetCmuVersion 
 *           |            |  RSCMU_TDMA_ConfEMAHOMeasMode
 *           |            |  RSCMU_TDMA_EMAHOAllCells
 *           |            |  RSCMU_TDMA_EMAHOCell
 *           |            |  RSCMU_TDMA_EMAHO_BER
 *           |            |  RSCMU_TDMA_EMAHO_WER
 *           |            |  RSCMU_TDMA_EMAHO_RSSI
 *           |            |  RSCMU_TDMA_EMAHO_CIR
 *           |            | 
 *           |            | Modifications 
 *           |            |  RSCMU_Init_TDMA
 *           |            |  RSCMU_TDMA_ContinueBER 
 *           |            |  RSCMU_TDMA_CalcBERLimitMatch
 *           |            |  RSCMU_TDMA_NPowSetExpectedPower
 *           |            |  RSCMU_TDMA_ConfPowUppLimLineLevel
 *           |            |  RSCMU_TDMA_ConfPowUppLimLineEnable
 *           |            |  RSCMU_TDMA_ConfPowLowLimLineLevel
 *           |            |  RSCMU_TDMA_ConfPowLowLimLineEnable
 *           |            |  RSCMU_TDMA_ConfPowLimitLeakage
 *           |            |  RSCMU_TDMA_ConfPowLimitDefault
 *           |            |  rename RSCMU_TDMA_SenseMobileInfoCapability_Ex (name too long)
 *           |            |  into RSCMU_TDMA_SenseMSInfoCapability_Ex 
 *           |            |  RSCMU_TDMA_SenseLevDefault
 *           |            |  RSCMU_TDMA_TrigSeqDefault 
 *           |            |  RSCMU_TDMA_ConfBERContLimDefault
 *           |            |  RSCMU_TDMA_ConfMAHODef
 *           |            |  RSCMU_TDMA_ConfMAHOChanSort
 *           |            |  RSCMU_TDMA_ConfMAHONeighborChan
 *           |            |  RSCMU_TDMA_ConfNetNeighborChanSort
 *           |            |  RSCMU_TDMA_ConfPowContDefault 
 *           |            |  RSCMU_TDMA_ConfPowLimitDefault
 *           |            |  RSCMU_TDMA_ConfModContDefault
 *           |            |  RSCMU_TDMA_ConfModLimDefault  
 *           |            |  RSCMU_TDMA_ConfSpecLimChanDefault 
 *           |            |  RSCMU_TDMA_ConfSpecContDefault
 *           |            |  RSCMU_TDMA_ConfSpecStatDefault
 * ---------------------------------------------------------------------------- 
 *  03.01.03 | JM GAYET   | 
 *  V3.10RC01|            | Modifications
 *           |            |  RSCMU_Init_TDMA
 *           |            |  RSCMU_TDMA_StatOperSymbEvent
 * ---------------------------------------------------------------------------- 
 *  09.01.03 |W.Klotzsche | 
 *  V3.10.02 |            | Modifications
 *           |            |  Removed #pragma pack(1) from h file
 * ---------------------------------------------------------------------------- 
 *  22.01.03 | JM GAYET   | 
 * V3.10RC03 |            |  RSCMU_TDMA_EMAHOCell - Function Panel
 *           |            |  RSCMU_TDMA_StatOperSymbEnab
 *           |            |  RSCMU_TDMA_StatOperSymbEvent
 *           |            |  RSCMU_TDMA_CalcMod_Overview_Ex
 *           |            |  RSCMU_TDMA_CalcMod_Error_Ex
 * ---------------------------------------------------------------------------- 
 *  31.01.03 |W.Klotzsche | 
 *  V3.10.03 |            | Modifications :
 *           |            | Renamed Revision to 3.10.03
 * ----------------------------------------------------------------------------
 *  06.02.03 |J.Kominek   | 
 *  V3.10.04 |            | Creation:
 *           |            | RSCMU_TDMA_EMAHOAllCells_Ex
 *           |            | RSCMU_TDMA_EMAHOCell_Ex
 *           |            | RSCMU_TDMA_MAHOAllCells_Ex
 *           |            | RSCMU_TDMA_MAHOCell_Ex
 * ----------------------------------------------------------------------------
 *  15.12.03 |JM GAYET    | 
 *  V3.50.00 |            | Revision to 3.50.0
 *           |            | 
 * ----------------------------------------------------------------------------
 *  26.04.04 |JM GAYET    | 
 *  V3.52.00 |            | Revision to 3.52.00
 * ----------------------------------------------------------------------------
 *  14.01.05 | P.MARCALIK | 
 *  V3.60.00 |            | Creation:
 *           |            | RSCMU_TDMA_NetIdASID
 *           |            |
 * ----------------------------------------------------------------------------
 *  13.09.05 | J.KOMINEK  | 
 *  V3.60.01 |            | - Index added to CHM help file
 *           |            | - System locale are set to default "C"
 * ----------------------------------------------------------------------------
 *  23.04.07 | J.KOMINEK  | 
 *  V3.60.02 |            | - New installer, added .NET wrappers, fixed 
 *           |            |   installation issue with rscmu200 ver. 4.30 driver
 * ----------------------------------------------------------------------------
 *  31.07.07 | J.KOMINEK  | - Fixed .NET wrappers
 *  V3.60.03 |            | 
 * ----------------------------------------------------------------------------
 ******************************************************************************/

/* INCLUDE FILES */
// modif JMG
#include <locale.h>
#include "rscmuk2t.h"

/* DEFINES */
#define RSCMUK2T_REVISION  "Rev 3.60.03, 08/2007"  // Instrument Driver Revision

// Structure "RSCMU_TDMA_Globals" is initialized for each Session in an 'init' function
struct RSCMU_TDMA_Globals              
{
  struct RSCMU_SESSION_Globals  RSCMU_tGlobal;
  struct RSCMU_HandOver         RSCMU_tHandOver;
  ViChar                        rdABuf[RD_BUFFER_SIZE_ARRAY];
};

/* FUNCTION PROTOTYPES */
static void     checkRange( ViInt32 cmd, ... );
static void     RSCMU_ReturnArrayValues( ViChar[], ViReal64[] );
static ViInt32  RSCMU_SeparateString( ViChar[], ViChar[], ViChar[38][30] );
static ViStatus getBuffers( ViSession, ViChar**, ViChar**, ViChar[] );
static ViStatus RSCMU_ReturnACPResponse( ViChar[669][20], SCALAR_ACP * );
static ViStatus RSCMU_ReturnBERResponse( ViChar[669][20], BER_RESULTS * );
static ViStatus RSCMU_ReturnLimits( ViChar[3][30], RSCMUK2T_ERROR_LIMITS * );
static ViStatus RSCMU_ReturnModLimits( ViChar[5][30], ViInt32 *, ViReal64 *, ViReal64 *, ViReal64 *, ViReal64 * );
static ViStatus RSCMU_GetMeasurementStatus( ViInt32*, ViChar[38][30], ViInt32 );
static ViStatus RSCMU_GetMeasureMatching( ViInt32*, ViChar[38][30], ViInt32 );
static ViStatus RSCMU_MatchLimits( ViChar[3][30], RSCMUK2T_ERROR_LIMITS * );
static ViStatus RSCMU_errorMessage( ViSession, ViStatus, ViChar[] );
static ViStatus RSCMU_ReturnACPLimits( ViChar    valuesTmp[669][20]
                                     , ViInt32   ACPeakPower[]
                                     , ViInt32   ACRMSPower[]
                                     , ViInt32   ACPeakPowerPeak[]
                                     , ViInt32   ACPeakPowerRMS[]
                                     , ViInt32   ACAveragePowerRMS[]
                                     );
static ViStatus RSCMU_ReturnCapability( ViChar      valuesTmp[38][30]
                                      , CAPABILITY *values
                                      );


/* SUBROUTINES CALLED */

/* EXTERNALLY DEFINED GLOBAL CONSTANTS */
/* NONE */

/* INTERNALLY DEFINED GLOBAL CONSTANTS */
/* NONE */

/* EXTERNALLY DEFINED GLOBAL VARIABLES */
/* NONE */ 

/* INTERNALLY DEFINED GLOBAL VARIABLES */
/* NONE */ 



/* STATIC CONSTANTS */
/* NONE */

/* STATIC VARIABLES */
/* NONE */



//*********************************************************************
// Strings for IS136 Remote Commands
//*********************************************************************
// JMG 021231
static LIST arrayType =
   { 2
    , "ARR", "SUB"
    };

// JMG 021231
static LIST traceMode =
   { 4
    , "ALL", "ARIT", "MIN", "MAX"
    };
    
static LIST measMode = 
   { 4
   , "CURR", "AVER", "MAX", "MIN"
   };

static LIST measMode1 = 
   { 2
   , "CMM", "AVER"
   };

static LIST measMode2 = 
   { 3
   , "CURR", "AVER", "MMAX"
   };

static LIST symbols =
   { 2
   , "WBUR", "FTSY"
   };
   
static LIST LimitArea = 
   { 2
   , "LOWER", "UPPER"
   };

static LIST plusMinus = 
   { 2
   , "P", "N"   
   };

static LIST powerType =
   { 2
   , "NBUR", "SBUR"
   };
   
static LIST testType =
   { 4
   , "OVER", "PERR", "MERR", "EVM"
   };
   
static LIST mode = 
   { 3
//JMG 021224   , "MANUAL", "AUTOMATIC"
   , "MAN", "AUTO", "DMAC"   
   };

static LIST enable = 
   { 2
   , "OFF", "ON"
   };

static LIST attenuation = 
   { 3
   , "NORMAL", "LNOISE", "LDISTORTION"
   };
//JMG 0201218
static LIST trigSrc = 
   { 5
   , "FRUN", "RFPOWER", "IFPOWER", "EXTERN", "SIGN"
   };

static LIST threshold = 
   { 3
   , "LOW", "MEDIUM", "HIGH"
   };

static LIST expectedSync = 
   { 8
   , "OFF", "IS1", "IS2", "IS3", "IS4", "IS5", "IS6", "ALL"
   };

static LIST RFgenStatus = 
   { 3
   , "OFF", "RUN", "ERR"
   };

static LIST modType = 
   { 3
   , "BER", "CW", "PRBS"
   };

static LIST inpConn = 
   { 3
   , "RF1", "RF2", "RF4"
   };

static LIST outpConn = 
   { 3
   , "RF1", "RF2", "RF3"
   };

static LIST inpSrc = 
   { 3
   , "1", "2", "4"
   };

static LIST outpSrc = 
   { 3
   , "1", "2", "3"
   };


// JMG
static LIST inpSpeCod =
    { 2
      ,"GEN","HAND"
     };

// JMG   
static LIST outSpeDecod =
    { 4
      ,"ANAL","HAND","ANA2","ABOT"
     };
     
static LIST eventReport = 
   { 4
   , "OFF" , "SRQ", "SOPC", "SRSQ"
   };

static LIST powerStatus = 
   { 6
   , "OFF", "RUN", "STOP", "ERR", "STEP", "RDY"
   };

static LIST control = 
   { 2
   , "SCAL", "ARR"
   };

static LIST repetition = 
   { 3
   , "CONT", "SING", "RF4"
   };

static LIST stopCond = 
   { 2
   , "NONE", "SONERROR"
   };

static LIST stepMode = 
   { 2
   , "NONE", "STEP"
   };

static LIST oversampling = 
   { 2
   , "1", "8"
   };

static LIST burstMatch = 
   { 3
   , "MATC", "NMAT", "INV"
   };

static LIST modMode = 
   { 3
   , "CURRENT", "MAXMIN", "AVERAGE"
   };

static LIST phErrRMSCurrent = 
   { 4
   , "NMAU", "NMAL", "INV", "OK"
   };

static LIST spectrumStatus = 
   { 2
   , "ERR", "RDY"
   };

static LIST sigAction = 
   { 5
   , "SOFF", "SON", "CTM", "SMS", "CREL"
   };

static LIST speech =
   { 3
   , "ECHO", "LOOP", "HSET"
   };

static LIST voice =
   { 3
   , "VSELP", "ACELP", "MSELECTED"
   };
      
static LIST slotCCH =
   { 2
   , "C1", "C14"
   };

static LIST slotTCH =
   { 3
   , "C14", "C25", "C36"
   };

static LIST idType =
   { 4
   , "ID20", "ID24", "MIN", "ID50"
   };

static LIST dic =
   { 2
   , "DCCH", "DTC"
   };

static LIST shortBurst =
   { 2
   , "NORMAL", "SHORTENED"
   };

static LIST NetworkDelay =
   { 15
   , "0", "15", "30", "45", "60", "75", "90", "105"
   , "150", "195", "240", "285", "330", "375", "420"
   };

static LIST ClkFreqMHz =
   { 4
   , "9.72", "12.96", "19.44", "38.88"
   };
   
static LIST FreqUnits =
   { 4
   , "HZ", "KHZ", "MHZ", "GHZ"
   };
   
static char *ReportRSSI[] =
   { "NAN"
   , "RS0",  "RS1",  "RS2",  "RS3",  "RS4",  "RS5",  "RS6",  "RS7"
   , "RS8",  "RS9",  "RS10", "RS11", "RS12", "RS13", "RS14", "RS15"
   , "RS16", "RS17", "RS18", "RS19", "RS20", "RS21", "RS22", "RS23"
   , "RS24", "RS25", "RS26", "RS27", "RS28", "RS29", "RS30", "RS31"
   };

static char *ReportBER[] =
   { "NAN"
   , "BER0",  "BER1",  "BER2",  "BER3",  "BER4",  "BER5",  "BER6",  "BER7"
   };
   
static char *HandoffTargets[] =
   { "\"IS136800MS\"",           "\"IS1361900MS\"",          "\"AMPSMS\""
   ,  "\"IS136800MSFallback\"",  "\"IS1361900MSFallback\"",  "\"AMPSMSFallback\""
   ,  "\"NONE\""
   };
// JMG 030122
static char *SRS[]=
   {"CFM","RFM","LORL","MREG","MINV","E5","RFNS","MDER","E8","TCH","MREP","RFIO","RFIU","E13","E14","E15","NONE"
   };
// JMG 030103   
static LIST mahosel = 
   { 2
   , "MAHO", "EMAHO"
   };
   
// JMG 030103   
static LIST emahoMode  = 
   { 2
   , "CIR", "WER"
   };

// JMG 030103   
static LIST band  = 
   { 3
   , "OFF", "B08" , "B19"
   };

static char *ReportERSSI[] =
   { "NAN"
   , "ER00", "ER01", "ER02", "ER03", "ER04", "ER05", "ER06", "ER07", "ER08", "ER09"
   , "ER10", "ER11", "ER12", "ER13", "ER14", "ER15", "ER16", "ER17", "ER18", "ER19"
   , "ER20", "ER21", "ER22", "ER23", "ER24", "ER25", "ER26", "ER27", "ER28", "ER29"
   , "ER30", "ER31", "ER32", "ER33", "ER34", "ER35", "ER36", "ER37", "ER38", "ER39"
   , "ER40", "ER41"
   };

static char *ReportEBER[] =
   { "NAN"
   , "EB00",  "EB01",  "EB02",  "EB03",  "EB04",  "EB05",  "EB06",  "EB07"
   , "EB08",  "EB09",  "EB10",  "EB11",  "EB12",  "EB13",  "EB14",  "EB15"
   };

static char *ReportWER[] =
   { "NAN"
   , "WE00",  "WE01",  "WE02",  "WE03",  "WE04",  "WE05",  "WE06",  "WE07"
   , "WE08",  "WE09",  "WE10",  "WE11",  "WE12",  "WE13",  "WE14",  "WE15"
   };
   
static char *ReportCIR[] =
   { "NAN"
   , "CI00",  "CI01",  "CI02",  "CI03",  "CI04",  "CI05",  "CI06",  "CI07"
   , "CI08",  "CI09",  "CI10",  "CI11",  "CI12",  "CI13",  "CI14",  "CI15"
   };
   

//*********************************************************************
// Parameter Lists for IS136 Remote Commands
//*********************************************************************

// JMG 030103
static PARAM_BLOCK mahoconf = 
   { 1
   , INTEGER_TYPE, 0, 1,  &emahoMode
   , INTEGER_TYPE, 0, 2,  &band
   , INTEGER_TYPE, 0, 24, NULL
   , INTEGER_TYPE, 0, 1, &enable
   , INTEGER_TYPE, 1, 1999, NULL
   };

// JMG 030103
static PARAM_BLOCK emahoMMode = 
   { 1
   , INTEGER_TYPE, 0, 1, &emahoMode
   };

// JMG 030103
static PARAM_BLOCK mahoDef = 
   { 2
   , INTEGER_TYPE, 0, 1, &mahosel
   , INTEGER_TYPE, 0, 1, &enable
   };

// JMG 030102
static PARAM_BLOCK specMode = 
   { 3
   , INTEGER_TYPE,      0, 3, &traceMode
   , FLOAT_TYPE,    -27.0, 190.0, NULL
   , INTEGER_TYPE,      0, 872, NULL
   };

// JMG 030102
static PARAM_BLOCK confArrMode = 
   { 4
   , INTEGER_TYPE, 0, 3, &testType
   , INTEGER_TYPE, 0, 3, &traceMode
   , INTEGER_TYPE, 6, 162, NULL
   , INTEGER_TYPE, 0, 157, NULL
   };


// JMG 030122
static PARAM_BLOCK CalcArr = 
   { 2
   , INTEGER_TYPE, 0, 1, &arrayType
   , INTEGER_TYPE, 0, 1, &powerType
   };

// JMG 021231
static PARAM_BLOCK ReadPower = 
   { 3
   , INTEGER_TYPE, 0, 1, &arrayType
   , INTEGER_TYPE, 0, 1, &powerType
   , INTEGER_TYPE, 0, 3, &measMode
   };


// JMG 030102
static PARAM_BLOCK ReadSpec = 
   { 2
   , INTEGER_TYPE, 0, 1, &arrayType
   , INTEGER_TYPE, 0, 3, &measMode
   };

static PARAM_BLOCK Power = 
   { 1 
   , INTEGER_TYPE, 0, 1, &powerType
   };

static PARAM_BLOCK Grid = 
   { 2 
   , INTEGER_TYPE, 0, 1, &powerType
   , INTEGER_TYPE, 0, 1, &enable
   };

static PARAM_BLOCK ModGrid = 
   { 2 
   , INTEGER_TYPE, 0, 3, &testType
   , INTEGER_TYPE, 0, 1, &enable
   };

static PARAM_BLOCK SpecGrid = 
   { 1 
   , INTEGER_TYPE, 0, 1, &enable
   };

static PARAM_BLOCK Default = 
   { 1 
   , INTEGER_TYPE, 0, 1, &enable
   };

static PARAM_BLOCK ClkMode = 
   { 1 
   , INTEGER_TYPE, 0, 1, &enable
   };

static PARAM_BLOCK ClkFreq = 
   { 1 
   , INTEGER_TYPE, 0, 3, &ClkFreqMHz
   };

static PARAM_BLOCK TriggerSrc = 
   { 1 
//JMG 021218   , INTEGER_TYPE, 0, 3, &trigSrc
   , INTEGER_TYPE, 0, 4, &trigSrc
   };

static PARAM_BLOCK AttLvl = 
   { 1 
   , INTEGER_TYPE, 0, 2, &attenuation
   };

static PARAM_BLOCK InpLvl = 
   { 1 
//JMG 021224   , INTEGER_TYPE, 0, 1, &mode
   , INTEGER_TYPE, 0, 2, &mode
   };

static PARAM_BLOCK MaxLvl = 
   { 1 
   , FLOAT_TYPE, -37.0, 43.0, NULL
   };

static PARAM_BLOCK TrThresh = 
   { 1 
   , INTEGER_TYPE, 0, 2, &threshold
   };

static PARAM_BLOCK EventReport = 
   { 2 
   , INTEGER_TYPE, 0, 1, &powerType
   , INTEGER_TYPE, 0, 3, &eventReport
   };

static PARAM_BLOCK ModEventReport = 
   { 2 
   , INTEGER_TYPE, 0, 3, &testType
   , INTEGER_TYPE, 0, 3, &eventReport
   };

static PARAM_BLOCK SpecEvtReport = 
   { 1 
   , INTEGER_TYPE, 0, 3, &eventReport
   };

static PARAM_BLOCK Sync = 
   { 1 
   , INTEGER_TYPE, 0, 7, &expectedSync
   };

static PARAM_BLOCK Scope = 
   { 4
   , INTEGER_TYPE, 0, 1,    &powerType
   , INTEGER_TYPE, 0, 1,    &control
   , INTEGER_TYPE, 1, 1000, NULL
   , INTEGER_TYPE, 0, 1,    &oversampling
   };

static PARAM_BLOCK ModScope = 
   { 3
   , INTEGER_TYPE, 0, 3,    &testType
   , INTEGER_TYPE, 0, 1,    &control
   , INTEGER_TYPE, 1, 1000, NULL
   };

static PARAM_BLOCK CfgRep = 
   { 4
   , INTEGER_TYPE, 0, 1, &powerType
   , INTEGER_TYPE, 0, 2, &repetition
   , INTEGER_TYPE, 0, 1, &stopCond
   , INTEGER_TYPE, 0, 1, &stepMode
   };

static PARAM_BLOCK SignalRep = 
   { 3 
   , INTEGER_TYPE, 0, 10000, NULL
   , INTEGER_TYPE, 0, 1,     &stopCond
   , INTEGER_TYPE, 0, 1,     &stepMode
   };

static PARAM_BLOCK UppLimitEnable = 
   { 2 
   , INTEGER_TYPE, 0, 1, &LimitArea
   , INTEGER_TYPE, 0, 1, &enable
   };

// JMG 030106
static PARAM_BLOCK PowDef = 
   { 2 
    , INTEGER_TYPE, 0, 1, &powerType
    , INTEGER_TYPE, 0, 1, &enable
   };

// JMG 021228
static PARAM_BLOCK LimitEnable = 
   { 2 
    , INTEGER_TYPE, 0, 1, &powerType
    , INTEGER_TYPE, 0, 1, &enable
   };

// JMG 021228
static PARAM_BLOCK UppLimitLine = 
   { 4 
   , INTEGER_TYPE,    0,  1, &powerType
   , INTEGER_TYPE,    1,  5, &LimitArea
   , FLOAT_TYPE,   -100, 10, NULL
   , INTEGER_TYPE,    0,  1, &enable
   };

// JMG 021228
static PARAM_BLOCK LowLimitLine = 
   { 3 
   , INTEGER_TYPE,    0,  1, &powerType
   , FLOAT_TYPE,   -100, 10, NULL
   , INTEGER_TYPE,    0,  1, &enable
   };
// JMG 021228
static PARAM_BLOCK LeakagePower =
   { 2
   , INTEGER_TYPE,    0,  1, &powerType
   , FLOAT_TYPE,    -80,  0, NULL
   };
   
static PARAM_BLOCK Limits = 
   { 2 
   , FLOAT_TYPE, 0.0, 50.0, NULL
   , FLOAT_TYPE, 0.0, 50.0, NULL
   };

static PARAM_BLOCK FreqChan = 
   { 1
   , FLOAT_TYPE, 0.2, 2700.0, NULL
   };

static PARAM_BLOCK RFChan = 
   { 1 
   , INTEGER_TYPE, 1, 1999, NULL
   };

static PARAM_BLOCK FreqOffset = 
   { 1 
   , FLOAT_TYPE, -15.0, 15.0, NULL
   };

static PARAM_BLOCK RFlvl = 
   { 1 
   , FLOAT_TYPE, -137.0, 33.0, NULL
   };

static PARAM_BLOCK ChanMode = 
   { 5 
   , INTEGER_TYPE,     1,     3, NULL
   , INTEGER_TYPE,     0,     1, &plusMinus
   , FLOAT_TYPE,   -99.9, +99.9, NULL
   , FLOAT_TYPE,   -99.9, +99.9, NULL
   , INTEGER_TYPE,     0,     1, &enable
   };

static PARAM_BLOCK ChanEnable = 
   { 3 
   , INTEGER_TYPE, 1, 3, NULL
   , INTEGER_TYPE, 0, 1, &plusMinus
   , INTEGER_TYPE, 0, 1, &enable
   };

static PARAM_BLOCK SpecBurst = 
   { 1 
   , INTEGER_TYPE, 1, 1000, NULL
   };

static PARAM_BLOCK SpecGraph = 
   { 1 
   , INTEGER_TYPE, 0, 2, &modMode
   };

static PARAM_BLOCK ModType = 
   { 1 
   , INTEGER_TYPE, 0, 2, &modType
   };

static PARAM_BLOCK Input = 
   { 1 
   , INTEGER_TYPE, 0, 2, &inpConn
   };

static PARAM_BLOCK Output = 
   { 1 
   , INTEGER_TYPE, 0, 2, &outpConn
   };

static PARAM_BLOCK InpAtt = 
   { 2 
   , INTEGER_TYPE, 0,     2,    &inpSrc
   , FLOAT_TYPE,   -50.0, 50.0, NULL
   };

static PARAM_BLOCK InConn = 
   { 1 
   , INTEGER_TYPE, 0, 3, &inpConn
   };

static PARAM_BLOCK OutpAtt = 
   { 2 
   , INTEGER_TYPE, 0,     2,    &outpSrc
   , FLOAT_TYPE,   -50.0, 50.0, NULL
   };

static PARAM_BLOCK OutConn = 
   { 1 
   , INTEGER_TYPE, 0, 2, &outpConn
   };


static PARAM_BLOCK InputCodec = 
   { 1 
   , INTEGER_TYPE, 0, 1, &inpSpeCod
   };

static PARAM_BLOCK OutputCodec = 
   { 1 
   , INTEGER_TYPE, 0, 3, &outSpeDecod
   };

static PARAM_BLOCK Area = 
   { 1 
   , INTEGER_TYPE, 1, 5, NULL
   };
// JMG 021231
static PARAM_BLOCK Range = 
   { 5
   , INTEGER_TYPE, 0,   3,    &testType
   , INTEGER_TYPE, 0,   3,    &traceMode
   , INTEGER_TYPE, 0,   1,    &oversampling
   , INTEGER_TYPE, -20, 181,  NULL
   , INTEGER_TYPE, 0,   1616, NULL
   };

static PARAM_BLOCK Application = 
   { 1 
   , INTEGER_TYPE, 0, 3, &testType
   };

static PARAM_BLOCK ModCfgRep = 
   { 4 
   , INTEGER_TYPE, 0, 3, &testType
   , INTEGER_TYPE, 0, 2, &repetition
   , INTEGER_TYPE, 0, 1, &stopCond
   , INTEGER_TYPE, 0, 1, &stepMode
   };

static PARAM_BLOCK SpecCfgRep = 
   { 3 
   , INTEGER_TYPE, 0, 2, &repetition
   , INTEGER_TYPE, 0, 1, &stopCond
   , INTEGER_TYPE, 0, 1, &stepMode
   };

static PARAM_BLOCK ModDefault = 
   { 1 
   , INTEGER_TYPE, 0, 1, &enable
   };

static PARAM_BLOCK ModLimits = 
   { 11 
   , INTEGER_TYPE, 0,      1,    &measMode1
   , INTEGER_TYPE, 0,      1,    &symbols
   , FLOAT_TYPE,   0.0,    50.0, NULL
   , FLOAT_TYPE,   0.0,    50.0, NULL
   , FLOAT_TYPE,   0.0,    50.0, NULL
   , FLOAT_TYPE,   0.0,    50.0, NULL
   , FLOAT_TYPE,   0.0,    50.0, NULL
   , FLOAT_TYPE,   0.0,    50.0, NULL
   , FLOAT_TYPE,   -100.0, 0.0,  NULL
   , FLOAT_TYPE,   -100.0, 0.0,  NULL
   , FLOAT_TYPE,   0,      1000, NULL
   };

static PARAM_BLOCK NumBursts = 
   { 2 
   , INTEGER_TYPE, 0,   3,    &testType
   , INTEGER_TYPE, 0,   1,    &symbols
   };
// JMG 021231
static PARAM_BLOCK ModMode = 
   { 3
   , INTEGER_TYPE, 0,   1,    &arrayType
   , INTEGER_TYPE, 0,   3,    &testType
   , INTEGER_TYPE, 0,   2,    &measMode2
   };

static PARAM_BLOCK SignalAction = 
   { 1 
   , INTEGER_TYPE, 0, 4, &sigAction
   };

static PARAM_BLOCK MacTCH =
   { 1 
   , INTEGER_TYPE, 0, 10, NULL
   };

static PARAM_BLOCK ChanTCH =
   { 1 
   , INTEGER_TYPE, 1, 1999, NULL
   };

static PARAM_BLOCK LevelTCH =
   { 1 
   , FLOAT_TYPE, -131, 3, NULL
   };

static PARAM_BLOCK SlotConfigTCH = 
   { 1 
   , INTEGER_TYPE, 0, 2, &slotTCH
   };

static PARAM_BLOCK ChanCCH =
   { 1 
   , INTEGER_TYPE, 1, 1999, NULL
   };

static PARAM_BLOCK LevelCCH =
   { 1 
   , FLOAT_TYPE, -131, 3, NULL
   };

static PARAM_BLOCK SlotConfigCCH = 
   { 1 
   , INTEGER_TYPE, 0, 1, &slotCCH
   };

static PARAM_BLOCK BssSpeech = 
   { 1 
   , INTEGER_TYPE, 0, 2, &speech
   };

static PARAM_BLOCK BssVoice = 
   { 1 
   , INTEGER_TYPE, 0, 2, &voice
   };

static PARAM_BLOCK NetIdType =
   { 1 
   , INTEGER_TYPE, 0, 3, &idType
   };

static PARAM_BLOCK NetDIC =
   { 1 
   , INTEGER_TYPE, 0, 1, &dic
   };

static PARAM_BLOCK SBIndicator =
   { 1 
   , INTEGER_TYPE, 0, 1, &shortBurst
   };

static PARAM_BLOCK LossLinkTO =
   { 1 
   , INTEGER_TYPE, 1, 20, NULL
   };

static PARAM_BLOCK RegPeriodTO =
   { 1 
   , INTEGER_TYPE, 4, 3600, NULL
   };

static PARAM_BLOCK NetSID =
   { 1 
   , INTEGER_TYPE, 0, 32767, NULL
   };

static PARAM_BLOCK NetSOC =
   { 1 
   , INTEGER_TYPE, 0, 4096, NULL
   };

static PARAM_BLOCK NetMCC =
   { 1 
   , INTEGER_TYPE, 0, 1023, NULL
   };

static PARAM_BLOCK NetScanInt =
   { 1 
   , INTEGER_TYPE, 1, 16, NULL
   };

static PARAM_BLOCK NetDelay =
   { 1 
   , INTEGER_TYPE, 0, 14, NULL
   };

static PARAM_BLOCK NetRAMIN =
   { 1 
   , INTEGER_TYPE, -111, -51, NULL
   };

static PARAM_BLOCK NetSUFF =
   { 1 
   , INTEGER_TYPE, -111, -51, NULL
   };

static PARAM_BLOCK NetDTCMAC =
   { 1 
   , INTEGER_TYPE, 0, 10, NULL
   };

static PARAM_BLOCK NetDCCMAC =
   { 1 
   , INTEGER_TYPE, 0, 7, NULL
   };

static PARAM_BLOCK NetID20 =
   { 1 
   , INTEGER_TYPE, 0, 1048575, NULL
   };

static PARAM_BLOCK NetID24 =
   { 1 
   , INTEGER_TYPE, 0, 16777215, NULL
   };

static PARAM_BLOCK NetNumFSlots =
   { 1 
   , INTEGER_TYPE, 5, 10, NULL
   };

static PARAM_BLOCK NetNumESlots =
   { 1 
   , INTEGER_TYPE, 1, 8, NULL
   };

static PARAM_BLOCK NetCCSDVCC =
   { 1 
   , INTEGER_TYPE, 0, 255, NULL
   };

static PARAM_BLOCK NetNeighbors =
   { 2
   , INTEGER_TYPE, 1, 24,   NULL
   , INTEGER_TYPE, 0, 1023, NULL
   };
   
static PARAM_BLOCK TimeRange =
   { 2
   , FLOAT_TYPE,   -1.8, 1.8, NULL
   , INTEGER_TYPE, 1,    9,   NULL
   };
   
static PARAM_BLOCK AdjChannel =
   { 1
   , INTEGER_TYPE, -3, 3, NULL
   };
   
static PARAM_BLOCK ConfBER =
   { 4
   , INTEGER_TYPE, 1,    5,   NULL
   , FLOAT_TYPE,   -137, 13,  NULL
   , INTEGER_TYPE, 1,    500, NULL
   , FLOAT_TYPE,   0,    100, NULL
   };
   
static PARAM_BLOCK MAHOcell =
   { 1
   , INTEGER_TYPE, 1, 24, NULL
   };
static PARAM_BLOCK EMAHOcell =
   { 1
   , INTEGER_TYPE, 1, 22, NULL
   };
   
static PARAM_BLOCK ExpectedPow =
   { 1 
   , FLOAT_TYPE, -100.0, +39.0, NULL
   };   

static PARAM_BLOCK NPowStat = 
   { 1
   , INTEGER_TYPE, 1, 1000, NULL
   };

static PARAM_BLOCK NPowRep = 
   { 3 
   , INTEGER_TYPE, 0, 2, &repetition
   , INTEGER_TYPE, 0, 1, &stopCond
   , INTEGER_TYPE, 0, 1, &stepMode
   };

static PARAM_BLOCK NPowCont = 
   { 4
   , INTEGER_TYPE, 1, 1000, NULL
   , INTEGER_TYPE, 0, 2,    &repetition
   , INTEGER_TYPE, 0, 1,    &stopCond
   , INTEGER_TYPE, 0, 1,    &stepMode
   };

static PARAM_BLOCK NPowEvtReport = 
   { 1 
   , INTEGER_TYPE, 0, 3, &eventReport
   };

static PARAM_BLOCK BERCont = 
   { 4
   , INTEGER_TYPE, 1, 5,    NULL
   , INTEGER_TYPE, 0, 2,    &repetition
   , INTEGER_TYPE, 0, 1,    &stopCond
   , INTEGER_TYPE, 0, 1,    &stepMode
   };
   
//*********************************************************************
// Rohde & Schwarz CMU Command Table for IS136 (TDMA)
//*********************************************************************

COMMAND_INFO IS136[] =
{ // Group Configuration
  //   Subsystem LEVel (Input Level)
  /* 000 */     "LEV:DEF %s",
                   NULL,
                   NULL,
                   NULL,
                   &Default,
                   NULL
  /* 001 */   , "LEV:MODE %s",                                                       
                   NULL,           
                   NULL,
                   NULL,       
                   &InpLvl,      
                   NULL
  /* 002 */   , "LEV:MAX %lf",  
                   NULL,           
                   NULL,
                   NULL,       
                   &MaxLvl,      
                   NULL
  /* 003 */   , "LEV:ATT %s",  
                   NULL,           
                   NULL,
                   NULL,       
                   &AttLvl,      
                   NULL

  //   Subsystem TRIGger (Trigger Mode)
  /* 004 */   , "TRIG:DEF %s",  
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,      
                   NULL
  /* 005 */   , "TRIG:SOUR %s",  
                   NULL,           
                   NULL,
                   NULL,       
                   &TriggerSrc,      
                   NULL
  /* 006 */   , "TRIG:THR %s",  
                   NULL,           
                   NULL,
                   NULL,       
                   &TrThresh,      
                   NULL

  // Connection Control
  //   Subsystem RFANalyzer Frequency (Analyzed Input Signals)
  /* 007 */   , "RFAN:FREQ:UNIT MHZ;:RFAN:FREQ %lf",  
                   NULL,           
                   NULL,
                   NULL,       
                   &FreqChan,      
                   NULL
  /* 008 */   , "RFAN:FREQ:UNIT CH;:RFAN:FREQ %d",  
                   NULL,
                   NULL,
                   NULL,       
                   &RFChan,       
                   NULL
  /* 009 */   , "RFAN:FREQ:OFFS %lf KHZ",  
                   NULL,           
                   NULL,
                   NULL,       
                   &FreqOffset,      
                   NULL
  /* 010 */   , "RFAN:EMSS %s",  
                   NULL,           
                   NULL,
                   NULL,       
                   &Sync,      
                   NULL

  // Generator Object - RFGenerator Control
  /* 011 */   , "INIT:RFG",                                                      
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL
  /* 012 */   , "ABOR:RFG",                                                         
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL
  /* 013 */   , "FETC:RFG:STAT?",                                                 
                   NULL,
                   NULL,
                   NULL,       
                   NULL,       
                   NULL

  // Generator Level
  //   Subsystem RFGenerator:LEVel
  /* 014 */   , "SOUR:RFG:LEV %6.2lf DBM",                                       
                   NULL,           
                   NULL,
                   NULL,       
                   &RFlvl,       
                   NULL

  //   Subsystem RFGenerator:FREQuency
  /* 015 */   , "SOUR:RFG:FREQ:UNIT MHZ;:SOUR:RFG:FREQ %lf",                                   
                   NULL,           
                   NULL,
                   NULL,       
                   &FreqChan,       
                   NULL
  /* 016 */   , "SOUR:RFG:FREQ:UNIT CH;:SOUR:RFG:FREQ %d",                                       
                   NULL,
                   NULL,
                   NULL,       
                   &RFChan,       
                   NULL
  /* 017 */   , "SOUR:RFG:FREQ:OFFS %lf KHZ",                                    
                   NULL,           
                   NULL,
                   NULL,       
                   &FreqOffset,       
                   NULL

  //   Subsystem RFGenerator:MODulation
  /* 018 */   , "SOUR:RFG:MOD:RFS:TYPE %s",                              
                   NULL,           
                   NULL,
                   NULL,       
                   &ModType,       
                   NULL

  //   Subsystem for Input and Output
  /* 019 */   , "INP %s",                                                                  
                   NULL,           
                   NULL,
                   NULL,       
                   &Input,       
                   NULL
  /* 020 */   , "OUTP %s",                                                                 
                   NULL,           
                   NULL,
                   NULL,       
                   &Output,       
                   NULL
  /* 021 JMG 021216   , "SENS:CORRECTION:LOSS:INP%s %lf", */
  /* 021 */   , "SENS:CORR:LOSS:INP%s %lf",
                   NULL,           
                   NULL,
                   NULL,       
                   &InpAtt,       
                   NULL
  /* 022 JMG 021216   , "SOURCE:CORRECTION:LOSS:INP%s %lf", */
  /* 022 */   , "SOUR:CORR:LOSS:INP%s %lf",  
                   NULL,           
                   NULL,
                   NULL,       
                   &InpAtt,       
                   NULL
  /* 023 JMG 021216   , "SENS:CORRECTION:LOSS:OUTP%s %lf", */
  /* 023 */   , "SENS:CORR:LOSS:OUTP%s %lf",  
                   NULL,           
                   NULL,
                   NULL,       
                   &OutpAtt,       
                   NULL
  /* 024 JMG 021216   , "SOURCE:CORRECTION:LOSS:OUTP%s %lf", */
  /* 024 */   , "SOUR:CORR:LOSS:OUTP%s %lf",  
                   NULL,           
                   NULL,
                   NULL,       
                   &OutpAtt,       
                   NULL

  //   Subsystem REFerence (Synchronization)
  /* 025 */   , "SOURCE:DM:CLOCK:STATE %s",                                                  
                   NULL,           
                   NULL,
                   NULL,       
                   &ClkMode,       
                   NULL 
  /* 026 */   , "SOURCE:DM:CLOCK:FREQ %s",                                              
                   NULL,           
                   NULL,
                   NULL,       
                   &ClkFreq,       
                   NULL 

  // Measurement Object - POWer[:NORMal]
  //   Control of measurement - Subsystem POWer[:NORMal]
  /* 027 */   , "INIT:POW:%s",                                                            
                   NULL,           
                   NULL,
                   NULL,       
                   &Power,       
                   NULL 
  /* 028 */   , "ABOR:POW:%s",                                                               
                   NULL,           
                   NULL,
                   NULL,       
                   &Power,
                   NULL 
  /* 029 */   , "STOP:POW:%s",                                                                
                   NULL,           
                   NULL,
                   NULL,       
                   &Power,
                   NULL 
  /* 030 */   , "RESTART:POWER:%s",
                   NULL,           
                   NULL,
                   NULL,       
                   &Power,
                   NULL 
  /* 031 */   , "CONT:POW:%s",                                                            
                   NULL,           
                   NULL,
                   NULL,       
                   &Power,
                   NULL 
  /* 032 */   , "CONF:POW:%s:EREP %s",                                
                   NULL,           
                   NULL,
                   NULL,       
                   &EventReport,       
                   NULL 
  /* 033 */   , "CONF:POW:%s:CONT %s, %d;:CONF:POW:%s:TIME:OVER %s",
                   NULL,
                   NULL,
                   NULL,       
                   &Scope,       
                   NULL
  /* 034 */   , "CONF:POW:%s:CONT:REP %s, %s, %s",                
                   NULL,           
                   NULL,
                   NULL,       
                   &CfgRep,       
                   NULL 
  /* 035 */   , "DISP:POW:%s:CONT:GRID %s",                                
                   NULL,           
                   NULL,
                   NULL,       
                   &Grid,       
                   NULL 
  /* 036 */   , "FETC:POW:%s:STAT?",                                   
                   NULL,
                   NULL,
                   NULL,       
                   &Power,
                   NULL

  //   Subsystem CONFigure:POWer:LIMIt:LINE:UPPer
  /* 037 */   , "CONF:POW:%s:LIM:UPP:AREA%d %lf, %s",                    
                   NULL,           
                   NULL,
                   NULL,       
                   &UppLimitLine,       
                   NULL 
  /* 038 */   , "CONF:POW:%s:LIM:UPP:AREA%d:ENAB %s",                 
                   NULL,           
                   NULL,
                   NULL,       
                   &UppLimitEnable,       
                   NULL 
  /* JMG 021228 039   , "CONF:POW:LIMIT:POIN:LPOW %lf", */
  /* 039 */   , "CONF:POW:%s:LIM:POIN:LPOW %lf",
                   NULL,           
                   NULL,
                   NULL,       
                   &LeakagePower,       
                   NULL 
  /* 040 */   , "CONF:HAND:TARGET %s",                         
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL 
  // Measure Values
  //   Subsystem POWer[:NORMal][:RESult]
  /* 041 */   , "CONF:SUB:POW:%s %s,%d,%d",
                   NULL,           
                   NULL,
                   NULL,       
                   &Range,       
                   NULL 
  /* 042 */   , "READ:POW:%s?",
                   NULL,
                   NULL,
                   NULL,       
                   &Power,       
                   NULL
  /* 043 */   , "FETC:POW:%s?",
                   NULL,           
                   NULL,
                   NULL,       
                   &Power,       
                   NULL
  /* 044 */   , "SAMP:POW:%s?",
                   NULL,
                   NULL,
                   NULL,       
                   &Power,       
                   NULL
  /* 045 */   , "CALC:ARR:POW:%s:%s:MATC:LIM?",    
                   NULL,
                   NULL,
                   NULL,       
                   &CalcArr,       
                   NULL
  /* 046 */   , "READ:%s:POW:%s:%s?",  
                   NULL,
                   NULL,
                   NULL,       
                   &ReadPower,       
                   NULL
  /* 047 */   , "FETC:%s:POW:%s:%s?",
                   NULL,
                   NULL,
                   NULL,       
                   &ReadPower,       
                   NULL
  /* 048 */   , "SAMP:%s:POW:%s:%s?",
                   NULL,
                   NULL,
                   NULL,       
                   &ReadPower,       
                   NULL
  /* 049 */   , "CALC:POW:%s:RES:MATC:RAMP?",           
                   NULL,
                   NULL,
                   NULL,       
                   &Power,
                   NULL

  //   Measurement Object MODulation
  /* 050 */   , "INIT:MOD:%s",                                                    
                   NULL,           
                   NULL,
                   NULL,       
                   &Application,       
                   NULL 
  /* 051 */   , "ABOR:MOD:%s",                                                       
                   NULL,           
                   NULL,
                   NULL,       
                   &Application,       
                   NULL 
  /* 052 */   , "STOP:MOD:%s",                                                        
                   NULL,           
                   NULL,
                   NULL,       
                   &Application,       
                   NULL 
  /* 053 */   , "CONT:MOD:%s",                                                    
                   NULL,           
                   NULL,
                   NULL,       
                   &Application,       
                   NULL 
  /* 054 */   , "CONF:MOD:%s:EREP %s",                               
                   NULL,           
                   NULL,
                   NULL,       
                   &ModEventReport,       
                   NULL 
  /* 055 */   , "FETC:MOD:%s:STAT?",                                               
                   NULL,
                   NULL,
                   NULL,       
                   &Application,       
                   NULL

  //   Subsystem MODulation[:xxx]:CONTrol
  /* 056 */   , "CONF:MOD:%s:CONT %s, %d",                              
                   NULL,           
                   NULL,
                   NULL,       
                   &ModScope,       
                   NULL 
  /* 057 */   , "CONF:MOD:%s:CONT:REP %s, %s, %s",               
                   NULL,           
                   NULL,
                   NULL,       
                   &ModCfgRep,       
                   NULL 
  /* 058 */   , "CONF:MOD:%s:CONT:DEF %s",                          
                   NULL,           
                   NULL,
                   NULL,       
                   &ModDefault,       
                   NULL 
  /* 059 */   , "DISP:MOD:%s:CONT:GRID %s",                               
                   NULL,           
                   NULL,
                   NULL,       
                   &ModGrid,       
                   NULL 
  /* 060 */   , "CONF:MOD:OEMP:%s:LIM:%s %lf, %lf, %lf, %lf, %lf, %lf, %lf, %lf, %lf",                                                      
                   NULL,           
                   NULL,
                   NULL,       
                   &ModLimits,       
                   NULL 
  /* 061 */   , "CONF:MOD:OEMP:LIM:DEF %s",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &ModDefault,       
                   NULL 
  // JMG 021228                   
  /* 062 */   , "CONF:POW:%s:LIM:LOW:AREA1 %lf, %s",                    
                   NULL,           
                   NULL,
                   NULL,       
                   &LowLimitLine,       
                   NULL  

  //   Measured Values
  //     Subsystem MODulation[:xxx][:RESult]
  /* 063 */   , "READ:MOD:%s:%s?",
                   NULL,
                   NULL,
                   NULL,       
                   &NumBursts,
                   NULL
  /* 064 */   , "FETC:MOD:%s:%s?",
                   NULL,
                   NULL,
                   NULL,       
                   &NumBursts,
                   NULL
  /* 065 */   , "SAMP:MOD:%s:%s?",
                   NULL,
                   NULL,
                   NULL,       
                   &NumBursts,
                   NULL
  /* 066 */   , "CALC:MOD:%s:MATC:LIM:%s?",  
                   NULL,
                   NULL,
                   NULL,       
                   &NumBursts,       
                   NULL
  /* 067 */   , "CALC:ARRAY:MOD:%s:LIM:MATC:%s?",        
                   NULL,
                   NULL,
                   NULL,       
                   &NumBursts,       
                   NULL
  /* 068 */   , "READ:%s:MOD:%s:%s?",                              
                   NULL,
                   NULL,
                   NULL,       
                   &ModMode,       
                   NULL
  /* 069 */   , "FETC:%s:MOD:%s:%s?",                             
                   NULL,
                   NULL,
                   NULL,       
                   &ModMode,       
                   NULL
  /* 070 */   , "SAMP:%s:MOD:%s:%s?",                            
                   NULL,
                   NULL,
                   NULL,       
                   &ModMode,       
                   NULL

  // Spectrum / ACP
  //   Control of Measurement
  //     Subsystem SPECtrum[:ACPower]
  /* 071 */   , "INIT:SPEC",                                                         
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL 
  /* 072 */   , "ABOR:SPEC",                                                            
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL 
  /* 073 */   , "STOP:SPEC",                                                             
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL 
  /* 074 */   , "RESTART:SPEC",                                                          
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL 
  /* 075 */   , "CONT:SPEC",                                                         
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL 
  /* 076 */   , "CONF:SPEC:EREP %s",                                  
                   NULL,           
                   NULL,
                   NULL,       
                   &SpecEvtReport,       
                   NULL 
  /* 077 */   , "FETC:SPEC?",                                                    
                   NULL,
                   NULL,
                   NULL,       
                   NULL,       
                   NULL
  /* 078 */   , "READ:SPEC?",                                                     
                   NULL,
                   NULL,
                   NULL,       
                   NULL,       
                   NULL

  //     Subsystem SPECTrum:MODulation:CONTrol
  /* 079 */   , "CONF:SPEC:CONT:REP %s, %s, %s",                      
                   NULL,           
                   NULL,
                   NULL,       
                   &SpecCfgRep,       
                   NULL 
  /* 080 */   , "DISP:SPEC:CONT:GRID %s",                                  
                   NULL,           
                   NULL,
                   NULL,       
                   &SpecGrid,       
                   NULL 
  /* 081 */   , "CONF:SPEC:CONT:DEF %s",                             
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,       
                   NULL 

  //     Subsystem SPECTrum[:ACPower]:LIMit:CHANnel
  /* 082 */   , "CONF:SPEC:ACP:LIM:CH%s%d %lf, %lf, %s",                     
                   NULL,           
                   NULL,
                   NULL,       
                   &ChanMode,       
                   NULL 
  /* 083 */   , "CONF:SPEC:ACP:LIM:CH%s%d:ENAB %s",  
                   NULL,           
                   NULL,
                   NULL,       
                   &ChanEnable,       
                   NULL 

  //     Subsystem SPECTrum[:ACPower]:STATistics
  /* 084 */   , "CONF:SPEC:CONT SCAL, %d;:CONF:SPEC:CONT ARR, %d",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &SpecBurst,       
                   NULL 
  /* 085 */   , "CONF:SUB:SPEC:TDOM %s,%lf,%d",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &specMode,       
                   NULL 
  /* 086 */   , "CONF:SPEC:CONT:DEF %s",                          
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,       
                   NULL 
  /* 087 */   , "SAMP:SPEC?",
                   NULL,
                   NULL,
                   NULL,       
                   &ReadSpec,       
                   NULL
  /* 088 */   , "READ:%s:SPEC:TDOM:%s?",  
                   NULL,
                   NULL,
                   NULL,
                   &ReadSpec,
                   NULL
  /* 089 */   , "PROC:SIGN:ACT %s",
                   NULL,
                   NULL,
                   NULL,
                   &SignalAction,
                   NULL
  /* 090 */   , "PROC:SIGN:DTC:MAC %d",
                   NULL,
                   NULL,
                   NULL,
                   &MacTCH,
                   NULL
  /* 091 */   , "PROC:SIGN:DTC:CHAN %d",
                   NULL,
                   NULL,
                   NULL,
                   &ChanTCH,
                   NULL
  /* 092 */   , "PROC:SIGN:DTC:SLOT %s",
                   NULL,
                   NULL,
                   NULL,
                   &SlotConfigTCH,
                   NULL
  /* 093 */   , "PROC:BSS:DTC:LEVEL %lf",
                   NULL,
                   NULL,
                   NULL,
                   &LevelTCH,
                   NULL
  /* 094 */   , "CONF:BSS:SPEECH %s",  
                   NULL,
                   NULL,
                   NULL,
                   &BssSpeech,
                   NULL
  /* 095 */   , "SIGN:STAT?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /* 096 */   , "SENSE:MSS:MSID:TYPE?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /* 097 */   , "SENSE:MSS:MSID:NUMBER?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /* 098 */   , "SENSE:MSS:ESN?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /* 099 */   , "SENSE:MSS:PCLASS?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /* 100 */   , "SENSE:MSS:DTX?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /* 101 */   , "SENSE:MSS:BANDWIDTH?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /* 102 */   , "SENSE:MSS:PVER?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /* 103 */   , "SENSE:MSS:DNUMBER?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /* 104 */   , "SENSE:MSS:VCODER?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /* 105 */   , "SENS:RXQ:MAHO:CQU:BER?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /* 106 */   , "SENS:RXQ:MAHO:CQU:RSSI?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /* 107 */   , "INIT:WPOW",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /* 108 */   , "ABOR:WPOW",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /* 109 */   , "STOP:WPOW",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /* 110 */   , "CONT:WPOW",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /* 111 */   , "FETCH:WPOW:STAT?",  
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /* 112 */   , "FETCH:WPOW:RES?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /* 113 */   , "CONF:WPOW:CONT:REP %s, %s, %s",
                   NULL,
                   NULL,
                   NULL,
                   &SignalRep,
                   NULL
  /* 114 */   , "CONF:BSS:SPEECH %s",
                   NULL,
                   NULL,
                   NULL,
                   &BssSpeech,
                   NULL
  /* 115 */   , "CONF:BSS:VCODER %s",
                   NULL,
                   NULL,
                   NULL,
                   &BssVoice,
                   NULL
  /* 116 */   , "CONF:BSS:DCCH:CHANNEL %d",
                   NULL,
                   NULL,
                   NULL,
                   &ChanCCH,
                   NULL
  /* 117 */   , "CONF:BSS:DCCH:SLOT %s",
                   NULL,
                   NULL,
                   NULL,
                   &SlotConfigCCH,
                   NULL
  /* 118 */   , "CONF:BSS:DCCH:LEV %lf",
                   NULL,
                   NULL,
                   NULL,
                   &LevelCCH,
                   NULL
  /* 119 */   , "CONF:BSS:DTC:CHAN %d",
                   NULL,
                   NULL,
                   NULL,
                   &ChanTCH,
                   NULL
  /* 120 */   , "CONF:BSS:DTC:SLOT %s",
                   NULL,
                   NULL,
                   NULL,
                   &SlotConfigTCH,
                   NULL
  /* 121 */   , "CONF:BSS:DTC:LEV %lf",
                   NULL,
                   NULL,
                   NULL,
                   &LevelTCH,
                   NULL
  /* 122 */   , "CONF:NETW:IDENTITY:SID %d",
                   NULL,
                   NULL,
                   NULL,
                   &NetSID,
                   NULL
  /* 123 */   , "CONF:NETW:IDENTITY:MCC %d",
                   NULL,
                   NULL,
                   NULL,
                   &NetMCC,
                   NULL
  /* 124 */   , "CONF:NETW:SMODE:PUREG %s",
                   NULL,
                   NULL,
                   NULL,
                   &Default,
                   NULL
  /* 125 */   , "CONF:NETW:SMODE:PDREG %s",
                   NULL,
                   NULL,
                   NULL,
                   &Default,
                   NULL
  /* 126 */   , "CONF:NETW:SMODE:SYREG %s",
                   NULL,
                   NULL,
                   NULL,
                   &Default,
                   NULL
  /* 127 */   , "CONF:NETW:SMODE:DEREG %s",
                   NULL,
                   NULL,
                   NULL,
                   &Default,
                   NULL
  /* 128 */   , "CONF:NETW:SMODE:IDTYPE %s",
                   NULL,
                   NULL,
                   NULL,
                   &NetIdType,
                   NULL
  /* JMG 021228 129    , "CONF:POW:%s:LIM:LOW:ENAB %s", */
  /* 129 */   , "CONF:POW:%s:LIM:LOW:AREA1:ENAB %s",                   
                   NULL,           
                   NULL,
                   NULL,       
                   &LimitEnable,       
                   NULL 
  /* 130 */   , "CONF:NETW:SMODE:IDMIN %s",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /* 131 */   , "CONF:NETW:SMODE:IDIMSI %s",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /* 132 */   , "CONF:NETW:REQUEST:SNUMBER %s",
                   NULL,
                   NULL,
                   NULL,
                   &Default,
                   NULL
  /* 133 */   , "CONF:NETW:REQUEST:CAPABILITY %s",
                   NULL,
                   NULL,
                   NULL,
                   &Default,
                   NULL
  /* 134 */   , "CONF:NETW:MS:DCCMAC %d",
                   NULL,
                   NULL,
                   NULL,
                   &NetDCCMAC,
                   NULL
  /* 135 */   , "CONF:NETW:MS:DTCMAC %d",
                   NULL,
                   NULL,
                   NULL,
                   &NetDTCMAC,
                   NULL
  /* 136 */   , "CONF:NETW:MS:DIC %s",
                   NULL,
                   NULL,
                   NULL,
                   &NetDIC,
                   NULL
  /* 137 */   , "CONF:NETW:MS:SUFF %d",
                   NULL,
                   NULL,
                   NULL,
                   &NetSUFF,
                   NULL
  /* 138 */   , "CONF:NETW:MS:RAMIN %d",
                   NULL,
                   NULL,
                   NULL,
                   &NetRAMIN,
                   NULL
  /* 139 */   , "CONF:NETW:MS:SCANINTERVAL %d",
                   NULL,
                   NULL,
                   NULL,
                   &NetScanInt,
                   NULL
  /* 140 */   , "CONF:NETW:MS:DELAY %s",
                   NULL,
                   NULL,
                   NULL,
                   &NetDelay,
                   NULL
  /* 141 */   , "CONF:NETW:MS:SBINDICATOR %s",
                   NULL,
                   NULL,
                   NULL,
                   &SBIndicator,
                   NULL
  /* 142 */   , "CONF:NETW:SYSTEM:NOFSLOTS %d",
                   NULL,
                   NULL,
                   NULL,
                   &NetNumFSlots,
                   NULL
  /* 143 */   , "CONF:NETW:SYSTEM:NOESLOTS %d",
                   NULL,
                   NULL,
                   NULL,
                   &NetNumESlots,
                   NULL
  /* 144 */   , "CONF:NETW:SYSTEM:CCSDVCC %d",
                   NULL,
                   NULL,
                   NULL,
                   &NetCCSDVCC,
                   NULL
  /* 145 */   , "CONF:NETW:TIM:LORLINK %d",
                   NULL,
                   NULL,
                   NULL,
                   &LossLinkTO,
                   NULL
  /* 146 */   , "CONF:NETW:TIM:RPER %d",
                   NULL,
                   NULL,
                   NULL,
                   &RegPeriodTO,
                   NULL
  /* JMG 021228 147    , "CONF:POWER:DQPSK:LIMIT:DEF %s", */
  /* 147 */   , "CONF:POW:%s:LIM:DEF %s",  
                   NULL,           
                   NULL,
                   NULL,       
                   &LimitEnable,       
                   NULL 
  /* 148 */   , "READ:WPOW?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /* 149 */   , "SAMPLE:WPOW?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /* 150 */   , "CONF:NETW:NCD:CELL%d %d",
                   NULL,
                   NULL,
                   NULL,
                   &NetNeighbors,
                   NULL
  /* JMG 030103 151    , "CONF:NETW:NCH:LSOR %s", */
  /* 151 */   , "CONF:RXQ:MAHO:CONT:NCELls:LSOR %s",  
                   NULL,
                   NULL,
                   NULL,
                   &Default,
                   NULL
  /* 152 */   , "SENSE:RXQ:MAHO:NCEL:CELL%d?",
                   NULL,
                   NULL,
                   NULL,
                   &MAHOcell,
                   NULL
  /* 153 */   , "CONF:ARR:SPEC:ACP:TIME:RANGE %lf MHZ %d",
                   NULL,
                   NULL,
                   NULL,
                   &TimeRange,
                   NULL
  /* 154 */   , "CONF:SPEC:CONT:ACH %d",
                   NULL,
                   NULL,
                   NULL,
                   &AdjChannel,
                   NULL
  /* 155 */   , "CONF:NETW:NCD:CELL%d %s",
                   NULL,
                   NULL,
                   NULL,
                   &NetNeighbors,
                   NULL
  /* 156 */   , "FETC:SPEC:STAT?",                                                    
                   NULL,
                   NULL,
                   NULL,       
                   NULL,       
                   NULL
  /* 157 */   , "FETC:RXQ:BER:STAT?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /* 158 */   , "CONF:NETW:SMODE:ID20 %d",
                   NULL,
                   NULL,
                   NULL,
                   &NetID20,
                   NULL
  /* 159 */   , "CONF:NETW:SMODE:ID24 %d",
                   NULL,
                   NULL,
                   NULL,
                   &NetID24,
                   NULL
  /* 160 */   , "INIT:RXQ:BER",  
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /* 161 */   , "ABOR:RXQ:BER",  
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /* 162 */   , "STOP:RXQ:BER",  
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /* 163 */   , "CONF:SPEC:LIM:DEF %s",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,       
                   NULL  
  /* JMG 164 , "RESTART:RXQ:SSHOT", */   
  /* 164 */   , "CONT:RXQ:BER",  
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /* 165 */   , "READ:RXQ:BER?",  
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /* 166 */   , "FETC:RXQ:BER?",  
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /* 167 */   , "SENSE:RXQ:MAHO:NCEL?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /* 168 */   , "CONF:BSS:OCHANDOFF:DTC:CHANNEL %d",
                   NULL,
                   NULL,
                   NULL,
                   &ChanTCH,
                   NULL
  /* 169 */   , "CONF:BSS:OCHANDOFF:DTC:SLOTCONFIG %s",
                   NULL,
                   NULL,
                   NULL,
                   &SlotConfigTCH,
                   NULL
  /* 170 */   , "CONF:BSS:OCHANDOFF:DTC:LEVEL %lf",
                   NULL,
                   NULL,
                   NULL,
                   &LevelTCH,
                   NULL
  /* 171 */   , "CONF:NETW:OCHANDOFF:DTCMAC %d",
                   NULL,
                   NULL,
                   NULL,
                   &NetDTCMAC,
                   NULL
  /*JMG  172    , "CONF:RXQ:BER:CONT:TSET1:LEV %lf;:CONF:RXQ:BER:CONT:TSET1:FRAM %d;:CONF:RXQ:BER:LIM:TSET1:ABIT %lf", */
                , "CONF:RXQ:BER:CONT:TSET%1d:LEV %lf;:CONF:RXQ:BER:CONT:TSET%1d:FRAM %d;:CONF:RXQ:BER:LIM:TSET%1d:ABIT %lf",
                   NULL,
                   NULL,
                   NULL,
                   &ConfBER,
                   NULL
  /* 173 */   , "CONF:POW:LIM:LOW:AREA %lf, %s",                    
                   NULL,           
                   NULL,
                   NULL,       
                   &LowLimitLine,       
                   NULL 
  /* 174 */   , "CONF:POW:LIM:LOW:ENAB %s",                 
                   NULL,           
                   NULL,
                   NULL,       
                   &LimitEnable,       
                   NULL 
  /* 175 */   , "CONF:POW:LIM:DEF %s",                 
                   NULL,           
                   NULL,
                   NULL,       
                   &LimitEnable,       
                   NULL 
  /* 176 */   , "CONF:SPEC:LIM:DEF %s",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,       
                   NULL                    
  /* 177 */   , "CONF:NETW:IDENTITY:SOC %d",
                   NULL,
                   NULL,
                   NULL,
                   &NetSOC,
                   NULL
  /* 178 */   , "CALC:SPEC:MATC:LIM?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /* 179 */   , "SENSE:MSS:ACAP?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /* 180 */   , "CONF:NETW:TIM:RPER OFF",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /*JMG 181 */ ,"CONF:NPOW:EPOW %lf",  
                   NULL,
                   NULL,
                   NULL,
                   &ExpectedPow,
                   NULL
  /*JMG 182 */ ,"CONF:NPOW:CONT:STAT %d;:CONF:NPOW:CONT:REP %s, %s, %s",  
                   NULL,
                   NULL,
                   NULL,
                   &NPowCont,
                   NULL       
  /*JMG 183 */, "CONF:NPOW:CONT:STAT %d",  
                   NULL,
                   NULL,
                   NULL,
                   &NPowStat,
                   NULL    
  /*JMG 184 */, "CONF:NPOW:CONT:REP %s, %s, %s",  
                   NULL,
                   NULL,
                   NULL,
                   &NPowRep,
                   NULL 
  /*JMG 185 */  ,"INIT:NPOW",                                                      
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL
  /*JMG 186 */  ,"ABOR:NPOW",                                                         
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL
  /*JMG 187 */  ,"STOP:NPOW",                                                         
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL
  /*JMG 188 */  ,"CONT:NPOW",                                                      
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL
  /*JMG 189 */  ,"FETC:NPOW:STAT?",                                                 
                   NULL,
                   NULL,
                   NULL,       
                   NULL,       
                   NULL
  /*JMG 190 */ ,"CONF:NPOW:EREP %s",  
                   NULL,
                   NULL,
                   NULL,
                   &NPowEvtReport,
                   NULL 
  /*JMG 191 */  ,"READ:NPOW?",                                                         
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL 
  /*JMG 192 */  ,"FETC:NPOW?",                                                            
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL 
  /*JMG 193 */  ,"SAMP:NPOW?",                                                             
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL 

  /*JMG 194 */  ,"ROUT:SPEN %s",                                                             
                   NULL,           
                   NULL,
                   NULL,       
                   &InputCodec,       
                   NULL 
                   
  /*JMG 195 */  ,"ROUT:SPD %s",                                                             
                   NULL,           
                   NULL,
                   NULL,       
                   &OutputCodec,       
                   NULL 
  /*JMG 196 */  ,"SYST:RES:CURR",                                                             
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL 
  // JMG 021217                 
  /*JMG 197 */  ,"CONF:RXQ:BER:TSET T%1d",                                                             
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL 

  /*JMG 198 */ ,"CONF:RXQ:BER:CONT:TSET%1d:REP %s, %s, %s",  
                   NULL,
                   NULL,
                   NULL,
                   &BERCont,
                   NULL       
  /*JMG 199 */ , "CONF:POW:%s:CONT:DEF %s",
                   NULL,
                   NULL,
                   NULL,
                   &PowDef,
                   NULL

  /*JMG 200 */ , "CONF:RXQ:BER:LIM:DEF %s",
                   NULL,
                   NULL,
                   NULL,
                   &Default,
                   NULL
  /*JMG 201 */ , "CALC:RXQ:BER:MATC?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /*JMG 202 */  , "CONF:RXQ:BER:EREP %s",                                  
                   NULL,           
                   NULL,
                   NULL,       
                   &SpecEvtReport,       
                   NULL 
  /*JMG 203 */  , "CONF:WPOW:EREP %s",                                  
                   NULL,           
                   NULL,
                   NULL,       
                   &SpecEvtReport,       
                   NULL 
  /*JMG 204 */  , "STAT:OPER:SYMB:ENAB %s",                                  
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL 
  /*JMG 205 */  , "STAT:OPER:SYMB?",                                  
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL 
  /*JMG 206 */   , "CONF:SUB:MOD:%s %s,%d,%d",
                   NULL,           
                   NULL,
                   NULL,       
                   &confArrMode,       
                   NULL 
  /*JMG 207 */   , "FETC:%s:SPEC:TDOM:%s?",  
                   NULL,
                   NULL,
                   NULL,
                   &ReadSpec,
                   NULL
  /*JMG 208 */   , "SAMP:%s:SPEC:TDOM:%s?",  
                   NULL,
                   NULL,
                   NULL,
                   &ReadSpec,
                   NULL
  /*JMG 209 */   , "CONF:RXQ:%s:CONT:DEF %s",  
                   NULL,
                   NULL,
                   NULL,
                   &mahoDef,
                   NULL
  /*JMG 210 */   , "CONF:RXQ:%s:CONT:NCEL:LSOR %s",  
                   NULL,
                   NULL,
                   NULL,
                   &mahoDef,
                   NULL
  /*JMG 211 */   , "CONF:RXQ:EMAHO:CONT:RSEL %s",  
                   NULL,
                   NULL,
                   NULL,
                   &emahoMMode,
                   NULL

  /*JMG 212 */   , "CONF:RXQ:CONT:%s:NCEL:CELL%d %s,%s",  
                   NULL,
                   NULL,
                   NULL,
                   &mahoconf,
                   NULL
  /*JMG 213 */   , "RXQ:EMAHO:CQU:RSSI?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /*JMG 214 */   , "RXQ:EMAHO:CQU:BER?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /*JMG 215 */   , "RXQ:EMAHO:CQU:CIR?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /*JMG 216 */   , "RXQ:EMAHO:CQU:WER?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /*JMG 217 */   , "RXQ:EMAHO:NCEL?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /*JMG 218 */   , "RXQ:EMAHO:NCEL:CELL%d?",
                   NULL,
                   NULL,
                   NULL,
                   &EMAHOcell,
                   NULL
  /* 219 */     , "CONF:NETW:IDEN:ASID %s",
                   NULL,
                   NULL,
                   NULL,
                   &Default,
                   NULL
};                       

static ViInt16 NUM_CMDS = ( sizeof( IS136 ) / sizeof( COMMAND_INFO ) );


/**************************************************************************
 *
 * NAME:        RSCMU_Init_TDMA
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC
   RSCMU_Init_TDMA( ViSession  instrSessionBase
                  , ViSession *instrSessionTDMA
                  , ViInt32    TDMAFunctionGroup
                  , ViChar     errorMessage[]
                  )
{
   ViStatus    RSCMU_Status      = VI_SUCCESS;  
   ViSession   globalSession     = 0;
   ViInt32     secondAddr        = RSCMU_SECONDARY_ADDRESS_INVALID;
   ViInt32     comp              = 1; 
   ViInt32     firstFreeSecAddr  = RSCMU_SECONDARY_ADDRESS_INVALID;
   ViChar      FctGrpBuffer[128] = "";
   ViChar      resource[25]      = "";
   ViBoolean   Flag              = RSCMU_OFF;
   ViSession   DefaultRM;
  
   struct RSCMU_Base_Globals  *p_globalvarBase;
   struct RSCMU_TDMA_Globals  *p_globalvarTDMA;

   // Get a copy of the global data for this session.
   if( (RSCMU_Status = viGetAttribute( instrSessionBase
                                     , VI_ATTR_USER_DATA
                                     , (ViAddr)&p_globalvarBase
                                     )) < 0 )
   {
      return RSCMU_errorMessage( instrSessionBase, RSCMU_Status, errorMessage );
   }
   DefaultRM = p_globalvarBase->RSCMU_tGlobal.RSCMU_RmSessionDefault;

   // Verift that the VISA Resource Manager has been opened.
   if( DefaultRM != 0 )
   {
      // Which Function Group does the User want?
      switch( TDMAFunctionGroup )
      {
      case RSCMU_IS136800MS_NSIG:
         // Record "Function Group Name" for the actual Session.
         strcpy( FctGrpBuffer, "\"IS136800MS_NSig\"" );
         break;

      case RSCMU_IS1361900MS_NSIG:
         // Record "Function Group Name" for the actual Session.
         strcpy( FctGrpBuffer, "\"IS1361900MS_NSig\"" );
         break;

      case RSCMU_IS136800MS_SIG:
         // Record "Function Group Name" for the actual Session.
         strcpy( FctGrpBuffer, "\"IS136800MS_Sig\"" );
         break;

      case RSCMU_IS1361900MS_SIG:
         // Record "Function Group Name" for the actual Session.
         strcpy( FctGrpBuffer, "\"IS1361900MS_Sig\"" );
         break;

      default:
         break;
      }

      // Init the Error Message  
      strcpy( errorMessage, "No Error" );
      
      // Find the Secondary address
      while ((comp != 0) && (secondAddr <= RSCMU_SECONDARY_ADDRESS_MAX))
      {
         secondAddr++;
         comp = strncmp( p_globalvarBase->RSCMU_tSecAddr[secondAddr].FctGrp
                       , FctGrpBuffer
                       , strlen(FctGrpBuffer)
                       );

         if( comp == 0 ) 
         {
            Flag = RSCMU_ON;
         }   
         else
         {
            ViInt32 comp1;
            comp1 = strncmp (p_globalvarBase->RSCMU_tSecAddr[secondAddr].FctGrp, "NONE", 4);  
            if( (comp1 == 0) && 
                (firstFreeSecAddr == RSCMU_SECONDARY_ADDRESS_INVALID)
              )
            {
               firstFreeSecAddr = secondAddr;
            }  
         }
      }

      if( Flag == RSCMU_OFF )
      {
         if( (RSCMU_Status = RSCMU_Base_SystRemAddrSec( instrSessionBase, firstFreeSecAddr, TDMAFunctionGroup, errorMessage)) < 0 )
         {
            return RSCMU_Base_errorMessage (instrSessionBase, RSCMU_ERROR_INVALID_FCT_GRP, errorMessage);
         }
         Flag = RSCMU_ON;     
         secondAddr = firstFreeSecAddr;
      }

      // Hardware Connection
      if( strncmp( "GPIB"
                 , p_globalvarBase->RSCMU_tGlobal.RSCMU_SCPIConnection
                 , 4
                 ) == 0 )
      {
          sprintf (resource, "%s::%d::%d::INSTR",p_globalvarBase->RSCMU_tGlobal.RSCMU_SCPIConnection, p_globalvarBase->RSCMU_tGlobal.RSCMU_primary_address, secondAddr);
      }
      else
      {
          sprintf (resource, "%s::INSTR",p_globalvarBase->RSCMU_tGlobal.RSCMU_SCPIConnection);
      }
      
      // Open instrument session 
      if( (RSCMU_Status = viOpen( DefaultRM
                                , resource
                                , VI_NULL
                                , RSCMU_TMO_VALUE
                                , instrSessionTDMA
                                )) < 0 )
      {
         if( (RSCMU_Status = viClose( DefaultRM )) < 0 )
         {
            return( RSCMU_Status );
         }
      }

      // Allocate space for "struct RSCMU_SESSION_Globals" 
      if( (p_globalvarTDMA =
            (struct RSCMU_TDMA_Globals *)
            malloc(sizeof(struct RSCMU_TDMA_Globals))) == 0 )
      {
         return RSCMU_initCleanUp( DefaultRM
                                 , *instrSessionTDMA
                                 , RSCMU_Status
                                 );
      }
       
      if( (RSCMU_Status = viSetAttribute( *instrSessionTDMA
                                        , VI_ATTR_USER_DATA
                                        , (ViAttrState)p_globalvarTDMA
                                        )) < 0 )
      {
         return RSCMU_initCleanUp( DefaultRM
                                 , *instrSessionTDMA
                                 , RSCMU_Status
                                 );
      }

      // Which Function Group does the User want?
      switch( TDMAFunctionGroup )
      {
      case RSCMU_IS136800MS_SIG:
         // Record the "HandOverName" for the actual Session.
         strcpy( p_globalvarTDMA->RSCMU_tHandOver.HandOverSessionName, "\"IS136800MS\"" );
         break;

      case RSCMU_IS1361900MS_SIG:
         // Record the "HandOverName" for the actual Session.
         strcpy( p_globalvarTDMA->RSCMU_tHandOver.HandOverSessionName, "\"IS1361900MS\"" );
         break;

      case RSCMU_IS136800MS_NSIG:
      case RSCMU_IS1361900MS_NSIG:
      default:
         break;
      }

      // Set initial values of variables for function Group 'TDMA' .    
      strcpy( p_globalvarTDMA->RSCMU_tGlobal.FGrp_Name, FctGrpBuffer );
      strcpy( p_globalvarTDMA->RSCMU_tGlobal.RSCMU_SCPIConnection, p_globalvarBase->RSCMU_tGlobal.RSCMU_SCPIConnection);
      
      p_globalvarTDMA->RSCMU_tGlobal.RSCMU_primary_address      = p_globalvarBase->RSCMU_tGlobal.RSCMU_primary_address;

      p_globalvarTDMA->RSCMU_tGlobal.RSCMU_secondary_address    =  secondAddr;

      p_globalvarTDMA->RSCMU_tGlobal.RSCMU_SessionNb            = *instrSessionTDMA;

//JMG 021224
      // Copy CMU FW
      p_globalvarTDMA->RSCMU_tGlobal.RSCMU_FW_Version           = p_globalvarBase->RSCMU_tGlobal.RSCMU_FW_Version;
      strcpy (p_globalvarTDMA->RSCMU_tGlobal.CmuVersion, p_globalvarBase->RSCMU_tGlobal.CmuVersion);
      
      p_globalvarTDMA->RSCMU_tGlobal.RSCMU_Type                 = p_globalvarBase->RSCMU_tGlobal.RSCMU_Type;

//JMG 030107      
      strcpy (p_globalvarTDMA->RSCMU_tGlobal.DrvVersion, RSCMUK2T_REVISION);
      
      p_globalvarTDMA->RSCMU_tGlobal.RSCMU_TRACE = 
         p_globalvarBase->RSCMU_tGlobal.RSCMU_TRACE;
   
      // If the RSCMU_Trace_ON has already been executed, record the 
      // characteristics of the trace file, then the base can trace what's 
      // happening on the secondary address initialized in THIS function.
      // NOTE:
      // This was not the case before: we were obliged to set the trace 
      // to ON after, and only after initialization of All the secondary 
      // addresses we want to trace.
      p_globalvarTDMA->RSCMU_tGlobal.RSCMU_FileHandle        =
         p_globalvarBase->RSCMU_tGlobal.RSCMU_FileHandle;
      
      p_globalvarTDMA->RSCMU_tGlobal.RSCMU_AddrTargetFile    =
         (ViAddr)p_globalvarBase->RSCMU_tGlobal.RSCMU_AddrTargetFile;
      
      p_globalvarTDMA->RSCMU_tGlobal.RSCMU_StateTraceFile    =
         p_globalvarBase->RSCMU_tGlobal.RSCMU_StateTraceFile;
      
      // Record the execution of this Init Function.    
      p_globalvarBase->RSCMU_tSecAddr[secondAddr].SessionNb = 
         *instrSessionTDMA;  
  
      // Timeout set to Basic value
      RSCMU_Status = viSetAttribute( *instrSessionTDMA
                                   , VI_ATTR_TMO_VALUE
                                   , RSCMU_TMO_VALUE
                                   );
   }
   else
   {
      RSCMU_Status = -1;
   }
   
   return( RSCMU_Status );

} // endof RSCMU_Init_TDMA()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_SenseLevDefault
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
// JMG 030106
ViStatus _VI_FUNC
   RSCMU_TDMA_SenseLevDefault( ViSession instrSession
                             , ViBoolean state
                             , ViChar    errorMessage[]
                             )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   if (state == RSCMU_OFF)
   {
   
        RSCMU_Status    = RSCMU_errorMessage( instrSession, RSCMU_IS136_WARNING_GPIB_FEATURE, errorMessage );
        return( RSCMU_Status);
   }

   checkRange( 0, &state );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[0].instrCommand
          , enable.list[state]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_SenseLevDefault()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_SenseLevMode
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC
   RSCMU_TDMA_SenseLevMode( ViSession instrSession
                          , ViInt32   inputLevelSetting
                          , ViChar    errorMessage[]
                          )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 1, &inputLevelSetting );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[1].instrCommand
          , mode.list[inputLevelSetting]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_SenseLevMode()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_SenseLevMax
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC
   RSCMU_TDMA_SenseLevMax( ViSession instrSession
                         , ViReal64  inputLevelMaximumdBm
                         , ViChar    errorMessage[]
                         )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 2, &inputLevelMaximumdBm );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[2].instrCommand
          , inputLevelMaximumdBm
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_SenseLevMax()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_SenseLevAtt
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC
   RSCMU_TDMA_SenseLevAtt( ViSession instrSession
                         , ViInt32   inputLevelAttenuation
                         , ViChar    errorMessage[]
                         )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 3, &inputLevelAttenuation );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[3].instrCommand
          , attenuation.list[inputLevelAttenuation]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_SenseLevAtt()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_TrigSeqDefault
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
// JMG 030106
ViStatus _VI_FUNC
   RSCMU_TDMA_TrigSeqDefault( ViSession instrSession
                            , ViBoolean state
                            , ViChar    errorMessage[]
                            )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   if (state == RSCMU_OFF)
   {
   
        RSCMU_Status    = RSCMU_errorMessage( instrSession, RSCMU_IS136_WARNING_GPIB_FEATURE, errorMessage );
        return( RSCMU_Status);
   }
   
   checkRange( 4, &state );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[4].instrCommand
          , enable.list[state]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_TrigSeqDefault()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_TrigSeqSource
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC
   RSCMU_TDMA_TrigSeqSource( ViSession instrSession
                           , ViInt32   triggerMode
                           , ViChar    errorMessage[]
                           )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 5, &triggerMode );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[5].instrCommand
          , trigSrc.list[triggerMode]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_TrigSeqSource()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_TrigSeqThreshold
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC
   RSCMU_TDMA_TrigSeqThreshold( ViSession instrSession
                              , ViInt32   triggerThreshold
                              , ViChar    errorMessage[]
                              )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 6, &triggerThreshold );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[6].instrCommand
          , threshold.list[triggerThreshold]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_TrigSeqThreshold()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_SenseRfanFreq
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_SenseRfanFreq( ViSession instrSession
                           , ViReal64  frequency
                           , ViInt32   units
                           , ViChar    errorMessage[]
                           )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   // Convert frequency to MHZ prior to range checking.
   switch( units )
   {
   case RSCMU_HZ:
      frequency /= 1000000;
      break;
      
   case RSCMU_KHZ:
      frequency /= 1000;
      break;
      
   case RSCMU_MHZ:
      // range check units are MHZ
      break;
      
   case RSCMU_GHZ:
      frequency *= 1000;
      break;
      
   default:
      break;
      
   }
   
   // checkRange routine is not used due to bug in how unions are
   // handled when initializing float types.
   if( frequency < 0.2 )  frequency = 0.2;
   if( frequency > 2700 ) frequency = 2700;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[7].instrCommand
          , frequency
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_SenseRfanFreq()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_SenseRfanChan
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_SenseRfanChan( ViSession instrSession
                           , ViInt32   channel
                           , ViChar    errorMessage[]
                           )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 8, &channel );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[8].instrCommand
          , channel
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_SenseRfanChan()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_SenseRfanFreqOffset
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_SenseRfanFreqOffset( ViSession instrSession
                                 , ViReal64  frequencyOffsetkHz
                                 , ViChar    errorMessage[]
                                 )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 9, &frequencyOffsetkHz );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[9].instrCommand
          , frequencyOffsetkHz
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_SenseRfanFreqOffset()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_SenseRfanEMsSync
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_SenseRfanEMsSync( ViSession instrSession
                              , ViInt32   syncSequence
                              , ViChar    errorMessage[]
                              )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 10, &syncSequence );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[10].instrCommand
          , expectedSync.list[syncSequence]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_SenseRfanEMsSync()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_InitRfGenerator
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_InitRfGenerator( ViSession instrSession
                             , ViChar    errorMessage[]
                             )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[11].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_InitRfGenerator()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_AbortRfGenerator
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_AbortRfGenerator( ViSession instrSession
                              , ViChar    errorMessage[]
                              )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[12].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   return( RSCMU_Status );

} // endof RSCMU_TDMA_AbortRfGenerator()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_FetchRfGeneratorStatus
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_FetchRfGeneratorStatus( ViSession  instrSession
                                    , ViInt32   *generatorStatus
                                    , ViChar     errorMessage[]
                                    )
{
   ViStatus RSCMU_Status = VI_SUCCESS;
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
  
   // Fetch the generator status:
   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[13].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   if( RSCMU_Status >= 0 )
   {
      // Get the generator status:
      if( strncmp( "OFF", rdBuf, 3 ) == 0 ) 
      {
         *generatorStatus = RSCMU_GEN_STAT_OFF;
      }
      else if( strncmp( "RUN", rdBuf, 3 ) == 0 )
      {
         *generatorStatus = RSCMU_GEN_STAT_RUN;
      }
      else if( strncmp( "ERR", rdBuf, 3 ) == 0 )
      {
         *generatorStatus = RSCMU_GEN_STAT_ERR;
      }
   }

   return( RSCMU_Status );

} // endof RSCMU_TDMA_FetchRfGeneratorStatus()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_SourceRfGLevRfl
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_SourceRfGLevRfl( ViSession instrSession
                             , ViReal64  inputLevelMaximumdBm
                             , ViChar    errorMessage[]
                             )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 14, &inputLevelMaximumdBm );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[14].instrCommand
          , inputLevelMaximumdBm
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_SourceRfGLevRfl()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_SenseRfGFreq
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_SenseRfGFreq( ViSession instrSession
                          , ViReal64  frequency
                          , ViInt32   units
                          , ViChar    errorMessage[]
                          )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   // Convert frequency to MHZ prior to range checking.
   switch( units )
   {
   case RSCMU_HZ:
      frequency /= 1000000;
      break;
      
   case RSCMU_KHZ:
      frequency /= 1000;
      break;
      
   case RSCMU_MHZ:
      // range check units are MHZ
      break;
      
   case RSCMU_GHZ:
      frequency *= 1000;
      break;
      
   default:
      break;
      
   }

   // checkRange routine is not used due to bug in how unions are
   // handled when initializing float types.
   if( frequency < 0.2 )  frequency = 0.2;
   if( frequency > 2700 ) frequency = 2700;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[15].instrCommand
          , frequency
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_SenseRfGFreq()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_SenseRfanChan
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_SenseRfGChan( ViSession instrSession
                          , ViInt32   channel
                          , ViChar    errorMessage[]
                          )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 16, &channel );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[16].instrCommand
          , channel
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_SenseRfGChan()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_SenseRfGFreqOffset
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_SenseRfGFreqOffset( ViSession instrSession
                                , ViReal64  frequencyOffsetkHz
                                , ViChar    errorMessage[]
                                )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 17, &frequencyOffsetkHz );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[17].instrCommand
          , frequencyOffsetkHz
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_SenseRfGFreqOffset()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_SourceRfGModRfsType
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_SourceRfGModRfsType( ViSession instrSession
                                 , ViInt32   modulationType
                                 , ViChar    errorMessage[]
                                 )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 18, &modulationType );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[18].instrCommand
          , modType.list[modulationType]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_SourceRfGModRfsType()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_InpState
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_InpState( ViSession instrSession
                      , ViInt32   selectionOfInputConnector
                      , ViChar    errorMessage[]
                      )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 19, &selectionOfInputConnector );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[19].instrCommand
          , inpConn.list[selectionOfInputConnector]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_InpState()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_OutpState
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_OutpState( ViSession instrSession
                      , ViInt32   selectionOfOutputConnector
                      , ViChar    errorMessage[]
                      )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 20, &selectionOfOutputConnector );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[20].instrCommand
          , outpConn.list[selectionOfOutputConnector]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_OutpState()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_SenseCorrLossInp
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_SenseCorrLossInp( ViSession instrSession
                              , ViInt32   selectionOfInputConnector
                              , ViReal64  externalAttenuationdB
                              , ViChar    errorMessage[]
                              )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 21, &selectionOfInputConnector, &externalAttenuationdB );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[21].instrCommand
          , inpSrc.list[selectionOfInputConnector]
          , externalAttenuationdB
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_SenseCorrLossInp()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_SourceCorrLossInp
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_SourceCorrLossInp( ViSession instrSession
                               , ViInt32   selectionOfInputConnector
                               , ViReal64  externalAttenuationdB
                               , ViChar    errorMessage[]
                               )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 22, &selectionOfInputConnector, &externalAttenuationdB );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[22].instrCommand
          , inpSrc.list[selectionOfInputConnector]
          , externalAttenuationdB
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_SourceCorrLossInp()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_SenseCorrLossOutp
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_SenseCorrLossOutp( ViSession instrSession
                               , ViInt32   selectionOfOutputConnector
                               , ViReal64  externalAttenuationdB
                               , ViChar    errorMessage[]
                               )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 23, &selectionOfOutputConnector, &externalAttenuationdB );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[23].instrCommand
          , outpSrc.list[selectionOfOutputConnector]
          , externalAttenuationdB
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_SenseCorrLossOutp()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_SourceCorrLossOutp
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_SourceCorrLossOutp( ViSession instrSession
                                , ViInt32   selectionOfOutputConnector
                                , ViReal64  externalAttenuationdB
                                , ViChar    errorMessage[]
                                )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 24, &selectionOfOutputConnector, &externalAttenuationdB );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[24].instrCommand
          , outpSrc.list[selectionOfOutputConnector]
          , externalAttenuationdB
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_SourceCorrLossOutp()

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_CorrLossInpOutp
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_TDMA_CorrLossInpOutp (ViSession instrumentHandle,
                                              ViInt32 selection_ofOutputConnector,
                                              ViReal64 outputAttenuation_dB,
                                              ViInt32 selection_ofInputConnector,
                                              ViReal64 inputAttenuation_dB,
                                              ViChar errorMessage[])
{
   ViStatus  RSCMU_Status   = VI_SUCCESS; 
   ViChar    Format[80]     = "\0"; // JMG {NULL};
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   
   checkRange( 24,  &selection_ofOutputConnector,   &outputAttenuation_dB );
   checkRange( 21,  &selection_ofInputConnector,    &inputAttenuation_dB );
   
   getBuffers( instrumentHandle
                 , &wrtBuf
                 , &rdBuf
                 , errorMessage
                 );
                                 
   strcpy(Format,IS136[24].instrCommand );
   strcat(Format,";:\0");
   strcat(Format,IS136[21].instrCommand);
   strcat(Format,"\0");
   
   sprintf( wrtBuf
                  , Format
                  , outpSrc.list[selection_ofOutputConnector]
                  , outputAttenuation_dB
                  , inpSrc.list[selection_ofInputConnector]
                  , inputAttenuation_dB
                  
                  );

   
     
   
   RSCMU_Status = RSCMU_Query( instrumentHandle
                 , wrtBuf
                 , rdBuf
                 , RSCMU_STB_ON
                 , errorMessage
                 );

   return( RSCMU_Status );

    
}  // endof RSCMU_TDMA_CorrLossInpOutp()

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_RoutSpenInp
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_TDMA_RoutSpenInp (ViSession instrumentHandle,
                                          ViInt32 speechEncoder,
                                          ViChar errorMessage[])
{

   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    
   
   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
       return RSCMU_Status;                                        

   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_05, errorMessage); 
       
   checkRange( 194, &speechEncoder );
   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[194].instrCommand
          , inpSpeCod.list[speechEncoder]
          );

   RSCMU_Status = RSCMU_Query( instrumentHandle
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );


    
}

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_RoutSpdOutp
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_TDMA_RoutSpdOutp (ViSession instrumentHandle,
                                          ViInt32 speechDecoder,
                                          ViChar errorMessage[])
{

   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    
   
   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
       return RSCMU_Status;                                        

   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_05, errorMessage); 


  checkRange( 195, &speechDecoder );
   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[195].instrCommand
          , outSpeDecod.list[speechDecoder]
          );

   RSCMU_Status = RSCMU_Query( instrumentHandle
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );


}

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_SourceDmClockState
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_SourceDmClockState( ViSession instrSession
                                , ViBoolean referenceFreqAtREFOUT2
                                , ViChar    errorMessage[]
                                )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 25, &referenceFreqAtREFOUT2 );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[25].instrCommand
          , enable.list[referenceFreqAtREFOUT2]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_SourceDmClockState()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_SourceDmClockFreq
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_SourceDmClockFreq( ViSession instrSession
                               , ViInt32   referenceFrequencyMHz
                               , ViChar    errorMessage[]
                               )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 26, &referenceFrequencyMHz );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[26].instrCommand
          , ClkFreqMHz.list[referenceFrequencyMHz]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_SourceDmClockFreq()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_CalcSpecLimitMatch
 *
 * DESCRIPTION: NONE
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_CalcSpecLimitMatch( ViSession instrSession
                                , ViInt32   ACPeakPower[]
                                , ViInt32   ACRMSPower[]
                                , ViInt32   ACPeakPowerPeak[]
                                , ViInt32   ACPeakPowerRMS[]
                                , ViInt32   ACAveragePowerRMS[]
                                , ViChar    errorMessage[]
                                )
{
   ViStatus   RSCMU_Status = VI_SUCCESS;  
   ViChar    *wrtBuf;
   ViChar    *rdBuf;
   ViInt32   NumOfMeasValues;
   ViChar     TempBuf[669][20];  

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[178].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   NumOfMeasValues = RSCMU_scanStringBurst( rdBuf, TempBuf );
   RSCMU_ReturnACPLimits( TempBuf
                        , &ACPeakPower[0]
                        , &ACRMSPower[0]
                        , &ACPeakPowerPeak[0]
                        , &ACPeakPowerRMS[0]
                        , &ACAveragePowerRMS[0]
                        );
                        
   return( RSCMU_Status );

} // endof RSCMU_TDMA_CalcSpecLimitMatch()

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfBERContRep
 *
 * DESCRIPTION: NONE   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_TDMA_ConfBERContRep (ViSession  instrumentHandle,
                                             ViInt32    tset, 
                                             ViInt32    rep,
                                             ViInt32    stopCondition,
                                             ViInt32    step,
                                             ViChar     errorMessage[])
{

    
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        

   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_05, errorMessage); 

   checkRange( 198, &tset, &rep, &stopCondition, &step);
   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[198].instrCommand
          , tset
          , repetition.list[rep]
          , stopCond.list[stopCondition]
          , stepMode.list[step]
          );

   RSCMU_Status = RSCMU_Query( instrumentHandle
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

    
    
}  // end of RSCMU_TDMA_ConfBERContRep

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfBER
 *
 * DESCRIPTION: NONE   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfBER( ViSession instrSession
                     , ViReal64  RFGeneratorLevel
                     , ViInt32   numFramesTransmitted
                     , ViReal64  limit
                     , ViChar    errorMessage[]
                     )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViInt32  tset = 1;
   
   checkRange( 172, &tset, &RFGeneratorLevel, &numFramesTransmitted, &limit );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[172].instrCommand
          , tset
          , RFGeneratorLevel
          , tset
          , numFramesTransmitted
          , tset
          , limit
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfBER()

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfBER_Ex
 *
 * DESCRIPTION: NONE   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_TDMA_ConfBER_Ex (ViSession  instrSession,
                                         ViInt32    tset,
                                         ViReal64   RFGeneratorLevel,
                                         ViInt32    numFramesTransmitted,
                                         ViReal64   limit,
                                         ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    
   
   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
       return RSCMU_Status;                                        

   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
       return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage); 
   
   checkRange( 172, &tset, &RFGeneratorLevel, &numFramesTransmitted, &limit );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[172].instrCommand
          , tset
          , RFGeneratorLevel
          , tset
          , numFramesTransmitted
          , tset
          , limit
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   

   return( RSCMU_Status );
    
} // end of RSCMU_TDMA_ConfBER_Ex

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfBERContLimDefault
 *
 * DESCRIPTION: NONE   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
// JMG 030106
ViStatus _VI_FUNC RSCMU_TDMA_ConfBERContLimDefault (ViSession   instrSession,
                                                    ViBoolean   state,
                                                    ViChar      errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    
   
   if (state == RSCMU_OFF)
   {
   
        RSCMU_Status    = RSCMU_errorMessage( instrSession, RSCMU_IS136_WARNING_GPIB_FEATURE, errorMessage );
        return( RSCMU_Status);
   }

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
       return RSCMU_Status;                                        

   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
       return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage); 


   checkRange( 200, &state );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[200].instrCommand
          , enable.list[state]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} // end of RSCMU_TDMA_ConfBERContLimDefault

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_InitBER
 *
 * DESCRIPTION: NONE   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_InitBER( ViSession instrSession
                     , ViChar    errorMessage[]
                     )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[160].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_InitBER()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_AbortBER
 *
 * DESCRIPTION: NONE   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_AbortBER( ViSession instrSession
                      , ViChar    errorMessage[]
                      )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[161].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   return( RSCMU_Status );

} // endof RSCMU_TDMA_AbortBER()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_StopBER
 *
 * DESCRIPTION: NONE   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_StopBER( ViSession instrSession
                     , ViChar    errorMessage[]
                     )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[162].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   return( RSCMU_Status );

} // endof RSCMU_TDMA_StopBER()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ContinueBER
 *
 * DESCRIPTION: NONE   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ContinueBER( ViSession instrSession
                         , ViChar    errorMessage[]
                         )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[164].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   return( RSCMU_Status );

} // endof RSCMU_TDMA_ContinueBER()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_FetchBERStatus
 *
 * DESCRIPTION: NONE   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_FetchBERStatus( ViSession  instrSession
                            , ViInt32   *measurementStatus
                            , ViInt32   *CurrentStatCycleCount
                            , ViInt32   *CurrentEvalPeriodCount
                            , ViChar     errorMessage[]
                            )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;
   ViChar    tab[38][30];    

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[157].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   if( RSCMU_Status >= 0 )
   {
       // Separate the CMU response:
       RSCMU_SeparateString( rdBuf, ",", tab );

       // Get the measurement status
       RSCMU_Status = 
          RSCMU_GetMeasurementStatus( measurementStatus, tab, 0 );

       // Get the counter for current statistics cycle
       if( strcmp( tab[1], "NONE" ) != 0 )
       {
          sscanf( tab[1], "%d", CurrentStatCycleCount );
       }
       else
       {
          *CurrentStatCycleCount = RSCMU_OFF;
       }

       // Get the counter for current evaluation period within a cycle
       if( strcmp( tab[2], "NONE" ) != 0 )
       {
          sscanf( tab[2], "%d", CurrentEvalPeriodCount );
       }
       else
       {
          *CurrentEvalPeriodCount = RSCMU_OFF;
       }
   }

   return( RSCMU_Status );

} // endof RSCMU_TDMA_FetchBERStatus()

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfBERErep
 *
 * DESCRIPTION: NONE   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_TDMA_ConfBERErep (ViSession instrSession,
                                          ViInt32   measurementEventReporting,
                                          ViChar    errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 202, &measurementEventReporting );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[202].instrCommand
          , eventReport.list[measurementEventReporting]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
}  // endof RSCMU_TDMA_ConfBERErep()

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ReadBER
 *
 * DESCRIPTION: NONE   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ReadBER( ViSession    instrSession
                     , BER_RESULTS *BER
                     , ViChar       errorMessage[]
                     )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;
   ViInt32   numMeasValues;
   ViChar   *rdBuf;
   ViChar   *wrtBuf;
   ViChar    TempBuf[669][20];   

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[165].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   numMeasValues = RSCMU_scanStringBurst( rdBuf, TempBuf );
   RSCMU_Status  = RSCMU_ReturnBERResponse( TempBuf, BER );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ReadBER()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_FetchBER
 *
 * DESCRIPTION: NONE   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_FetchBER( ViSession    instrSession
                      , BER_RESULTS *BER
                      , ViChar       errorMessage[]
                      )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;
   ViInt32   numMeasValues;
   ViChar   *rdBuf;
   ViChar   *wrtBuf;
   ViChar    TempBuf[669][20];  

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[166].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   numMeasValues = RSCMU_scanStringBurst( rdBuf, TempBuf );
   RSCMU_Status  = RSCMU_ReturnBERResponse( TempBuf, BER );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_FetchBER()

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_CalcBERLimitMatch
 *
 * DESCRIPTION: This function changes between the different signalling 
 *              states of the CMU.   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_TDMA_CalcBERLimitMatch (ViSession   instrSession,
                                                ViInt32     *BERLimitMatch,
                                                ViChar      errorMessage[])
{
    
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[38][30]; 
   
   // Check if the function is correctly used:               
  // checkRange( 49, &application );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Fetch the Measurement status. 
   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[201].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   
   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   // Extract the CMU response:
   if( strncmp( "PASS", tab[0], 4 ) == 0 )
   {
     *BERLimitMatch = RSCMU_MATCH_MATC;
   }
   else if( strncmp( "FAILT", tab[0], 4 ) == 0 )  
   {
      *BERLimitMatch = RSCMU_MATCH_NMAT;
   }
   else if( strncmp( "INV", tab[0], 3 ) == 0 ) 
   {
      *BERLimitMatch = RSCMU_MATCH_INV;  
   }
   else if( strncmp( "OUT", tab[0], 3 ) == 0 ) 
   {
      *BERLimitMatch = RSCMU_MATCH_OUT;  
   }
    else if( strncmp( "NAN", tab[0], 3 ) == 0 ) 
   {
      *BERLimitMatch = RSCMU_NAN_VI_INT32;  
   }

      
   return( RSCMU_Status );


} // endof RSCMU_TDMA_CalcBERLimitMatch()

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfMAHODef
 *
 * DESCRIPTION: This function changes between the different signalling 
 *              states of the CMU.   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
// JMG 0300106
ViStatus _VI_FUNC RSCMU_TDMA_ConfMAHODef (ViSession     instrSession,
                                          ViBoolean     measSelection,
                                          ViBoolean     state,
                                          ViChar        errorMessage[])
{

   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        

   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
       return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage); 
   
   if (state == RSCMU_OFF)
   {
   
        RSCMU_Status    = RSCMU_errorMessage( instrSession, RSCMU_IS136_WARNING_GPIB_FEATURE, errorMessage );
        return( RSCMU_Status);
   }
   
   checkRange( 209, &measSelection, &state );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[209].instrCommand
          , mahosel.list[measSelection]
          , enable.list[state]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );


}

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfMAHOChanSort
 *
 * DESCRIPTION: This function changes between the different signalling 
 *              states of the CMU.   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
// JMG 030106
ViStatus _VI_FUNC RSCMU_TDMA_ConfMAHOChanSort (ViSession    instrSession,
                                               ViBoolean    measSelection,
                                               ViBoolean    state,
                                               ViChar       errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        

   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
       return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage); 
  
   if (state == RSCMU_OFF)
   {
   
        RSCMU_Status    = RSCMU_errorMessage( instrSession, RSCMU_IS136_WARNING_GPIB_FEATURE, errorMessage );
        return( RSCMU_Status);
   }

   checkRange( 210, &measSelection, &state );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[210].instrCommand
          , mahosel.list[measSelection]
          , enable.list[state]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
}

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfEMAHOMeasMode
 *
 * DESCRIPTION:  
 *              
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
// JMG 030106
ViStatus _VI_FUNC RSCMU_TDMA_ConfEMAHOMeasMode (ViSession   instrSession,
                                                ViBoolean   measurementMode,
                                                ViChar      errorMessage[])
{                                                       
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        

   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
       return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage); 
  
   checkRange( 211, &measurementMode );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[211].instrCommand
          , emahoMode.list[measurementMode]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
    
}

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfMAHONeighborChan
 *
 * DESCRIPTION: 
 *                
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
// JMG 030106
ViStatus _VI_FUNC RSCMU_TDMA_ConfMAHONeighborChan (ViSession    instrSession,
                                                   ViBoolean    measSelection,
                                                   ViInt32      neighborChannel,
                                                   ViInt32      hyperband,
                                                   ViInt32      channelNumber,
                                                   ViBoolean    state,
                                                   ViChar       errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar   temp[20] = "\0";
   struct   RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        

   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
       return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage); 
  
   
   checkRange( 212, &measSelection, &hyperband, &neighborChannel, &state , &channelNumber);

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   if (state == RSCMU_OFF)
    strcpy(temp, enable.list[state]);
   else
    sprintf(temp,"%4d", channelNumber);
   
   sprintf( wrtBuf
          , IS136[212].instrCommand
          , mahosel.list[measSelection]
          , neighborChannel
          , band.list[hyperband]
          , temp
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
   
}


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_MAHOCell
 *
 * DESCRIPTION: 
 *                
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_TDMA_MAHOCell (ViSession    instrSession,
                                       ViInt32      channel, 
                                       MAHO         *singleCellMAHO,
                                       ViChar       errorMessage[])
{
   ViStatus   RSCMU_Status = VI_SUCCESS;  
   ViBoolean  match        = RSCMU_FALSE;
   ViInt32    i;
   ViInt32    length;
   ViChar    *rdBuf;
   ViChar    *wrtBuf;
   ViChar    tab[38][30];
   ViReal64   temp;    

   checkRange( 152, &channel );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[152].instrCommand
          , channel
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Read channel.
   sscanf( tab[0], "%lf",   &temp);
   sprintf(tab[0], "%4.0lf",temp);
   sscanf( tab[0], "%4d",   &singleCellMAHO->Channel);

   
   // Search table for a RSSI match.
   length = strlen( tab[1] );
   i      = 0;
   while( *ReportRSSI != NULL )
   {
      if( strncmp( ReportRSSI[i], tab[1], length ) == 0 ) 
      {
         match = RSCMU_TRUE;
         break;
      }
      i++;
   }
   
   // Set return value based on string match.
   if( match )
   {
      if( i == 0 )
      {
         singleCellMAHO->RSSI  = RSCMU_NAN_VI_INT32;
         singleCellMAHO->Level = 0;
      }
      else
      {
         singleCellMAHO->RSSI  = i - 1;
         singleCellMAHO->Level = -113 + (singleCellMAHO->RSSI * 2);
      }
   }
   else
   {
      singleCellMAHO->RSSI  = RSCMU_NAN_VI_INT32;
      singleCellMAHO->Level = 0;
      RSCMU_Status    = RSCMU_ERROR_NAN;
   }
   
   return( RSCMU_Status );    
}

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_MAHONAllCells
 *
 * DESCRIPTION: 
 *              .   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_TDMA_MAHOAllCells (ViSession    instrSession,
                                            MAHO        *allCellsMAHO,
                                            ViChar      errorMessage[])
{

   ViStatus   RSCMU_Status = VI_SUCCESS;  
   ViBoolean  match        = RSCMU_FALSE;
   ViInt32    i;
   ViInt32    j;
   ViInt32    length;
   ViChar    *rdBuf;
   ViChar    *wrtBuf;
   ViChar     TempBuf[669][20];  
   ViReal64   temp; 
   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[167].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   RSCMU_scanStringBurst( rdBuf, TempBuf );
   
   for( i = 0; i < 24; i++ )
   {
      // Read channel.
      sscanf( TempBuf[i*2], "%lf", &temp );
      sprintf( TempBuf[i*2],"%4.0lf",temp );
      sscanf( TempBuf[i*2], "%4d", &allCellsMAHO[i].Channel );

      // Search table for a RSSI match.
      length = strlen( TempBuf[(i*2)+1] );
      j      = 0;
      while( *ReportRSSI != NULL )
      {
         if( strncmp( ReportRSSI[j], TempBuf[(i*2)+1], length ) == 0 ) 
         {
            match = RSCMU_TRUE;
            break;
         }
         j++;
      }
   
      // Set return value based on string match.
      if( match )
      {
         if( j == 0 )
         {
            allCellsMAHO[i].RSSI  = RSCMU_NAN_VI_INT32;
            allCellsMAHO[i].Level = 0;
         }
         else
         {
            allCellsMAHO[i].RSSI  = j - 1;
            allCellsMAHO[i].Level = -113 + ((j - 1) * 2);
         }
      }
      else
      {
         allCellsMAHO[i].RSSI  = RSCMU_NAN_VI_INT32;
         allCellsMAHO[i].Level = 0;
         RSCMU_Status          = RSCMU_ERROR_NAN;
      }
   }
   
   return( RSCMU_Status );
    
}

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_EMAHOAllCells
 *
 * DESCRIPTION: 
 *              .   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_TDMA_EMAHOAllCells (ViSession   instrSession,
                                            EMAHO       *allCellsEMAHO,
                                            ViChar      errorMessage[])
{
   ViStatus   RSCMU_Status = VI_SUCCESS;  
   ViBoolean  match        = RSCMU_FALSE;
   ViInt32    i;
   ViInt32    j;
   ViInt32    length;
   ViChar    *rdBuf;
   ViChar    *wrtBuf;
   ViChar     TempBuf[669][20];  
   ViReal64   temp; 
   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[217].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   RSCMU_scanStringBurst( rdBuf, TempBuf );
   
   for( i = 0; i < 22; i++ )
   {
      // Read channel.
      sscanf( TempBuf[i*2], "%lf", &temp );
      sprintf( TempBuf[i*2],"%4.0lf",temp );
      sscanf( TempBuf[i*2], "%4d", &allCellsEMAHO[i].Channel );

      // Search table for a RSSI match.
      length = strlen( TempBuf[(i*2)+1] );
      j      = 0;
      while( *ReportERSSI != NULL )
      {
         if( strncmp( ReportERSSI[j], TempBuf[(i*2)+1], length ) == 0 ) 
         {
            match = RSCMU_TRUE;
            break;
         }
         j++;
      }
   
      // Set return value based on string match.
      if( match )
      {
         if( j == 0 )
         {
            allCellsEMAHO[i].RSSI   = RSCMU_NAN_VI_INT32;
         }
         else
         {
            allCellsEMAHO[i].RSSI   = j - 1;
         }
      }
      else
      {
         allCellsEMAHO[i].RSSI      = RSCMU_NAN_VI_INT32;
         RSCMU_Status               = RSCMU_ERROR_NAN;
      }
   }


 return( RSCMU_Status );
}

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_EMAHOCell 
 *
 * DESCRIPTION: 
 *              .   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_TDMA_EMAHOCell (ViSession   instrSession, 
                                        ViInt32     channel,
                                        EMAHO       *EMAHOCell,
                                        ViChar      errorMessage[])
{
   ViStatus   RSCMU_Status = VI_SUCCESS;  
   ViBoolean  match        = RSCMU_FALSE;
   ViInt32    i;
   ViInt32    length;
   ViChar    *rdBuf;
   ViChar    *wrtBuf;
   ViChar    tab[38][30];
   ViReal64   temp;    

   checkRange( 218, &channel );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[218].instrCommand
          , channel
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Read channel.
   sscanf( tab[0], "%lf", &temp);
   sprintf(tab[0],"%4.0lf",temp);
   sscanf( tab[0], "%4d", &EMAHOCell->Channel);

   
   // Search table for a RSSI match.
   length = strlen( tab[1] );
   i      = 0;
   while( *ReportERSSI != NULL )
   {
      if( strncmp( ReportERSSI[i], tab[1], length ) == 0 ) 
      {
         match = RSCMU_TRUE;
         break;
      }
      i++;
   }
   
   // Set return value based on string match.
   if( match )
   {
      if( i == 0 )
      {
         EMAHOCell->RSSI  = RSCMU_NAN_VI_INT32;
      }
      else
      {
         EMAHOCell->RSSI  = i - 1;
      }
   }
   else
   {
      EMAHOCell->RSSI  = RSCMU_NAN_VI_INT32;
      RSCMU_Status    = RSCMU_ERROR_NAN;
   }


 return( RSCMU_Status );    
}

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_EMAHO_BER
 *
 * DESCRIPTION: 
 *              .   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_TDMA_EMAHO_BER (ViSession   instrSession,
                                        ViInt32     *EMAHOBER, 
                                        ViChar      errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViBoolean match        = RSCMU_FALSE;
   ViInt32   i;
   ViInt32   length;
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[214].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Search table for a match.
   i      = 0;
   length = strlen( rdBuf );
   while( *ReportEBER != NULL )
   {
      if( strncmp( ReportBER[i], rdBuf, length ) == 0 ) 
      {
         match = RSCMU_TRUE;
         break;
      }
      i++;
   }
   
   // Set return value based on string match.
   if( match )
   {
      if( i == 0 )
      {
         *EMAHOBER = RSCMU_NAN_VI_INT32;
      }
      else
      {
         *EMAHOBER = i - 1;
      }
   }
   else
   {
      *EMAHOBER    = RSCMU_NAN_VI_INT32;
      RSCMU_Status = RSCMU_ERROR_NAN;
   }
   
   return( RSCMU_Status );
    
}

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_EMAHO_WER
 *
 * DESCRIPTION: 
 *              .   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_TDMA_EMAHO_WER (ViSession instrSession,
                                        ViInt32     *EMAHOWER,
                                        ViChar      errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViBoolean match        = RSCMU_FALSE;
   ViInt32   i;
   ViInt32   length;
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[216].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Search table for a match.
   i      = 0;
   length = strlen( rdBuf );
   while( *ReportWER != NULL )
   {
      if( strncmp( ReportWER[i], rdBuf, length ) == 0 ) 
      {
         match = RSCMU_TRUE;
         break;
      }
      i++;
   }
   
   // Set return value based on string match.
   if( match )
   {
      if( i == 0 )
      {
         *EMAHOWER = RSCMU_NAN_VI_INT32;
      }
      else
      {
         *EMAHOWER = i - 1;
      }
   }
   else
   {
      *EMAHOWER    = RSCMU_NAN_VI_INT32;
      RSCMU_Status = RSCMU_ERROR_NAN;
   }
   
   return( RSCMU_Status );
    
}



/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_EMAHO_RSSI
 *
 * DESCRIPTION: 
 *              .   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_TDMA_EMAHO_RSSI (ViSession  instrSession,
                                         ViInt32    *ERSSI, 
                                         ViChar     errorMessage[])
{
   ViStatus   RSCMU_Status = VI_SUCCESS;
   ViBoolean  match        = RSCMU_FALSE;
   ViInt32    i;
   ViInt32    length;
   ViChar    *wrtBuf;
   ViChar    *rdBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[213].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Search table for a match.
   length = strlen( rdBuf );
   i      = 0;
   while( *ReportERSSI != NULL )
   {
      if( strncmp( ReportERSSI[i], rdBuf, length ) == 0 ) 
      {
         match = RSCMU_TRUE;
         break;
      }
      i++;
   }
   
   // Set return value based on string match.
   if( match )
   {
      if( i == 0 )
      {
         *ERSSI             = RSCMU_NAN_VI_INT32;
      }
      else
      {
         *ERSSI             = i - 1;
      }
   }
   else
   {
      *ERSSI                = RSCMU_NAN_VI_INT32;
      RSCMU_Status          = RSCMU_ERROR_NAN;
   }
   
   return( RSCMU_Status );
    
}

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_EMAHO_CIR
 *
 * DESCRIPTION: 
 *              .   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_TDMA_EMAHO_CIR (ViSession   instrSession,
                                        ViInt32     *EMAHOCIR, 
                                        ViChar      errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViBoolean match        = RSCMU_FALSE;
   ViInt32   i;
   ViInt32   length;
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[215].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Search table for a match.
   i      = 0;
   length = strlen( rdBuf );
   while( *ReportCIR != NULL )
   {
      if( strncmp( ReportCIR[i], rdBuf, length ) == 0 ) 
      {
         match = RSCMU_TRUE;
         break;
      }
      i++;
   }
   
   // Set return value based on string match.
   if( match )
   {
      if( i == 0 )
      {
         *EMAHOCIR = RSCMU_NAN_VI_INT32;
      }
      else
      {
         *EMAHOCIR = i - 1;
      }
   }
   else
   {
      *EMAHOCIR    = RSCMU_NAN_VI_INT32;
      RSCMU_Status = RSCMU_ERROR_NAN;
   }
   
   return( RSCMU_Status );
    
}

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ProcSigAction
 *
 * DESCRIPTION: This function changes between the different signalling 
 *              states of the CMU.   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ProcSigAction( ViSession instrSession
                           , ViInt32   signallingState
                           , ViChar    errorMessage[]
                           )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViInt32   currState;
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   if( (RSCMU_Status = RSCMU_TDMA_ProcSigState( instrSession
                                              , &currState
                                              , errorMessage
                                              )) < 0 )
   {
      return( RSCMU_Status );
   }

   checkRange( 89, &signallingState );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   switch( signallingState )
   {
   case RSCMU_SON:
      // Be sure that CMU is in SOFF
      if( currState != RSCMU_TDMA_STATE_SOFF )
      {
         // do nothing
         return RSCMU_errorMessage( instrSession, RSCMU_IS136_ERROR_INVALID_SIGN_STAT, errorMessage );
      }
      break;

   case RSCMU_SOFF:
      break;

   case RSCMU_CTM:   // Call to mobile
      // Be sure that CMU is in SON, REG and not in CEST.
      if( ((currState != RSCMU_TDMA_STATE_SON) && (currState != RSCMU_TDMA_STATE_REG)) || 
          (currState == RSCMU_TDMA_STATE_CEST) )
      {
         return RSCMU_errorMessage( instrSession, RSCMU_IS136_ERROR_INVALID_SIGN_STAT, errorMessage );
      }
      break;

   case RSCMU_SMS:
      // Be sure that CMU is in REG state
      if( currState != RSCMU_TDMA_STATE_REG )
      {
         return RSCMU_errorMessage( instrSession, RSCMU_IS136_ERROR_INVALID_SIGN_STAT, errorMessage );
      }
      break;

   case RSCMU_CREL:  // Release the call
      // Be sure that CMU is in CEST.
      if( currState != RSCMU_TDMA_STATE_CEST )
      {
        return RSCMU_errorMessage( instrSession, RSCMU_IS136_ERROR_INVALID_SIGN_STAT, errorMessage);
      }
      break;
      
   default:
        return RSCMU_errorMessage( instrSession, RSCMU_IS136_ERROR_INVALID_SIGN_STAT, errorMessage);
   }
                             
   // Send command ONLY if no errors in the signalling state were detected!
   sprintf( wrtBuf
          , IS136[89].instrCommand
          , sigAction.list[signallingState]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ProcSigAction()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_Registration
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_Registration( ViSession instrSession
                          , ViInt32   timeout
                          , ViChar    errorMessage[]
                          )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;
   ViBoolean TimerExpired = RSCMU_FALSE;
   ViInt32   state        = 0;
   clock_t   StartTime;
   clock_t   DeltaTime;

   // Check timeout is between 1 and 60 seconds.
   if( timeout < 1 )
   {
      timeout = 1;
   }
   else if( timeout > 60 )
   {
      timeout = 60;
   }

  if( RSCMU_Status == VI_SUCCESS )
   {
      // Wait for mobile registration
      StartTime = clock() / CLOCKS_PER_SEC;
      while( (state != RSCMU_TDMA_STATE_REG) && (RSCMU_Status == VI_SUCCESS) && !TimerExpired )
      {
         
         RSCMU_Delay (0.100);
         RSCMU_Status = RSCMU_TDMA_ProcSigState( instrSession
                                               , &state
                                               , errorMessage
                                               );
 
            
         DeltaTime = (clock() / CLOCKS_PER_SEC) - StartTime;
         if( DeltaTime >= timeout )
         {
            TimerExpired = RSCMU_TRUE;
         }
      }

      if( TimerExpired )
      {
         RSCMU_Status = RSCMU_errorMessage( instrSession, RSCMU_ERROR_TIMEOUT, errorMessage );
      }
      else if( RSCMU_Status != VI_SUCCESS )
      {
         RSCMU_Status = RSCMU_errorMessage( instrSession, RSCMU_IS136_ERROR_CALL_FROM_MS_FAILED, errorMessage );
      }
   }
   
   return( RSCMU_Status );

} // endof RSCMU_TDMA_Registration()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_Origination
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_Origination( ViSession instrSession
                         , ViInt32   timeout
                         , ViChar    errorMessage[]
                         )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;
   ViBoolean TimerExpired = RSCMU_FALSE;
   ViInt32   state        = 0;
   clock_t   StartTime;
   clock_t   DeltaTime;

   // Check timeout is between 1 and 60 seconds.
   if( timeout < 1 )
   {
      timeout = 1;
   }
   else if( timeout > 60 )
   {
      timeout = 60;
   }

   if( RSCMU_Status == VI_SUCCESS )
   {
      // Wait for mobile registration
      StartTime = clock() / CLOCKS_PER_SEC;
      while( (state != RSCMU_TDMA_STATE_CEST) && (RSCMU_Status == VI_SUCCESS) && !TimerExpired )
      {
         RSCMU_Delay (0.100);         
         RSCMU_Status = RSCMU_TDMA_ProcSigState( instrSession
                                               , &state
                                               , errorMessage
                                               );
         DeltaTime = (clock() / CLOCKS_PER_SEC) - StartTime;
         if( DeltaTime >= timeout )
         {
            TimerExpired = RSCMU_TRUE;
         }
      }

      if( TimerExpired )
      {
         RSCMU_Status = RSCMU_errorMessage( instrSession, RSCMU_ERROR_TIMEOUT, errorMessage );
      }
      else if( RSCMU_Status != VI_SUCCESS )
      {
         RSCMU_Status = RSCMU_errorMessage( instrSession, RSCMU_IS136_ERROR_CALL_FROM_MS_FAILED, errorMessage );
      }
   }
   
   return( RSCMU_Status );

} // endof RSCMU_TDMA_Origination()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_PagingCallToMS
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_PagingCallToMS( ViSession instrSession
                            , ViInt32   timeout
                            , ViChar    errorMessage[]
                            )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;
   ViStatus  status;
   ViBoolean TimerExpired = RSCMU_FALSE;
   ViInt32   state        = 0;
   ViInt32   attrTO;
   clock_t   StartTime;
   clock_t   DeltaTime;

   // Check timeout is between 1 and 60 seconds.
   if( timeout < 5 )
   {
      timeout = 5;
   }
   else if( timeout > 60 )
   {
      timeout = 60;
   }

   RSCMU_Status = viGetAttribute( instrSession, VI_ATTR_TMO_VALUE, &attrTO );

   if( attrTO < (timeout * 1000) )
   {
      RSCMU_Status = viSetAttribute( instrSession
                                   , VI_ATTR_TMO_VALUE
                                   , timeout * 1000
                                   );
   }
   
   // Paging (call to MS).
   RSCMU_Status = RSCMU_TDMA_ProcSigAction( instrSession
                                          , RSCMU_CTM
                                          , errorMessage
                                          );
   
   // Wait for call released from MS
   StartTime = clock() / CLOCKS_PER_SEC;
   RSCMU_Status = RSCMU_TDMA_ProcSigState( instrSession
                                         , &state
                                         , errorMessage
                                         );
   while( (state != RSCMU_TDMA_STATE_CEST) && (RSCMU_Status == VI_SUCCESS) && !TimerExpired )
   {

      RSCMU_Delay (0.100);      
      RSCMU_Status = RSCMU_TDMA_ProcSigState( instrSession
                                            , &state
                                            , errorMessage
                                            );
      DeltaTime = (clock() / CLOCKS_PER_SEC) - StartTime;
      if( DeltaTime >= timeout )
      {
         TimerExpired = RSCMU_TRUE;
      }
   }

   // Determine if the test passed.
   if( state != RSCMU_TDMA_STATE_CEST )
   {
      RSCMU_Status = RSCMU_errorMessage( instrSession, RSCMU_IS136_ERROR_CALL_TO_MS_FAILED, errorMessage );
   }
   else if( TimerExpired )
   {
      RSCMU_Status = RSCMU_errorMessage( instrSession, RSCMU_ERROR_TIMEOUT, errorMessage );
   }
   
   // DO NOT use RSCMU_Status since we want to return the status of
   // the paging function!!
   status = viSetAttribute( instrSession , VI_ATTR_TMO_VALUE, attrTO );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_PagingCallToMS()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ReleaseCallFromMS
 *
 * DESCRIPTION: This routine releases the call by CMU.
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ReleaseCallFromMS( ViSession instrSession
                               , ViInt32   timeout
                               , ViChar    errorMessage[]
                               )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;
   ViBoolean TimerExpired = RSCMU_FALSE;
   ViInt32   state        = 0;
   clock_t   StartTime;
   clock_t   DeltaTime;

   // Verify CMU is in CEST.
   RSCMU_Status = RSCMU_TDMA_ProcSigState( instrSession, &state, errorMessage );
   if( state != RSCMU_TDMA_STATE_CEST )
   {
      return RSCMU_errorMessage( instrSession
                               , RSCMU_IS136_ERROR_INVALID_SIGN_STAT
                               , errorMessage
                               );
   }
   
   // Check timeout is between 1 and 60 seconds.
   if( timeout < 1 )
   {
      timeout = 1;
   }
   else if( timeout > 60 )
   {
      timeout = 60;
   }

   // Wait for call released from MS
   StartTime = clock() / CLOCKS_PER_SEC;
   while( (state == RSCMU_TDMA_STATE_CEST) && (RSCMU_Status == VI_SUCCESS) && !TimerExpired )
   {
      RSCMU_Delay (0.100);
      RSCMU_Status = RSCMU_TDMA_ProcSigState( instrSession
                                            , &state
                                            , errorMessage
                                            );
      DeltaTime = (clock() / CLOCKS_PER_SEC) - StartTime;
      if( DeltaTime >= timeout )
      {
         TimerExpired = RSCMU_TRUE;
      }
   }

   if( TimerExpired )
   {
      RSCMU_Status = RSCMU_errorMessage( instrSession, RSCMU_ERROR_TIMEOUT, errorMessage );
   }
   else if( RSCMU_Status != VI_SUCCESS )
   {
      RSCMU_Status = RSCMU_errorMessage( instrSession, RSCMU_IS136_ERROR_RELEASE_TO_MS_FAILED, errorMessage );
   }
   
   return( RSCMU_Status );

} // endof RSCMU_TDMA_ReleaseCallFromMS()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ReleaseCallFromBST
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ReleaseCallFromBST( ViSession instrSession
                                , ViChar    errorMessage[]
                                )
{
   ViStatus RSCMU_Status = VI_SUCCESS;
   ViInt32  state        = 0;

   // Verify CMU is in CEST.
   RSCMU_Status = RSCMU_TDMA_ProcSigState( instrSession, &state, errorMessage );
   if( state != RSCMU_TDMA_STATE_CEST )
   {
      return RSCMU_errorMessage( instrSession
                               , RSCMU_IS136_ERROR_INVALID_SIGN_STAT
                               , errorMessage
                               );
   }
   
   // Release the call.
   RSCMU_Status = RSCMU_TDMA_ProcSigAction( instrSession
                                          , RSCMU_CREL
                                          , errorMessage
                                          );

   if( RSCMU_Status == VI_SUCCESS )
   {
      RSCMU_Status = RSCMU_TDMA_ProcSigState( instrSession
                                            , &state
                                            , errorMessage
                                            );
      if( state == RSCMU_TDMA_STATE_CEST )
      {
         RSCMU_Status = RSCMU_errorMessage( instrSession, RSCMU_IS136_ERROR_RELEASE_TO_MS_FAILED, errorMessage );
      }
   }
   
   return( RSCMU_Status );

} // endof RSCMU_TDMA_ReleaseCallFromBST()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ProcSigState
 *
 * DESCRIPTION: This routine reads the current signalling state of the CMU.
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ProcSigState( ViSession  instrSession
                          , ViInt32   *state
                          , ViChar     errorMessage[]
                          )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[95].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Get signalling state
   if( strncmp( "SOFF", rdBuf, 4 ) == 0 )
   {
     *state = RSCMU_TDMA_STATE_SOFF;
   }
   else if( strncmp( "SON", rdBuf, 3 ) == 0 )  
   {
      *state = RSCMU_TDMA_STATE_SON;
   }
   else if( strncmp( "REG", rdBuf, 3 ) == 0 ) 
   {
      *state = RSCMU_TDMA_STATE_REG;  
   }
   else if( strncmp( "ALRT", rdBuf, 4 ) == 0 ) 
   {
      *state = RSCMU_TDMA_STATE_ALRT;  
   }
   else if( strncmp( "CEST", rdBuf, 4 ) == 0 ) 
   {
      *state = RSCMU_TDMA_STATE_CEST;  
   }
   else if( strncmp( "CPEN", rdBuf, 4 ) == 0 ) 
   {
      *state = RSCMU_TDMA_STATE_CPEN;  
   }
   else if( strncmp( "RPEN", rdBuf, 4 ) == 0 ) 
   {
      *state = RSCMU_TDMA_STATE_RPEN;  
   }
  
   return( RSCMU_Status );

} // endof RSCMU_TDMA_ProcSigState()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ProcSigDtcMac
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ProcSigDtcMac( ViSession instrSession
                           , ViInt32   level
                           , ViChar    errorMessage[]
                           )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 90, &level );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[90].instrCommand
          , level
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ProcSigDtcMac()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ProcSigTrafficChan
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ProcSigTrafficChan( ViSession instrSession
                                , ViInt32   channel
                                , ViChar    errorMessage[]
                                )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 91, &channel );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[91].instrCommand
          , channel
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ProcSigTrafficChan()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ProcSigSlotConfig
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ProcSigSlotConfig( ViSession instrSession
                               , ViInt32   slot
                               , ViChar    errorMessage[]
                               )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 92, &slot );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[92].instrCommand
          , slotTCH.list[slot]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ProcSigSlotConfig()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_InitSPower
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_InitSPower( ViSession instrSession
                        , ViChar    errorMessage[]
                        )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[107].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_InitSPower()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_AbortSPower
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_AbortSPower( ViSession instrSession
                         , ViChar    errorMessage[]
                         )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[108].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_AbortSPower()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_StopSPower
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_StopSPower( ViSession instrSession
                        , ViChar    errorMessage[]
                        )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[109].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_StopSPower()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ContinueSPower
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ContinueSPower( ViSession instrSession
                            , ViChar    errorMessage[]
                            )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[110].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ContinueSPower()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_FetchSPowerStatus
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_FetchSPowerStatus( ViSession  instrSession
                               , ViInt32   *measurementStatus
                               , ViInt32   *CurrentStatCycleCount
                               , ViInt32   *CurrentEvalPeriodCount
                               , ViChar     errorMessage[]
                               )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;
   ViChar    tab[38][30];    

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[111].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   if( RSCMU_Status >= 0 )
   {
       // Separate the CMU response:
       RSCMU_SeparateString( rdBuf, ",", tab );

       // Get the measurement status
       RSCMU_Status = 
          RSCMU_GetMeasurementStatus( measurementStatus, tab, 0 );

       // Get the counter for current statistics cycle
       if( strcmp( tab[1], "NONE" ) != 0 )
       {
          sscanf( tab[1], "%d", CurrentStatCycleCount );
       }
       else
       {
          *CurrentStatCycleCount = RSCMU_OFF;
       }

       // Get the counter for current evaluation period within a cycle
       if( strcmp( tab[2], "NONE" ) != 0 )
       {
          sscanf( tab[2], "%d", CurrentEvalPeriodCount );
       }
       else
       {
          *CurrentEvalPeriodCount = RSCMU_OFF;
       }
   }

   return( RSCMU_Status );

} // endof RSCMU_TDMA_FetchSPowerStatus()

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfSPowerEReport
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_TDMA_ConfSPowerEReport (ViSession   instrSession,
                                                ViInt32     measurementEventReporting,
                                                ViChar      errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 203, &measurementEventReporting );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[203].instrCommand
          , eventReport.list[measurementEventReporting]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} // endof RSCMU_TDMA_ConfSPowerEReport()

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ReadSPowerResult
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ReadSPowerResult( ViSession  instrSession
                              , ViReal64  *PeakPower
                              , ViChar     errorMessage[]
                              )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[148].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Get the Peak Power
   if( strcmp( rdBuf, "NAN" ) != 0 )
   {
      sscanf( rdBuf, "%lf", PeakPower );
   }
   else
   {
      *PeakPower = RSCMU_NAN; 
   }

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ReadSPowerResult()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_FetchSPowerResult
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_FetchSPowerResult( ViSession instrSession
                               , ViReal64  *PeakPower
                               , ViChar    errorMessage[]
                               )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[112].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Get the Peak Power
   if( strcmp( rdBuf, "NAN" ) != 0 )
   {
      sscanf( rdBuf, "%lf", PeakPower );
   }
   else
   {
      *PeakPower = RSCMU_NAN; 
   }

   return( RSCMU_Status );

} // endof RSCMU_TDMA_FetchSPowerResult()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_SampleSPowerResult
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_SampleSPowerResult( ViSession instrSession
                                , ViReal64  *PeakPower
                                , ViChar    errorMessage[]
                                )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[149].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Get the Peak Power
   if( strcmp( rdBuf, "NAN" ) != 0 )
   {
      sscanf( rdBuf, "%lf", PeakPower );
   }
   else
   {
      *PeakPower = RSCMU_NAN; 
   }

   return( RSCMU_Status );

} // endof RSCMU_TDMA_SampleSPowerResult()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_SPowerContRep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_SPowerContRep( ViSession instrSession
                           , ViInt32   rep
                           , ViInt32   stopCondition
                           , ViInt32   step
                           , ViChar    errorMessage[]
                           )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 113, &rep, &stopCondition, &step );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[113].instrCommand
          , repetition.list[rep]
          , stopCond.list[stopCondition]
          , stepMode.list[step]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_SPowerContRep()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfHandoffTDMA
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC // JMG
   RSCMU_TDMA_ConfHandoffTDMA( ViSession instrSession
                             , ViInt32   DTCChannel
                             , ViReal64  level
                             , ViInt32   DTCMAC
                             , ViInt32   timeslot
                             , ViChar    errorMessage[])
{
   ViStatus RSCMU_Status = VI_SUCCESS;
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 168, &DTCChannel );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
   
   sprintf( wrtBuf
          , IS136[168].instrCommand
          , DTCChannel
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   checkRange( 169, &timeslot );

   sprintf( wrtBuf
          , IS136[169].instrCommand
          , slotTCH.list[timeslot]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   checkRange( 170, &level );

   sprintf( wrtBuf
          , IS136[170].instrCommand
          , level
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   checkRange( 171, &DTCMAC );

   sprintf( wrtBuf
          , IS136[171].instrCommand
          , DTCMAC
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
   
} // endof RSCMU_TDMA_ConfHandoffTDMA()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_Handoff
 *
 * DESCRIPTION: This routine performs a handover from the Original Network 
 *              Session Handle (instrSession) to the Destination Network 
 *              Session Handle (DestinationHandle).
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_Handoff( ViSession instrSession
                     , ViSession DestinationHandle
                     , ViInt32   Target
                     , ViInt32   Timeout
                     , ViChar    errorMessage[]
                     )
{
   ViStatus  RSCMU_Status   = VI_SUCCESS;
   ViBoolean Found          = RSCMU_FALSE;
   ViBoolean TimerExpired   = RSCMU_FALSE;
   ViChar    TargetName[30] = "";
   ViInt32   state          = 0;
   ViInt32   cnt            = 0;
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   clock_t   StartTime;
   clock_t   DeltaTime;
   ViInt16   i;
   ViChar    tab[38][30];    

   if( Timeout < 5 )
   {
      Timeout = 5;
   }
   else if( Timeout > 60 )
   {
      Timeout = 60;
   }
   
   if( DestinationHandle == (ViSession)NULL )
   {
      return RSCMU_errorMessage( instrSession
                               , RSCMU_IS136_ERROR_INVALID_HANDOVER_TARGET
                               , errorMessage
                               );
   }

   if( instrSession == (ViSession)NULL )
   {
      return RSCMU_errorMessage( instrSession
                               , RSCMU_ERROR_PARAMETER1
                               , errorMessage
                               );
   }

   // Get the 'HandOverSessionName' of the TargetSession
   strncpy( TargetName
          , HandoffTargets[Target]
          , strlen( HandoffTargets[Target] )
          );

   // Get pointers to buffers.
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
   
   // Extract HandOver TargetList, compare TargetHandle with it.  
   if( (RSCMU_Status = RSCMU_Query( instrSession
                                  , "STATUS:HANDOFF:TARGET:LIST?"
                                  , rdBuf
                                  , RSCMU_STB_ON
                                  , errorMessage
                                  ) ) < 0 )
   {
      return( RSCMU_Status );
   }
 
   // Separate the CMU response:
   cnt = RSCMU_SeparateString( rdBuf, ",", tab );

   // Determine if the destination target was found in the list.
   for( i = 0; i < cnt; i++ )
   {
      if( strncmp( TargetName, tab[i], strlen(tab[i]) ) == 0 )
      {
         Found = RSCMU_TRUE;
      }
   }

   if( !Found )
   {
      return RSCMU_errorMessage( instrSession, RSCMU_IS136_ERROR_INVALID_HANDOVER_TARGET, errorMessage ); 
   }

   // Be sured that RSCMU is in CEST.
   if( RSCMU_Status = RSCMU_TDMA_ProcSigState( instrSession, &state, errorMessage ) )
   {
      return( RSCMU_Status );
   }

   if( state != RSCMU_TDMA_STATE_CEST )
   {
      return RSCMU_errorMessage( instrSession, RSCMU_IS136_ERROR_INVALID_SIGN_STAT, errorMessage );
   }
   
   // Abort all measurements for the source session.
   RSCMU_Status = RSCMU_TDMA_AbortSpec( instrSession, errorMessage );
   RSCMU_Status = RSCMU_TDMA_AbortMod( instrSession, RSCMU_OVERVIEW, errorMessage );
   RSCMU_Status = RSCMU_TDMA_AbortMod( instrSession, RSCMU_PERROR, errorMessage );
   RSCMU_Status = RSCMU_TDMA_AbortMod( instrSession, RSCMU_MERROR, errorMessage );
   RSCMU_Status = RSCMU_TDMA_AbortMod( instrSession, RSCMU_EVM, errorMessage );
   RSCMU_Status = RSCMU_TDMA_AbortSPower( instrSession, errorMessage );
   RSCMU_Status = RSCMU_TDMA_AbortPow( instrSession, RSCMU_NORMAL, errorMessage );
   RSCMU_Status = RSCMU_TDMA_AbortPow( instrSession, RSCMU_SHORT, errorMessage );

   // Configure Handoff for alternate network.
   sprintf( wrtBuf
          , IS136[40].instrCommand
          , TargetName
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Perform Handoff to alternate network.
   RSCMU_Status = RSCMU_Query( instrSession
                             , "PROC:SIGN:ACT HAND"
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Delay 1 second to allow CMU to process the message.
   StartTime = clock() / CLOCKS_PER_SEC;
   while( !TimerExpired )
   {
      DeltaTime = (clock() / CLOCKS_PER_SEC) - StartTime;
      if( DeltaTime >= 1 )
      {
         TimerExpired = RSCMU_TRUE;
      }
   }
   TimerExpired = RSCMU_FALSE;

   // Wait for handoff to be completed.
   RSCMU_Status = RSCMU_TDMA_ProcSigState( DestinationHandle
                                         , &state
                                         , errorMessage
                                         );
   StartTime = clock() / CLOCKS_PER_SEC;
   while( (state != RSCMU_TDMA_STATE_CEST) && (RSCMU_Status == VI_SUCCESS) && !TimerExpired )
   {
      RSCMU_Status = RSCMU_TDMA_ProcSigState( DestinationHandle
                                            , &state
                                            , errorMessage
                                            );
      DeltaTime = (clock() / CLOCKS_PER_SEC) - StartTime;
      if( DeltaTime >= Timeout )
      {
         TimerExpired = RSCMU_TRUE;
      }
   }

   if( TimerExpired )
   {
      RSCMU_Status = RSCMU_errorMessage( DestinationHandle, RSCMU_ERROR_TIMEOUT, errorMessage );
   }
   else if( RSCMU_Status != VI_SUCCESS )
   {
      RSCMU_Status = RSCMU_errorMessage( DestinationHandle, RSCMU_IS136_ERROR_INVALID_HANDOVER_TARGET, errorMessage );
   }
   
   return( RSCMU_Status );
   
} // endof RSCMU_TDMA_Handoff()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfBSSignalSpeech
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfBSSignalSpeech( ViSession instrSession
                                , ViInt32   state
                                , ViChar    errorMessage[]
                                )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   if (state == RSCMU_HSET) 
   {
   
       // Get the global structure
       if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
        return RSCMU_Status;                                        

       if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
           return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage); 

   }

   
   checkRange( 114, &state );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[114].instrCommand
          , speech.list[state]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfBSSignalSpeech()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ProcBSSignalSpeech
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ProcBSSignalSpeech( ViSession instrSession
                                , ViInt32   state
                                , ViChar    errorMessage[]
                                )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   if (state == RSCMU_HSET) 
   {
   
       // Get the global structure
       if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
        return RSCMU_Status;                                        

       if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
           return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage); 

   }
   
   checkRange( 94, &state );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[94].instrCommand
          , speech.list[state]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ProcBSSignalSpeech()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfBSSignalVoiceCoder
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfBSSignalVoiceCoder( ViSession instrSession
                                    , ViInt32   VoiceCoder
                                    , ViChar    errorMessage[]
                                    )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 115, &VoiceCoder );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[115].instrCommand
          , voice.list[VoiceCoder]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfBSSignalVoiceCoder()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfBSGlobal
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfBSGlobal( ViSession instrSession
                          , ViInt32   DCCHChannel
                          , ViInt32   DCCHSlot
                          , ViInt32   DCCHMAC
                          , ViReal64  DCCHPowerLevel
                          , ViInt32   DTCChannel
                          , ViInt32   DTCSlot
                          , ViInt32   DTCMAC
                          , ViReal64  DTCPowerLevel
                          , ViInt32   SID
                          , ViInt32   voiceCoder
                          , ViInt32   DVCC
                          , ViChar    errorMessage[]
                          )
{
   ViStatus RSCMU_Status = VI_SUCCESS;  

   RSCMU_Status = RSCMU_TDMA_ConfBSSignalCCHChannel( instrSession, DCCHChannel, errorMessage );
   RSCMU_Status = RSCMU_TDMA_ConfBSSignalCCHSlot( instrSession, DCCHSlot, errorMessage );
   RSCMU_Status = RSCMU_TDMA_ConfNetDccMac( instrSession, DCCHMAC, errorMessage );
   RSCMU_Status = RSCMU_TDMA_ConfBSSignalCCHLevel( instrSession, DCCHPowerLevel, errorMessage );
   
   RSCMU_Status = RSCMU_TDMA_ConfBSSignalTCHChannel( instrSession, DTCChannel, errorMessage );
   RSCMU_Status = RSCMU_TDMA_ConfBSSignalTCHSlot( instrSession, DTCSlot, errorMessage );
   RSCMU_Status = RSCMU_TDMA_ConfNetDtcMac( instrSession, DTCMAC, errorMessage );
   RSCMU_Status = RSCMU_TDMA_ConfBSSignalTCHLevel( instrSession, DTCPowerLevel, errorMessage );

   RSCMU_Status = RSCMU_TDMA_NetIdSID( instrSession, SID, errorMessage );
   RSCMU_Status = RSCMU_TDMA_ConfBSSignalVoiceCoder( instrSession, voiceCoder, errorMessage );
   RSCMU_Status = RSCMU_TDMA_ConfNetSysCcsDvcc( instrSession, DVCC, errorMessage );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfBSGlobal()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfBSSignalCCHChannel
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfBSSignalCCHChannel( ViSession instrSession
                                    , ViInt32   channel
                                    , ViChar    errorMessage[]
                                    )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 116, &channel );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[116].instrCommand
          , channel
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfBSSignalCCHChannel()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfBSSignalCCHSlot
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfBSSignalCCHSlot( ViSession instrSession
                                 , ViInt32   slot
                                 , ViChar    errorMessage[]
                                 )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 117, &slot );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[117].instrCommand
          , slotCCH.list[slot]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfBSSignalCCHSlot()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfBSSignalCCHLevel
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfBSSignalCCHLevel( ViSession instrSession
                                  , ViReal64  level
                                  , ViChar    errorMessage[]
                                  )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 118, &level );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[118].instrCommand
          , level
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfBSSignalCCHLevel()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfBSSignalTCHChannel
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfBSSignalTCHChannel( ViSession instrSession
                                    , ViInt32   channel
                                    , ViChar    errorMessage[]
                                    )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 119, &channel );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[119].instrCommand
          , channel
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfBSSignalTCHChannel()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfBSSignalTCHSlot
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfBSSignalTCHSlot( ViSession instrSession
                                 , ViInt32   slot
                                 , ViChar    errorMessage[]
                                 )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 120, &slot );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[120].instrCommand
          , slotTCH.list[slot]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfBSSignalTCHSlot()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfBSSignalTCHLevel
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfBSSignalTCHLevel( ViSession instrSession
                                  , ViReal64  level
                                  , ViChar    errorMessage[]
                                  )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 121, &level );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[121].instrCommand
          , level
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfBSSignalTCHLevel()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ProcBSSignalTCHLevel
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ProcBSSignalTCHLevel( ViSession instrSession
                                  , ViReal64  level
                                  , ViChar    errorMessage[]
                                  )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 93, &level );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[93].instrCommand
          , level
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ProcBSSignalTCHLevel()

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_NetIdSOC
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_NetIdSOC( ViSession instrSession
                      , ViInt32   SOC
                      , ViChar    errorMessage[]
                      )   

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    
   
   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
       return RSCMU_Status;                                        

   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
       return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage); 


   
   checkRange( 177, &SOC );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[177].instrCommand
          , SOC
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_NetIdSOC()

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_NetIdSID
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_NetIdSID( ViSession instrSession
                      , ViInt32   SID
                      , ViChar    errorMessage[]
                      )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 122, &SID );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[122].instrCommand
          , SID
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_NetIdSID()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_NetIdMCC
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_NetIdMCC( ViSession instrSession
                      , ViInt32   MCC
                      , ViChar    errorMessage[]
                      )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 123, &MCC );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[123].instrCommand
          , MCC
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_NetIdMCC()

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_NetIdASID
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC 
   RSCMU_TDMA_NetIdASID( ViSession instrSession
                                    , ViBoolean state
                                    , ViChar    errorMessage[]
                                    )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 219, &state );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[219].instrCommand
          , enable.list[state]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_NetIdASID()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfNetSignalModePOReg
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfNetSignalModePOReg( ViSession instrSession
                                    , ViBoolean state
                                    , ViChar    errorMessage[]
                                    )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 124, &state );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[124].instrCommand
          , enable.list[state]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfNetSignalModePOReg()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfNetSigModePDReg
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfNetSigModePDReg( ViSession instrSession
                                 , ViBoolean state
                                 , ViChar    errorMessage[]
                                 )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 125, &state );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[125].instrCommand
          , enable.list[state]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfNetSigModePDReg()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfNetSigModeSysReg
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfNetSigModeSysReg( ViSession instrSession
                                  , ViBoolean state
                                  , ViChar    errorMessage[]
                                  )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 126, &state );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[126].instrCommand
          , enable.list[state]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfNetSigModeSysReg()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfNetSigModeReg
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfNetSigModeReg( ViSession instrSession
                               , ViBoolean state
                               , ViChar    errorMessage[]
                               )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 127, &state );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[127].instrCommand
          , enable.list[state]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfNetSigModeReg()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfNetSigModeIdType
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfNetSigModeIdType( ViSession instrSession
                                  , ViInt32   state
                                  , ViChar    errorMessage[]
                                  )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 128, &state );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[128].instrCommand
          , idType.list[state]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfNetSigModeIdType()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfNetSigModeID20
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfNetSigModeID20( ViSession instrSession
                                , ViInt32   SignalChan
                                , ViChar    errorMessage[]
                                )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 158, &SignalChan );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[158].instrCommand
          , SignalChan
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfNetSigModeID20()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfNetSigModeID24
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfNetSigModeID24( ViSession instrSession
                                , ViInt32   SignalChan
                                , ViChar    errorMessage[]
                                )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 159, &SignalChan );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[159].instrCommand
          , SignalChan
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfNetSigModeID24()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfNetSigModeIDMIN
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfNetSigModeIDMIN( ViSession  instrSession
                                 , ViChar    *SignalChan
                                 , ViChar     errorMessage[]
                                 )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[130].instrCommand
          , SignalChan
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfNetSigModeIDMIN()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfNetSigModeIDIMSI
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfNetSigModeIDIMSI( ViSession  instrSession
                                  , ViChar    *SignalChan
                                  , ViChar     errorMessage[]
                                  )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[131].instrCommand
          , SignalChan
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfNetSigModeIDIMSI()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfNetReqSN
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfNetReqSN( ViSession instrSession
                          , ViBoolean state
                          , ViChar    errorMessage[]
                          )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 132, &state );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[132].instrCommand
          , enable.list[state]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfNetReqSN()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfNetReqCapability
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfNetReqCapability( ViSession instrSession
                                  , ViBoolean state
                                  , ViChar    errorMessage[]
                                  )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 133, &state );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[133].instrCommand
          , enable.list[state]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfNetReqCapability()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfNetDccMac
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfNetDccMac( ViSession instrSession
                           , ViInt32   dccmac
                           , ViChar    errorMessage[]
                           )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 134, &dccmac );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[134].instrCommand
          , dccmac
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfNetDccMac()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfNetDtcMac
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfNetDtcMac( ViSession instrSession
                           , ViInt32   dtcmac
                           , ViChar    errorMessage[]
                           )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 135, &dtcmac );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[135].instrCommand
          , dtcmac
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfNetDtcMac()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfNetDic
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfNetDic( ViSession instrSession
                        , ViInt32   state
                        , ViChar    errorMessage[]
                        )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 136, &state );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[136].instrCommand
          , dic.list[state]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfNetDic()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfNetSuff
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfNetSuff( ViSession instrSession
                         , ViInt32   suff
                         , ViChar    errorMessage[]
                         )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 137, &suff );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[137].instrCommand
          , suff
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfNetSuff()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfNetRaMin
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfNetRaMin( ViSession instrSession
                          , ViInt32   ramin
                          , ViChar    errorMessage[]
                          )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 138, &ramin );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[138].instrCommand
          , ramin
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfNetRaMin()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfNetScanInt
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfNetScanInt( ViSession instrSession
                            , ViInt32   interval
                            , ViChar    errorMessage[]
                            )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 139, &interval );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[139].instrCommand
          , interval
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfNetScanInt()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfNetDelay
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfNetDelay( ViSession instrSession
                          , ViInt32   delay
                          , ViChar    errorMessage[]
                          )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 140, &delay );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[140].instrCommand
          , NetworkDelay.list[delay]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfNetDelay()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfNetShortBurstInd
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfNetShortBurstInd( ViSession instrSession
                                  , ViInt32   BurstDuration
                                  , ViChar    errorMessage[]
                                  )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 141, &BurstDuration );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[141].instrCommand
          , shortBurst.list[BurstDuration]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfNetShortBurstInd()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfNetSysNumFbcchSlots
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfNetSysNumFbcchSlots( ViSession instrSession
                                     , ViInt32   NumSlots
                                     , ViChar    errorMessage[]
                                     )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 142, &NumSlots );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[142].instrCommand
          , NumSlots
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfNetSysNumFbcchSlots()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfNetSysNumEbcchSlots
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfNetSysNumEbcchSlots( ViSession instrSession
                                     , ViInt32   NumSlots
                                     , ViChar    errorMessage[]
                                     )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 143, &NumSlots );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[143].instrCommand
          , NumSlots
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfNetSysNumEbcchSlots()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfNetSysCcsDvcc
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfNetSysCcsDvcc( ViSession instrSession
                               , ViInt32   ColorCode
                               , ViChar    errorMessage[]
                               )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 144, &ColorCode );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[144].instrCommand
          , ColorCode
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfNetSysCcsDvcc()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfNetTimeoutLostConn
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfNetTimeoutLostConn( ViSession instrSession
                                    , ViInt32   timeout
                                    , ViChar    errorMessage[]
                                    )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 145, &timeout );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[145].instrCommand
          , timeout
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfNetTimeoutLostConn()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfNetTimeoutRegPeriod
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfNetTimeoutRegPeriod( ViSession instrSession
                                     , ViInt32   timeout
                                     , ViChar    errorMessage[]
                                     )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   if( timeout != 0 )
   {
      checkRange( 146, &timeout );
      sprintf( wrtBuf
             , IS136[146].instrCommand
             , timeout
             );

      RSCMU_Status = RSCMU_Query( instrSession
                                , wrtBuf
                                , rdBuf
                                , RSCMU_STB_ON
                                , errorMessage
                                );
   }
   else
   {
      RSCMU_Status = RSCMU_Query( instrSession
                                , (ViChar *)IS136[180].instrCommand
                                , rdBuf
                                , RSCMU_STB_ON
                                , errorMessage
                                );
   }

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfNetTimeoutRegPeriod()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfNetNeighborChan
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfNetNeighborChan( ViSession instrSession
                                 , ViInt32   neighborChannel
                                 , ViInt32   channelNumber
                                 , ViChar    errorMessage[]
                                 )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 150, &neighborChannel, &channelNumber );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // If channel number is 0 the turning channel reporting OFF.
   if( channelNumber == 0 )
   {
      sprintf( wrtBuf
             , IS136[155].instrCommand
             , neighborChannel
             , "OFF"
             );
   }
   else
   {
      sprintf( wrtBuf
             , IS136[150].instrCommand
             , neighborChannel
             , channelNumber
             );
   }
   
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfNetNeighborChan()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfNetNeighborChanSort
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
// JMG 030106
ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfNetNeighborChanSort( ViSession instrSession
                                     , ViBoolean state
                                     , ViChar    errorMessage[]
                                     )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   if (state == RSCMU_OFF)
   {
   
        RSCMU_Status    = RSCMU_errorMessage( instrSession, RSCMU_IS136_WARNING_GPIB_FEATURE, errorMessage );
        return( RSCMU_Status);
   }

   checkRange( 151, &state );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[151].instrCommand
          , enable.list[state]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfNetNeighborChanSort()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_SenseMobileInfoCapability
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_SenseMobileInfoCapability( ViSession   instrSession
                                       , ViChar      softwareVersion[]
                                       , ViChar      firmwareVersion[]
                                       , ViChar      modelNumber[]
                                       , ViChar      manufacturerCode[]
                                       , ViInt32    *maxPFC
                                       , CAPABILITY *capabilities
                                       , ViChar      errorMessage[]
                                       )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;
   ViChar    tab[38][30];    

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[179].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );


   if( RSCMU_Status >= 0 )
   {
       // Separate the CMU response:
       RSCMU_SeparateString( rdBuf, ",", tab );
       
       // Extract the versions, model, etc. from response.
       strcpy( softwareVersion,  &tab[0][0] );
       strcpy( firmwareVersion,  &tab[1][0] );
       strcpy( modelNumber,      &tab[2][0] );
       strcpy( manufacturerCode, &tab[3][0] );
       
      if( strcmp( &tab[4][0], "NAN" ) != 0 )
      {
         sscanf( &tab[4][0], "%d", maxPFC );
      }
      else 
      {
         *maxPFC = RSCMU_NAN_VI_INT32; 
      }
  
       // Extract the mobile phone capabilities.
       RSCMU_ReturnCapability( &tab[5], capabilities );
   }

   return( RSCMU_Status );

} // endof RSCMU_TDMA_SenseMobileInfoCapability()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_SenseMobileInfoIdType
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_SenseMobileInfoIdType( ViSession  instrSession
                                   , ViInt32   *IDtype
                                   , ViChar     errorMessage[]
                                   )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[96].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Get the mobile reported ID Type
   if( strncmp( "NAN", rdBuf, 3 ) == 0 ) 
   {
      *IDtype = 0;
   }
   else if( strncmp( "ID20", rdBuf, 4 ) == 0 )
   {
      *IDtype = 1;
   }
   else if( strncmp( "ID24", rdBuf, 4 ) == 0 )
   {
      *IDtype = 2;
   }
   else if( strncmp( "MIN", rdBuf, 3 ) == 0 )
   {
      *IDtype = 3;
   }
   else if( strncmp( "ID50", rdBuf, 4 ) == 0 )
   {
      *IDtype = 4;
   }

   return( RSCMU_Status );

} // endof RSCMU_TDMA_SenseMobileInfoIdType()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_SenseMobileInfoNum
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_SenseMobileInfoNum( ViSession instrSession
                                , ViChar    infoNum[]
                                , ViChar    errorMessage[]
                                )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[97].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Get the mobile reported ID Number.
   // Remove leading and trailing " and add line terminator.
   strncpy( infoNum, &rdBuf[1], strlen(rdBuf) - 2 );
   infoNum[strlen(rdBuf) - 2] = '\0';
   
   return( RSCMU_Status );

} // endof RSCMU_TDMA_SenseMobileInfoNum()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_SenseMobileInfoESN
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_SenseMobileInfoESN( ViSession instrSession
                                , ViChar    ESN[]
                                , ViChar    errorMessage[]
                                )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;
   ViChar   *rdBuf;
   ViChar   *wrtBuf;
   ViUInt32   index; // JMG 031218

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[98].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Get the ESN.
   if( strcmp( rdBuf, "NAN" ) != 0 )
   {
      // Determine if a "-" is contained in the string.
      index = strcspn( &rdBuf[1], "-" );
      if( index == strlen(rdBuf) )
      {
         // Remove leading and trailing ".
         strncpy( ESN, &rdBuf[1], strlen(rdBuf) - 2 );
      }
      else
      {
         strncpy( ESN, &rdBuf[1], index );
         // Replace "-" with "0".
         ESN[index] = '0';
         // Make sure to skip over leading and trailing "
         strncpy( &ESN[index+1], &rdBuf[index+2], strlen(rdBuf) - index - 2 );
      }
      
      // Add line terminator.
      ESN[strlen(rdBuf) - 2] = '\0';
   }
   else
   {
      strcpy( ESN, "00000000000" );
   }
   
   return( RSCMU_Status );

} // endof RSCMU_TDMA_SenseMobileInfoESN()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_SenseMobileInfoPowClass
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_SenseMobileInfoPowClass( ViSession  instrSession
                                     , ViInt32   *PowerClass
                                     , ViChar     errorMessage[]
                                     )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[99].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Get the mobile reported ID Number
   if( strcmp( &rdBuf[0], "NAN" ) != 0 )
   {
      sscanf( &rdBuf[0], "%d", PowerClass );
   }
   else 
   {
      *PowerClass = RSCMU_NAN_VI_INT32; 
   }
  
   return( RSCMU_Status );

} // endof RSCMU_TDMA_SenseMobileInfoPowClass()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_SenseMobileInfoDtx
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_SenseMobileInfoDtx( ViSession  instrSession
                                , ViInt32   *DTX
                                , ViChar     errorMessage[]
                                )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[100].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Get the mobile reported ID Type
   if( strncmp( "NAN", rdBuf, 3 ) == 0 ) 
   {
      *DTX = 0;
   }
   else if( strncmp( "NSUP", rdBuf, 4 ) == 0 )
   {
      *DTX = 1;
   }
   else if( strncmp( "SUPP", rdBuf, 4 ) == 0 )
   {
      *DTX = 2;
   }

   return( RSCMU_Status );

} // endof RSCMU_TDMA_SenseMobileInfoDtx()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_SenseMobileInfoBandwidth
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_SenseMobileInfoBandwidth( ViSession  instrSession
                                      , ViInt32   *bandwidth
                                      , ViChar     errorMessage[]
                                      )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[101].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Get the mobile reported ID Type
   if( strncmp( "NAN", rdBuf, 3 ) == 0 ) 
   {
      *bandwidth = 0;
   }
   else if( strncmp( "MH20", rdBuf, 4 ) == 0 )
   {
      *bandwidth = 1;
   }
   else if( strncmp( "MH25", rdBuf, 4 ) == 0 )
   {
      *bandwidth = 2;
   }

   return( RSCMU_Status );

} // endof RSCMU_TDMA_SenseMobileInfoBandwidth()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_SenseMobileInfoProtocolVer
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_SenseMobileInfoProtocolVer( ViSession  instrSession
                                        , ViInt32   *ProtocolVersion
                                        , ViChar     errorMessage[]
                                        )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[102].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Get the mobile reported ID Type
   if( strncmp( "NAN", rdBuf, 3 ) == 0 ) 
   {
      *ProtocolVersion = 0;
   }
   else if( strncmp( "PV0", rdBuf, 3 ) == 0 )
   {
      *ProtocolVersion = 1;
   }
   else if( strncmp( "PV1", rdBuf, 3 ) == 0 )
   {
      *ProtocolVersion = 2;
   }
   else if( strncmp( "PV2", rdBuf, 3 ) == 0 )
   {
      *ProtocolVersion = 3;
   }
   else if( strncmp( "PV3", rdBuf, 3 ) == 0 )
   {
      *ProtocolVersion = 4;
   }
   else if( strncmp( "PV4", rdBuf, 3 ) == 0 )
   {
      *ProtocolVersion = 5;
   }
   else if( strncmp( "PV5", rdBuf, 3 ) == 0 )
   {
      *ProtocolVersion = 6;
   }

   return( RSCMU_Status );

} // endof RSCMU_TDMA_SenseMobileInfoProtocolVer()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_SenseMobileInfoDialledNum
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_SenseMobileInfoDialledNum( ViSession instrSession
                                       , ViChar    DialledNumber[]
                                       , ViChar    errorMessage[]
                                       )
{
   ViStatus RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
   

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[103].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Get the mobile reported ID Number
   strncpy( DialledNumber, &rdBuf[1], strlen(rdBuf) - 2 );
   DialledNumber[strlen(rdBuf) - 2] = '\0';
  
   return( RSCMU_Status );

} // endof RSCMU_TDMA_SenseMobileInfoDialledNum()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_SenseMobileInfoVoiceCoder
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_SenseMobileInfoVoiceCoder( ViSession  instrSession
                                       , ViInt32   *VoiceCoder
                                       , ViChar     errorMessage[]
                                       )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[104].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Get the mobile reported ID Type
   if( strncmp( "NAN", rdBuf, 3 ) == 0 ) 
   {
      *VoiceCoder = 0;
   }
   else if( strncmp( "VSEL", rdBuf, 4 ) == 0 )
   {
      *VoiceCoder = 1;
   }
   else if( strncmp( "ACEL", rdBuf, 4 ) == 0 )
   {
      *VoiceCoder = 2;
   }
   else if( strncmp( "MSEL", rdBuf, 4 ) == 0 )
   {
      *VoiceCoder = 3;
   }

   return( RSCMU_Status );

} // endof RSCMU_TDMA_SenseMobileInfoVoiceCoder()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_NPowSetExpectedPower
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_TDMA_NPowSetExpectedPower (ViSession   instrumentHandle,
                                                   ViReal64    setExpectedPower_dBm,
                                                   ViChar      errorMessage[])
{

   ViStatus  RSCMU_Status = VI_SUCCESS;  
// JMG   ViChar   *wrtBuf;
// JMG  ViChar   *rdBuf;
// JMG  struct      RSCMU_SESSION_Globals  *p_globalvarBase;    
   
    RSCMU_Status    = RSCMU_errorMessage( instrumentHandle, RSCMU_IS136_WARNING_GPIB_FEATURE, errorMessage );

/*
   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        

   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_07)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_07, errorMessage); 


   checkRange( 181
             , &setExpectedPower_dBm
             );
   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[181].instrCommand
          , setExpectedPower_dBm
          );

   RSCMU_Status = RSCMU_Query( instrumentHandle
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
*/
   return( RSCMU_Status );


} // RSCMU_TDMA_NPowSetExpectedPower

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfNPowControl
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_TDMA_ConfNPowControl (ViSession instrumentHandle,
                                              ViInt32 statistics,
                                              ViInt32 rep,
                                              ViInt32 stopCondition,
                                              ViInt32 step,
                                              ViChar errorMessage[])
{
    
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        

   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_07)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_07, errorMessage); 

   checkRange( 182, &statistics, &rep, &stopCondition, &step);
   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[182].instrCommand
          , statistics
          , repetition.list[rep]
          , stopCond.list[stopCondition]
          , stepMode.list[step]
          );

   RSCMU_Status = RSCMU_Query( instrumentHandle
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // RSCMU_TDMA_ConfNPowControl

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfNPowControlStats
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_TDMA_ConfNPowControlStats (ViSession instrumentHandle,
                                                   ViInt32 statistics,
                                                   ViChar errorMessage[])
{
    
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        

   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_07)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_07, errorMessage); 

   checkRange( 183, &statistics);
   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[183].instrCommand
          , statistics
          );

   RSCMU_Status = RSCMU_Query( instrumentHandle
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // RSCMU_TDMA_ConfNPowControlStats

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfNPowControlRep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_TDMA_ConfNPowControlRep (ViSession instrumentHandle,
                                                 ViInt32 rep,
                                                 ViInt32 stopCondition,
                                                 ViInt32 step,
                                                 ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        

   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_07)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_07, errorMessage); 

   checkRange( 184, &rep, &stopCondition, &step);
   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[184].instrCommand
          , repetition.list[rep]
          , stopCond.list[stopCondition]
          , stepMode.list[step]
          );

   RSCMU_Status = RSCMU_Query( instrumentHandle
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );    
}
// RSCMU_TDMA_ConfNPowControlRep


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_InitNPow
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_TDMA_InitNPow (ViSession instrumentHandle,
                                       ViChar errorMessage[])
{
    
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        

   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_07)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_07, errorMessage); 

   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrumentHandle
                             , (ViChar *)IS136[185].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   return( RSCMU_Status );

} // RSCMU_TDMA_InitNPow

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_AbortNPow
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_TDMA_AbortNPow (ViSession instrumentHandle,
                                        ViChar errorMessage[])
{

   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        

   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_07)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_07, errorMessage); 

   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrumentHandle
                             , (ViChar *)IS136[186].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   return( RSCMU_Status );
    
} //  RSCMU_TDMA_AbortNPow

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_StopNPow
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_TDMA_StopNPow (ViSession instrumentHandle,
                                       ViChar errorMessage[])
{

   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        

   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_07)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_07, errorMessage); 

   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrumentHandle
                             , (ViChar *)IS136[187].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   return( RSCMU_Status );
   
} // RSCMU_TDMA_StopNPow

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ContinueNPow
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_TDMA_ContinueNPow (ViSession instrumentHandle,
                                           ViChar errorMessage[])
{

   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        

   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_07)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_07, errorMessage); 

   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrumentHandle
                             , (ViChar *)IS136[188].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );  
   
} // RSCMU_CDMA_ContinueNPow

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_FetchNPowStatus
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_TDMA_FetchNPowStatus (ViSession instrumentHandle,
                                              ViInt32 *measurementStatus,
                                              ViInt32 *counter_forStatisticsCycle,
                                              ViInt32 *counter_forEvaluationPeriod,
                                              ViChar errorMessage[])
{

   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;
   ViChar    tab[38][30]; 
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        

   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_07)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_07, errorMessage); 

   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrumentHandle
                             , (ViChar *)IS136[189].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   if( RSCMU_Status >= 0 )
   {
       // Separate the CMU response:
       RSCMU_SeparateString( rdBuf, ",", tab );

       // Get the measurement status
       RSCMU_Status = 
          RSCMU_GetMeasurementStatus( measurementStatus, tab, 0 );

       // Get the counter for current statistics cycle
       if( strcmp( tab[1], "NONE" ) != 0 )
       {
          sscanf( tab[1], "%d", counter_forStatisticsCycle );
       }
       else
       {
          *counter_forStatisticsCycle = RSCMU_OFF;
       }

       // Get the counter for current evaluation period within a cycle
       if( strcmp( tab[2], "NONE" ) != 0 )
       {
          sscanf( tab[2], "%d", counter_forEvaluationPeriod );
       }
       else
       {
          *counter_forEvaluationPeriod = RSCMU_OFF;
       }
   }

   return( RSCMU_Status );
    
} // RSCMU_TDMA_FetchNPowStatus

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfNPowEReport
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_TDMA_ConfNPowEReport (ViSession instrumentHandle,
                                              ViInt32 measurementEventReporting,
                                              ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        

   
   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_07)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_07, errorMessage); 

   checkRange( 190, &measurementEventReporting );
   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[190].instrCommand
          , eventReport.list[measurementEventReporting]
          );

   RSCMU_Status = RSCMU_Query( instrumentHandle
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    

} // RSCMU_TDMA_ConfNPowEReport

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ReadNPow
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_TDMA_ReadNPow (ViSession instrumentHandle,
                                       ViReal64 *currentAveragePower_dBm,
                                       ViReal64 *currentMinPower_dBm,
                                       ViReal64 *currentMaxPower_dBm,
                                       ViReal64 *averageAveragePower_dBm,
                                       ViReal64 *averageMinPower_dBm,
                                       ViReal64 *averageMaxPower_dBm,
                                       ViChar errorMessage[])
{
    
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[38][30]; 
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        

   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_07)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_07, errorMessage); 

   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrumentHandle
                             , (ViChar *)IS136[191].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   // Get currentAveragePower
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", currentAveragePower_dBm );
   }
   else
   {
      *currentAveragePower_dBm = RSCMU_NAN;
   }

   // Get currentMinPower
   if( strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", currentMinPower_dBm );
   }
   else
   {
      *currentMinPower_dBm = RSCMU_NAN;
   }

   // Get currentMaxPower
   if( strcmp( tab[2], "NAN" ) != 0 )
   {
      sscanf( tab[2], "%lf", currentMaxPower_dBm );
   }
   else
   {
      *currentMaxPower_dBm = RSCMU_NAN;
   }

   // Get averageAveragePower
   if( strcmp( tab[3], "NAN" ) != 0 )
   {
      sscanf( tab[3], "%lf", averageAveragePower_dBm );
   }
   else
   {
      *averageAveragePower_dBm = RSCMU_NAN;
   }
   
   // Get averageMinPower
   if( strcmp( tab[4], "NAN" ) != 0 )
   {
      sscanf( tab[4], "%lf", averageMinPower_dBm );
   }
   else
   {
      *averageMinPower_dBm = RSCMU_NAN;
   }
   
   // Get averageMaxPower
   if( strcmp( tab[5], "NAN" ) != 0 )
   {
      sscanf( tab[5], "%lf", averageMaxPower_dBm );
   }
   else
   {
      *averageMaxPower_dBm = RSCMU_NAN;
   }

   return( RSCMU_Status );


}  // RSCMU_TDMA_ReadNPow


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_FetchNPow
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_TDMA_FetchNPow (ViSession instrumentHandle,
                                        ViReal64 *currentAveragePower_dBm,
                                        ViReal64 *averageAveragePower_dBm,
                                        ViReal64 *currentMinPower_dBm,
                                        ViReal64 *averageMinPower_dBm,
                                        ViReal64 *currentMaxPower_dBm,
                                        ViReal64 *averageMaxPower_dBm,
                                        ViChar errorMessage[])
{

   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[38][30]; 
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        
   
   
   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_07)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_07, errorMessage); 

   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrumentHandle
                             , (ViChar *)IS136[192].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   // Get currentAveragePower
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", currentAveragePower_dBm );
   }
   else
   {
      *currentAveragePower_dBm = RSCMU_NAN;
   }

   // Get currentMinPower
   if( strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", currentMinPower_dBm );
   }
   else
   {
      *currentMinPower_dBm = RSCMU_NAN;
   }

   // Get currentMaxPower
   if( strcmp( tab[2], "NAN" ) != 0 )
   {
      sscanf( tab[2], "%lf", currentMaxPower_dBm );
   }
   else
   {
      *currentMaxPower_dBm = RSCMU_NAN;
   }

   // Get averageAveragePower
   if( strcmp( tab[3], "NAN" ) != 0 )
   {
      sscanf( tab[3], "%lf", averageAveragePower_dBm );
   }
   else
   {
      *averageAveragePower_dBm = RSCMU_NAN;
   }
   
   // Get averageMinPower
   if( strcmp( tab[4], "NAN" ) != 0 )
   {
      sscanf( tab[4], "%lf", averageMinPower_dBm );
   }
   else
   {
      *averageMinPower_dBm = RSCMU_NAN;
   }
   
   // Get averageMaxPower
   if( strcmp( tab[5], "NAN" ) != 0 )
   {
      sscanf( tab[5], "%lf", averageMaxPower_dBm );
   }
   else
   {
      *averageMaxPower_dBm = RSCMU_NAN;
   }

   return( RSCMU_Status );
    
} // RSCMU_TDMA_FetchNPow

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_SampleNPow
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_TDMA_SampleNPow (ViSession instrumentHandle,
                                         ViReal64 *currentAveragePower_dBm,
                                         ViReal64 *averageAveragePower_dBm,
                                         ViReal64 *currentMinPower_dBm,
                                         ViReal64 *averageMinPower_dBm,
                                         ViReal64 *currentMaxPower_dBm,
                                         ViReal64 *averageMaxPower_dBm,
                                         ViChar errorMessage[])
{
    
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[38][30]; 
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        

   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_07)
       return RSCMU_Base_errorMessage(instrumentHandle, RSCMU_ERROR_FW_VERSION_3_07, errorMessage); 

   getBuffers( instrumentHandle
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrumentHandle
                             , (ViChar *)IS136[193].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   // Get currentAveragePower
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", currentAveragePower_dBm );
   }
   else
   {
      *currentAveragePower_dBm = RSCMU_NAN;
   }

   // Get currentMinPower
   if( strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", currentMinPower_dBm );
   }
   else
   {
      *currentMinPower_dBm = RSCMU_NAN;
   }

   // Get currentMaxPower
   if( strcmp( tab[2], "NAN" ) != 0 )
   {
      sscanf( tab[2], "%lf", currentMaxPower_dBm );
   }
   else
   {
      *currentMaxPower_dBm = RSCMU_NAN;
   }

   // Get averageAveragePower
   if( strcmp( tab[3], "NAN" ) != 0 )
   {
      sscanf( tab[3], "%lf", averageAveragePower_dBm );
   }
   else
   {
      *averageAveragePower_dBm = RSCMU_NAN;
   }
   
   // Get averageMinPower
   if( strcmp( tab[4], "NAN" ) != 0 )
   {
      sscanf( tab[4], "%lf", averageMinPower_dBm );
   }
   else
   {
      *averageMinPower_dBm = RSCMU_NAN;
   }
   
   // Get averageMaxPower
   if( strcmp( tab[5], "NAN" ) != 0 )
   {
      sscanf( tab[5], "%lf", averageMaxPower_dBm );
   }
   else
   {
      *averageMaxPower_dBm = RSCMU_NAN;
   }

   return( RSCMU_Status );


}  // RSCMU_TDMA_SampleNPow

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_InitPow
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_InitPow( ViSession instrSession
                     , ViInt32   application
                     , ViChar    errorMessage[]
                     )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 27, &application );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[27].instrCommand
          , powerType.list[application]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   return( RSCMU_Status );

} // endof RSCMU_TDMA_InitPow()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_AbortPow
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_AbortPow( ViSession instrSession
                      , ViInt32   application
                      , ViChar    errorMessage[]
                      )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 28, &application );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[28].instrCommand
          , powerType.list[application]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   return( RSCMU_Status );

} // endof RSCMU_TDMA_AbortPow()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_StopPow
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_StopPow( ViSession instrSession
                     , ViInt32   application
                     , ViChar    errorMessage[]
                     )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 29, &application );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[29].instrCommand
          , powerType.list[application]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   return( RSCMU_Status );

} // endof RSCMU_TDMA_StopPow()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_RestartPow
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_RestartPow( ViSession instrSession
                        , ViInt32   application
                        , ViChar    errorMessage[]
                        )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
//   ViChar   *wrtBuf;
//   ViChar   *rdBuf;

   
        RSCMU_Status    = RSCMU_errorMessage( instrSession, RSCMU_IS136_WARNING_GPIB_FEATURE, errorMessage );

/*
   checkRange( 30, &application );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[30].instrCommand
          , powerType.list[application]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
*/
   return( RSCMU_Status );

} // endof RSCMU_TDMA_RestartPow()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ContinuePow
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ContinuePow( ViSession instrSession
                         , ViInt32   application
                         , ViChar    errorMessage[]
                         )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 31, &application );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[31].instrCommand
          , powerType.list[application]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   return( RSCMU_Status );

} // endof RSCMU_TDMA_ContinuePow()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_FetchPowStatus
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_FetchPowStatus( ViSession  instrSession
                            , ViInt32    application
                            , ViInt32   *measurementStatus
                            , ViInt32   *CurrentStatCycleCount
                            , ViInt32   *CurrentEvalPeriodCount
                            , ViChar     errorMessage[]
                            )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[38][30];    

   checkRange( 36, &application );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[36].instrCommand
          , powerType.list[application]
          );


   // Fetch the measurement status:
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   if( RSCMU_Status >= 0 )
   {
       // Separate the CMU response:
       RSCMU_SeparateString( rdBuf, ",", tab );

       // Get the measurement status
       RSCMU_Status = 
          RSCMU_GetMeasurementStatus( measurementStatus, tab, 0 );

       // Get the counter for current statistics cycle
       if( strcmp( tab[1], "NONE" ) != 0 )
       {
          sscanf( tab[1], "%d", CurrentStatCycleCount );
       }
       else
       {
          *CurrentStatCycleCount = RSCMU_OFF;
       }

       // Get the counter for current evaluation period within a cycle
       if( strcmp( tab[2], "NONE" ) != 0 )
       {
          sscanf( tab[2], "%d", CurrentEvalPeriodCount );
       }
       else
       {
          *CurrentEvalPeriodCount = RSCMU_OFF;
       }
   }

   return RSCMU_Status;
  
} // endof RSCMU_TDMA_FetchPowStatus()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfPowErep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfPowErep( ViSession instrSession
                         , ViInt32   application
                         , ViInt32   measurementEventReporting
                         , ViChar    errorMessage[]
                         )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 32, &application, &measurementEventReporting );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[32].instrCommand
          , powerType.list[application]
          , eventReport.list[measurementEventReporting]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfPowErep()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfPowCont
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfPowCont( ViSession instrSession
                         , ViInt32   application
                         , ViInt32   measType
                         , ViInt32   statistics
                         , ViInt32   oversample
                         , ViChar    errorMessage[]
                         )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 33, &application, &measType, &statistics, &oversample );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[33].instrCommand
          , powerType.list[application]
          , control.list[measType]
          , statistics
          , powerType.list[application]
          , oversampling.list[oversample]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfPowCont()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfPowContRep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfPowContRep( ViSession instrSession
                            , ViInt32   application
                            , ViInt32   rep
                            , ViInt32   stopCondition
                            , ViInt32   step
                            , ViChar    errorMessage[]
                            )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 34, &application, &rep, &stopCondition, &step );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[34].instrCommand
          , powerType.list[application]
          , repetition.list[rep]
          , stopCond.list[stopCondition]
          , stepMode.list[step]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfPowContRep()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfPowContDefault
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
// JMG 030106
ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfPowContDefault( ViSession instrSession
                                , ViInt32   application
                                , ViBoolean state
                                , ViChar    errorMessage[]
                                )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   if (state == RSCMU_OFF)
   {
   
        RSCMU_Status    = RSCMU_errorMessage( instrSession, RSCMU_IS136_WARNING_GPIB_FEATURE, errorMessage );
        return( RSCMU_Status);
   }

   checkRange( 199, &application, &state );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[199].instrCommand
          , powerType.list[application]
          , enable.list[state]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfPowContDefault()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_DispPowContGrid
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_DispPowContGrid( ViSession instrSession
                             , ViInt32   application
                             , ViBoolean gridLines
                             , ViChar    errorMessage[]
                             )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 35, &application, &gridLines );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[35].instrCommand
          , powerType.list[application]
          , enable.list[gridLines]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_DispPowContGrid()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfPowUppLimLineLevel
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfPowUppLimLineLevel( ViSession     instrSession
                                    , ViInt32       application
                                    , ViInt32       area
                                    , ViReal64      level
                                    , ViBoolean     state
                                    , ViChar        errorMessage[]
                                    )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 37, &application, &area, &level, &state );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[37].instrCommand
          , powerType.list[application]
          , area
          , level
          , enable.list[state]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfPowUppLimLineLevel()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfPowUppLimLineEnable
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfPowUppLimLineEnable( ViSession    instrSession
                                     , ViInt32      application
                                     , ViInt32      area
                                     , ViBoolean    state
                                     , ViChar       errorMessage[]
                                     )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 38, &application, &area, &state );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[38].instrCommand
          , powerType.list[application]
          , area
          , enable.list[state]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfPowUppLimLineEnable()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfPowLowLimLineLevel
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfPowLowLimLineLevel( ViSession instrSession
                                    , ViInt32   application
                                    , ViReal64  level
                                    , ViBoolean state
                                    , ViChar    errorMessage[]
                                    )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 62, &application, &level, &state );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[62].instrCommand
          , powerType.list[application]
          , level
          , enable.list[state]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfPowLowLimLineLevel()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfPowLowLimLineEnable
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfPowLowLimLineEnable( ViSession    instrSession
                                     , ViInt32      application
                                     , ViBoolean    state
                                     , ViChar       errorMessage[]
                                     )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 129, &application, &state );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[129].instrCommand
          , powerType.list[application]
          , enable.list[state]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfPowLowLimLineEnable()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfPowLimitLeakage
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfPowLimitLeakage( ViSession    instrSession
                                 , ViInt32      application
                                 , ViReal64     leakagePower
                                 , ViChar       errorMessage[]
                                 )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 39, &application, &leakagePower );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[39].instrCommand
          , powerType.list[application]
          , leakagePower
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfPowLimitLeakage()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfPowLimitDefault
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfPowLimitDefault( ViSession    instrSession
                                 , ViInt32      application
                                 , ViBoolean    state
                                 , ViChar       errorMessage[]
                                 )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   if (state == RSCMU_OFF)
   {
   
        RSCMU_Status    = RSCMU_errorMessage( instrSession, RSCMU_IS136_WARNING_GPIB_FEATURE, errorMessage );
        return( RSCMU_Status);
   }

   checkRange( 147, &application, &state );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[147].instrCommand
          , powerType.list[application]
          , enable.list[state]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfModContDefault()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfArrPowRange
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfArrPowRange( ViSession instrSession
                             , ViInt32   application
                             , ViInt32   subArrMode
                             , ViInt32   oversamp
                             , ViInt32   firstMeasurementPoint
                             , ViInt32   numberofResultstoReturn
                             , ViChar    errorMessage[]
                             )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   if ((oversamp == RSCMU_OVERSAMPLE1) && (numberofResultstoReturn >= 202))
    numberofResultstoReturn = 202;
   
   checkRange( 41
             , &application
             , &subArrMode
             , &oversamp
             , &firstMeasurementPoint
             , &numberofResultstoReturn
             );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[41].instrCommand
          , powerType.list[application]
          , traceMode.list[subArrMode]
          , firstMeasurementPoint
          , numberofResultstoReturn
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfArrPowRange()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ReadArrPowBurst
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ReadArrPowBurst( ViSession instrSession
                             , ViInt32   application
                             , ViInt32   measureType
                             , ViReal64  BurstPower[]
                             , ViChar    errorMessage[]
                             )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViInt32  arrtype = 0;
   struct   RSCMU_TDMA_Globals  *p_globalvarTDMA;
  

   //Get the global structure
   // JMG 030102
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarTDMA)) < 0)
     return RSCMU_Status;                                        

   
   switch (measureType )
   {
       case RSCMU_CURRENT:
        arrtype = 0; 
       break;
   
       case RSCMU_AVERAGE:
        arrtype = 0; 
       break;

       case RSCMU_MAXIMUM:
        arrtype = 0; 
       break;
   
       case RSCMU_MINIMUM:
        arrtype = 0; 
       break;

       case RSCMU_CURRENT_SUB:
        arrtype = 1; 
        measureType = measureType - 4;
       break;
   
       case RSCMU_AVERAGE_SUB:
        arrtype = 1; 
        measureType = measureType - 4;
       break;

       case RSCMU_MAXIMUM_SUB:
        arrtype = 1; 
        measureType = measureType - 4;
       break;
   
       case RSCMU_MINIMUM_SUB:
        arrtype = 1; 
        measureType = measureType - 4;
       break;
   }
    
   // Check if the function is correctly used:
   checkRange( 46, &arrtype, &application, &measureType );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[46].instrCommand
          , arrayType.list[arrtype]
          , powerType.list[application]
          , measMode.list[measureType]
          );


   // JMG 030102
   RSCMU_Status = RSCMU_Query_Array( instrSession
                             , wrtBuf
                             , &p_globalvarTDMA->rdABuf[0]
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   RSCMU_ReturnArrayValues( p_globalvarTDMA->rdABuf, BurstPower );
   
                             
/* JMG 030102
   // Allocate a much larger memory block than the default.
   rdBuf = malloc( RD_BUFFER_SIZE_ARRAY );
   if( rdBuf != NULL )
   {
#if 0
      if( (RSCMU_Status = RSCMU_Query( instrSession
                                     , wrtBuf
                                     , rdBuf
                                     , RSCMU_STB_ON
                                     , errorMessage
                                     )) < 0 )
      {
         free( rdBuf );
         return( RSCMU_Status );
      }
#else
      // Write data to the CMU
      if ((RSCMU_Status = RSCMU_Write (instrSession, wrtBuf, RSCMU_STB_ON, strlen(wrtBuf), errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }

      // Read the resulting output
      if ((RSCMU_Status = RSCMU_Read (instrSession, rdBuf, RD_BUFFER_SIZE_ARRAY, errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }
#endif

      // Find all burst power values by breaking the read buffer:
      RSCMU_ReturnArrayValues( rdBuf, BurstPower );

      // Free the temporary buffer allocation.
      free( rdBuf );
   }
   else
   {
      RSCMU_Status = RSCMU_ERROR_MEMORY_ALLOCATION;
   }

*/   
   return( RSCMU_Status );

} // endof RSCMU_TDMA_ReadArrPowBurst()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_FetchArrPowBurst
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_FetchArrPowBurst( ViSession instrSession
                              , ViInt32   application
                              , ViInt32   measureType
                              , ViReal64  BurstPower[]
                              , ViChar    errorMessage[]
                              )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViInt32  arrtype = 0;
   struct   RSCMU_TDMA_Globals  *p_globalvarTDMA;
  

   //Get the global structure
   // JMG 030102
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarTDMA)) < 0)
     return RSCMU_Status;                                        

   switch (measureType )
   {
       case RSCMU_CURRENT:
        arrtype = 0; 
       break;
   
       case RSCMU_AVERAGE:
        arrtype = 0; 
       break;

       case RSCMU_MAXIMUM:
        arrtype = 0; 
       break;
   
       case RSCMU_MINIMUM:
        arrtype = 0; 
       break;

       case RSCMU_CURRENT_SUB:
        arrtype = 1; 
        measureType = measureType - 4;
       break;
   
       case RSCMU_AVERAGE_SUB:
        arrtype = 1; 
        measureType = measureType - 4;
       break;

       case RSCMU_MAXIMUM_SUB:
        arrtype = 1; 
        measureType = measureType - 4;
       break;
   
       case RSCMU_MINIMUM_SUB:
        arrtype = 1; 
        measureType = measureType - 4;
       break;
   }

   // Check if the function is correctly used:
   checkRange( 47, &arrtype, &application, &measureType );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[47].instrCommand
          , arrayType.list[arrtype]
          , powerType.list[application]
          , measMode.list[measureType]
          );

   // JMG 030102
   RSCMU_Status = RSCMU_Query_Array( instrSession
                             , wrtBuf
                             , &p_globalvarTDMA->rdABuf[0]
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   RSCMU_ReturnArrayValues( p_globalvarTDMA->rdABuf, BurstPower );

/* JMG 030102

   // Allocate a much larger memory block than the default.
   rdBuf = malloc( RD_BUFFER_SIZE_ARRAY );
   if( rdBuf != NULL )
   {
#if 0
      if( (RSCMU_Status = RSCMU_Query( instrSession
                                     , wrtBuf
                                     , rdBuf
                                     , RSCMU_STB_ON
                                     , errorMessage
                                     )) < 0 )
      {
         free( rdBuf );
         return( RSCMU_Status );
      }
#else
      // Write data to the CMU
      if ((RSCMU_Status = RSCMU_Write (instrSession, wrtBuf, RSCMU_STB_ON, strlen(wrtBuf), errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }

      // Read the resulting output
      if ((RSCMU_Status = RSCMU_Read (instrSession, rdBuf, RD_BUFFER_SIZE_ARRAY, errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }
#endif

      // Find all burst power values by breaking the read buffer:
      RSCMU_ReturnArrayValues( rdBuf
                             , BurstPower
                             );

      // Free the temporary buffer allocation.
      free( rdBuf );
   }
   else
   {
      RSCMU_Status = RSCMU_ERROR_MEMORY_ALLOCATION;
   }
*/   
   return( RSCMU_Status );

} // endof RSCMU_TDMA_FetchArrPowBurst()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_SampleArrPowBurst
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_SampleArrPowBurst( ViSession instrSession
                               , ViInt32   application
                               , ViInt32   measureType
                               , ViReal64  BurstPower[]
                               , ViChar    errorMessage[]
                               )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViInt32  arrtype = 0;
   struct   RSCMU_TDMA_Globals  *p_globalvarTDMA;
  

   //Get the global structure
   // JMG 030102
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarTDMA)) < 0)
     return RSCMU_Status;                                        

   switch (measureType )
   {
       case RSCMU_CURRENT:
        arrtype = 0; 
       break;
   
       case RSCMU_AVERAGE:
        arrtype = 0; 
       break;

       case RSCMU_MAXIMUM:
        arrtype = 0; 
       break;
   
       case RSCMU_MINIMUM:
        arrtype = 0; 
       break;

       case RSCMU_CURRENT_SUB:
        arrtype = 1; 
        measureType = measureType - 4;
       break;
   
       case RSCMU_AVERAGE_SUB:
        arrtype = 1; 
        measureType = measureType - 4;
       break;

       case RSCMU_MAXIMUM_SUB:
        arrtype = 1; 
        measureType = measureType - 4;
       break;
   
       case RSCMU_MINIMUM_SUB:
        arrtype = 1; 
        measureType = measureType - 4;
       break;
   }

   // Check if the function is correctly used:
   checkRange( 48, &arrtype, &application, &measureType );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[48].instrCommand
          , arrayType.list[arrtype]
          , powerType.list[application]
          , measMode.list[measureType]
          );

   RSCMU_Status = RSCMU_Query_Array( instrSession
                             , wrtBuf
                             , &p_globalvarTDMA->rdABuf[0]
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   RSCMU_ReturnArrayValues( p_globalvarTDMA->rdABuf, BurstPower );

/* JMG 030102
   // Allocate a much larger memory block than the default.
   rdBuf = malloc( RD_BUFFER_SIZE_ARRAY );
   if( rdBuf != NULL )
   {
#if 0
      if( (RSCMU_Status = RSCMU_Query( instrSession
                                     , wrtBuf
                                     , rdBuf
                                     , RSCMU_STB_ON
                                     , errorMessage
                                     )) < 0 )
      {
         free( rdBuf );
         return( RSCMU_Status );
      }
#else
      // Write data to the CMU
      if ((RSCMU_Status = RSCMU_Write (instrSession, wrtBuf, RSCMU_STB_ON, strlen(wrtBuf), errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }

      // Read the resulting output
      if ((RSCMU_Status = RSCMU_Read (instrSession, rdBuf, RD_BUFFER_SIZE_ARRAY, errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }
#endif

      // Find all burst power values by breaking the read buffer:
      RSCMU_ReturnArrayValues( rdBuf
                             , BurstPower
                             );

      // Free the temporary buffer allocation.
      free( rdBuf );
   }
   else
   {
      RSCMU_Status = RSCMU_ERROR_MEMORY_ALLOCATION;
   }
*/   
   return( RSCMU_Status );

} // endof RSCMU_TDMA_SampleArrPowBurst()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_CalcScalPowMatchBurst
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_CalcScalPowMatchBurst( ViSession  instrSession
                                   , ViInt32    application
                                   , ViInt32   *Current_Power
                                   , ViInt32   *Min_Power
                                   , ViInt32   *Max_Power
                                   , ViInt32   *Average_Power
                                   , ViChar     errorMessage[]
                                   )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[38][30]; 
   
   // Check if the function is correctly used:               
   checkRange( 49, &application );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Fetch the Measurement status. 
   sprintf( wrtBuf
          , IS136[49].instrCommand
          , powerType.list[application]
          );

   if( (RSCMU_Status = RSCMU_Query( instrSession
                                  , wrtBuf
                                  , rdBuf
                                  , RSCMU_STB_ON
                                  , errorMessage
                                  )) < 0 )
   {
      return RSCMU_Status;
   }   
   
   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   // Extract the CMU response:
   if( strncmp( "MATC", tab[0], 4 ) == 0 )
   {
     *Current_Power = RSCMU_MATCH_MATC;
   }
   else if( strncmp( "NMAT", tab[0], 4 ) == 0 )  
   {
      *Current_Power = RSCMU_MATCH_NMAT;
   }
   else if( strncmp( "INV", tab[0], 3 ) == 0 ) 
   {
      *Current_Power = RSCMU_MATCH_INV;  
   }
   else if( strncmp( "OUT", tab[0], 3 ) == 0 ) 
   {
      *Current_Power = RSCMU_MATCH_OUT;  
   }
    else if( strncmp( "NAN", tab[0], 3 ) == 0 ) 
   {
      *Current_Power = RSCMU_NAN_VI_INT32;  
   }

     // Extract the CMU response:
   if( strncmp( "MATC", tab[1], 4 ) == 0 )
   {
     *Min_Power = RSCMU_MATCH_MATC;
   }
   else if( strncmp( "NMAT", tab[1], 4 ) == 0 )  
   {
      *Min_Power = RSCMU_MATCH_NMAT;
   }
   else if( strncmp( "INV", tab[1], 3 ) == 0 ) 
   {
      *Min_Power = RSCMU_MATCH_INV;  
   }
   else if( strncmp( "OUT", tab[1], 3 ) == 0 ) 
   {
      *Min_Power = RSCMU_MATCH_OUT;  
   }
    else if( strncmp( "NAN", tab[1], 3 ) == 0 ) 
   {
      *Min_Power = RSCMU_NAN_VI_INT32;  
   }

   // Extract the CMU response:
   if( strncmp( "MATC", tab[2], 4 ) == 0 )
   {
     *Max_Power = RSCMU_MATCH_MATC;
   }
   else if( strncmp( "NMAT", tab[2], 4 ) == 0 )  
   {
      *Max_Power = RSCMU_MATCH_NMAT;
   }
   else if( strncmp( "INV", tab[2], 3 ) == 0 ) 
   {
      *Max_Power = RSCMU_MATCH_INV;  
   }
   else if( strncmp( "OUT", tab[2], 3 ) == 0 ) 
   {
      *Max_Power = RSCMU_MATCH_OUT;  
   }
    else if( strncmp( "NAN", tab[2], 3 ) == 0 ) 
   {
      *Max_Power = RSCMU_NAN_VI_INT32;  
   }

   // Extract the CMU response:
   if( strncmp( "MATC", tab[3], 4 ) == 0 )
   {
     *Average_Power = RSCMU_MATCH_MATC;
   }
   else if( strncmp( "NMAT", tab[3], 4 ) == 0 )  
   {
      *Average_Power = RSCMU_MATCH_NMAT;
   }
   else if( strncmp( "INV", tab[3], 3 ) == 0 ) 
   {
      *Average_Power = RSCMU_MATCH_INV;  
   }
   else if( strncmp( "OUT", tab[3], 3 ) == 0 ) 
   {
      *Average_Power = RSCMU_MATCH_OUT;  
   }
    else if( strncmp( "NAN", tab[3], 3 ) == 0 ) 
   {
      *Average_Power = RSCMU_NAN_VI_INT32;  
   }
      
   return( RSCMU_Status );

} // endof RSCMU_TDMA_CalcScalPowMatchBurst()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_CalcArrPowMatchArea
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_CalcArrPowMatchArea( ViSession instrSession
                                 , ViInt32    application
                                 , ViInt32    measureType
                                 , ViInt32   *upperLimit
                                 , ViInt32   *lowerLimit
                                 , ViChar     errorMessage[]
                                 )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[38][30];    
      
   // Check if the function is correctly used:               
   checkRange( 45, &application, &measureType );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Fetch the Measurement status. 
   sprintf( wrtBuf
          , IS136[45].instrCommand
          , powerType.list[application]
          , measMode.list[measureType]
          );

   if( (RSCMU_Status = RSCMU_Query( instrSession
                                  , wrtBuf
                                  , rdBuf
                                  , RSCMU_STB_ON
                                  , errorMessage
                                  )) < 0 )
   {
      return RSCMU_Status;
   }   

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Extract the CMU response:
   if (strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%d", upperLimit );
   }
   else 
   {
      *upperLimit = RSCMU_NAN_VI_INT32;  // JMG
   }

   if (strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%d", lowerLimit );
   }
   else 
   {
      *lowerLimit = RSCMU_NAN_VI_INT32; // JMG
   }
  
   return( RSCMU_Status );

} // endof RSCMU_TDMA_CalcArrPowMatchArea()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ReadScalPow
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ReadScalPow( ViSession  instrSession
                         , ViInt32    application
                         , ViReal64  *burstOutOfTol
                         , ViReal64  *PeakPower
                         , ViReal64  *RMSPower
                         , ViReal64  *PeakLeakagePower
                         , ViReal64  *RMSLeakagePower
                         , ViInt32   *burstMatchingCurrent
                         , ViInt32   *burstMatchingMin
                         , ViInt32   *burstMatchingMax
                         , ViInt32   *burstMatchingAvg
                         , ViChar     errorMessage[]
                         )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[38][30];    
      
   // Check if the function is correctly used:               
   checkRange( 42, &application );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Fetch the Measurement status. 
   sprintf( wrtBuf
          , IS136[42].instrCommand
          , powerType.list[application]
          );

   if( (RSCMU_Status = RSCMU_Query( instrSession
                                  , wrtBuf
                                  , rdBuf
                                  , RSCMU_STB_ON
                                  , errorMessage
                                  )) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Get the number of bursts out of tolerance
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", burstOutOfTol );
   }
   else 
   {
      *burstOutOfTol = RSCMU_NAN; 
   }
  
   // Get the RMS peak burst power
   if (strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", PeakPower );
   }
   else 
   {
      *RMSPower = RSCMU_NAN; 
   }
  
   // Get the peak burst power
   if (strcmp( tab[2], "NAN" ) != 0 )
   {
      sscanf( tab[2], "%lf", RMSPower );
   }
   else
   {
      *PeakPower = RSCMU_NAN;
   }
    
   // Get the RMS peak leakage power
   if (strcmp( tab[3], "NAN" ) != 0 )
   {
      sscanf( tab[3], "%lf", PeakLeakagePower );
   }
   else
   {
      *RMSLeakagePower = RSCMU_NAN; 
   }
  
   // Get the peak leakage power
   if( strcmp( tab[4], "NAN" ) != 0 )
   {
      sscanf( tab[4], "%lf", RMSLeakagePower );
   }
   else
   {
      *PeakLeakagePower = RSCMU_NAN;
   }
    
   // Get burst matching
   if( strncmp( "MATC", tab[5], 4 ) == 0 )
   {
     *burstMatchingCurrent = RSCMU_MATCH_MATC;
   }
   else if( strncmp( "NMAT", tab[5], 4 ) == 0 )  
   {
      *burstMatchingCurrent = RSCMU_MATCH_NMAT;
   }
   else if( strncmp( "INV", tab[5], 3 ) == 0 ) 
   {
      *burstMatchingCurrent = RSCMU_MATCH_INV;  
   }
  
   if( strncmp( "MATC", tab[6], 4 ) == 0 )
   {
     *burstMatchingMin = RSCMU_MATCH_MATC;
   }
   else if( strncmp( "NMAT", tab[6], 4 ) == 0 )  
   {
      *burstMatchingMin = RSCMU_MATCH_NMAT;
   }
   else if( strncmp( "INV", tab[6], 3 ) == 0 ) 
   {
      *burstMatchingMin = RSCMU_MATCH_INV;  
   }
  
   if( strncmp( "MATC", tab[7], 4 ) == 0 )
   {
     *burstMatchingMax = RSCMU_MATCH_MATC;
   }
   else if( strncmp( "NMAT", tab[7], 4 ) == 0 )  
   {
      *burstMatchingMax = RSCMU_MATCH_NMAT;
   }
   else if( strncmp( "INV", tab[7], 3 ) == 0 ) 
   {
      *burstMatchingMax = RSCMU_MATCH_INV;  
   }
  
   if( strncmp( "MATC", tab[8], 4 ) == 0 )
   {
     *burstMatchingAvg = RSCMU_MATCH_MATC;
   }
   else if( strncmp( "NMAT", tab[8], 4 ) == 0 )  
   {
      *burstMatchingAvg = RSCMU_MATCH_NMAT;
   }
   else if( strncmp( "INV", tab[8], 3 ) == 0 ) 
   {
      *burstMatchingAvg = RSCMU_MATCH_INV;  
   }
  
   return( RSCMU_Status );

} // endof RSCMU_TDMA_ReadScalPow()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_FetchScalPow
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_FetchScalPow( ViSession  instrSession
                          , ViInt32    application
                          , ViReal64  *burstOutOfTol
                          , ViReal64  *PeakPower
                          , ViReal64  *RMSPower
                          , ViReal64  *PeakLeakagePower
                          , ViReal64  *RMSLeakagePower
                          , ViInt32   *burstMatchingCurrent
                          , ViInt32   *burstMatchingMin
                          , ViInt32   *burstMatchingMax
                          , ViInt32   *burstMatchingAvg
                          , ViChar     errorMessage[]
                          )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[38][30];    
      
   // Check if the function is correctly used:               
   checkRange( 43, &application );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Fetch the Measurement status. 
   sprintf( wrtBuf
          , IS136[43].instrCommand
          , powerType.list[application]
          );

   if( (RSCMU_Status = RSCMU_Query( instrSession
                                  , wrtBuf
                                  , rdBuf
                                  , RSCMU_STB_ON
                                  , errorMessage
                                  )) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Get the number of bursts out of tolerance
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", burstOutOfTol );
   }
   else 
   {
      *burstOutOfTol = RSCMU_NAN; 
   }
  
   // Get the RMS peak burst power
   if (strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", PeakPower );
   }
   else 
   {
      *RMSPower = RSCMU_NAN; 
   }
  
   // Get the peak burst power
   if (strcmp( tab[2], "NAN" ) != 0 )
   {
      sscanf( tab[2], "%lf", RMSPower );
   }
   else
   {
      *PeakPower = RSCMU_NAN;
   }
    
   // Get the RMS peak leakage power
   if (strcmp( tab[3], "NAN" ) != 0 )
   {
      sscanf( tab[3], "%lf", PeakLeakagePower );
   }
   else
   {
      *RMSLeakagePower = RSCMU_NAN; 
   }
  
   // Get the peak leakage power
   if( strcmp( tab[4], "NAN" ) != 0 )
   {
      sscanf( tab[4], "%lf", RMSLeakagePower );
   }
   else
   {
      *PeakLeakagePower = RSCMU_NAN;
   }
    
   // Get burst matching
   if( strncmp( "MATC", tab[5], 4 ) == 0 )
   {
     *burstMatchingCurrent = RSCMU_MATCH_MATC;
   }
   else if( strncmp( "NMAT", tab[5], 4 ) == 0 )  
   {
      *burstMatchingCurrent = RSCMU_MATCH_NMAT;
   }
   else if( strncmp( "INV", tab[5], 3 ) == 0 ) 
   {
      *burstMatchingCurrent = RSCMU_MATCH_INV;  
   }
  
   if( strncmp( "MATC", tab[6], 4 ) == 0 )
   {
     *burstMatchingMin = RSCMU_MATCH_MATC;
   }
   else if( strncmp( "NMAT", tab[6], 4 ) == 0 )  
   {
      *burstMatchingMin = RSCMU_MATCH_NMAT;
   }
   else if( strncmp( "INV", tab[6], 3 ) == 0 ) 
   {
      *burstMatchingMin = RSCMU_MATCH_INV;  
   }
  
   if( strncmp( "MATC", tab[7], 4 ) == 0 )
   {
     *burstMatchingMax = RSCMU_MATCH_MATC;
   }
   else if( strncmp( "NMAT", tab[7], 4 ) == 0 )  
   {
      *burstMatchingMax = RSCMU_MATCH_NMAT;
   }
   else if( strncmp( "INV", tab[7], 3 ) == 0 ) 
   {
      *burstMatchingMax = RSCMU_MATCH_INV;  
   }
  
   if( strncmp( "MATC", tab[8], 4 ) == 0 )
   {
     *burstMatchingAvg = RSCMU_MATCH_MATC;
   }
   else if( strncmp( "NMAT", tab[8], 4 ) == 0 )  
   {
      *burstMatchingAvg = RSCMU_MATCH_NMAT;
   }
   else if( strncmp( "INV", tab[8], 3 ) == 0 ) 
   {
      *burstMatchingAvg = RSCMU_MATCH_INV;  
   }
  
   return( RSCMU_Status );

}
 // endof RSCMU_TDMA_FetchScalPow()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_SampleScalPow
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus  _VI_FUNC
   RSCMU_TDMA_SampleScalPow( ViSession  instrSession
                           , ViInt32    application
                           , ViReal64  *burstOutOfTol
                           , ViReal64  *PeakPower
                           , ViReal64  *RMSPower
                           , ViReal64  *PeakLeakagePower
                           , ViReal64  *RMSLeakagePower
                           , ViInt32   *burstMatchingCurrent
                           , ViInt32   *burstMatchingMin
                           , ViInt32   *burstMatchingMax
                           , ViInt32   *burstMatchingAvg
                           , ViChar     errorMessage[]
                           )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[38][30];    
      
   // Check if the function is correctly used:               
   checkRange( 44, &application );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Fetch the Measurement status. 
   sprintf( wrtBuf
          , IS136[44].instrCommand
          , powerType.list[application]
          );

   if( (RSCMU_Status = RSCMU_Query( instrSession
                                  , wrtBuf
                                  , rdBuf
                                  , RSCMU_STB_ON
                                  , errorMessage
                                  )) < 0 )
   {
      return( RSCMU_Status );
   }   

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Get the number of bursts out of tolerance
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", burstOutOfTol );
   }
   else 
   {
      *burstOutOfTol = RSCMU_NAN; 
   }
  
   // Get the RMS peak burst power
   if (strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", PeakPower );
   }
   else 
   {
      *RMSPower = RSCMU_NAN; 
   }
  
   // Get the peak burst power
   if (strcmp( tab[2], "NAN" ) != 0 )
   {
      sscanf( tab[2], "%lf", RMSPower );
   }
   else
   {
      *PeakPower = RSCMU_NAN;
   }
    
   // Get the RMS peak leakage power
   if (strcmp( tab[3], "NAN" ) != 0 )
   {
      sscanf( tab[3], "%lf", PeakLeakagePower );
   }
   else
   {
      *RMSLeakagePower = RSCMU_NAN; 
   }
  
   // Get the peak leakage power
   if( strcmp( tab[4], "NAN" ) != 0 )
   {
      sscanf( tab[4], "%lf", RMSLeakagePower );
   }
   else
   {
      *PeakLeakagePower = RSCMU_NAN;
   }
    
   // Get burst matching
   if( strncmp( "MATC", tab[5], 4 ) == 0 )
   {
     *burstMatchingCurrent = RSCMU_MATCH_MATC;
   }
   else if( strncmp( "NMAT", tab[5], 4 ) == 0 )  
   {
      *burstMatchingCurrent = RSCMU_MATCH_NMAT;
   }
   else if( strncmp( "INV", tab[5], 3 ) == 0 ) 
   {
      *burstMatchingCurrent = RSCMU_MATCH_INV;  
   }
  
   if( strncmp( "MATC", tab[6], 4 ) == 0 )
   {
     *burstMatchingMin = RSCMU_MATCH_MATC;
   }
   else if( strncmp( "NMAT", tab[6], 4 ) == 0 )  
   {
      *burstMatchingMin = RSCMU_MATCH_NMAT;
   }
   else if( strncmp( "INV", tab[6], 3 ) == 0 ) 
   {
      *burstMatchingMin = RSCMU_MATCH_INV;  
   }
  
   if( strncmp( "MATC", tab[7], 4 ) == 0 )
   {
     *burstMatchingMax = RSCMU_MATCH_MATC;
   }
   else if( strncmp( "NMAT", tab[7], 4 ) == 0 )  
   {
      *burstMatchingMax = RSCMU_MATCH_NMAT;
   }
   else if( strncmp( "INV", tab[7], 3 ) == 0 ) 
   {
      *burstMatchingMax = RSCMU_MATCH_INV;  
   }
  
   if( strncmp( "MATC", tab[8], 4 ) == 0 )
   {
     *burstMatchingAvg = RSCMU_MATCH_MATC;
   }
   else if( strncmp( "NMAT", tab[8], 4 ) == 0 )  
   {
      *burstMatchingAvg = RSCMU_MATCH_NMAT;
   }
   else if( strncmp( "INV", tab[8], 3 ) == 0 ) 
   {
      *burstMatchingAvg = RSCMU_MATCH_INV;  
   }
  
   return( RSCMU_Status );

} // endof RSCMU_TDMA_SampleScalPow()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfModCont
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfModCont( ViSession instrSession
                         , ViInt32   type
                         , ViInt32   mode
                         , ViInt32   statistics
                         , ViChar    errorMessage[]
                         )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 56, &type, &mode, &statistics );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[56].instrCommand
          , testType.list[type]
          , control.list[mode]
          , statistics
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfModCont()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfModContRep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfModContRep( ViSession instrSession
                            , ViInt32   type
                            , ViInt32   rep
                            , ViInt32   stopCondition
                            , ViInt32   step
                            , ViChar    errorMessage[]
                            )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 57, &type, &rep, &stopCondition, &step );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[57].instrCommand
          , testType.list[type]
          , repetition.list[rep]
          , stopCond.list[stopCondition]
          , stepMode.list[step]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfModContRep()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfModContDefault
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfModContDefault( ViSession instrSession
                                , ViInt32   type
                                , ViBoolean state
                                , ViChar    errorMessage[]
                                )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   if (state == RSCMU_OFF)
   {
   
        RSCMU_Status    = RSCMU_errorMessage( instrSession, RSCMU_IS136_WARNING_GPIB_FEATURE, errorMessage );
        return( RSCMU_Status);
   }

   checkRange( 58, &type, &state );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[58].instrCommand
          , testType.list[type]
          , enable.list[state]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfModContDefault()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_DispModContGrid
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_DispModContGrid( ViSession instrSession
                             , ViInt32   type
                             , ViBoolean gridLines
                             , ViChar    errorMessage[]
                             )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 59, &type, &gridLines );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[59].instrCommand
          , testType.list[type]
          , enable.list[gridLines]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_DispModContGrid()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfModLimDefault
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
// JMG 030106
ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfModLimDefault( ViSession instrSession
                               , ViBoolean state
                               , ViChar    errorMessage[]
                               )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   if (state == RSCMU_OFF)
   {
   
        RSCMU_Status    = RSCMU_errorMessage( instrSession, RSCMU_IS136_WARNING_GPIB_FEATURE, errorMessage );
        return( RSCMU_Status);
   }

   checkRange( 61, &state );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[61].instrCommand
          , enable.list[state]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfModLimDefault()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfModLim
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfModLim( ViSession instrSession
                        , ViInt32   mode
                        , ViInt32   numSymbols
                        , ViReal64  phaseErrorPeak
                        , ViReal64  phaseErrorRMS
                        , ViReal64  MagErrorPeak
                        , ViReal64  MagErrorRMS
                        , ViReal64  EVMErrorPeak
                        , ViReal64  EVMErrorRMS
                        , ViReal64  OriginOffset
                        , ViReal64  IQImbalance
                        , ViReal64  FreqError
                        , ViChar    errorMessage[]
                        )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 60
             , &mode
             , &numSymbols
             , &phaseErrorPeak
             , &phaseErrorRMS
             , &MagErrorPeak
             , &MagErrorRMS
             , &EVMErrorPeak
             , &EVMErrorRMS
             , &OriginOffset
             , &IQImbalance
             , &FreqError
             );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[60].instrCommand
          , measMode1.list[mode]
          , symbols.list[numSymbols]
          , phaseErrorPeak
          , phaseErrorRMS
          , MagErrorPeak
          , MagErrorRMS
          , EVMErrorPeak
          , EVMErrorRMS
          , OriginOffset
          , IQImbalance
          , FreqError
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfModLim()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_InitMod
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_InitMod( ViSession instrSession
                     , ViInt32   type
                     , ViChar    errorMessage[]
                     )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 50, &type );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[50].instrCommand
          , testType.list[type]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_InitMod()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_AbortMod
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_AbortMod( ViSession instrSession
                      , ViInt32   type
                      , ViChar    errorMessage[]
                      )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 51, &type );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[51].instrCommand
          , testType.list[type]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_AbortMod()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_StopMod
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_StopMod( ViSession instrSession
                     , ViInt32   type
                     , ViChar    errorMessage[]
                     )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 52, &type );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[52].instrCommand
          , testType.list[type]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_StopMod()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ContinueMod
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ContinueMod( ViSession instrSession
                         , ViInt32   type
                         , ViChar    errorMessage[]
                         )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 53, &type );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[53].instrCommand
          , testType.list[type]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ContinueMod()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_FetchModStatus
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_FetchModStatus( ViSession  instrSession
                            , ViInt32    type
                            , ViInt32   *MeasurementStatus
                            , ViInt32   *CounterForCurrentStatCycle
                            , ViInt32   *CounterForEvalPeriod
                            , ViChar     errorMessage[]
                            )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[38][30];    

   checkRange( 55, &type );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[55].instrCommand
          , testType.list[type]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Get the measurement status
   RSCMU_Status = RSCMU_GetMeasurementStatus( MeasurementStatus, tab, 0 );

   // Get the counter for current statistics cycle
   if( strcmp( tab[1], "NONE" ) != 0 )
   {
      sscanf( tab[1], "%d", CounterForCurrentStatCycle );
   }
   else
   {
      *CounterForCurrentStatCycle = RSCMU_OFF;
   }

   // Get the counter for current evaluation period within a cycle
   if( strcmp( tab[2], "NONE" ) != 0 )
   {
      sscanf( tab[2], "%d", CounterForEvalPeriod );
   }
   else
   {
      *CounterForEvalPeriod = RSCMU_OFF;
   }

   return( RSCMU_Status );

} // endof RSCMU_TDMA_FetchModStatus()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfModErep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfModErep( ViSession instrSession
                         , ViInt32   type
                         , ViInt32   measurementEventReporting
                         , ViChar    errorMessage[]
                         )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 54, &type, &measurementEventReporting );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[54].instrCommand
          , testType.list[type]
          , eventReport.list[measurementEventReporting]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfModErep()

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfArrModRange
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_TDMA_ConfArrModRange (ViSession instrSession,
                                              ViInt32   measurementType,
                                              ViInt32   measurementMode,
                                              ViInt32   firstMeasurementPoint,
                                              ViInt32   numberofResultstoReturn,
                                              ViChar    errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

  
   checkRange( 206
             , &measurementType
             , &measurementMode
             , &firstMeasurementPoint
             , &numberofResultstoReturn
             );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[206].instrCommand
          , testType.list[measurementType]
          , traceMode.list[measurementMode]
          , firstMeasurementPoint
          , numberofResultstoReturn
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} // endof RSCMU_TDMA_ConfArrModRange()

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ReadArrayMod
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ReadArrayMod( ViSession instrSession
                          , ViInt32   measurementType
                          , ViInt32   measurementMode
                          , ViReal64  BurstPower[]
                          , ViChar    errorMessage[]
                          )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViInt32  arrtype = 0;
   struct   RSCMU_TDMA_Globals  *p_globalvarTDMA;
  

   //Get the global structure
   // JMG 030102
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarTDMA)) < 0)
     return RSCMU_Status;                                        

   
   switch(measurementMode)
   {
   case     RSCMU_MOD_CURR:
    arrtype         = 0;
   break;
   
   case     RSCMU_MOD_AVER:
    arrtype         = 0;
   break;
   
   case     RSCMU_MOD_MMAX:
    arrtype         = 0;
   break;

   case     RSCMU_MOD_CURR_SUB:
    arrtype         = 1;
    measurementMode = measurementMode - 3;
   break;
   
   case     RSCMU_MOD_AVER_SUB:
    arrtype = 1;
    measurementMode = measurementMode - 3;
   break;
   
   case     RSCMU_MOD_MMAX_SUB:
    arrtype = 1;
    measurementMode = measurementMode - 3;
   break;
   
   }
   
   checkRange( 68, &arrtype , &measurementType, &measurementMode );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[68].instrCommand
          , arrayType.list[arrtype]
          , testType.list [measurementType]
          , measMode2.list[measurementMode]
          );

   // JMG 030102
   RSCMU_Status = RSCMU_Query_Array( instrSession
                             , wrtBuf
                             , &p_globalvarTDMA->rdABuf[0]
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   RSCMU_ReturnArrayValues( p_globalvarTDMA->rdABuf, BurstPower );

/* JMG 030102
    // Allocate a much larger memory block than the default.
   rdBuf = malloc( RD_BUFFER_SIZE_ARRAY );
   if( rdBuf != NULL )
   {
#if 0
      RSCMU_Status = RSCMU_Query( instrSession
                                , wrtBuf
                                , rdBuf
                                , RSCMU_STB_ON
                                , errorMessage
                                );
#else
      // Write data to the CMU
      if ((RSCMU_Status = RSCMU_Write (instrSession, wrtBuf, RSCMU_STB_ON, strlen(wrtBuf), errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }

      // Read the resulting output
      if ((RSCMU_Status = RSCMU_Read (instrSession, rdBuf, RD_BUFFER_SIZE_ARRAY, errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }
#endif

      // Find all burst power values by breaking the read buffer:
      RSCMU_ReturnArrayValues( rdBuf
                             , BurstPower
                             );

      // Free the temporary buffer allocation.
      free( rdBuf );
   }
   else
   {
      RSCMU_Status = RSCMU_ERROR_MEMORY_ALLOCATION;
   }
*/   
   return( RSCMU_Status );

} // endof RSCMU_TDMA_ReadArrayMod()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_FetchArrayMod
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_FetchArrayMod( ViSession instrSession
                           , ViInt32   measurementType
                           , ViInt32   measurementMode
                           , ViReal64  BurstPower[]
                           , ViChar    errorMessage[]
                           )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViInt32  arrtype = 0;
   struct   RSCMU_TDMA_Globals  *p_globalvarTDMA;
  

   //Get the global structure
   // JMG 030102
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarTDMA)) < 0)
     return RSCMU_Status;                                        

   switch(measurementMode)
   {
   case     RSCMU_MOD_CURR:
    arrtype         = 0;
   break;
   
   case     RSCMU_MOD_AVER:
    arrtype         = 0;
   break;
   
   case     RSCMU_MOD_MMAX:
    arrtype         = 0;
   break;

   case     RSCMU_MOD_CURR_SUB:
    arrtype         = 1;
    measurementMode = measurementMode - 3;
   break;
   
   case     RSCMU_MOD_AVER_SUB:
    arrtype = 1;
    measurementMode = measurementMode - 3;
   break;
   
   case     RSCMU_MOD_MMAX_SUB:
    arrtype = 1;
    measurementMode = measurementMode - 3;
   break;
   
   }
   
   checkRange( 69, &arrtype , &measurementType, &measurementMode );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[69].instrCommand
          , arrayType.list[arrtype]
          , testType.list [measurementType]
          , measMode2.list[measurementMode]
          );
   // JMG 030102
   RSCMU_Status = RSCMU_Query_Array( instrSession
                             , wrtBuf
                             , &p_globalvarTDMA->rdABuf[0]
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   RSCMU_ReturnArrayValues( p_globalvarTDMA->rdABuf, BurstPower );

/* JMG 030102          
    // Allocate a much larger memory block than the default.
   rdBuf = malloc( RD_BUFFER_SIZE_ARRAY );
   if( rdBuf != NULL )
   {
#if 0
      RSCMU_Status = RSCMU_Query( instrSession
                                , wrtBuf
                                , rdBuf
                                , RSCMU_STB_ON
                                , errorMessage
                                );
#else
      // Write data to the CMU
      if ((RSCMU_Status = RSCMU_Write (instrSession, wrtBuf, RSCMU_STB_ON, strlen(wrtBuf), errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }

      // Read the resulting output
      if ((RSCMU_Status = RSCMU_Read (instrSession, rdBuf, RD_BUFFER_SIZE_ARRAY, errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }
#endif

      // Find all burst power values by breaking the read buffer:
      RSCMU_ReturnArrayValues( rdBuf
                             , BurstPower
                             );

      // Free the temporary buffer allocation.
      free( rdBuf );
   }
   else
   {
      RSCMU_Status = RSCMU_ERROR_MEMORY_ALLOCATION;
   }
*/
   return( RSCMU_Status );

} // endof RSCMU_TDMA_FetchArrayMod()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_SampleArrayMod
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_SampleArrayMod( ViSession instrSession
                            , ViInt32   measurementType
                            , ViInt32   measurementMode
                            , ViReal64  BurstPower[]
                            , ViChar    errorMessage[]
                            )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViInt32  arrtype = 0;
   struct   RSCMU_TDMA_Globals  *p_globalvarTDMA;
  

   //Get the global structure
   // JMG 030102
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarTDMA)) < 0)
     return RSCMU_Status;                                        

   switch(measurementMode)
   {
   case     RSCMU_MOD_CURR:
    arrtype         = 0;
   break;
   
   case     RSCMU_MOD_AVER:
    arrtype         = 0;
   break;
   
   case     RSCMU_MOD_MMAX:
    arrtype         = 0;
   break;

   case     RSCMU_MOD_CURR_SUB:
    arrtype         = 1;
    measurementMode = measurementMode - 3;
   break;
   
   case     RSCMU_MOD_AVER_SUB:
    arrtype = 1;
    measurementMode = measurementMode - 3;
   break;
   
   case     RSCMU_MOD_MMAX_SUB:
    arrtype = 1;
    measurementMode = measurementMode - 3;
   break;
   
   }
   
   checkRange( 70, &arrtype , &measurementType, &measurementMode );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[70].instrCommand
          , arrayType.list[arrtype]
          , testType.list [measurementType]
          , measMode2.list[measurementMode]
          );
   // JMG 030102
   RSCMU_Status = RSCMU_Query_Array( instrSession
                             , wrtBuf
                             , &p_globalvarTDMA->rdABuf[0]
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   RSCMU_ReturnArrayValues( p_globalvarTDMA->rdABuf, BurstPower );
   
/* JMG 030102          
    // Allocate a much larger memory block than the default.
   rdBuf = malloc( RD_BUFFER_SIZE_ARRAY );
   if( rdBuf != NULL )
   {
#if 0
      RSCMU_Status = RSCMU_Query( instrSession
                                , wrtBuf
                                , rdBuf
                                , RSCMU_STB_ON
                                , errorMessage
                                );
#else
      // Write data to the CMU
      if ((RSCMU_Status = RSCMU_Write (instrSession, wrtBuf, RSCMU_STB_ON, strlen(wrtBuf), errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }

      // Read the resulting output
      if ((RSCMU_Status = RSCMU_Read (instrSession, rdBuf, RD_BUFFER_SIZE_ARRAY, errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }
#endif

      // Find all burst power values by breaking the read buffer:
      RSCMU_ReturnArrayValues( rdBuf
                             , BurstPower
                             );

      // Free the temporary buffer allocation.
      free( rdBuf );
   }
   else
   {
      RSCMU_Status = RSCMU_ERROR_MEMORY_ALLOCATION;
   }
*/   
   return( RSCMU_Status );

} // endof RSCMU_TDMA_SampleArrayMod()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ReadMod
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ReadMod( ViSession           instrSession
                     , ViInt32             type
                     , ViInt32             SelectNumBursts
                     , RSCMUK2T_ERROR_MOD *Modulation
                     , RSCMUK2T_OVERVIEW  *Overview
                     , ViChar              errorMessage[]
                     )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[38][30];    

   checkRange( 63, &type, &SelectNumBursts );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[63].instrCommand
          , testType.list[type]
          , symbols.list[SelectNumBursts]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   if( type == RSCMU_OVERVIEW )
   {
      RSCMU_Status = RSCMU_ReturnLimits( &tab[0]
                                       , &Overview->PErrPeak
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[3]
                                       , &Overview->PErrRMS
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[6]
                                       , &Overview->MErrPeak
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[9]
                                       , &Overview->MErrRMS
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[12]
                                       , &Overview->EVMPeak
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[15]
                                       , &Overview->EVMRMS
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[18]
                                       , &Overview->OriginOffset
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[21]
                                       , &Overview->IQImbalance
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[24]
                                       , &Overview->FreqErr
                                       );
      RSCMU_Status = RSCMU_ReturnModLimits( &tab[27]
                                          , &Overview->Sync
                                          , &Overview->AmplitudeDrop
                                          , &Overview->TimingErr
                                          , &Overview->PowerRMS
                                          , &Overview->BurstsOutOfTolerance
                                          );
   }
   else
   {
      RSCMU_Status = RSCMU_ReturnLimits( &tab[0]
                                       , &Modulation->Peak
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[3]
                                       , &Modulation->RMS
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[6]
                                       , &Modulation->OriginOffset
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[9]
                                       , &Modulation->IQImbalance
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[12]
                                       , &Modulation->FreqErr
                                       );
      RSCMU_Status = RSCMU_ReturnModLimits( &tab[15]
                                          , &Modulation->Sync
                                          , &Modulation->AmplitudeDrop
                                          , &Modulation->TimingErr
                                          , &Modulation->PowerRMS
                                          , &Modulation->BurstsOutOfTolerance
                                          );
   }

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ReadMod()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_FetchMod
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_FetchMod( ViSession           instrSession
                      , ViInt32             type
                      , ViInt32             SelectNumBursts
                      , RSCMUK2T_ERROR_MOD *Modulation
                      , RSCMUK2T_OVERVIEW  *Overview
                      , ViChar              errorMessage[]
                      )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[38][30];    
   
   checkRange( 64, &type, &SelectNumBursts );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[64].instrCommand
          , testType.list[type]
          , symbols.list[SelectNumBursts]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   if( type == RSCMU_OVERVIEW )
   {
      RSCMU_Status = RSCMU_ReturnLimits( &tab[0]
                                       , &Overview->PErrPeak
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[3]
                                       , &Overview->PErrRMS
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[6]
                                       , &Overview->MErrPeak
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[9]
                                       , &Overview->MErrRMS
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[12]
                                       , &Overview->EVMPeak
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[15]
                                       , &Overview->EVMRMS
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[18]
                                       , &Overview->OriginOffset
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[21]
                                       , &Overview->IQImbalance
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[24]
                                       , &Overview->FreqErr
                                       );
      RSCMU_Status = RSCMU_ReturnModLimits( &tab[27]
                                          , &Overview->Sync
                                          , &Overview->AmplitudeDrop
                                          , &Overview->TimingErr
                                          , &Overview->PowerRMS
                                          , &Overview->BurstsOutOfTolerance
                                          );
   }
   else
   {
      RSCMU_Status = RSCMU_ReturnLimits( &tab[0]
                                       , &Modulation->Peak
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[3]
                                       , &Modulation->RMS
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[6]
                                       , &Modulation->OriginOffset
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[9]
                                       , &Modulation->IQImbalance
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[12]
                                       , &Modulation->FreqErr
                                       );
      RSCMU_Status = RSCMU_ReturnModLimits( &tab[15]
                                          , &Modulation->Sync
                                          , &Modulation->AmplitudeDrop
                                          , &Modulation->TimingErr
                                          , &Modulation->PowerRMS
                                          , &Modulation->BurstsOutOfTolerance
                                          );
   }

   return( RSCMU_Status );

} // endof RSCMU_TDMA_FetchMod()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_SampleMod
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_SampleMod( ViSession           instrSession
                       , ViInt32             type
                       , ViInt32             SelectNumBursts
                       , RSCMUK2T_ERROR_MOD *Modulation
                       , RSCMUK2T_OVERVIEW  *Overview
                       , ViChar              errorMessage[]
                       )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[38][30];    

   checkRange( 65, &type, &SelectNumBursts );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[65].instrCommand
          , testType.list[type]
          , symbols.list[SelectNumBursts]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   if( type == RSCMU_OVERVIEW )
   {
      RSCMU_Status = RSCMU_ReturnLimits( &tab[0]
                                       , &Overview->PErrPeak
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[3]
                                       , &Overview->PErrRMS
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[6]
                                       , &Overview->MErrPeak
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[9]
                                       , &Overview->MErrRMS
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[12]
                                       , &Overview->EVMPeak
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[15]
                                       , &Overview->EVMRMS
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[18]
                                       , &Overview->OriginOffset
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[21]
                                       , &Overview->IQImbalance
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[24]
                                       , &Overview->FreqErr
                                       );
      RSCMU_Status = RSCMU_ReturnModLimits( &tab[27]
                                          , &Overview->Sync
                                          , &Overview->AmplitudeDrop
                                          , &Overview->TimingErr
                                          , &Overview->PowerRMS
                                          , &Overview->BurstsOutOfTolerance
                                          );
   }
   else
   {
      RSCMU_Status = RSCMU_ReturnLimits( &tab[0]
                                       , &Modulation->Peak
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[3]
                                       , &Modulation->RMS
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[6]
                                       , &Modulation->OriginOffset
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[9]
                                       , &Modulation->IQImbalance
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[12]
                                       , &Modulation->FreqErr
                                       );
      RSCMU_Status = RSCMU_ReturnModLimits( &tab[15]
                                          , &Modulation->Sync
                                          , &Modulation->AmplitudeDrop
                                          , &Modulation->TimingErr
                                          , &Modulation->PowerRMS
                                          , &Modulation->BurstsOutOfTolerance
                                          );
   }

   return( RSCMU_Status );

} // endof RSCMU_TDMA_SampleMod()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_CalcMod
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_CalcMod( ViSession           instrSession
                     , ViInt32             type
                     , ViInt32             SymbolRange
                     , RSCMUK2T_ERROR_MOD *Modulation
                     , RSCMUK2T_OVERVIEW  *Overview
                     , ViChar              errorMessage[]
                     )
{
   ViStatus   RSCMU_Status = VI_SUCCESS;  
   ViChar    *wrtBuf;
   ViChar    *rdBuf;
   ViChar     tab[38][30]; 

   checkRange( 66, &type, &SymbolRange );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[66].instrCommand
          , testType.list[type]
          , symbols.list[SymbolRange]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   if ( type == RSCMU_OVERVIEW )
   {
      RSCMU_Status = RSCMU_MatchLimits( &tab[0]
                                      , &Overview->PErrPeak
                                      );
      RSCMU_Status = RSCMU_MatchLimits( &tab[3]
                                      , &Overview->PErrRMS
                                      );
      RSCMU_Status = RSCMU_MatchLimits( &tab[6]
                                      , &Overview->MErrPeak
                                      );
      RSCMU_Status = RSCMU_MatchLimits( &tab[9]
                                      , &Overview->MErrRMS
                                      );
      RSCMU_Status = RSCMU_MatchLimits( &tab[12]
                                      , &Overview->EVMPeak
                                      );
      RSCMU_Status = RSCMU_MatchLimits( &tab[15]
                                      , &Overview->EVMRMS
                                      );
      RSCMU_Status = RSCMU_MatchLimits( &tab[18]
                                      , &Overview->OriginOffset
                                      );
      RSCMU_Status = RSCMU_MatchLimits( &tab[21]
                                      , &Overview->IQImbalance
                                      );
      RSCMU_Status = RSCMU_MatchLimits( &tab[24]
                                      , &Overview->FreqErr
                                      );
   }
   else
   {
      RSCMU_Status = RSCMU_MatchLimits( &tab[0]
                                      , &Modulation->Peak
                                      );
      RSCMU_Status = RSCMU_MatchLimits( &tab[3]
                                      , &Modulation->RMS
                                      );
      RSCMU_Status = RSCMU_MatchLimits( &tab[6]
                                      , &Modulation->OriginOffset
                                      );
      RSCMU_Status = RSCMU_MatchLimits( &tab[9]
                                      , &Modulation->IQImbalance
                                      );
      RSCMU_Status = RSCMU_MatchLimits( &tab[12]
                                      , &Modulation->FreqErr
                                      );
   }

   return( RSCMU_Status );

} // endof RSCMU_TDMA_CalcMod()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_CalcArrLimitMatching
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_CalcArrLimitMatching( ViSession  instrSession
                                  , ViInt32    type
                                  , ViInt32    SelectBurst
                                  , ViInt32   *phErrPeak
                                  , ViInt32   *phErrRMS
                                  , ViInt32   *freqErr
                                  , ViInt32   *avgBurstPowerCurr
                                  , ViChar     errorMessage[]
                                  )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[38][30];    

   checkRange( 67, &type, &SelectBurst );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[67].instrCommand
          , testType.list[type]
          , symbols.list[SelectBurst]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   switch( SelectBurst )
   {
   case RSCMU_CURRENT:
      // Max phase error with single-value measurement  
      RSCMU_Status = RSCMU_GetMeasureMatching( phErrPeak, tab, 0 );

      // RMS phase error with single-value measurement 
      RSCMU_Status = RSCMU_GetMeasureMatching( phErrRMS, tab, 3 );

      // Frequency error with single-value measurement 
      RSCMU_Status = RSCMU_GetMeasureMatching( freqErr, tab, 6 );
      break;

   case RSCMU_AVERAGED:
      // Max phase error with average measurement
      RSCMU_Status = RSCMU_GetMeasureMatching( phErrPeak, tab, 1 );

      // RMS phase error with average measurement
      RSCMU_Status = RSCMU_GetMeasureMatching( phErrRMS, tab, 4 );

      // Frequency error with average measurement
      RSCMU_Status = RSCMU_GetMeasureMatching( freqErr, tab, 7 );
      break;

   case RSCMU_MAXMIN:
      // Max phase error with extreme-value measurement    
      RSCMU_Status = RSCMU_GetMeasureMatching( phErrPeak, tab, 2 );

      // RMS phase error with extreme-value measurement
      RSCMU_Status = RSCMU_GetMeasureMatching( phErrRMS, tab, 5 );

      // Frequency error with extreme-value measurement
      RSCMU_Status = RSCMU_GetMeasureMatching( freqErr, tab, 8 );
      break;
   }
   // Average burst power with single-value measurement 
   RSCMU_Status = RSCMU_GetMeasureMatching( avgBurstPowerCurr, tab, 9 );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_CalcArrLimitMatching()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfSpecTimeRange
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfSpecTimeRange( ViSession instrSession
                               , ViReal64  firstMeasurementPoint
                               , ViInt32   numberofResults
                               , ViChar    errorMessage[]
                               )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViInt32  mode = 0;

   checkRange( 85, &mode, &firstMeasurementPoint, &numberofResults );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[85].instrCommand
          , traceMode.list[mode]
          , firstMeasurementPoint
          , numberofResults
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfSpecTimeRange()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfSpecTimeAdjChan
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfSpecTimeAdjChan( ViSession instrSession
                                 , ViInt32   numberofAdjacentChannels
                                 , ViChar    errorMessage[]
                                 )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 154, &numberofAdjacentChannels );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[154].instrCommand
          , numberofAdjacentChannels
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfSpecTimeAdjChan()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfSpecLimChanDefault
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
// JMG 030106
ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfSpecLimChanDefault( ViSession instrSession
                                    , ViBoolean state
                                    , ViChar    errorMessage[]
                                    )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   if (state == RSCMU_OFF)
   {
   
        RSCMU_Status    = RSCMU_errorMessage( instrSession, RSCMU_IS136_WARNING_GPIB_FEATURE, errorMessage );
        return( RSCMU_Status);
   }

   checkRange( 163, &state );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[163].instrCommand
          , enable.list[state]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfSpecLimChanDefault()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_InitSpec
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_InitSpec( ViSession instrSession
                      , ViChar    errorMessage[]
                      )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[71].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   return( RSCMU_Status );

} // endof RSCMU_TDMA_InitSpec()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_AbortSpec
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_AbortSpec( ViSession instrSession
                       , ViChar    errorMessage[]
                       )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[72].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   return( RSCMU_Status );

} // endof RSCMU_TDMA_AbortSpec()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_StopSpec
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_StopSpec( ViSession instrSession
                      , ViChar    errorMessage[]
                      )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[73].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   return( RSCMU_Status );

} // endof RSCMU_TDMA_StopSpec()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_RestartSpec
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_RestartSpec( ViSession instrSession
                         , ViChar    errorMessage[]
                         )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   
  RSCMU_Status  = RSCMU_errorMessage( instrSession, RSCMU_IS136_WARNING_GPIB_FEATURE, errorMessage );

/*
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[74].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
*/  
   return( RSCMU_Status );

} // endof RSCMU_TDMA_RestartSpec()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ContinueSpec
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ContinueSpec( ViSession instrSession
                          , ViChar    errorMessage[]
                          )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[75].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   return( RSCMU_Status );

} // endof RSCMU_TDMA_ContinueSpec()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_FetchSpecStatus
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_FetchSpecStatus( ViSession  instrSession
                             , ViInt32   *MeasurementStatus
                             , ViInt32   *CounterForMeasurementCycle
                             , ViInt32   *CounterForStatistics
                             , ViChar     errorMessage[]
                             )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[38][30];    

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[156].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Get the measurement status
   RSCMU_Status = RSCMU_GetMeasurementStatus( MeasurementStatus, tab, 0 );

   // Get the counter for current statistics cycle
   if( strcmp( tab[1], "NONE" ) != 0 )
   {
      sscanf( tab[1], "%d", CounterForMeasurementCycle );
   }
   else
   {
      *CounterForMeasurementCycle = RSCMU_OFF;
   }

   // Get the counter for current evaluation period within a cycle
   if( strcmp( tab[2], "NONE" ) != 0 )
   {
      sscanf( tab[2], "%d", CounterForStatistics );
   }
   else
   {
      *CounterForStatistics = RSCMU_OFF;
   }

   return( RSCMU_Status );

} // endof RSCMU_TDMA_FetchSpecStatus()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfSpecErep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfSpecErep( ViSession instrSession
                          , ViInt32   MeasurementEventReporting
                          , ViChar    errorMessage[]
                          )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 76, &MeasurementEventReporting );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[76].instrCommand
          , eventReport.list[MeasurementEventReporting]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfSpecErep()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfBERTset
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_TDMA_ConfBERTset (ViSession instrSession, ViInt32 tset, ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        

   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
       return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage); 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[197].instrCommand
          , tset
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} // end of RSCMU_TDMA_ConfBERTset

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfSpecContRep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfSpecContRep( ViSession instrSession
                             , ViInt32   rep
                             , ViInt32   stopCondition
                             , ViInt32   step
                             , ViChar    errorMessage[]
                             )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 79, &rep , &stopCondition, &step );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[79].instrCommand
          , repetition.list[rep]
          , stopCond.list[stopCondition]
          , stepMode.list[step]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfSpecContRep()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfSpecContDefault
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
// JMG 030106
ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfSpecContDefault( ViSession instrSession
                                 , ViBoolean state
                                 , ViChar    errorMessage[]
                                 )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   if (state == RSCMU_OFF)
   {
   
        RSCMU_Status    = RSCMU_errorMessage( instrSession, RSCMU_IS136_WARNING_GPIB_FEATURE, errorMessage );
        return( RSCMU_Status);
   }

   checkRange( 81, &state );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[81].instrCommand
          , enable.list[state]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfSpecContDefault()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_DispSpecContGrid
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_DispSpecContGrid( ViSession instrSession
                              , ViBoolean gridLines
                              , ViChar    errorMessage[]
                              )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 80, &gridLines );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[80].instrCommand
          , enable.list[gridLines]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_DispSpecContGrid()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfSpecLimChan
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfSpecLimChan( ViSession instrSession
                             , ViInt32   Channel
                             , ViInt32   Limit
                             , ViReal64  peak
                             , ViReal64  RMS
                             , ViBoolean state
                             , ViChar    errorMessage[]
                             )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 82, &Channel, &Limit, &peak, &RMS, &state );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[82].instrCommand
          , plusMinus.list[Limit]
          , Channel
          , peak
          , RMS
          , enable.list[state]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfSpecLimChan()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfSpecLimChanEnable
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfSpecLimChanEnable( ViSession instrSession
                                   , ViInt32   Channel
                                   , ViInt32   Limit
                                   , ViBoolean state
                                   , ViChar    errorMessage[]
                                   )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 83, &Channel, &Limit, &state );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[83].instrCommand
          , plusMinus.list[Limit]
          , Channel
          , enable.list[state]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfSpecLimChanEnab()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfSpecStatBurst
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfSpecStatBurst( ViSession instrSession
                               , ViInt32   numBursts
                               , ViChar    errorMessage[]
                               )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 84, &numBursts );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[84].instrCommand
          , numBursts
          , numBursts
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfSpecStatBurst()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfSpecStatGraph
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

//ViStatus _VI_FUNC RSCMU_TDMA_ConfSpecStatGraph( ViSession instrSession, ViInt32   graphMode, ViChar    errorMessage[])
// JMG 030102
ViStatus _VI_FUNC RSCMU_TDMA_ConfSpecStatGraph (ViSession   instrSession,
                                                ViInt32     measurementMode,
                                                ViReal64    firstMeasurementPoint,
                                                ViInt32     number_ofResults_toReturn,
                                                ViChar      errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 85, &measurementMode, &firstMeasurementPoint, &number_ofResults_toReturn);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[85].instrCommand
          , traceMode.list[measurementMode]
          , firstMeasurementPoint
          , number_ofResults_toReturn
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfSpecStatGraph()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ConfSpecStatDefault
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
// JMG 030106
ViStatus _VI_FUNC 
   RSCMU_TDMA_ConfSpecStatDefault( ViSession instrSession
                                 , ViBoolean state
                                 , ViChar    errorMessage[]
                                 )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   if (state == RSCMU_OFF)
   {
   
        RSCMU_Status    = RSCMU_errorMessage( instrSession, RSCMU_IS136_WARNING_GPIB_FEATURE, errorMessage );
        return( RSCMU_Status);
   }

   checkRange( 86, &state );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[86].instrCommand
          , enable.list[state]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ConfSpecStatDefault()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ReadArrSpec
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ReadArrSpec( ViSession  instrSession
                         , ViInt32    measurementMode
                         , ViReal64   BurstPower[]
                         , ViChar     errorMessage[]
                         )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViInt32  arrtype = 0;
   struct   RSCMU_TDMA_Globals  *p_globalvarTDMA;
  

   //Get the global structure
   // JMG 030102
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarTDMA)) < 0)
     return RSCMU_Status;                                        

   
   switch(measurementMode)
   {
   case     RSCMU_CURRENT:
    arrtype         = 0;
   break;
   
   case     RSCMU_AVERAGE:
    arrtype         = 0;
   break;
   
   case     RSCMU_MAXIMUM:
    arrtype         = 0;
   break;

   case     RSCMU_MINIMUM:
    arrtype         = 0;
   break;

   case     RSCMU_CURRENT_SUB:
    arrtype         = 1;
    measurementMode = measurementMode - 4;
   break;
   
   case     RSCMU_AVERAGE_SUB:
    arrtype = 1;
    measurementMode = measurementMode - 4;
   break;
   
   case     RSCMU_MAXIMUM_SUB:
    arrtype = 1;
    measurementMode = measurementMode - 4;
   break;

   case     RSCMU_MINIMUM_SUB:
    arrtype = 1;
    measurementMode = measurementMode - 4;
   break;
   
   }
   
   
   checkRange( 88, &arrtype, &measurementMode );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
          , IS136[88].instrCommand
          , arrayType.list[arrtype]
          , measMode.list[measurementMode]
          );

   // JMG 030102
   RSCMU_Status = RSCMU_Query_Array( instrSession
                             , wrtBuf
                             , &p_globalvarTDMA->rdABuf[0]
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   RSCMU_ReturnArrayValues( p_globalvarTDMA->rdABuf, BurstPower );

/* JMG 030102
    // Allocate a much larger memory block than the default.
   rdBuf = malloc( RD_BUFFER_SIZE_ARRAY );
   if( rdBuf != NULL )
   {
#if 0
      RSCMU_Status = RSCMU_Query( instrSession
                                , wrtBuf
                                , rdBuf
                                , RSCMU_STB_ON
                                , errorMessage
                                );
#else
      // Write data to the CMU
      if ((RSCMU_Status = RSCMU_Write (instrSession, wrtBuf, RSCMU_STB_ON, strlen(wrtBuf), errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }

      // Read the resulting output
      if ((RSCMU_Status = RSCMU_Read (instrSession, rdBuf, RD_BUFFER_SIZE_ARRAY, errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }
#endif

      // Find all burst power values by breaking the read buffer:
      RSCMU_ReturnArrayValues( rdBuf
                             , BurstPower
                             );

      // Free the temporary buffer allocation.
      free( rdBuf );
   }
   else
   {
      RSCMU_Status = RSCMU_ERROR_MEMORY_ALLOCATION;
   }
*/
   return( RSCMU_Status );

} // endof RSCMU_TDMA_ReadArrSpec()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_FetchArrSpec
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_FetchArrSpec( ViSession  instrSession
                          , ViInt32    measurementMode
                          , ViReal64   BurstPower[]
                          , ViChar     errorMessage[]
                          )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViInt32  arrtype = 0;
   struct   RSCMU_TDMA_Globals  *p_globalvarTDMA;
  

   //Get the global structure
   // JMG 030102
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarTDMA)) < 0)
     return RSCMU_Status;   
   
   switch(measurementMode)
   {
   case     RSCMU_CURRENT:
    arrtype         = 0;
   break;
   
   case     RSCMU_AVERAGE:
    arrtype         = 0;
   break;
   
   case     RSCMU_MAXIMUM:
    arrtype         = 0;
   break;

   case     RSCMU_MINIMUM:
    arrtype         = 0;
   break;

   case     RSCMU_CURRENT_SUB:
    arrtype         = 1;
    measurementMode = measurementMode - 4;
   break;
   
   case     RSCMU_AVERAGE_SUB:
    arrtype = 1;
    measurementMode = measurementMode - 4;
   break;
   
   case     RSCMU_MAXIMUM_SUB:
    arrtype = 1;
    measurementMode = measurementMode - 4;
   break;

   case     RSCMU_MINIMUM_SUB:
    arrtype = 1;
    measurementMode = measurementMode - 4;
   break;
   
   }
   
   
   checkRange( 207, &arrtype, &measurementMode );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[207].instrCommand
          , arrayType.list[arrtype]
          , measMode.list[measurementMode]
          );

   // JMG 030102
   RSCMU_Status = RSCMU_Query_Array( instrSession
                             , wrtBuf
                             , &p_globalvarTDMA->rdABuf[0]
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   RSCMU_ReturnArrayValues( p_globalvarTDMA->rdABuf, BurstPower );

/* JMG 030102

    // Allocate a much larger memory block than the default.
   rdBuf = malloc( RD_BUFFER_SIZE_ARRAY );
   if( rdBuf != NULL )
   {
#if 0
      RSCMU_Status = RSCMU_Query( instrSession
                                , wrtBuf
                                , rdBuf
                                , RSCMU_STB_ON
                                , errorMessage
                                );
#else
      // Write data to the CMU
      if ((RSCMU_Status = RSCMU_Write (instrSession, wrtBuf, RSCMU_STB_ON, strlen(wrtBuf), errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }

      // Read the resulting output
      if ((RSCMU_Status = RSCMU_Read (instrSession, rdBuf, RD_BUFFER_SIZE_ARRAY, errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }
#endif

      // Find all burst power values by breaking the read buffer:
      RSCMU_ReturnArrayValues( rdBuf
                             , BurstPower
                             );

      // Free the temporary buffer allocation.
      free( rdBuf );
   }
   else
   {
      RSCMU_Status = RSCMU_ERROR_MEMORY_ALLOCATION;
   }
*/
   return( RSCMU_Status );

} // endof RSCMU_TDMA_FetchArrSpec()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_SampleArrSpec
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_SampleArrSpec( ViSession  instrSession
                           , ViInt32    measurementMode
                           , ViReal64   BurstPower[]
                           , ViChar     errorMessage[]
                           )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViInt32  arrtype = 0;
   struct   RSCMU_TDMA_Globals  *p_globalvarTDMA;
  

   //Get the global structure
   // JMG 030102
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarTDMA)) < 0)
     return RSCMU_Status;                                        

   
   switch(measurementMode)
   {
   case     RSCMU_CURRENT:
    arrtype         = 0;
   break;
   
   case     RSCMU_AVERAGE:
    arrtype         = 0;
   break;
   
   case     RSCMU_MAXIMUM:
    arrtype         = 0;
   break;

   case     RSCMU_MINIMUM:
    arrtype         = 0;
   break;

   case     RSCMU_CURRENT_SUB:
    arrtype         = 1;
    measurementMode = measurementMode - 4;
   break;
   
   case     RSCMU_AVERAGE_SUB:
    arrtype = 1;
    measurementMode = measurementMode - 4;
   break;
   
   case     RSCMU_MAXIMUM_SUB:
    arrtype = 1;
    measurementMode = measurementMode - 4;
   break;

   case     RSCMU_MINIMUM_SUB:
    arrtype = 1;
    measurementMode = measurementMode - 4;
   break;
   
   }
   
   
   checkRange( 208, &arrtype , &measurementMode );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[208].instrCommand
          , arrayType.list[arrtype]
          , measMode.list[measurementMode]
          );

   // JMG 030102
   RSCMU_Status = RSCMU_Query_Array( instrSession
                             , wrtBuf
                             , &p_globalvarTDMA->rdABuf[0]
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   RSCMU_ReturnArrayValues( p_globalvarTDMA->rdABuf, BurstPower );

/* JMG 030201
    // Allocate a much larger memory block than the default.
   rdBuf = malloc( RD_BUFFER_SIZE_ARRAY );
   if( rdBuf != NULL )
   {
#if 0
      RSCMU_Status = RSCMU_Query( instrSession
                                , wrtBuf
                                , rdBuf
                                , RSCMU_STB_ON
                                , errorMessage
                                );
#else
      // Write data to the CMU
      if ((RSCMU_Status = RSCMU_Write (instrSession, wrtBuf, RSCMU_STB_ON, strlen(wrtBuf), errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }

      // Read the resulting output
      if ((RSCMU_Status = RSCMU_Read (instrSession, rdBuf, RD_BUFFER_SIZE_ARRAY, errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }
#endif

      // Find all burst power values by breaking the read buffer:
      RSCMU_ReturnArrayValues( rdBuf
                             , BurstPower
                             );

      // Free the temporary buffer allocation.
      free( rdBuf );
   }
   else
   {
      RSCMU_Status = RSCMU_ERROR_MEMORY_ALLOCATION;
   }
*/
   return( RSCMU_Status );

} // endof RSCMU_TDMA_SampleArrSpec()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ReadScalSpec
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_ReadScalSpec( ViSession   instrSession
                          , SCALAR_ACP *ACP
                          , ViChar      errorMessage[]
                          )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViInt32   NumOfMeasValues;
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    TempBuf[669][20];  

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
  
   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[78].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   NumOfMeasValues = RSCMU_scanStringBurst( rdBuf, TempBuf );
   RSCMU_ReturnACPResponse( TempBuf, ACP );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_ReadScalSpec()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_FetchScalSpec
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_FetchScalSpec( ViSession   instrSession
                           , SCALAR_ACP *ACP
                           , ViChar      errorMessage[]
                           )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViInt32   NumOfMeasValues;
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    TempBuf[669][20];  

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
  
   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[77].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   NumOfMeasValues = RSCMU_scanStringBurst( rdBuf, TempBuf );
   RSCMU_ReturnACPResponse( TempBuf, ACP );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_FetchScalSpec()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_SampleScalSpec
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_SampleScalSpec( ViSession   instrSession
                            , SCALAR_ACP *ACP
                            , ViChar      errorMessage[]
                            )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViInt32   NumOfMeasValues;
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    TempBuf[669][20];  

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
  
   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[87].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   NumOfMeasValues = RSCMU_scanStringBurst( rdBuf, TempBuf );
   RSCMU_ReturnACPResponse( TempBuf, ACP );

   return( RSCMU_Status );

} // endof RSCMU_TDMA_SampleScalSpec()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_SenseChanQualityBER
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_SenseChanQualityBER( ViSession  instrSession
                                 , ViInt32   *BER
                                 , ViChar     errorMessage[]
                                 )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViBoolean match        = RSCMU_FALSE;
   ViInt32   i;
   ViInt32   length;
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[105].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Search table for a match.
   i      = 0;
   length = strlen( rdBuf );
   while( *ReportBER != NULL )
   {
      if( strncmp( ReportBER[i], rdBuf, length ) == 0 ) 
      {
         match = RSCMU_TRUE;
         break;
      }
      i++;
   }
   
   // Set return value based on string match.
   if( match )
   {
      if( i == 0 )
      {
         *BER = RSCMU_NAN_VI_INT32;
      }
      else
      {
         *BER = i - 1;
      }
   }
   else
   {
      *BER         = RSCMU_NAN_VI_INT32;
      RSCMU_Status = RSCMU_ERROR_NAN;
   }
   
   return( RSCMU_Status );

} // endof RSCMU_TDMA_SenseChanQualityBER()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_SenseChanQualityRSSI
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_SenseChanQualityRSSI( ViSession  instrSession
                                  , ViInt32   *RSSI
                                  , ViInt32   *level
                                  , ViChar     errorMessage[]
                                  )
{
   ViStatus   RSCMU_Status = VI_SUCCESS;
   ViBoolean  match        = RSCMU_FALSE;
   ViInt32    i;
   ViInt32    length;
   ViChar    *wrtBuf;
   ViChar    *rdBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[106].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Search table for a match.
   length = strlen( rdBuf );
   i      = 0;
   while( *ReportRSSI != NULL )
   {
      if( strncmp( ReportRSSI[i], rdBuf, length ) == 0 ) 
      {
         match = RSCMU_TRUE;
         break;
      }
      i++;
   }
   
   // Set return value based on string match.
   if( match )
   {
      if( i == 0 )
      {
         *RSSI  = RSCMU_NAN_VI_INT32;
         *level = 0;
      }
      else
      {
         *RSSI = i - 1;
         *level = -113 + (*RSSI * 2);
      }
   }
   else
   {
      *RSSI        = RSCMU_NAN_VI_INT32;
      *level       = 0;
      RSCMU_Status = RSCMU_ERROR_NAN;
   }
   
   return( RSCMU_Status );

} // endof RSCMU_TDMA_SenseChanQualityRSSI()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_SenseChanQualityMAHONCells
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_SenseChanQualityMAHONCells( ViSession  instrSession
                                       , MAHO      *allCellsMAHO
                                       , ViChar     errorMessage[]
                                       )
{
   ViStatus   RSCMU_Status = VI_SUCCESS;  
   ViBoolean  match        = RSCMU_FALSE;
   ViInt32    i;
   ViInt32    j;
   ViInt32    length;
   ViChar    *rdBuf;
   ViChar    *wrtBuf;
   ViChar     TempBuf[669][20];  
   ViReal64   temp; 
   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[167].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   RSCMU_scanStringBurst( rdBuf, TempBuf );
   
   for( i = 0; i < 24; i++ )
   {
      // Read channel.
      sscanf( TempBuf[i*2], "%lf", &temp );
      sprintf( TempBuf[i*2],"%4.0lf",temp );
      sscanf( TempBuf[i*2], "%4d", &allCellsMAHO[i].Channel );

      // Search table for a RSSI match.
      length = strlen( TempBuf[(i*2)+1] );
      j      = 0;
      while( *ReportRSSI != NULL )
      {
         if( strncmp( ReportRSSI[j], TempBuf[(i*2)+1], length ) == 0 ) 
         {
            match = RSCMU_TRUE;
            break;
         }
         j++;
      }
   
      // Set return value based on string match.
      if( match )
      {
         if( j == 0 )
         {
            allCellsMAHO[i].RSSI  = RSCMU_NAN_VI_INT32;
            allCellsMAHO[i].Level = 0;
         }
         else
         {
            allCellsMAHO[i].RSSI  = j - 1;
            allCellsMAHO[i].Level = -113 + ((j - 1) * 2);
         }
      }
      else
      {
         allCellsMAHO[i].RSSI  = RSCMU_NAN_VI_INT32;
         allCellsMAHO[i].Level = 0;
         RSCMU_Status          = RSCMU_ERROR_NAN;
      }
   }
   
   return( RSCMU_Status );

} // endof RSCMU_TDMA_SenseChanQualityMAHONCells()


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_SenseChanQualityMAHOCell
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_SenseChanQualityMAHOCell( ViSession  instrSession
                                      , ViInt32    channel
                                      , MAHO      *cellMAHO
                                      , ViChar     errorMessage[]
                                      )
{
   ViStatus   RSCMU_Status = VI_SUCCESS;  
   ViBoolean  match        = RSCMU_FALSE;
   ViInt32    i;
   ViInt32    length;
   ViChar    *rdBuf;
   ViChar    *wrtBuf;
   ViChar    tab[38][30];
   ViReal64   temp;    

   checkRange( 152, &channel );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[152].instrCommand
          , channel
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Read channel.
   sscanf( tab[0], "%lf", &temp);
   sprintf(tab[0],"%4.0lf",temp);
   sscanf( tab[0], "%4d", &cellMAHO->Channel);

   
   // Search table for a RSSI match.
   length = strlen( tab[1] );
   i      = 0;
   while( *ReportRSSI != NULL )
   {
      if( strncmp( ReportRSSI[i], tab[1], length ) == 0 ) 
      {
         match = RSCMU_TRUE;
         break;
      }
      i++;
   }
   
   // Set return value based on string match.
   if( match )
   {
      if( i == 0 )
      {
         cellMAHO->RSSI  = RSCMU_NAN_VI_INT32;
         cellMAHO->Level = 0;
      }
      else
      {
         cellMAHO->RSSI  = i - 1;
         cellMAHO->Level = -113 + (cellMAHO->RSSI * 2);
      }
   }
   else
   {
      cellMAHO->RSSI  = RSCMU_NAN_VI_INT32;
      cellMAHO->Level = 0;
      RSCMU_Status    = RSCMU_ERROR_NAN;
   }
   
   return( RSCMU_Status );

} // endof RSCMU_TDMA_SenseChanQualityMAHOCell()

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_SetCmuVersion
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_TDMA_SetCmuVersion (ViSession   instrumentHandle,
                                            ViChar      firmwareVersion[],
                                            ViChar      errorMessage[])
{

 ViStatus    RSCMU_Status           = VI_SUCCESS;
 ViInt32     CurrentVersion         = 241;
 struct      RSCMU_SESSION_Globals  *p_globalvarBase;    
   
   // Get the global structure
 if ((RSCMU_Status = viGetAttribute (instrumentHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
       return RSCMU_Status;                                        

 strcpy (p_globalvarBase->CmuVersion, firmwareVersion);
 RSCMU_Status = RSCMU_CurrentVersion (instrumentHandle, &CurrentVersion, errorMessage);

 p_globalvarBase->RSCMU_FW_Version = CurrentVersion;

 return( RSCMU_Status );
} // end of RSCMU_TDMA_SetCmuVersion

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_Reset
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/



ViStatus _VI_FUNC RSCMU_TDMA_Reset (ViSession   instrSession,
                                    ViUInt32    max_timeout_in_ms,
                                    ViChar      errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;
   ViUInt32 timeout_in_ms   = 0;
   
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        

   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_10)
       return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

                
   RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_TMO_VALUE, &timeout_in_ms);
   RSCMU_Status = viSetAttribute (instrSession, VI_ATTR_TMO_VALUE, max_timeout_in_ms);
   

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[196].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   RSCMU_Status = viSetAttribute (instrSession, VI_ATTR_TMO_VALUE, timeout_in_ms);
    
   return( RSCMU_Status );
    
} // end of RSCMU_TDMA_Reset

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_GPIB_Timeout
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_TDMA_GPIB_Timeout (ViSession instrumentHandle,
                                           ViUInt32 timeout_in_ms,
                                           ViChar errorMessage[])
{

        ViStatus  RSCMU_Status = VI_SUCCESS;  
    

    RSCMU_Status = viSetAttribute (instrumentHandle, VI_ATTR_TMO_VALUE, timeout_in_ms);

    if (RSCMU_Status != VI_SUCCESS)
        viStatusDesc (instrumentHandle, RSCMU_Status, errorMessage);    
        
    return( RSCMU_Status );     

}  // end of RSCMU_TDMA_GPIB_Timeout 


/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_StatOperSymbEnab
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_TDMA_StatOperSymbEnab (ViSession instrSession,
                                               ViBoolean CFM, 
                                               ViBoolean RFM,
                                               ViBoolean LORL, 
                                               ViBoolean MREG,
                                               ViBoolean MINV,                                               
                                               ViBoolean RFNS,
                                               ViBoolean MDER,
                                               ViBoolean TCH,
                                               ViBoolean MREP, 
                                               ViBoolean RFIO,
                                               ViBoolean RFIU,
                                               ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;
   ViChar   temp[80];
   
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        

   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
       return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage); 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   
   
   strcpy(temp, "\0");
   
   if (CFM != 65535)
     strcat(temp, SRS[RSCMU_TDMA_CFM]);

   if (RFM != 65535)
   {
     if (strlen(temp) != 0)
        strcat(temp, ","); 
     
     strcat(temp, SRS[RSCMU_TDMA_RFM]);
     
   }
   
   if (MREG != 65535)
   {
     if (strlen(temp) != 0)
        strcat(temp, ","); 
     
     strcat(temp, SRS[RSCMU_TDMA_MREG]);
     
   }

   if (MINV != 65535)
   {
     if (strlen(temp) != 0) 
        strcat(temp, ","); 
     
     strcat(temp, SRS[RSCMU_TDMA_MINV]);
   }
   
   if (RFNS != 65535)
   {
     if (strlen(temp) != 0) 
        strcat(temp, ","); 
     
     strcat(temp, SRS[RSCMU_TDMA_RFNS]);
   }

   if (MDER != 65535)
   {
     if (strlen(temp) != 0) 
        strcat(temp, ","); 
     
     strcat(temp, SRS[RSCMU_TDMA_MDER]);
     
   }
   
   if (TCH != 65535)
   {
     if (strlen(temp) != 0)
        strcat(temp, ","); 
     
     strcat(temp, SRS[RSCMU_TDMA_TCH]);
     
   }

   if (MREP != 65535)
   {
     if (strlen(temp) != 0)
        strcat(temp, ","); 
     
     strcat(temp, SRS[RSCMU_TDMA_MREP]);
     
   }
    
   if (RFIO != 65535)
   {
     if (strlen(temp) != 0)
        strcat(temp, ","); 
     
     strcat(temp, SRS[RSCMU_TDMA_RFIO]);
     
   }
   

   if (RFIU != 65535)
   {
     if (strlen(temp) != 0)
        strcat(temp, ","); 
     
     strcat(temp, SRS[RSCMU_TDMA_RFIU]);
     
   }
   
   
   if (strlen(temp) == 0) 
    sprintf(wrtBuf,IS136[204].instrCommand,"NONE");
   else
    sprintf(wrtBuf,IS136[204].instrCommand,temp);
   
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

    
} // end of RSCMU_TDMA_StatOperSymbEnab   

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_StatOperSymbEvent
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_TDMA_StatOperSymbEvent (ViSession   instrSession,
                                                ViInt32     *nb,
                                                ViInt32     *statusOperEvent,
                                                ViChar      SstatusOperEvent[],
                                                ViChar      errorMessage[])
{
   ViStatus  RSCMU_Status   = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;
   ViChar   Sevent[38][30];
   ViInt32  i               = 0;
   ViInt32  n               = 0;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[205].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   
   
   if( RSCMU_Status >= 0 )
   {
       // Separate the CMU response:
       *nb= RSCMU_SeparateString( rdBuf, ",", Sevent );
       
       *statusOperEvent = 0;
       strcpy(SstatusOperEvent, "\0");

       for (i=0;i<*nb;i++)
       {
           
           if (strncmp("NONE", Sevent[i], 4) == 0)
           {
                
                *statusOperEvent =  0;
                strcat(SstatusOperEvent, SRS[16]);
                strcat(SstatusOperEvent, ",\0");    
                
            }
                
           
           if ((strncmp(SRS[RSCMU_TDMA_CFM],Sevent[i],3) == 0)  || (strncmp("E1",Sevent[i],2) == 0))
           {
                *statusOperEvent    =  *statusOperEvent + 1;
                strcat(SstatusOperEvent, SRS[RSCMU_TDMA_CFM]);
                strcat(SstatusOperEvent,",\0");
           }
           
           if ((strncmp(SRS[RSCMU_TDMA_RFM],Sevent[i],3) == 0)  || (strncmp("E2", Sevent[i],2) == 0))
           {
                *statusOperEvent =  *statusOperEvent + 2;
                strcat(SstatusOperEvent, SRS[RSCMU_TDMA_RFM]);
                strcat(SstatusOperEvent,",\0");
           }
    

           if ((strncmp(SRS[RSCMU_TDMA_LORL],Sevent[i],4) == 0) || (strncmp("E3", Sevent[i],2 ) == 0))
           {
                *statusOperEvent =  *statusOperEvent + 4;
                strcat(SstatusOperEvent, SRS[RSCMU_TDMA_LORL]);
                strcat(SstatusOperEvent,",\0");
           }
                
   
           if ((strncmp(SRS[RSCMU_TDMA_MREG],Sevent[i],4) == 0) || (strncmp("E4", Sevent[i],2 ) == 0))
           {
                *statusOperEvent =  *statusOperEvent + 8;
                strcat(SstatusOperEvent, SRS[RSCMU_TDMA_MREG]);
                strcat(SstatusOperEvent,",\0");
           }
                

           if  ((strncmp(SRS[RSCMU_TDMA_MINV],Sevent[i],4) == 0) || (strncmp("E5", Sevent[i],2 ) == 0))
           {
                *statusOperEvent =  *statusOperEvent + 16;
                strcat(SstatusOperEvent, SRS[RSCMU_TDMA_MINV]);
                strcat(SstatusOperEvent,",\0");
           }
                
            
           if (strncmp("E6", Sevent[i],2 ) == 0)
           {
                *statusOperEvent =  *statusOperEvent + 32;
                strcat(SstatusOperEvent, SRS[5]);
                strcat(SstatusOperEvent,",\0");
           }
                
            
           if ((strncmp(SRS[RSCMU_TDMA_RFNS],Sevent[i],4) == 0) || (strncmp("E7", Sevent[i],2 ) == 0))
           {
                *statusOperEvent =  *statusOperEvent + 64;
                strcat(SstatusOperEvent, SRS[RSCMU_TDMA_RFNS]);
                strcat(SstatusOperEvent,",\0");
           }
                

           if ((strncmp(SRS[RSCMU_TDMA_MDER],Sevent[i],4) == 0) || (strncmp("E8", Sevent[i],2 ) == 0))
           {
                *statusOperEvent =  *statusOperEvent + 128;
                strcat(SstatusOperEvent, SRS[RSCMU_TDMA_MDER]);
                strcat(SstatusOperEvent,",\0");
           }
            

           if (strncmp("E9", Sevent[i],2 ) == 0)
           {
                *statusOperEvent =  *statusOperEvent + 256;
                strcat(SstatusOperEvent, SRS[8]);
                strcat(SstatusOperEvent,",\0");
           }
                
   
           if ((strncmp(SRS[RSCMU_TDMA_TCH],Sevent[i],3) == 0)  || (strncmp("E10", Sevent[i],2 ) == 0))
           {
                *statusOperEvent =  *statusOperEvent + 512;
                strcat(SstatusOperEvent, SRS[RSCMU_TDMA_TCH]);
                strcat(SstatusOperEvent,",\0");
           }
                

           if ((strncmp(SRS[RSCMU_TDMA_MREP], Sevent[i], 4) == 0)  || (strncmp("E11", Sevent[i],2 ) == 0))
           {
                *statusOperEvent =  *statusOperEvent + 1024;
                strcat(SstatusOperEvent, SRS[RSCMU_TDMA_MREP]);
                strcat(SstatusOperEvent,",\0");
           }
                

           if ((strncmp(SRS[RSCMU_TDMA_RFIO],Sevent[i], 4) == 0) || (strncmp("E12", Sevent[i],2 ) == 0))
           {
                *statusOperEvent =  *statusOperEvent + 2048;   
                strcat(SstatusOperEvent, SRS[RSCMU_TDMA_RFIO]);
                strcat(SstatusOperEvent,",\0");
           }
                
    
           if ((strncmp(SRS[RSCMU_TDMA_RFIU], Sevent[i], 4) == 0) || (strncmp("E13", Sevent[i],2 ) == 0))
           {
                *statusOperEvent =  *statusOperEvent + 4096;   
                strcat(SstatusOperEvent, SRS[RSCMU_TDMA_RFIU]);
                strcat(SstatusOperEvent,",\0");
           }
                

           if (strncmp("E14", Sevent[i],2 ) == 0)
           {
                *statusOperEvent =  *statusOperEvent + 8192;   
                strcat(SstatusOperEvent, SRS[13]);
                strcat(SstatusOperEvent,",\0");
           }
                
    
           if (strncmp("E15", Sevent[i],2 ) == 0)
           {
                *statusOperEvent =  *statusOperEvent + 16384; 
                strcat(SstatusOperEvent, SRS[14]);
                strcat(SstatusOperEvent,",\0");
           }
                

           if (strncmp("E16", Sevent[i],2 ) == 0)
           {
                *statusOperEvent =  *statusOperEvent + 32768;
                strcat(SstatusOperEvent, SRS[15]);
                strcat(SstatusOperEvent,",\0");
           }
                
        } 
        
        if (*statusOperEvent == 0) *nb = 0;
    }

   return( RSCMU_Status );
    
}  // end of RSCMU_TDMA_StatOperSymbEvent  

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_Close
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_Close( ViSession instrSessionTDMA
                   , ViChar    errorMessage[]
                   )
{
   ViStatus RSCMU_Status = VI_SUCCESS;  
   struct RSCMU_TDMA_Globals *p_globalvarTDMA;

   if( (RSCMU_Status = viGetAttribute( instrSessionTDMA
                                     , VI_ATTR_USER_DATA
                                     , (ViAddr)&p_globalvarTDMA
                                     )) < 0 )
   {
      return RSCMU_errorMessage( instrSessionTDMA
                               , RSCMU_Status
                               , errorMessage
                               );
   }
   
   // Deallocate all system resources allocated to the GSMNSig Session:
   if( (RSCMU_Status = viClose( instrSessionTDMA )) < 0 )
   {
      return( RSCMU_Status );
   }
    
   // Deallocate the space pointed by p_globalvarGSM:
   if( p_globalvarTDMA )
   {
      free( p_globalvarTDMA );
   }

   return( RSCMU_Status );

} // endof RSCMU_TDMA_Close()


/**************************************************************************
 *
 * NAME:        checkRange
 *
 * DESCRIPTION: This routine is responsible for range limiting the 
 *              parameters to be within the defined legal values for a
 *              variable number of arguments.
 *
 * INPUTS:      ViInt32 cmd - index into the IS136 command table
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       This routine is passed a variable number of parameters based
 *              on the command to be executed.
 *
 ***************************************************************************
 ***************************************************************************/


static void checkRange( ViInt32 cmd, ... )
{
   va_list     params;
   ViInt32     i;
   ViInt32     type;
   ViInt32     *iValue;
   ViReal64    *fValue;

   // init variable arguments
   va_start( params, cmd );
   
   // range check each parameter
   for( i = 0; i < IS136[cmd].xmit->num; i++ )
   {
      // determine variable type
      type = IS136[cmd].xmit->p[i].i.type;
      switch( type )
      {
      case INTEGER_TYPE:
         iValue = va_arg( params, ViInt32* );
      
         if( *iValue > IS136[cmd].xmit->p[ i ].i.max )
         {
            *iValue = IS136[cmd].xmit->p[ i ].i.max;
         }
         else if( *iValue < IS136[cmd].xmit->p[ i ].i.min )
         {
            *iValue = IS136[cmd].xmit->p[ i ].i.min;
         }
         break;
         
      case FLOAT_TYPE:
         fValue = va_arg( params, ViReal64* );
        
         if( *fValue > IS136[cmd].xmit->p[ i ].i.max )
         {
            *fValue = IS136[cmd].xmit->p[ i ].i.max;
         }
         else if( *fValue < IS136[cmd].xmit->p[ i ].i.min )
         {
            *fValue = IS136[cmd].xmit->p[ i ].i.min;
         }
         break;
         
      case STRING_30_TYPE:
      default:
         break;
      }
   }
   
   // reset variable arguments
   va_end( params );
   
} // endof checkRange()


/**************************************************************************
 *
 * NAME:        getBuffers
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


static ViStatus getBuffers( ViSession  instrSessionTDMA
                          , ViChar    **wrtBuf
                          , ViChar    **rdBuf
                          , ViChar     errorMessage[]
                          )
{
   ViStatus RSCMU_Status = VI_SUCCESS;  
   struct RSCMU_TDMA_Globals *p_globalvarTDMA;

   if( (RSCMU_Status = viGetAttribute( instrSessionTDMA
                                     , VI_ATTR_USER_DATA
                                     , (ViAddr)&p_globalvarTDMA
                                     )) < 0 )
   {
      return RSCMU_errorMessage( instrSessionTDMA
                               , RSCMU_Status
                               , errorMessage
                               );
   }
   
   *wrtBuf = &(p_globalvarTDMA->RSCMU_tGlobal.wrtBuf[0]);
   *rdBuf  = &(p_globalvarTDMA->RSCMU_tGlobal.rdBuf[0]);
   
   return( RSCMU_Status );

} // endof getBufers()


/*===========================================================================*/
/* Function: Error Message
/* Purpose : This function translates the error return value from the
/*           instrument driver into a user-readable string.
/*===========================================================================*/
static ViStatus RSCMU_errorMessage( ViSession       instrSession
                                  , ViStatus        statusCode
                                  , ViChar _VI_FAR  message[]
                                  )
{
    ViStatus RSCMU_Status = VI_SUCCESS;
    ViInt16  i;
    
    /*=======================================================================*/
    /* RSCMU_stringValPair is used in the RSCMU_errorMessage function
    /*=======================================================================*/
    typedef struct  RSCMU_stringValPair
    {
        ViStatus stringVal;
        ViString stringName;
    }  RSCMU_tStringValPair;
    
    #define IS136_EXPAND(id, value, text) {id, text},
    RSCMU_tStringValPair statusDescArray[] = {
        RSCMU_LIST_OF_SPECIFIC_ERROR_MESSAGES_IS136
    };
    #define NUM_IS136_ERRORS (sizeof(statusDescArray) / sizeof(RSCMU_tStringValPair))
    #undef IS136_EXPAND

    #define EXPAND(id, value, text) {id, text},
    RSCMU_tStringValPair baseDescArray[] = {
        RSCMU_LIST_OF_SPECIFIC_ERROR_MESSAGES
    };
    #define NUM_BASE_ERRORS (sizeof(baseDescArray) / sizeof(RSCMU_tStringValPair))
    #undef EXPAND

    strcpy( message, "No Error" );

    RSCMU_Status = viStatusDesc( instrSession, statusCode, message );
    if( RSCMU_Status == VI_WARN_UNKNOWN_STATUS )
    {
        // Search RSCMU base errors.
        for( i=0; (i < NUM_BASE_ERRORS) && baseDescArray[i].stringName; i++ )
        {
            if( baseDescArray[i].stringVal == statusCode )
            {
                strcpy( message, baseDescArray[i].stringName );
                return( statusCode );
            }
        }

        // Search IS136 specific errors.
        for( i=0; (i < NUM_IS136_ERRORS) && statusDescArray[i].stringName; i++ )
        {
            if( statusDescArray[i].stringVal == statusCode )
            {
                strcpy( message, statusDescArray[i].stringName );
                return( statusCode );
            }
        }
        sprintf( message, "Unknown Error 0x%08lX", statusCode );
        return( VI_WARN_UNKNOWN_STATUS );
    }
    else if( RSCMU_Status == VI_ERROR_USER_BUF )
    {
      sprintf( message, "The user buffer is not valid for the required size." );
      return( VI_ERROR_USER_BUF );
    }
    
    // Here the call was successful:
    return( statusCode );
}


/*===========================================================================*/
/* Function: RSCMU_SeparateString                                                
/* Purpose : This function breaks a string into tokens, which are separated 
/*           by one specified delimiter character.                 
/*           The resulted strings are putted in 'Tokens'.              
/*===========================================================================*/
static ViInt32 RSCMU_SeparateString( ViChar StringToSeparate[]
                                   , ViChar Delimiters[]
                                   , ViChar Tokens[38][30]
                                   )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;
   ViChar   *Token;
   ViInt16   Index = 0;
   ViInt32   cnt   = 0;

   Token = strtok( StringToSeparate, Delimiters );
  
   while( Token )
   {
      strcpy( Tokens[Index++], Token );
      Token = strtok( NULL, Delimiters );
      cnt++;
   }
  
   while( Index < 35 )
   {
      strcpy( Tokens[Index++], "" );
   }
  
   return( cnt );
   
}


/*===========================================================================*/
/* Function: RSCMU_ReturnCapability
/* Purpose : This function returns the values of reported capabilities.
/*===========================================================================*/
static ViStatus RSCMU_ReturnCapability( ViChar      valuesTmp[38][30]
                                      , CAPABILITY *values
                                      )
{
   ViStatus RSCMU_Status = VI_SUCCESS;

   if( strcmp( valuesTmp[0], "NAN" ) != 0 )
   {
      sscanf( valuesTmp[0], "%d", &values->SOC );
   }
   else
   {
      values->SOC = RSCMU_NAN_VI_INT32;
   }

   if( strcmp( valuesTmp[1], "NAN" ) != 0 )
   {
      sscanf( valuesTmp[1], "%d", &values->BSMC );
   }
   else
   {
      values->BSMC = RSCMU_NAN_VI_INT32;
   }

   if( strcmp( valuesTmp[2], "NAN" ) != 0 )
   {
      sscanf( valuesTmp[2], "%d", &values->AsyncData );
   }
   else
   {
      values->AsyncData = RSCMU_NAN_VI_INT32;
   }

   if( strcmp( valuesTmp[3], "NAN" ) != 0 )
   {
      sscanf( valuesTmp[3], "%d", &values->G3Fax );
   }
   else
   {
      values->G3Fax = RSCMU_NAN_VI_INT32;
   }

   if( strcmp( valuesTmp[4], "NAN" ) != 0 )
   {
      sscanf( valuesTmp[4], "%d", &values->SMS );
   }
   else
   {
      values->SMS = RSCMU_NAN_VI_INT32;
   }

   if( strcmp( valuesTmp[5], "NAN" ) != 0 )
   {
      sscanf( valuesTmp[5], "%d", &values->Subaddressing );
   }
   else
   {
      values->Subaddressing = RSCMU_NAN_VI_INT32;
   }

   if( strcmp( valuesTmp[6], "NAN" ) != 0 )
   {
      sscanf( valuesTmp[6], "%d", &values->BandAB_800 );
   }
   else
   {
      values->BandAB_800 = RSCMU_NAN_VI_INT32;
   }

   if( strcmp( valuesTmp[7], "NAN" ) != 0 )
   {
      sscanf( valuesTmp[7], "%d", &values->BandA_1900 );
   }
   else
   {
      values->BandA_1900 = RSCMU_NAN_VI_INT32;
   }

   if( strcmp( valuesTmp[8], "NAN" ) != 0 )
   {
      sscanf( valuesTmp[8], "%d", &values->BandB_1900 );
   }
   else
   {
      values->BandB_1900 = RSCMU_NAN_VI_INT32;
   }

   if( strcmp( valuesTmp[9], "NAN" ) != 0 )
   {
      sscanf( valuesTmp[9], "%d", &values->BandC_1900 );
   }
   else
   {
      values->BandC_1900 = RSCMU_NAN_VI_INT32;
   }

   if( strcmp( valuesTmp[10], "NAN" ) != 0 )
   {
      sscanf( valuesTmp[10], "%d", &values->BandD_1900 );
   }
   else
   {
      values->BandD_1900 = RSCMU_NAN_VI_INT32;
   }

   if( strcmp( valuesTmp[11], "NAN" ) != 0 )
   {
      sscanf( valuesTmp[11], "%d", &values->BandE_1900 );
   }
   else
   {
      values->BandE_1900 = RSCMU_NAN_VI_INT32;
   }

   if( strcmp( valuesTmp[12], "NAN" ) != 0 )
   {
      sscanf( valuesTmp[12], "%d", &values->BandF_1900 );
   }
   else
   {
      values->BandF_1900 = RSCMU_NAN_VI_INT32;
   }

   if( strcmp( valuesTmp[13], "NAN" ) != 0 )
   {
      sscanf( valuesTmp[13], "%d", &values->IRA );
   }
   else
   {
      values->IRA = RSCMU_NAN_VI_INT32;
   }

   if( strcmp( valuesTmp[14], "NAN" ) != 0 )
   {
      sscanf( valuesTmp[14], "%d", &values->UserGroup );
   }
   else
   {
      values->UserGroup = RSCMU_NAN_VI_INT32;
   }

   if( strcmp( valuesTmp[15], "NAN" ) != 0 )
   {
      sscanf( valuesTmp[15], "%d", &values->AnalogSpeech_800 );
   }
   else
   {
      values->AnalogSpeech_800 = RSCMU_NAN_VI_INT32;
   }

   if( strcmp( valuesTmp[16], "NAN" ) != 0 )
   {
      sscanf( valuesTmp[16], "%d", &values->HalfRateDTC );
   }
   else
   {
      values->HalfRateDTC = RSCMU_NAN_VI_INT32;
   }

   if( strcmp( valuesTmp[17], "NAN" ) != 0 )
   {
      sscanf( valuesTmp[17], "%d", &values->DoubleRateDTC );
   }
   else
   {
      values->DoubleRateDTC = RSCMU_NAN_VI_INT32;
   }

   if( strcmp( valuesTmp[18], "NAN" ) != 0 )
   {
      sscanf( valuesTmp[18], "%d", &values->TripleRateDTC );
   }
   else
   {
      values->TripleRateDTC = RSCMU_NAN_VI_INT32;
   }

   if( strcmp( valuesTmp[19], "NAN" ) != 0 )
   {
      sscanf( valuesTmp[19], "%d", &values->STU3 );
   }
   else
   {
      values->STU3 = RSCMU_NAN_VI_INT32;
   }

   if( strcmp( valuesTmp[20], "NAN" ) != 0 )
   {
      sscanf( valuesTmp[20], "%d", &values->VselpVoiceCoder );
   }
   else
   {
      values->VselpVoiceCoder = RSCMU_NAN_VI_INT32;
   }

   if( strcmp( valuesTmp[21], "NAN" ) != 0 )
   {
      sscanf( valuesTmp[21], "%d", &values->AltVoiceCoder );
   }
   else
   {
      values->AltVoiceCoder = RSCMU_NAN_VI_INT32;
   }

   if( strcmp( valuesTmp[22], "NAN" ) != 0 )
   {
      sscanf( valuesTmp[22], "%d", &values->AltSOC );
   }
   else
   {
      values->AltSOC = RSCMU_NAN_VI_INT32;
   }

   return( RSCMU_Status );
}

/*===========================================================================*/
/* Function: RSCMU_ReturnBERResponse
/* Purpose : This function is call to return the values of BER response
/*===========================================================================*/
static ViStatus RSCMU_ReturnBERResponse( ViChar       valuesTmp[669][20]
                                       , BER_RESULTS *values
                                       )
{
   ViStatus RSCMU_Status = VI_SUCCESS;

   if( strcmp( valuesTmp[0], "NAN" ) != 0 )
   {
      sscanf( valuesTmp[0], "%lf", &values->TestTimeInSeconds );
   }
   else
   {
      values->TestTimeInSeconds = RSCMU_NAN;
   }

   if( strcmp( valuesTmp[1], "NAN" ) != 0 )
   {
      sscanf( valuesTmp[1], "%lf", &values->BER );
   }
   else
   {
      values->BER = RSCMU_NAN;
   }

   if( strcmp( valuesTmp[2], "NAN" ) != 0 )
   {
      sscanf( valuesTmp[2], "%d", &values->NumBitsDefaultPattern );
   }
   else
   {
      values->NumBitsDefaultPattern = RSCMU_NAN_VI_INT32;
   }

   if( strncmp( "PASS", valuesTmp[3], 4 ) == 0 ) 
   {
      values->Status = RSCMU_BER_STATUS_PASS;
   }
   else if( strncmp( "FAIL", valuesTmp[3], 4 ) == 0 )
   {
      values->Status = RSCMU_BER_STATUS_FAIL;
   }

   if( strcmp( valuesTmp[4], "NAN" ) != 0 )
   {
      sscanf( valuesTmp[4], "%d", &values->NumFramesTransmitted );
   }
   else
   {
      values->NumFramesTransmitted = RSCMU_NAN_VI_INT32;
   }

   if( strcmp( valuesTmp[5], "NAN" ) != 0 )
   {
      sscanf( valuesTmp[5], "%lf", &values->TxPower );
   }
   else
   {
      values->TxPower = RSCMU_NAN;
   }

   if( strcmp( valuesTmp[6], "NAN" ) != 0 )
   {
      sscanf( valuesTmp[6], "%d", &values->TxCarrierFreqErr );
   }
   else
   {
      values->TxCarrierFreqErr = RSCMU_NAN_VI_INT32;
   }

   if( strcmp( valuesTmp[7], "NAN" ) != 0 )
   {
      sscanf( valuesTmp[7], "%d", &values->SyncPatternDetected );
   }
   else
   {
      values->SyncPatternDetected = RSCMU_NAN_VI_INT32;
   }

   if( strcmp( valuesTmp[8], "NAN" ) != 0 )
   {
      sscanf( valuesTmp[8], "%d", &values->Percentage );
   }
   else
   {
      values->Percentage = RSCMU_NAN_VI_INT32;
   }

   return( RSCMU_Status );
}


/*===========================================================================*/
/* Function: RSCMU_GetReturnACPResponse
/* Purpose : This function is call to return the values of ACP response
/*===========================================================================*/
static ViStatus RSCMU_ReturnACPResponse( ViChar      valuesTmp[669][20]
                                       , SCALAR_ACP *values
                                       )
{
   ViStatus RSCMU_Status = VI_SUCCESS;
   ViInt32  i;
   ViInt32  j;
   
   // MS Power Peak
   sscanf( valuesTmp[0], "%lf", &values->Peak[0] );
   // MS Power RMS
   sscanf( valuesTmp[1], "%lf", &values->RMS[0] );
 
   j = 2;
   // AC Power Peak (-3 to +3)
   for( i = 0; i < 6; i++ ) 
   {
      if( strcmp( valuesTmp[i+j], "NAN" ) != 0 )
      {
         sscanf( valuesTmp[i+j], "%lf", &values->Peak[i+1] );
      }
      else
      {
         values->Peak[i] = RSCMU_NAN;
      }
   }
   j += i;

   // ACP RMS (-3 to +3)
   for( i = 0; i < 6; i++ ) 
   {
      if( strcmp( valuesTmp[j+i], "NAN" ) != 0 )
      {
         sscanf( valuesTmp[j+i], "%lf", &values->RMS[i+1] );
      }
      else
      {
         values->RMS[i] = RSCMU_NAN;
      }
   }
   j += i;

   // ACPPeak Peak (-3 to +3) 
   for( i = 0; i < 6; i++ ) 
   {
      if( strcmp( valuesTmp[j+i], "NAN" ) != 0 )
      {
         sscanf( valuesTmp[j+i], "%lf", &values->PeakPeak[i] );
      }
      else
      {
         values->PeakPeak[i] = RSCMU_NAN;
      }
   }
   j += i;

   // ACPPeak RMS (-3 to +3)  
   for( i = 0; i < 6; i++ ) 
   {
      if( strcmp( valuesTmp[j+i], "NAN" ) != 0 )
      {
         sscanf( valuesTmp[j+i], "%lf", &values->PeakRMS[i] );
      }
      else
      {
         values->PeakRMS[i] = RSCMU_NAN;
      }
   }
   j += i;

   // ACPAvg RMS (-3 to +3) 
   for( i = 0; i < 6; i++ ) 
   {
      if( strcmp( valuesTmp[j+i], "NAN" ) != 0 )
      {
         sscanf( valuesTmp[j+i], "%lf", &values->AverageRMS[i] );
      }
      else
      {
         values->AverageRMS[i] = RSCMU_NAN;
      }
   }
   j += i;
   
   // Bursts out of tolerance  
   if( strcmp( valuesTmp[j], "NAN" ) != 0 )
   {
      sscanf( valuesTmp[j], "%lf", &values->BurstsOutOfTolerance );
   }
   else
   {
      values->BurstsOutOfTolerance = RSCMU_NAN;
   }

   return( RSCMU_Status );
   
}


/*===========================================================================*/
/* Function: RSCMU_GetReturnACPLimits
/* Purpose : This function is call to return the values of ACP limits.
/*===========================================================================*/
static ViStatus RSCMU_ReturnACPLimits( ViChar    valuesTmp[669][20]
                                     , ViInt32   ACPeakPower[]
                                     , ViInt32   ACRMSPower[]
                                     , ViInt32   ACPeakPowerPeak[]
                                     , ViInt32   ACPeakPowerRMS[]
                                     , ViInt32   ACAveragePowerRMS[]
                                     )
{
   ViStatus RSCMU_Status = VI_SUCCESS;
   ViInt32  i;
   ViInt32  j            = 0;
   
   // AC Power Peak (-3 to +3)
   for( i = 0; i < 6; i++ ) 
   {
      if( strcmp( valuesTmp[i], "NMAU" ) == 0 )
      {
         ACPeakPower[i] = RSCMU_NMAU;
      }
      else if( strcmp( valuesTmp[i], "NMAL" ) == 0 ) 
      {
         ACPeakPower[i] = RSCMU_NMAL;
      }
      else if( strcmp( valuesTmp[i], "OK" ) == 0 ) 
      {
         ACPeakPower[i] = RSCMU_OK;  
      }
      else  // Measurement Invalid
      {
         ACPeakPower[i] = RSCMU_INV;  
      }
   }
   j += i;

   // ACP RMS (-3 to +3)
   for( i = 0; i < 6; i++ ) 
   {
      if( strcmp( valuesTmp[i+j], "NMAU" ) == 0 )
      {
         ACRMSPower[i] = RSCMU_NMAU;
      }
      else if( strcmp( valuesTmp[i+j], "NMAL" ) == 0 ) 
      {
         ACRMSPower[i] = RSCMU_NMAL;
      }
      else if( strcmp( valuesTmp[i+j], "OK" ) == 0 ) 
      {
         ACRMSPower[i] = RSCMU_OK;  
      }
      else  // Measurement Invalid
      {
         ACRMSPower[i] = RSCMU_INV;  
      }
   }
   j += i;

   // ACPPeak Peak (-3 to +3) 
   for( i = 0; i < 6; i++ ) 
   {
      if( strcmp( valuesTmp[i+j], "NMAU" ) == 0 )
      {
         ACPeakPowerPeak[i] = RSCMU_NMAU;
      }
      else if( strcmp( valuesTmp[i+j], "NMAL" ) == 0 ) 
      {
         ACPeakPowerPeak[i] = RSCMU_NMAL;
      }
      else if( strcmp( valuesTmp[i+j], "OK" ) == 0 ) 
      {
         ACPeakPowerPeak[i] = RSCMU_OK;  
      }
      else  // Measurement Invalid
      {
         ACPeakPowerPeak[i] = RSCMU_INV;  
      }
   }
   j += i;

   // ACPPeak RMS (-3 to +3)  
   for( i = 0; i < 6; i++ ) 
   {
      if( strcmp( valuesTmp[i+j], "NMAU" ) == 0 )
      {
         ACPeakPowerRMS[i] = RSCMU_NMAU;
      }
      else if( strcmp( valuesTmp[i+j], "NMAL" ) == 0 ) 
      {
         ACPeakPowerRMS[i] = RSCMU_NMAL;
      }
      else if( strcmp( valuesTmp[i+j], "OK" ) == 0 ) 
      {
         ACPeakPowerRMS[i] = RSCMU_OK;  
      }
      else  // Measurement Invalid
      {
         ACPeakPowerRMS[i] = RSCMU_INV;  
      }
   }
   j += i;

   // ACPAvg RMS (-3 to +3) 
   for( i = 0; i < 6; i++ ) 
   {
      if( strcmp( valuesTmp[i+j], "NMAU" ) == 0 )
      {
         ACAveragePowerRMS[i] = RSCMU_NMAU;
      }
      else if( strcmp( valuesTmp[i+j], "NMAL" ) == 0 ) 
      {
         ACAveragePowerRMS[i] = RSCMU_NMAL;
      }
      else if( strcmp( valuesTmp[i+j], "OK" ) == 0 ) 
      {
         ACAveragePowerRMS[i] = RSCMU_OK;  
      }
      else  // Measurement Invalid
      {
         ACAveragePowerRMS[i] = RSCMU_INV;  
      }
   }

   return( RSCMU_Status );
   
}


/*===========================================================================*/
/* Function: RSCMU_ReturnLimits
/* Purpose : This function is call to return the values of CMU respone
/*===========================================================================*/
static ViStatus RSCMU_ReturnLimits( ViChar                 valuesTmp[3][30]
                                  , RSCMUK2T_ERROR_LIMITS *value
                                  )
{
   ViStatus RSCMU_Status = VI_SUCCESS;

   if( strcmp( valuesTmp[0], "NAN" ) != 0 )
   {
      sscanf( valuesTmp[0], "%lf", &value->Current );
   }
   else
   {
      value->Current = RSCMU_NAN;
   }
   
   if( strcmp( valuesTmp[1], "NAN" ) != 0 )
   {
      sscanf( valuesTmp[1], "%lf", &value->Average );
   }
   else
   {
      value->Average = RSCMU_NAN;
   }

   if( strcmp( valuesTmp[2], "NAN" ) != 0 )
   {
      sscanf( valuesTmp[2], "%lf", &value->MaxMin );
   }
   else
   {
      value->MaxMin = RSCMU_NAN;
   }

   return RSCMU_Status;    
}


/*===========================================================================*/
/* Function: RSCMU_ReturnModLimits
/* Purpose : This function is call to return the values of CMU respone
/*===========================================================================*/
static ViStatus RSCMU_ReturnModLimits( ViChar    valuesTmp[5][30]
                                     , ViInt32  *Sync
                                     , ViReal64 *AmplitudeDrop
                                     , ViReal64 *TimingErr
                                     , ViReal64 *PowerRMS
                                     , ViReal64 *BurstsOutOfTolerance
                                     )
{
   ViStatus RSCMU_Status = VI_SUCCESS;

   // Determine the sync status:
   if( strncmp( "OFF", valuesTmp[0], 3 ) == 0 ) 
   {
      *Sync = RSCMU_IS136_OFF;
   }
   else if( strncmp( "IS1", valuesTmp[0], 3 ) == 0 )
   {
      *Sync = RSCMU_IS136_IS1;
   }
   else if( strncmp( "IS2", valuesTmp[0], 3 ) == 0 )
   {
      *Sync = RSCMU_IS136_IS2;
   }
   else if( strncmp( "IS3", valuesTmp[0], 3 ) == 0 )
   {
      *Sync = RSCMU_IS136_IS3;
   }
   else if( strncmp( "IS4", valuesTmp[0], 3 ) == 0 )
   {
      *Sync = RSCMU_IS136_IS4;
   }
   else if( strncmp( "IS5", valuesTmp[0], 3 ) == 0 )
   {
      *Sync = RSCMU_IS136_IS5;
   }
   else if( strncmp( "IS6", valuesTmp[0], 3 ) == 0 )
   {
      *Sync = RSCMU_IS136_IS6;
   }
   else if( strncmp( "ALL", valuesTmp[0], 3 ) == 0 )
   {
      *Sync = RSCMU_IS136_ALL;
   }
   
   // Determine the Amplitude Drop
   if( strcmp( valuesTmp[1], "NAN" ) != 0 )
   {
      sscanf( valuesTmp[1], "%lf", AmplitudeDrop );
   }
   else
   {
      *AmplitudeDrop = RSCMU_NAN;
   }

   // Determine the Timing Error
   if( strcmp( valuesTmp[2], "NAN" ) != 0 )
   {
      sscanf( valuesTmp[2], "%lf", TimingErr );
   }
   else
   {
      *TimingErr = RSCMU_NAN;
   }

   // Determine the RMS Power
   if( strcmp( valuesTmp[3], "NAN" ) != 0 )
   {
      sscanf( valuesTmp[3], "%lf", PowerRMS );
   }
   else
   {
      *PowerRMS = RSCMU_NAN;
   }

   // Determine the number of bursts out of tolerance
   if( strcmp( valuesTmp[4], "NAN" ) != 0 )
   {
      sscanf( valuesTmp[4], "%lf", BurstsOutOfTolerance );
   }
   else
   {
      *BurstsOutOfTolerance = RSCMU_NAN;
   }

   return( RSCMU_Status );
}


/*===========================================================================*/
/* Function: RSCMU_MatchLimits
/* Purpose : This function is call to return the error limits for the
/*           scalar measured values.
/*===========================================================================*/
static ViStatus RSCMU_MatchLimits( ViChar                 valuesTmp[3][30]
                                 , RSCMUK2T_ERROR_LIMITS *value
                                 )
{
   ViStatus RSCMU_Status = VI_SUCCESS;
   
   // Current
   if( strcmp( valuesTmp[0], "NMAU" ) == 0 )
   {
      value->Current = RSCMU_NMAU;
   }
   else if( strcmp( valuesTmp[0], "NMAL" ) == 0 ) 
   {
      value->Current = RSCMU_NMAL;
   }
   else if( strcmp( valuesTmp[0], "OK" ) == 0 ) 
   {
         value->Current = RSCMU_OK;  
   }
   else  // Measurement Invalid
   {
      value->Current = RSCMU_INV;  
   }

   // Average
   if( strcmp( valuesTmp[1], "NMAU" ) == 0 )
   {
      value->Average = RSCMU_NMAU;
   }
   else if( strcmp( valuesTmp[1], "NMAL" ) == 0 ) 
   {
      value->Average = RSCMU_NMAL;
   }
   else if( strcmp( valuesTmp[1], "OK" ) == 0 ) 
   {
      value->Average = RSCMU_OK;  
   }
   else  // Measurement Invalid
   {
      value->Average = RSCMU_INV;  
   }

   // MaxMin
   if( strcmp( valuesTmp[2], "NMAU" ) == 0 )
   {
      value->MaxMin = RSCMU_NMAU;
   }
   else if( strcmp( valuesTmp[2], "NMAL" ) == 0 ) 
   {
      value->MaxMin = RSCMU_NMAL;
   }
   else if( strcmp( valuesTmp[2], "OK" ) == 0 ) 
   {
      value->MaxMin = RSCMU_OK;  
   }
   else  // Measurement Invalid
   {
      value->MaxMin = RSCMU_INV;  
   }
      
   return RSCMU_Status;    
}


/*===========================================================================*/
/* Function: RSCMU_GetMeasurementStatus
/* Purpose : This function is call to get the measurement status
/*===========================================================================*/
static ViStatus RSCMU_GetMeasurementStatus( ViInt32 *MeasStatus
                                          , ViChar   tab[38][30]
                                          , ViInt32  Index
                                          )
{
   ViStatus RSCMU_Status = VI_SUCCESS;
  
   if( strncmp( "OFF", tab[Index], 3 ) == 0 )  
   {
      *MeasStatus = RSCMU_MEAS_OFF;
   }
   else if( strncmp( "RUN", tab[Index], 3 ) == 0 )
   {
      *MeasStatus = RSCMU_MEAS_RUN;
   }
   else if( strncmp( "STOP", tab[Index], 4 ) == 0 )
   {
      *MeasStatus = RSCMU_MEAS_STOP;
   }
   else if( strncmp( "ERR", tab[Index], 3 ) == 0 )
   {
      *MeasStatus = RSCMU_MEAS_ERR;
   }
   else if( strncmp( "STEP", tab[Index], 4 ) == 0 )
   {
      *MeasStatus = RSCMU_MEAS_STEP;
   }
   else if( strncmp( "RDY", tab[Index], 3 ) == 0 )
   {
      *MeasStatus = RSCMU_MEAS_RDY; 
   }
   else if( strncmp( "PASS", tab[Index], 4 ) == 0 )
   {
      *MeasStatus = RSCMU_MEAS_STATUS_PASS;
   }
   else if( strncmp( "FAIL", tab[Index], 4 ) == 0 )
   {
      *MeasStatus = RSCMU_MEAS_STATUS_FAIL;
   }
   else if( strncmp( "INV", tab[Index], 3 ) == 0 )
   {
      *MeasStatus = RSCMU_MEAS_STATUS_INV;
   }
   else if( strncmp( "TMER", tab[Index], 4 ) == 0 )
   {
      *MeasStatus = RSCMU_MEAS_STATUS_TMER;
   }
   else if( strncmp( "IMP", tab[Index], 3 ) == 0 )
   {
      *MeasStatus = RSCMU_MEAS_STATUS_IMP;
   }

  return RSCMU_Status;    
}


/*===========================================================================*/
/* Function: RSCMU_GetMeasureMatching
/* Purpose : This function is call to get the measure matching
/*===========================================================================*/
static ViStatus RSCMU_GetMeasureMatching( ViInt32 *Match
                                        , ViChar   tab[38][30]
                                        , ViInt32  NbBox
                                        )
{
   ViStatus RSCMU_Status = VI_SUCCESS;

   // For All Measured Values
   if( strncmp( "NMAU", tab[NbBox], 4 ) == 0 )
   {
      *Match = RSCMU_MEAS_MATCH_NMAU;
   }
   else if( strncmp( "NMAL", tab[NbBox], 4 ) == 0 )
   {
      *Match = RSCMU_MEAS_MATCH_NMAL;
   }
   else if( strncmp( "INV", tab[NbBox], 3 ) == 0 )
   {
      *Match = RSCMU_MEAS_MATCH_INV;
   }
   else if( strncmp( "OK", tab[NbBox], 2 ) == 0 )
   {
      *Match = RSCMU_MEAS_MATCH_OK;
   }

   // Burst Template Matching
   else if( strncmp( "MATC", tab[NbBox], 4 ) == 0 ) 
   {
      *Match = RSCMU_MATCH_MATC;
   }
   else if( strncmp( "NMAT", tab[NbBox], 4 ) == 0 ) 
   {
      *Match = RSCMU_MATCH_NMAT;
   }
   else if( strncmp( "INV", tab[NbBox], 3 ) == 0 )  
   {
      *Match = RSCMU_MATCH_INV; 
   }
   else if( strncmp( "NTSC", tab[NbBox], 4 ) == 0 )  
   {
      *Match = RSCMU_MATCH_NTSC; 
   }
   else if( strncmp( "OUT", tab[NbBox], 3 ) == 0 )  
   {
      *Match = RSCMU_MATCH_OUT;
   }
      
   return( RSCMU_Status );
}

/*===========================================================================*/
/* Function: RSCMU_ReturnArrayValues
/* Purpose : This function returns the values from the array string
/*===========================================================================*/
static void RSCMU_ReturnArrayValues( ViChar inBuf[], ViReal64 values[] )
{
   ViChar  *adr;
   ViInt32  i = 0;
   
   adr = strtok( inBuf, "," );
  
   while( adr )
   {
      if( strcmp(adr, "NAN") != 0 )
      {    
        sscanf( adr, "%lf", &values[i] );
      }
      else
      
      {
         values[i] = RSCMU_NAN;
      }
      adr = strtok( NULL, "," );
      i++;
   }
}

/* Ex Functions (No structures) */

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_FetchMod_Error_Ex
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC 
   RSCMU_TDMA_FetchMod_Error_Ex( ViSession instrSession
                               , ViInt32   type
                               , ViInt32   SelectNumBursts
                               , ViReal64  peak[]
                               , ViReal64  RMS[]
                               , ViReal64  originOffset[]
                               , ViReal64  IQImbalance[]
                               , ViReal64  freqErr[]
                               , ViInt32  *sync
                               , ViReal64 *amplitudeDrop
                               , ViReal64 *timingError
                               , ViReal64 *powerRMS
                               , ViReal64 *burstsOut_ofTolerance
                               , ViChar    errorMessage[]
                               )
{
   ViStatus            RSCMU_Status = VI_SUCCESS;  
   ViChar             *wrtBuf;
   ViChar             *rdBuf;
   RSCMUK2T_ERROR_MOD  Modulation;
   ViChar              tab[38][30];    

   checkRange( 64, &type, &SelectNumBursts );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[64].instrCommand
          , testType.list[type]
          , symbols.list[SelectNumBursts]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   RSCMU_Status = RSCMU_ReturnLimits( &tab[0]
                                   , &Modulation.Peak
                                   );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[3]
                                   , &Modulation.RMS
                                   );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[6]
                                   , &Modulation.OriginOffset
                                   );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[9]
                                   , &Modulation.IQImbalance
                                   );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[12]
                                   , &Modulation.FreqErr
                                   );
   RSCMU_Status = RSCMU_ReturnModLimits( &tab[15]
                                      , &Modulation.Sync
                                      , &Modulation.AmplitudeDrop
                                      , &Modulation.TimingErr
                                      , &Modulation.PowerRMS
                                      , &Modulation.BurstsOutOfTolerance
                                      );

   // Return Values
   peak[0]              = Modulation.Peak.Current;
   peak[1]              = Modulation.Peak.Average;
   peak[2]              = Modulation.Peak.MaxMin;
   RMS[0]               = Modulation.RMS.Current;
   RMS[1]               = Modulation.RMS.Average;
   RMS[2]               = Modulation.RMS.MaxMin;
   originOffset[0]         = Modulation.OriginOffset.Current;
   originOffset[1]         = Modulation.OriginOffset.Average;
   originOffset[2]         = Modulation.OriginOffset.MaxMin;
   IQImbalance[0]          = Modulation.IQImbalance.Current;
   IQImbalance[1]          = Modulation.IQImbalance.Average;
   IQImbalance[2]          = Modulation.IQImbalance.MaxMin;
   freqErr[0]           = Modulation.FreqErr.Current;
   freqErr[1]           = Modulation.FreqErr.Average;
   freqErr[2]           = Modulation.FreqErr.MaxMin;
   *sync                = Modulation.Sync;
   *amplitudeDrop          = Modulation.AmplitudeDrop;
   *timingError         = Modulation.TimingErr;
   *powerRMS            = Modulation.PowerRMS;
   *burstsOut_ofTolerance  = Modulation.BurstsOutOfTolerance;

   return( RSCMU_Status );

}

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_SampleMod_Error_Ex
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC 
   RSCMU_TDMA_SampleMod_Error_Ex( ViSession instrSession
                                , ViInt32   type
                                , ViInt32   SelectNumBursts
                                , ViReal64  peak[]
                                , ViReal64  RMS[]
                                , ViReal64  originOffset[]
                                , ViReal64  IQImbalance[]
                                , ViReal64  freqErr[]
                                , ViInt32  *sync
                                , ViReal64 *amplitudeDrop
                                , ViReal64 *timingError
                                , ViReal64 *powerRMS
                                , ViReal64 *burstsOut_ofTolerance
                                , ViChar    errorMessage[]
                                )

{
   ViStatus            RSCMU_Status = VI_SUCCESS;  
   ViChar             *wrtBuf;
   ViChar             *rdBuf;
   RSCMUK2T_ERROR_MOD  Modulation;
   ViChar              tab[38][30];    

   checkRange( 65, &type, &SelectNumBursts );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[65].instrCommand
          , testType.list[type]
          , symbols.list[SelectNumBursts]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   RSCMU_Status = RSCMU_ReturnLimits( &tab[0]
                                   , &Modulation.Peak
                                   );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[3]
                                   , &Modulation.RMS
                                   );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[6]
                                   , &Modulation.OriginOffset
                                   );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[9]
                                   , &Modulation.IQImbalance
                                   );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[12]
                                   , &Modulation.FreqErr
                                   );
   RSCMU_Status = RSCMU_ReturnModLimits( &tab[15]
                                      , &Modulation.Sync
                                      , &Modulation.AmplitudeDrop
                                      , &Modulation.TimingErr
                                      , &Modulation.PowerRMS
                                      , &Modulation.BurstsOutOfTolerance
                                      );

   // Return Values
   peak[0]              = Modulation.Peak.Current;
   peak[1]              = Modulation.Peak.Average;
   peak[2]              = Modulation.Peak.MaxMin;
   RMS[0]               = Modulation.RMS.Current;
   RMS[1]               = Modulation.RMS.Average;
   RMS[2]               = Modulation.RMS.MaxMin;
   originOffset[0]         = Modulation.OriginOffset.Current;
   originOffset[1]         = Modulation.OriginOffset.Average;
   originOffset[2]         = Modulation.OriginOffset.MaxMin;
   IQImbalance[0]          = Modulation.IQImbalance.Current;
   IQImbalance[1]          = Modulation.IQImbalance.Average;
   IQImbalance[2]          = Modulation.IQImbalance.MaxMin;
   freqErr[0]           = Modulation.FreqErr.Current;
   freqErr[1]           = Modulation.FreqErr.Average;
   freqErr[2]           = Modulation.FreqErr.MaxMin;
   *sync                = Modulation.Sync;
   *amplitudeDrop          = Modulation.AmplitudeDrop;
   *timingError         = Modulation.TimingErr;
   *powerRMS            = Modulation.PowerRMS;
   *burstsOut_ofTolerance  = Modulation.BurstsOutOfTolerance;

   return( RSCMU_Status );

}

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ReadMod_Error_Ex
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC 
   RSCMU_TDMA_ReadMod_Error_Ex( ViSession instrSession
                              , ViInt32   type
                              , ViInt32   SelectNumBursts
                              , ViReal64  peak[]
                              , ViReal64  RMS[]
                              , ViReal64  originOffset[]
                              , ViReal64  IQImbalance[]
                              , ViReal64  freqErr[]
                              , ViInt32  *sync
                              , ViReal64 *amplitudeDrop
                              , ViReal64 *timingError
                              , ViReal64 *powerRMS
                              , ViReal64 *burstsOut_ofTolerance
                              , ViChar    errorMessage[]
                              )
{
   ViStatus            RSCMU_Status = VI_SUCCESS;  
   ViChar             *wrtBuf;
   ViChar             *rdBuf;
   RSCMUK2T_ERROR_MOD  Modulation;
   ViChar              tab[38][30];    

   checkRange( 63, &type, &SelectNumBursts );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[63].instrCommand
          , testType.list[type]
          , symbols.list[SelectNumBursts]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   RSCMU_Status = RSCMU_ReturnLimits( &tab[0]
                                   , &Modulation.Peak
                                   );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[3]
                                   , &Modulation.RMS
                                   );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[6]
                                   , &Modulation.OriginOffset
                                   );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[9]
                                   , &Modulation.IQImbalance
                                   );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[12]
                                   , &Modulation.FreqErr
                                   );
   RSCMU_Status = RSCMU_ReturnModLimits( &tab[15]
                                      , &Modulation.Sync
                                      , &Modulation.AmplitudeDrop
                                      , &Modulation.TimingErr
                                      , &Modulation.PowerRMS
                                      , &Modulation.BurstsOutOfTolerance
                                      );

   // Return Values
   peak[0]              = Modulation.Peak.Current;
   peak[1]              = Modulation.Peak.Average;
   peak[2]              = Modulation.Peak.MaxMin;
   RMS[0]               = Modulation.RMS.Current;
   RMS[1]               = Modulation.RMS.Average;
   RMS[2]               = Modulation.RMS.MaxMin;
   originOffset[0]         = Modulation.OriginOffset.Current;
   originOffset[1]         = Modulation.OriginOffset.Average;
   originOffset[2]         = Modulation.OriginOffset.MaxMin;
   IQImbalance[0]          = Modulation.IQImbalance.Current;
   IQImbalance[1]          = Modulation.IQImbalance.Average;
   IQImbalance[2]          = Modulation.IQImbalance.MaxMin;
   freqErr[0]           = Modulation.FreqErr.Current;
   freqErr[1]           = Modulation.FreqErr.Average;
   freqErr[2]           = Modulation.FreqErr.MaxMin;
   *sync                = Modulation.Sync;
   *amplitudeDrop          = Modulation.AmplitudeDrop;
   *timingError         = Modulation.TimingErr;
   *powerRMS            = Modulation.PowerRMS;
   *burstsOut_ofTolerance  = Modulation.BurstsOutOfTolerance;

return( RSCMU_Status );

}

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_CalcMod_Error_Ex
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC 
   RSCMU_TDMA_CalcMod_Error_Ex( ViSession instrSession
                              , ViInt32   type
                              , ViInt32   SelectNumBursts
                              , ViReal64  peak[]
                              , ViReal64  RMS[]
                              , ViReal64  originOffset[]
                              , ViReal64  IQImbalance[]
                              , ViReal64  freqErr[]
                              , ViInt32  *sync
                              , ViReal64 *amplitudeDrop
                              , ViReal64 *timingError
                              , ViReal64 *powerRMS
                              , ViReal64 *burstsOut_ofTolerance
                              , ViChar    errorMessage[]
                              )
{
   ViStatus   RSCMU_Status = VI_SUCCESS;  
   ViChar    *wrtBuf;
   ViChar    *rdBuf;
   RSCMUK2T_ERROR_MOD  Modulation;
   ViChar     tab[38][30]; 

   checkRange( 66, &type, &SelectNumBursts );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[66].instrCommand
          , testType.list[type]
          , symbols.list[SelectNumBursts]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   RSCMU_Status = RSCMU_MatchLimits( &tab[0]
                                   , &Modulation.Peak
                                   );
   RSCMU_Status = RSCMU_MatchLimits( &tab[3]
                                   , &Modulation.RMS
                                   );
   RSCMU_Status = RSCMU_MatchLimits( &tab[6]
                                   , &Modulation.OriginOffset
                                   );
   RSCMU_Status = RSCMU_MatchLimits( &tab[9]
                                   , &Modulation.IQImbalance
                                   );
   RSCMU_Status = RSCMU_MatchLimits( &tab[12]
                                   , &Modulation.FreqErr
                                   );
   // Return Values
   peak[0]                  = Modulation.Peak.Current;
   peak[1]                  = Modulation.Peak.Average;
   peak[2]                  = Modulation.Peak.MaxMin;
   RMS[0]                   = Modulation.RMS.Current;
   RMS[1]                   = Modulation.RMS.Average;
   RMS[2]                   = Modulation.RMS.MaxMin;
   originOffset[0]          = Modulation.OriginOffset.Current;
   originOffset[1]          = Modulation.OriginOffset.Average;
   originOffset[2]          = Modulation.OriginOffset.MaxMin;
   IQImbalance[0]           = Modulation.IQImbalance.Current;
   IQImbalance[1]           = Modulation.IQImbalance.Average;
   IQImbalance[2]           = Modulation.IQImbalance.MaxMin;
   freqErr[0]               = Modulation.FreqErr.Current;
   freqErr[1]               = Modulation.FreqErr.Average;
   freqErr[2]               = Modulation.FreqErr.MaxMin;
   *sync                    = RSCMU_NAN_VI_INT32;
   *amplitudeDrop           = RSCMU_NAN;
   *timingError             = RSCMU_NAN;
   *powerRMS                = RSCMU_NAN;
   *burstsOut_ofTolerance   = RSCMU_NAN;

return( RSCMU_Status );

}

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ReadMod_Overview_Ex
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
ViStatus _VI_FUNC 
   RSCMU_TDMA_ReadMod_Overview_Ex( ViSession instrSession
                                 , ViInt32   SelectNumBursts
                                 , ViReal64  phaseErrorPeak[]
                                 , ViReal64  phaseErrorRMS[]
                                 , ViReal64  modErrorPeak[]
                                 , ViReal64  modErrorRMS[]
                                 , ViReal64  EVMPeak[]
                                 , ViReal64  EVMRMS[]
                                 , ViReal64  originOffset[]
                                 , ViReal64  IQImbalance[]
                                 , ViReal64  frequencyError[]
                                 , ViInt32  *sync
                                 , ViReal64 *amplitudeDrop
                                 , ViReal64 *timingError
                                 , ViReal64 *powerRMS
                                 , ViReal64 *burstsOut_ofTolerance
                                 , ViChar    errorMessage[]
                                 )
{
   ViStatus           RSCMU_Status = VI_SUCCESS;  
   ViChar            *wrtBuf;
   ViChar            *rdBuf;
   ViChar             tab[38][30];
   RSCMUK2T_OVERVIEW  Overview;     // JMG = {NULL};
   ViInt32            type          = RSCMU_OVERVIEW;
   
   
   checkRange( 63, &type , &SelectNumBursts );
   
   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[63].instrCommand
          , testType.list[RSCMU_OVERVIEW]
          , symbols.list[SelectNumBursts]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

     // Separate the CMU response:
     RSCMU_SeparateString( rdBuf, ",", tab );
   
      RSCMU_Status = RSCMU_ReturnLimits( &tab[0]
                                       , &Overview.PErrPeak
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[3]
                                       , &Overview.PErrRMS
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[6]
                                       , &Overview.MErrPeak
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[9]
                                       , &Overview.MErrRMS
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[12]
                                       , &Overview.EVMPeak
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[15]
                                       , &Overview.EVMRMS
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[18]
                                       , &Overview.OriginOffset
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[21]
                                       , &Overview.IQImbalance
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[24]
                                       , &Overview.FreqErr
                                       );
      RSCMU_Status = RSCMU_ReturnModLimits( &tab[27]
                                          , &Overview.Sync
                                          , &Overview.AmplitudeDrop
                                          , &Overview.TimingErr
                                          , &Overview.PowerRMS
                                          , &Overview.BurstsOutOfTolerance
                                          );

   //Return Values
   phaseErrorPeak[0]       = Overview.PErrPeak.Current;
   phaseErrorPeak[1]       = Overview.PErrPeak.Average;
   phaseErrorPeak[2]       = Overview.PErrPeak.MaxMin;
   phaseErrorRMS[0]        = Overview.PErrRMS.Current;
   phaseErrorRMS[1]        = Overview.PErrRMS.Average;
   phaseErrorRMS[2]        = Overview.PErrRMS.MaxMin;
   modErrorPeak[0]         = Overview.MErrPeak.Current;
   modErrorPeak[1]         = Overview.MErrPeak.Average;
   modErrorPeak[2]         = Overview.MErrPeak.MaxMin;
   modErrorRMS[0]          = Overview.MErrRMS.Current;
   modErrorRMS[1]          = Overview.MErrRMS.Average;
   modErrorRMS[2]          = Overview.MErrRMS.MaxMin;
   EVMPeak[0]              = Overview.EVMPeak.Current;
   EVMPeak[1]              = Overview.EVMPeak.Average;
   EVMPeak[2]              = Overview.EVMPeak.MaxMin;
   EVMRMS[0]               = Overview.EVMRMS.Current;
   EVMRMS[1]               = Overview.EVMRMS.Average;
   EVMRMS[2]               = Overview.EVMRMS.MaxMin;
   originOffset[0]         = Overview.OriginOffset.Current;
   originOffset[1]         = Overview.OriginOffset.Average;
   originOffset[2]         = Overview.OriginOffset.MaxMin;
   IQImbalance[0]          = Overview.IQImbalance.Current;
   IQImbalance[1]          = Overview.IQImbalance.Average;
   IQImbalance[2]          = Overview.IQImbalance.MaxMin;
   frequencyError[0]       = Overview.FreqErr.Current;
   frequencyError[1]       = Overview.FreqErr.Average;
   frequencyError[2]       = Overview.FreqErr.MaxMin;
   *sync                   = Overview.Sync;
   *amplitudeDrop          = Overview.AmplitudeDrop;
   *timingError            = Overview.TimingErr;
   *powerRMS               = Overview.PowerRMS;
   *burstsOut_ofTolerance  = Overview.BurstsOutOfTolerance;

   return( RSCMU_Status );

}

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_FetchMod_Overview_Ex
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC 
   RSCMU_TDMA_FetchMod_Overview_Ex( ViSession instrSession
                                  , ViInt32   SelectNumBursts
                                  , ViReal64  phaseErrorPeak[]
                                  , ViReal64  phaseErrorRMS[]
                                  , ViReal64  modErrorPeak[]
                                  , ViReal64  modErrorRMS[]
                                  , ViReal64  EVMPeak[]
                                  , ViReal64  EVMRMS[]
                                  , ViReal64  originOffset[]
                                  , ViReal64  IQImbalance[]
                                  , ViReal64  frequencyError[]
                                  , ViInt32  *sync
                                  , ViReal64 *amplitudeDrop
                                  , ViReal64 *timingError
                                  , ViReal64 *powerRMS
                                  , ViReal64 *burstsOut_ofTolerance
                                  , ViChar    errorMessage[]
                                  )
{
   ViStatus           RSCMU_Status = VI_SUCCESS;  
   ViChar            *wrtBuf;
   ViChar            *rdBuf;
   RSCMUK2T_OVERVIEW  Overview;
   ViChar             tab[38][30];    
   ViInt32            type = RSCMU_OVERVIEW;
   
   checkRange( 64, &type, &SelectNumBursts ); 
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[64].instrCommand
          , testType.list[RSCMU_OVERVIEW]
          , symbols.list[SelectNumBursts]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

     // Separate the CMU response:
     RSCMU_SeparateString( rdBuf, ",", tab );
   
      RSCMU_Status = RSCMU_ReturnLimits( &tab[0]
                                       , &Overview.PErrPeak
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[3]
                                       , &Overview.PErrRMS
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[6]
                                       , &Overview.MErrPeak
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[9]
                                       , &Overview.MErrRMS
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[12]
                                       , &Overview.EVMPeak
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[15]
                                       , &Overview.EVMRMS
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[18]
                                       , &Overview.OriginOffset
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[21]
                                       , &Overview.IQImbalance
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[24]
                                       , &Overview.FreqErr
                                       );
      RSCMU_Status = RSCMU_ReturnModLimits( &tab[27]
                                          , &Overview.Sync
                                          , &Overview.AmplitudeDrop
                                          , &Overview.TimingErr
                                          , &Overview.PowerRMS
                                          , &Overview.BurstsOutOfTolerance
                                          );

   //Return Values
   phaseErrorPeak[0]       = Overview.PErrPeak.Current;
   phaseErrorPeak[1]       = Overview.PErrPeak.Average;
   phaseErrorPeak[2]       = Overview.PErrPeak.MaxMin;
   phaseErrorRMS[0]        = Overview.PErrRMS.Current;
   phaseErrorRMS[1]        = Overview.PErrRMS.Average;
   phaseErrorRMS[2]        = Overview.PErrRMS.MaxMin;
   modErrorPeak[0]         = Overview.MErrPeak.Current;
   modErrorPeak[1]         = Overview.MErrPeak.Average;
   modErrorPeak[2]         = Overview.MErrPeak.MaxMin;
   modErrorRMS[0]          = Overview.MErrRMS.Current;
   modErrorRMS[1]          = Overview.MErrRMS.Average;
   modErrorRMS[2]          = Overview.MErrRMS.MaxMin;
   EVMPeak[0]              = Overview.EVMPeak.Current;
   EVMPeak[1]              = Overview.EVMPeak.Average;
   EVMPeak[2]              = Overview.EVMPeak.MaxMin;
   EVMRMS[0]               = Overview.EVMRMS.Current;
   EVMRMS[1]               = Overview.EVMRMS.Average;
   EVMRMS[2]               = Overview.EVMRMS.MaxMin;
   originOffset[0]         = Overview.OriginOffset.Current;
   originOffset[1]         = Overview.OriginOffset.Average;
   originOffset[2]         = Overview.OriginOffset.MaxMin;
   IQImbalance[0]          = Overview.IQImbalance.Current;
   IQImbalance[1]          = Overview.IQImbalance.Average;
   IQImbalance[2]          = Overview.IQImbalance.MaxMin;
   frequencyError[0]       = Overview.FreqErr.Current;
   frequencyError[1]       = Overview.FreqErr.Average;
   frequencyError[2]       = Overview.FreqErr.MaxMin;
   *sync                   = Overview.Sync;
   *amplitudeDrop          = Overview.AmplitudeDrop;
   *timingError            = Overview.TimingErr;
   *powerRMS               = Overview.PowerRMS;
   *burstsOut_ofTolerance  = Overview.BurstsOutOfTolerance;

   return( RSCMU_Status );

}

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_SampleMod_Overview_Ex
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC 
   RSCMU_TDMA_SampleMod_Overview_Ex( ViSession instrSession
                                   , ViInt32   SelectNumBursts
                                   , ViReal64  phaseErrorPeak[]
                                   , ViReal64  phaseErrorRMS[]
                                   , ViReal64  modErrorPeak[]
                                   , ViReal64  modErrorRMS[]
                                   , ViReal64  EVMPeak[]
                                   , ViReal64  EVMRMS[]
                                   , ViReal64  originOffset[]
                                   , ViReal64  IQImbalance[]
                                   , ViReal64  frequencyError[]
                                   , ViInt32  *sync
                                   , ViReal64 *amplitudeDrop
                                   , ViReal64 *timingError
                                   , ViReal64 *powerRMS
                                   , ViReal64 *burstsOut_ofTolerance
                                   , ViChar    errorMessage[]
                                   )
{
   ViStatus           RSCMU_Status = VI_SUCCESS;  
   ViChar            *wrtBuf;
   ViChar            *rdBuf;
   RSCMUK2T_OVERVIEW  Overview;
   ViChar             tab[38][30];    
   ViInt32            type = RSCMU_OVERVIEW;
   
   checkRange( 65, &type, &SelectNumBursts );   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[65].instrCommand
          , testType.list[RSCMU_OVERVIEW]
          , symbols.list[SelectNumBursts]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   RSCMU_Status = RSCMU_ReturnLimits( &tab[0]
                                   , &Overview.PErrPeak
                                   );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[3]
                                   , &Overview.PErrRMS
                                   );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[6]
                                   , &Overview.MErrPeak
                                   );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[9]
                                   , &Overview.MErrRMS
                                   );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[12]
                                   , &Overview.EVMPeak
                                   );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[15]
                                   , &Overview.EVMRMS
                                   );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[18]
                                   , &Overview.OriginOffset
                                   );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[21]
                                   , &Overview.IQImbalance
                                   );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[24]
                                   , &Overview.FreqErr
                                   );
   RSCMU_Status = RSCMU_ReturnModLimits( &tab[27]
                                      , &Overview.Sync
                                      , &Overview.AmplitudeDrop
                                      , &Overview.TimingErr
                                      , &Overview.PowerRMS
                                      , &Overview.BurstsOutOfTolerance
                                      );

   //Return Values
   phaseErrorPeak[0]       = Overview.PErrPeak.Current;
   phaseErrorPeak[1]       = Overview.PErrPeak.Average;
   phaseErrorPeak[2]       = Overview.PErrPeak.MaxMin;
   phaseErrorRMS[0]        = Overview.PErrRMS.Current;
   phaseErrorRMS[1]        = Overview.PErrRMS.Average;
   phaseErrorRMS[2]        = Overview.PErrRMS.MaxMin;
   modErrorPeak[0]         = Overview.MErrPeak.Current;
   modErrorPeak[1]         = Overview.MErrPeak.Average;
   modErrorPeak[2]         = Overview.MErrPeak.MaxMin;
   modErrorRMS[0]          = Overview.MErrRMS.Current;
   modErrorRMS[1]          = Overview.MErrRMS.Average;
   modErrorRMS[2]          = Overview.MErrRMS.MaxMin;
   EVMPeak[0]              = Overview.EVMPeak.Current;
   EVMPeak[1]              = Overview.EVMPeak.Average;
   EVMPeak[2]              = Overview.EVMPeak.MaxMin;
   EVMRMS[0]               = Overview.EVMRMS.Current;
   EVMRMS[1]               = Overview.EVMRMS.Average;
   EVMRMS[2]               = Overview.EVMRMS.MaxMin;
   originOffset[0]         = Overview.OriginOffset.Current;
   originOffset[1]         = Overview.OriginOffset.Average;
   originOffset[2]         = Overview.OriginOffset.MaxMin;
   IQImbalance[0]          = Overview.IQImbalance.Current;
   IQImbalance[1]          = Overview.IQImbalance.Average;
   IQImbalance[2]          = Overview.IQImbalance.MaxMin;
   frequencyError[0]       = Overview.FreqErr.Current;
   frequencyError[1]       = Overview.FreqErr.Average;
   frequencyError[2]       = Overview.FreqErr.MaxMin;
   *sync                   = Overview.Sync;
   *amplitudeDrop          = Overview.AmplitudeDrop;
   *timingError            = Overview.TimingErr;
   *powerRMS               = Overview.PowerRMS;
   *burstsOut_ofTolerance  = Overview.BurstsOutOfTolerance;

   return( RSCMU_Status );

}

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_CalcMod_Overview_Ex
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC 
   RSCMU_TDMA_CalcMod_Overview_Ex( ViSession instrSession
                                   , ViInt32   SelectNumBursts
                                   , ViReal64  phaseErrorPeak[]
                                   , ViReal64  phaseErrorRMS[]
                                   , ViReal64  modErrorPeak[]
                                   , ViReal64  modErrorRMS[]
                                   , ViReal64  EVMPeak[]
                                   , ViReal64  EVMRMS[]
                                   , ViReal64  originOffset[]
                                   , ViReal64  IQImbalance[]
                                   , ViReal64  frequencyError[]
                                   , ViInt32  *sync
                                   , ViReal64 *amplitudeDrop
                                   , ViReal64 *timingError
                                   , ViReal64 *powerRMS
                                   , ViReal64 *burstsOut_ofTolerance
                                   , ViChar    errorMessage[]
                                   )
{
   ViStatus   RSCMU_Status      = VI_SUCCESS;  
   ViChar    *wrtBuf;
   ViChar    *rdBuf;
   ViChar     tab[38][30]; 
   RSCMUK2T_OVERVIEW  Overview;     // JMG = {NULL};
   ViInt32            type      = RSCMU_OVERVIEW;

   checkRange( 66, &type, &SelectNumBursts );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[66].instrCommand
          , testType.list[type]
          , symbols.list[SelectNumBursts]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   RSCMU_Status = RSCMU_MatchLimits( &tab[0]
                                   , &Overview.PErrPeak
                                   );
   RSCMU_Status = RSCMU_MatchLimits( &tab[3]
                                   , &Overview.PErrRMS
                                   );
   RSCMU_Status = RSCMU_MatchLimits( &tab[6]
                                   , &Overview.MErrPeak
                                   );
   RSCMU_Status = RSCMU_MatchLimits( &tab[9]
                                   , &Overview.MErrRMS
                                   );
   RSCMU_Status = RSCMU_MatchLimits( &tab[12]
                                   , &Overview.EVMPeak
                                   );
   RSCMU_Status = RSCMU_MatchLimits( &tab[15]
                                   , &Overview.EVMRMS
                                   );
   RSCMU_Status = RSCMU_MatchLimits( &tab[18]
                                   , &Overview.OriginOffset
                                   );
   RSCMU_Status = RSCMU_MatchLimits( &tab[21]
                                   , &Overview.IQImbalance
                                   );
   RSCMU_Status = RSCMU_MatchLimits( &tab[24]
                                   , &Overview.FreqErr
                                   );
   //Return Values
   phaseErrorPeak[0]       = Overview.PErrPeak.Current;
   phaseErrorPeak[1]       = Overview.PErrPeak.Average;
   phaseErrorPeak[2]       = Overview.PErrPeak.MaxMin;
   phaseErrorRMS[0]        = Overview.PErrRMS.Current;
   phaseErrorRMS[1]        = Overview.PErrRMS.Average;
   phaseErrorRMS[2]        = Overview.PErrRMS.MaxMin;
   modErrorPeak[0]         = Overview.MErrPeak.Current;
   modErrorPeak[1]         = Overview.MErrPeak.Average;
   modErrorPeak[2]         = Overview.MErrPeak.MaxMin;
   modErrorRMS[0]          = Overview.MErrRMS.Current;
   modErrorRMS[1]          = Overview.MErrRMS.Average;
   modErrorRMS[2]          = Overview.MErrRMS.MaxMin;
   EVMPeak[0]              = Overview.EVMPeak.Current;
   EVMPeak[1]              = Overview.EVMPeak.Average;
   EVMPeak[2]              = Overview.EVMPeak.MaxMin;
   EVMRMS[0]               = Overview.EVMRMS.Current;
   EVMRMS[1]               = Overview.EVMRMS.Average;
   EVMRMS[2]               = Overview.EVMRMS.MaxMin;
   originOffset[0]         = Overview.OriginOffset.Current;
   originOffset[1]         = Overview.OriginOffset.Average;
   originOffset[2]         = Overview.OriginOffset.MaxMin;
   IQImbalance[0]          = Overview.IQImbalance.Current;
   IQImbalance[1]          = Overview.IQImbalance.Average;
   IQImbalance[2]          = Overview.IQImbalance.MaxMin;
   frequencyError[0]       = Overview.FreqErr.Current;
   frequencyError[1]       = Overview.FreqErr.Average;
   frequencyError[2]       = Overview.FreqErr.MaxMin;
   *sync                   = RSCMU_NAN_VI_INT32;
   *amplitudeDrop          = RSCMU_NAN;
   *timingError            = RSCMU_NAN;
   *powerRMS               = RSCMU_NAN;
   *burstsOut_ofTolerance  = RSCMU_NAN;

   return( RSCMU_Status );

}

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ReadScalSpec_Ex
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC 
   RSCMU_TDMA_ReadScalSpec_Ex( ViSession instrSession
                             , ViReal64  peak[]
                             , ViReal64  RMS[]
                             , ViReal64  peakPeak[]
                             , ViReal64  peakRMS[]
                             , ViReal64  averageRMS[]
                             , ViReal64 *burstOut_ofTolerance
                             , ViChar    errorMessage[]
                             )
{
   ViStatus    RSCMU_Status = VI_SUCCESS;  
   ViInt32     NumOfMeasValues, i = 0;
   ViChar     *wrtBuf;
   ViChar     *rdBuf;
   SCALAR_ACP ACP;
   ViChar      TempBuf[669][20];  
   
   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
  
   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[78].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   NumOfMeasValues = RSCMU_scanStringBurst( rdBuf, TempBuf );
   RSCMU_ReturnACPResponse( TempBuf, &ACP );

   // Return Values
   
   peak[0] = ACP.Peak[0];
   RMS[0]  = ACP.RMS[0];

   for( i = 0; i < 6; i++ )
   {   
     peak[i+1]     = ACP.Peak[i+1];
     RMS[i+1]      = ACP.RMS[i+1];
     peakPeak[i]   = ACP.PeakPeak[i];
     peakRMS[i]    = ACP.PeakRMS[i];
     averageRMS[i] = ACP.AverageRMS[i];
   }

   *burstOut_ofTolerance = ACP.BurstsOutOfTolerance;

   return( RSCMU_Status );

}

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_FetchScalSpec_Ex
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC 
   RSCMU_TDMA_FetchScalSpec_Ex( ViSession instrSession
                              , ViReal64  peak[]
                              , ViReal64  RMS[]
                              , ViReal64  peakPeak[]
                              , ViReal64  peakRMS[]
                              , ViReal64  averageRMS[]
                              , ViReal64 *burstOut_ofTolerance
                              , ViChar    errorMessage[]
                              )
{
   ViStatus    RSCMU_Status = VI_SUCCESS;  
   ViInt32     NumOfMeasValues, i = 0;
   ViChar     *wrtBuf;
   ViChar     *rdBuf;
   SCALAR_ACP  ACP;
   ViChar      TempBuf[669][20];  

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
  
   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[77].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   NumOfMeasValues = RSCMU_scanStringBurst( rdBuf, TempBuf );
   RSCMU_ReturnACPResponse( TempBuf, &ACP );

   // Return Values
   
   peak[0]  = ACP.Peak[0];
   RMS[0]   = ACP.RMS[0];

   for( i = 0; i < 6; i++ ) 
   {
     peak[i+1]     = ACP.Peak[i+1];
     RMS[i+1]      = ACP.RMS[i+1];
     peakPeak[i]   = ACP.PeakPeak[i];
     peakRMS[i]    = ACP.PeakRMS[i];
     averageRMS[i] = ACP.AverageRMS[i];
   }

   *burstOut_ofTolerance = ACP.BurstsOutOfTolerance;

   return( RSCMU_Status );

}

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_SampleScalSpec_Ex
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC 
   RSCMU_TDMA_SampleScalSpec_Ex( ViSession instrSession
                               , ViReal64  peak[]
                               , ViReal64  RMS[]
                               , ViReal64  peakPeak[]
                               , ViReal64  peakRMS[]
                               , ViReal64  averageRMS[]
                               , ViReal64 *burstOut_ofTolerance
                               , ViChar    errorMessage[]
                               )
{
   ViStatus    RSCMU_Status = VI_SUCCESS;  
   ViInt32     NumOfMeasValues, i = 0;
   ViChar     *wrtBuf;
   ViChar     *rdBuf;
   SCALAR_ACP  ACP;
   ViChar      TempBuf[669][20];  

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
  
   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[87].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   NumOfMeasValues = RSCMU_scanStringBurst( rdBuf, TempBuf );
   RSCMU_ReturnACPResponse( TempBuf, &ACP );

   // Return Values
   
   peak[0] = ACP.Peak[0];
   RMS[0]  = ACP.RMS[0];

   for( i = 0; i < 6; i++ )
   {   
     peak[i+1]     = ACP.Peak[i+1];
     RMS[i+1]      = ACP.RMS[i+1];
     peakPeak[i]   = ACP.PeakPeak[i];
     peakRMS[i]    = ACP.PeakRMS[i];
     averageRMS[i] = ACP.AverageRMS[i];
   }

   *burstOut_ofTolerance = ACP.BurstsOutOfTolerance;

   return( RSCMU_Status );

}

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_ReadBER_Ex
 *
 * DESCRIPTION: NONE   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC 
   RSCMU_TDMA_ReadBER_Ex( ViSession  instrSession
                        , ViReal64  *testTimeInSeconds
                        , ViReal64  *ber
                        , ViInt32   *numBitsDefaultPatern
                        , ViInt32   *status
                        , ViInt32   *numFramesTransmitted
                        , ViReal64  *TXPower
                        , ViInt32   *TXCarrierFreqErr
                        , ViInt32   *syncPatternDetected
                        , ViInt32   *percentage
                        , ViChar     errorMessage[]
                        )
{
   ViStatus     RSCMU_Status = VI_SUCCESS;
   ViInt32      numMeasValues;
   ViChar      *rdBuf;
   ViChar      *wrtBuf;
   BER_RESULTS BER;
   ViChar       TempBuf[669][20];  

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[165].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   numMeasValues = RSCMU_scanStringBurst( rdBuf, TempBuf );
   RSCMU_Status  = RSCMU_ReturnBERResponse( TempBuf, &BER );

   //Return Values
   *testTimeInSeconds      = BER.TestTimeInSeconds;
   *ber                    = BER.BER;
   *numBitsDefaultPatern   = BER.NumBitsDefaultPattern;
   *status                 = BER.Status;
   *numFramesTransmitted   = BER.NumFramesTransmitted;
   *TXPower                = BER.TxPower;
   *TXCarrierFreqErr       = BER.TxCarrierFreqErr;
   *syncPatternDetected    = BER.SyncPatternDetected;
   *percentage             = BER.Percentage;

   return( RSCMU_Status );

}

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_FetchBER
 *
 * DESCRIPTION: NONE   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC 
   RSCMU_TDMA_FetchBER_Ex( ViSession  instrSession
                         , ViReal64  *testTimeInSeconds
                         , ViReal64  *ber
                         , ViInt32   *numBitsDefaultPatern
                         , ViInt32   *status
                         , ViInt32   *numFramesTransmitted
                         , ViReal64  *TXPower
                         , ViInt32   *TXCarrierFreqErr
                         , ViInt32   *syncPatternDetected
                         , ViInt32   *percentage
                         , ViChar     errorMessage[]
                         )
{
   ViStatus     RSCMU_Status = VI_SUCCESS;
   ViInt32      numMeasValues;
   ViChar      *rdBuf;
   ViChar      *wrtBuf;
   BER_RESULTS  BER;
   ViChar       TempBuf[669][20];  

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[166].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   numMeasValues = RSCMU_scanStringBurst( rdBuf, TempBuf );
   RSCMU_Status  = RSCMU_ReturnBERResponse( TempBuf, &BER );

   //Return Values
   *testTimeInSeconds      = BER.TestTimeInSeconds;
   *ber                    = BER.BER;
   *numBitsDefaultPatern   = BER.NumBitsDefaultPattern;
   *status                 = BER.Status;
   *numFramesTransmitted   = BER.NumFramesTransmitted;
   *TXPower                = BER.TxPower;
   *TXCarrierFreqErr       = BER.TxCarrierFreqErr;
   *syncPatternDetected    = BER.SyncPatternDetected;
   *percentage             = BER.Percentage;
   
   return( RSCMU_Status );

}

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_SenseChanQualityMAHONCells
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC 
   RSCMU_TDMA_SenseChanQualityMAHONC_Ex( ViSession instrSession
                                       , ViInt32   channel[]
                                       , ViInt32   RSSI[]
                                       , ViReal64  level[]
                                       , ViChar    errorMessage[]
                                       )
{
   ViStatus   RSCMU_Status = VI_SUCCESS;  
   ViBoolean  match        = RSCMU_FALSE;
   ViInt32    i;
   ViInt32    j;
   ViInt32    length;
   ViChar    *rdBuf;
   ViChar    *wrtBuf;
   ViChar     TempBuf[669][20];  
   ViReal64   temp;
   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)IS136[167].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   RSCMU_scanStringBurst( rdBuf, TempBuf );
   
   for( i = 0; i < 24; i++ )
   {
      // Read channel.
      sscanf( TempBuf[i*2], "%lf", &temp );
      sprintf( TempBuf[i*2],"%4.0lf",temp );
      sscanf( TempBuf[i*2], "%4d", &channel[i] );
   
      // Search table for a RSSI match.
      length = strlen( TempBuf[(i*2)+1] );
      j      = 0;
      while( *ReportRSSI != NULL )
      {
         if( strncmp( ReportRSSI[j], TempBuf[(i*2)+1], length ) == 0 ) 
         {
            match = RSCMU_TRUE;
            break;
         }
         j++;
      }
   
      // Set return value based on string match.
      if( match )
      {
         if( j == 0 )
         {
            RSSI[i]  = RSCMU_NAN_VI_INT32;
            level[i] = 0;
         }
         else
         {
            RSSI[i]  = j - 1;
            level[i] = -113 + ((j - 1) * 2);
         }
      }
      else
      {
         RSSI[i]  = RSCMU_NAN_VI_INT32;
         level[i] = 0;
         RSCMU_Status          = RSCMU_ERROR_NAN;
      }
   }
   
   return( RSCMU_Status );

}

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_SenseChanQualityMAHOCell
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC 
   RSCMU_TDMA_SenseChanQualityMAHOC_Ex( ViSession instrSession
                                      , ViInt32   channel
                                      , ViInt32  *Channel
                                      , ViInt32  *RSSI
                                      , ViReal64 *level
                                      , ViChar    errorMessage[]
                                      )
{
   ViStatus   RSCMU_Status = VI_SUCCESS;  
   ViBoolean  match        = RSCMU_FALSE;
   ViInt32    i;
   ViInt32    length;
   ViChar    *rdBuf;
   ViChar    *wrtBuf;
   ViChar     tab[38][30];    
   ViReal64   temp;

   checkRange( 152, &channel );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , IS136[152].instrCommand
          , channel
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Read channel.
   sscanf( tab[0], "%lf", &temp );
   sprintf( tab[0],"%4.0lf",temp );
   sscanf( tab[0], "%4d", Channel );
  
  
   // Search table for a RSSI match.
   length = strlen( tab[1] );
   i      = 0;
   while( *ReportRSSI != NULL )
   {
      if( strncmp( ReportRSSI[i], tab[1], length ) == 0 ) 
      {
         match = RSCMU_TRUE;
         break;
      }
      i++;
   }
   
   // Set return value based on string match.
   if( match )
   {
      if( i == 0 )
      {
         *RSSI  = RSCMU_NAN_VI_INT32;
         *level = 0;
      }
      else
      {
         *RSSI  = i - 1;
         *level = -113 + ((*RSSI) * 2);
      }
   }
   else
   {
      *RSSI  = RSCMU_NAN_VI_INT32;
      *level = 0;
      RSCMU_Status    = RSCMU_ERROR_NAN;
   }
   
   return( RSCMU_Status );

}

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_SenseMobileInfoCapability_Ex
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_TDMA_SenseMSInfoCapability_Ex( ViSession   instrSession
                                       , ViChar      softwareVersion[]
                                       , ViChar      firmwareVersion[]
                                       , ViChar      modelNumber[]
                                       , ViChar      manufacturerCode[]
                                       , ViInt32    *maxPFC
                                       , ViInt32     capabilities[]
                                       , ViChar      errorMessage[]
                                       )
{
   CAPABILITY   cap;
   ViStatus  RSCMU_Status = VI_SUCCESS;  

   RSCMU_Status = RSCMU_TDMA_SenseMobileInfoCapability( instrSession
                             , softwareVersion
                             , firmwareVersion
                             , modelNumber
                             , manufacturerCode
                             , maxPFC
                             , &cap
                             , errorMessage
                             );


   if( RSCMU_Status >= 0 )
      memcpy(capabilities, &cap, sizeof(CAPABILITY));

   return( RSCMU_Status );

}


/*===========================================================================*/
/* Function: RSCMU_TDMA_GetResourceName                                      */
/* Purpose:  This function returns resource descriptor for TDMA option.      */
/*           Session parameter must contain at least 256 elements ViChar[256]*/
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_TDMA_GetResourceName (ViSession instrSession,
                                              ViSession instrSessionBase,
                                              ViChar _VI_FAR sessionName[])
{
   ViStatus    RSCMU_Status   = VI_SUCCESS;  
   ViInt32     comp;

   struct RSCMU_Base_Globals  *p_globalvarBase;
   struct RSCMU_TDMA_Globals  *p_globalvarTDMA;

    /* Get a copy of the global data for base session. */
   if( (RSCMU_Status = viGetAttribute( instrSessionBase
                                     , VI_ATTR_USER_DATA
                                     , (ViAddr)&p_globalvarBase
                                     )) < VI_SUCCESS )
   {
      return RSCMU_Status;
   }
   
   /* Get a copy of the global data for this session. */
   if( (RSCMU_Status = viGetAttribute( instrSession
                                     , VI_ATTR_USER_DATA
                                     , (ViAddr)&p_globalvarTDMA
                                     )) < VI_SUCCESS )
   {
      return RSCMU_Status;
   }
   
      // Hardware Connection
      comp = strncmp( "GPIB"
                    , p_globalvarBase->RSCMU_tGlobal.RSCMU_SCPIConnection
                    , 4
                    ); 

   if( comp == 0 )
   {
      sprintf( sessionName
             , "%s::%d::%d::INSTR"
             , p_globalvarBase->RSCMU_tGlobal.RSCMU_SCPIConnection
             , p_globalvarBase->RSCMU_tGlobal.RSCMU_primary_address
             , p_globalvarTDMA->RSCMU_tGlobal.RSCMU_secondary_address
             );
   }
   else
   {
      sprintf( sessionName
             , "%s::INSTR"
             , p_globalvarBase->RSCMU_tGlobal.RSCMU_SCPIConnection
             );
   }

   return RSCMU_Status;
}

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_EMAHOAllCells
 *
 * DESCRIPTION: 
 *              .   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_TDMA_EMAHOAllCells_Ex (ViSession instrSession,
                                               ViInt32 channels[], ViInt32 RSSI[],
                                               ViChar errorMessage[])
{
    ViStatus    RSCMU_Status;
    EMAHO       emaho[22];
    ViInt32     i;
    
    RSCMU_Status = RSCMU_TDMA_EMAHOAllCells (instrSession, emaho,
                                             errorMessage);
    if (RSCMU_Status!= VI_SUCCESS)
        return RSCMU_Status;
    
    for (i=0;i<22;i++)
    {
        channels[i] = emaho[i].Channel;
        RSSI[i] = emaho[i].RSSI;
    }
    
    return RSCMU_Status;
}

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_EMAHOCell 
 *
 * DESCRIPTION: 
 *              .   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_TDMA_EMAHOCell_Ex (ViSession instrSession,
                                           ViInt32 channel, ViInt32 channels[],
                                           ViInt32 RSSI[], ViChar errorMessage[])
{
    ViStatus    RSCMU_Status;
    EMAHO       emaho[22];
    ViInt32     i;
    
    RSCMU_Status = RSCMU_TDMA_EMAHOCell (instrSession, channel, emaho,
                                             errorMessage);
    if (RSCMU_Status!= VI_SUCCESS)
        return RSCMU_Status;
    
    for (i=0;i<22;i++)
    {
        channels[i] = emaho[i].Channel;
        RSSI[i] = emaho[i].RSSI;
    }
    
    return RSCMU_Status;
}

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_MAHONAllCells
 *
 * DESCRIPTION: 
 *              .   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_TDMA_MAHOAllCells_Ex (ViSession instrSession,
                                              ViInt32 channels[],
                                              ViInt32 RSSI[], ViReal64 level[],
                                              ViChar errorMessage[])
{
    ViStatus    RSCMU_Status;
    MAHO        maho[24];
    ViInt32     i;
    
    RSCMU_Status = RSCMU_TDMA_MAHOAllCells (instrSession, maho,
                                             errorMessage);
    if (RSCMU_Status!= VI_SUCCESS)
        return RSCMU_Status;
    
    for (i=0;i<24;i++)
    {
        channels[i] = maho[i].Channel;
        RSSI[i] = maho[i].RSSI;
        level[i] = maho[i].Level;
    }
    
    return RSCMU_Status;
}

/**************************************************************************
 *
 * NAME:        RSCMU_TDMA_MAHOCell
 *
 * DESCRIPTION: 
 *                
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_TDMA_MAHOCell_Ex (ViSession instrSession,
                                          ViInt32 channel, ViInt32 channels[],
                                          ViInt32 RSSI[], ViReal64 level[],
                                          ViChar errorMessage[])
{
    ViStatus    RSCMU_Status;
    MAHO        maho[24];
    ViInt32     i;
    
    RSCMU_Status = RSCMU_TDMA_MAHOCell (instrSession, channel, maho,
                                             errorMessage);
    if (RSCMU_Status!= VI_SUCCESS)
        return RSCMU_Status;
    
    for (i=0;i<24;i++)
    {
        channels[i] = maho[i].Channel;
        RSSI[i] = maho[i].RSSI;
        level[i] = maho[i].Level;
    }
    
    return RSCMU_Status;
}
/* Ex Functions (No structures) */

/*###########################################################################*/
/*                                                                           */
/*  VXI PLUG & PLAY COMPATIBILITY FUNCTIONS                                  */
/*                                                                           */
/*  These functions provide a VXIplug&play compatibily of this instrument    */
/*  driver with regard to the following documents:                           */
/*                                                                           */
/*  VPP-3.1: Instrument Drivers                                              */
/*      Architecture and Design                                              */
/*      Specification                                                        */
/*      Revision 4.0                                                         */
/*      February 5, 1996                                                     */
/*                                                                           */
/*  VPP-3.2: Instrument Driver                                               */
/*      Functional Body Specification                                        */
/*      Revision 4.0                                                         */
/*      February 2, 1996                                                     */
/*                                                                           */
/* By: Jan Sima                                                              */                                                       
/*                                                                           */
/*###########################################################################*/
#ifndef _REMVXIPNP

/*===========================================================================*/
/* Function: Initialize                                                      */
/* Purpose:  This function opens the instrument, queries the instrument      */
/*           for its ID, and initializes the instrument to a known state.    */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_init( ViRsrc     resourceName
                            , ViBoolean  IDQuery
                            , ViBoolean  resetDevice
                            , ViPSession instrSession
                            )
{
   ViStatus   RSCMU_status  = VI_SUCCESS;
   ViString   p2str;
   ViInt32    board         = 0;
   ViInt32    primaryAddr   = 0;
   ViInt32    secondaryAddr = 0;
   ViChar     errorMessage[WR_BUFFER_SIZE];
   ViSession  rmHandle;

   p2str = resourceName;
    
   if( strncmp (p2str, "GPIB", 4) != 0 )
   {
      return VI_ERROR_INV_RSRC_NAME;
   }
      
   p2str += 4;
   if( p2str[0] >= '0' && p2str[0] <= '9' )
   {
      board = (p2str++)[0] - '0';
   }
      
   if( strncmp(p2str, "::", 2) != 0 )
   {
      return VI_ERROR_INV_RSRC_NAME;
   }
      
   if( sscanf(p2str += 2, "%ld", &primaryAddr) != 1 )
   {
      return VI_ERROR_INV_RSRC_NAME;
   }

   p2str += (primaryAddr > 9) ? 2 : 1; 
   if( (strlen(p2str) != 0) && (strncmp(p2str, "::", 2) != 0) )
   {
      return VI_ERROR_INV_RSRC_NAME;
   }
   
   if( strlen(p2str) != 0 )
   {
      if( sscanf(p2str += 2, "%ld", &secondaryAddr) != 1 )
      {
         return VI_ERROR_INV_RSRC_NAME;
      }
      
      p2str += (secondaryAddr > 9) ? 2 : 1;     
      if( (strlen(p2str) != 0) && (strcmp(p2str, "::INSTR") != 0) )
      {
         return VI_ERROR_INV_RSRC_NAME;
      }
   }
      
   if( secondaryAddr == 0 )
   {
      if( (RSCMU_status = RSCMU_Init_Base( instrSession
                                         , RSCMU_GPIB
                                         , board
                                         , primaryAddr
                                         , IDQuery
                                         , resetDevice
                                         , errorMessage
                                         )) < 0 )
      {
         return( RSCMU_status );
      }
   } 
   else 
   {    
      if( (RSCMU_status = viOpenDefaultRM( &rmHandle )) != 0 )
      {
         return RSCMU_status;
      }
      
      if( (RSCMU_status = viOpen( rmHandle, resourceName, VI_NULL, VI_NULL, instrSession)) != 0 )
      {
         return RSCMU_status;
      }
   
      if( (RSCMU_status = viGpibControlREN( *instrSession, VI_GPIB_REN_ASSERT)) < 0 )
      {
         return RSCMU_status;
      }
    }    
    
    return RSCMU_status;
}

/*===========================================================================*/
/* Function: Init TDMA                                                       */
/* Purpose:  This function initializes the TDMA module's                     */
/*           global data structures. This function is used in VEE where this */
/*           can not be a part of the VXIpnp init function.                  */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_initTDMA( ViSession  TDMASession
                                , ViSession  BaseSession
                                , ViUInt32   TDMAFunctionGroup
                                )
{
   ViStatus    RSCMU_Status      = VI_SUCCESS;
   ViSession   globalSession     = 0;
   ViInt32     secondAddr        = 0;
   ViInt32     comp              = 1;
   ViChar      FctGrpBuffer[128] = "";
   ViChar      resource[25]      ="";
   ViReal64    Flag              = RSCMU_OFF;
   ViChar      errorMessage[WR_BUFFER_SIZE];
   ViSession   DefaultRM;

   struct RSCMU_Base_Globals  *p_globalvarBase;
   struct RSCMU_TDMA_Globals  *p_globalvarTDMA;

   // Which Function Group does the User want?
   switch( TDMAFunctionGroup )
   {
   case RSCMU_IS136800MS_NSIG:
      // Record "Function Group Name" for the actual Session.
      strcpy( FctGrpBuffer, "\"IS136800MS_NSig\"" );
      break;

   case RSCMU_IS1361900MS_NSIG:
      // Record "Function Group Name" for the actual Session.
      strcpy( FctGrpBuffer, "\"IS1361900MS_NSig\"" );
      break;

   case RSCMU_IS136800MS_SIG:
      // Record "Function Group Name" for the actual Session.
      strcpy( FctGrpBuffer, "\"IS136800MS_Sig\"" );
      break;

   case RSCMU_IS1361900MS_SIG:
      // Record "Function Group Name" for the actual Session.
      strcpy( FctGrpBuffer, "\"IS1361900MS_Sig\"" );
      break;

   default:
      break;
   }

   // Init the Error Message  
   strcpy (errorMessage, "No Error");

   // Get the current options (= Function Group Names) in the CMU.
   if ((RSCMU_Status = viGetAttribute (BaseSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
     return RSCMU_errorMessage (BaseSession, RSCMU_Status, errorMessage);
     
   DefaultRM = p_globalvarBase->RSCMU_tGlobal.RSCMU_RmSessionDefault;  

   // Find the Secondary address
   while( (comp != 0) && (secondAddr < 30) )
   {
      comp = strncmp( p_globalvarBase->RSCMU_tSecAddr[secondAddr].FctGrp
                    , FctGrpBuffer
                    , strlen( FctGrpBuffer )
                    );
      secondAddr++;
      if( comp == 0 )
      {
         Flag = RSCMU_ON;
      }
   }

   if( Flag == RSCMU_OFF )
   {
      return RSCMU_errorMessage( TDMASession
                               , RSCMU_ERROR_INVALID_FCT_GRP
                               , errorMessage
                               );
   }

    // Allocate space for "struct RSCMU_SESSION_Globals" 
   if( (p_globalvarTDMA =
         (struct RSCMU_TDMA_Globals *)
         malloc(sizeof(struct RSCMU_TDMA_Globals))) == 0 )
   {
      return RSCMU_initCleanUp( DefaultRM
                              , TDMASession
                              , RSCMU_Status
                              );
   }
     
   if( (RSCMU_Status = viSetAttribute( TDMASession
                                     , VI_ATTR_USER_DATA
                                     , (ViAttrState)p_globalvarTDMA
                                     )) < 0 )
   {
      return RSCMU_initCleanUp( DefaultRM
                              , TDMASession
                              , RSCMU_Status
                              );
   }
      
   // Which Function Group does the User want?
   switch( TDMAFunctionGroup )
   {
   case RSCMU_IS136800MS_SIG:
      // Record the "HandOverName" for the actual Session.
      strcpy( p_globalvarTDMA->RSCMU_tHandOver.HandOverSessionName, "\"IS136800MS\"" );
      break;

   case RSCMU_IS1361900MS_SIG:
      // Record the "HandOverName" for the actual Session.
      strcpy( p_globalvarTDMA->RSCMU_tHandOver.HandOverSessionName, "\"IS1361900MS\"" );
      break;

   case RSCMU_IS136800MS_NSIG:
   case RSCMU_IS1361900MS_NSIG:
   default:
      break;
   }
      
   // Set initial values of variables for function Group 'TDMA' .    
   strcpy( p_globalvarTDMA->RSCMU_tGlobal.FGrp_Name, FctGrpBuffer );
   strcpy (p_globalvarTDMA->RSCMU_tGlobal.RSCMU_SCPIConnection, p_globalvarBase->RSCMU_tGlobal.RSCMU_SCPIConnection);
   p_globalvarTDMA->RSCMU_tGlobal.RSCMU_primary_address = p_globalvarBase->RSCMU_tGlobal.RSCMU_primary_address;

   p_globalvarTDMA->RSCMU_tGlobal.RSCMU_secondary_address = secondAddr;
   p_globalvarTDMA->RSCMU_tGlobal.RSCMU_SessionNb = TDMASession;
   p_globalvarTDMA->RSCMU_tGlobal.RSCMU_TRACE = p_globalvarBase->RSCMU_tGlobal.RSCMU_TRACE;
 
   // If the RSCMU_Trace_ON has already been executed, record the characteristics of
   // the trace file, then the base can trace what's appening on the secondary address
   // initialized in THIS function (It was not the case before: we were obliged to 
   // set the trace to ON after, and only after initialization of All the secondary addresses
   // we want to trace)
    p_globalvarTDMA->RSCMU_tGlobal.RSCMU_FileHandle        =
       p_globalvarBase->RSCMU_tGlobal.RSCMU_FileHandle;
    
    p_globalvarTDMA->RSCMU_tGlobal.RSCMU_AddrTargetFile    =
       (ViAddr) p_globalvarBase->RSCMU_tGlobal.RSCMU_AddrTargetFile;
    
    p_globalvarTDMA->RSCMU_tGlobal.RSCMU_StateTraceFile    =
       p_globalvarBase->RSCMU_tGlobal.RSCMU_StateTraceFile;
    //*** ht 22/09/2000
    
    // Record the execution of this Init Function.    
    p_globalvarBase->RSCMU_tSecAddr[secondAddr - 1].SessionNb = 
       TDMASession;  

    // Timeout changed from 10s to 3 seconds 
    if( (RSCMU_Status = viSetAttribute( TDMASession
                                      , VI_ATTR_TMO_VALUE
                                      , 3000
                                      )) < 0 )
    {
       return( RSCMU_Status );
    }
 
 return( RSCMU_Status );

} // endof RSCMU_InitTDMA()

/*===========================================================================*/
/* Function: Get Instrument Handle                                           */
/* Purpose:  This function passes the instrument handle from the first       */
/*           parameter to the second parameter. This function is used in VEE */
/*           where it allows to get the current instrument handle.          */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GetInstrumentHandle (ViSession instrumentHandle,
                                             ViSession *instrumentHandleOut)
{
   *instrumentHandleOut = instrumentHandle;
    return 0;
}

/*===========================================================================*/
/* Function: Reset                                                           */
/* Purpose:  This function resets the instrument.  If the reset function     */
/*           is not supported by the instrument, this function returns       */
/*           the warning VI_WARN_NSUP_RESET.                                 */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_reset (ViSession instrSession)
{
   return VI_WARN_NSUP_RESET;
}

/*===========================================================================*/
/* Function: Self-Test                                                       */
/* Purpose:  This function executes the instrument self-test and returns     */
/*           the result. If the self test function is not supported by the   */
/*           instrument, this function returns the warning                   */
/*           VI_WARN_NSUP_SELF_TEST.                                         */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_self_test (ViSession instrSession,
                                    ViPInt16 testResult,
                                    ViChar _VI_FAR testMessage[])
{
    return VI_WARN_NSUP_SELF_TEST;
}

/*===========================================================================*/
/* Function: Error Query                                                     */
/* Purpose:  This function queries the instrument error queue, and returns   */
/*           the result.                                        */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_error_query (ViSession instrSession,
                                      ViPInt32 errorCode,
                                      ViChar _VI_FAR errorMessage[])
{
   return VI_WARN_NSUP_ERROR_QUERY;
}

/*===========================================================================*/
/* Function: Error Message                                                   */
/* Purpose:  This function translates the error return value from the        */
/*           instrument driver into a user-readable string.                  */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_error_message (ViSession instrSession,
                                        ViStatus statusCode,
                                        ViChar _VI_FAR errMessage[])
{
   return RSCMU_errorMessage (instrSession, statusCode, errMessage);
}

/*===========================================================================*/
/* Function: Revision Query                                                  */
/* Purpose:  This function returns the driver and instrument revisions.      */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_revision_query (ViSession instrSession,
                    ViChar _VI_FAR driverRev[], ViChar _VI_FAR instrRev[])
{
   strcpy (driverRev, RSCMUK2T_REVISION);
   if (instrRev != 0)
      {
      strcpy (instrRev, "Not defined");
      }

   return VI_SUCCESS;
}

/*===========================================================================*/
/* Function: Close                                                           */
/* Purpose:  This function closes the instrument.                            */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_close (ViSession instrSession)
{
    ViStatus RSCMU_Status = VI_SUCCESS;
    ViChar  errorMessage[WR_BUFFER_SIZE];
    ViUInt16 secAddr;
    
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_GPIB_SECONDARY_ADDR, &secAddr)) < 0)
      return RSCMU_Status;

    if (secAddr == 0) {
      if ((RSCMU_Status = RSCMU_Close_Base (instrSession, errorMessage)) < 0)
         return RSCMU_Status;
    } else {
      struct RSCMU_TDMA_Globals *p_globalvarTDMA;

      if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarTDMA)) < 0)
         return RSCMU_Status;

      // Deallocate all system resources
      if ((RSCMU_Status = viClose (instrSession)) < 0)
         return RSCMU_Status;
    
      // Deallocate the space pointed by p_globalvarTDMA
      if (p_globalvarTDMA)
         free (p_globalvarTDMA);
   }     
    return RSCMU_Status;
}

#endif

